
import { Eventer, Token, Listener } from "@arction/eventer";
import { Record } from 'immutable';/**
 * Chart abstraction layer that implements Chart title and padding.
 * @hidden Internal class
 */
export declare abstract class Chart extends Panel implements ChartAPI {
    protected readonly _ui: LayerXY;
    /**
     * @param   layerSupplier           LayerSupplier. Must NOT be cached, because it contains reference to actual Engine instance.
     * @param   _bg                     Rendering layer for background
     * @param   removeChart 	        Injectable panel/chart remove method
     * @param   _ui                     Rendering layer for Charts own UI-elements.
     *                                  This layer should NOT be used for elements created by users.
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @param   theme                   Theme used to style elements in the Chart.
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, _bg: LayerXY, _ui: LayerXY, removeChart: (chart: Panel) => void, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, theme?: Theme);
    /**
     * Get minimum size of Chart.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     * @hidden
     */
    abstract getMinimumSize(): Point | undefined;
    /**
     * Disable all animations of the Chart.
     * @return Chart itself for fluent interface
     */
    abstract disableAnimations<T>(): ThisType<T>;
    /**
     * Set text of Chart title.
     * @param   title  Chart title as a string.
     * @returns        Object itself for fluent interface.
     */
    setTitle(title: string): this;
    /**
     * Get text of Chart title.
     * @returns         Chart title as a string.
     */
    getTitle(): string;
    /**
     * Set fill style of Chart Title.
     *
     * Example usage:
     *```javascript
     * // Create a new style
     * Chart.setTitleFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * Chart.setTitleFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * Chart.setTitleFillStyle(emptyFill)
     * ```
     *
     * @param   value   Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns         Chart itself
     */
    setTitleFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Chart Title.
     * @returns FillStyle object
     */
    getTitleFillStyle(): FillStyle;
    /**
     * Set font of Chart Title.
     *
     * Example usage:
     *```javascript
     * // Create a new FontSettings
     * Chart.setTitleFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Change existing settings
     * Chart.setTitleFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     *
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Chart itself
     */
    setTitleFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Chart title.
     * @return  FontSettings object
     */
    getTitleFont(): FontSettings;
    /**
     * Specifies padding before chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap between the top of chart and its title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginTop(marginPixels: pixel): this;
    /**
     * @returns Padding before Chart title
     */
    getTitleMarginTop(): number;
    /**
     * Specifies padding after chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap after the chart title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginBottom(marginPixels: pixel): this;
    /**
     * @returns Padding after Chart title
     */
    getTitleMarginBottom(): number;
    /**
     * Set padding around Chart in pixels.
     * @param   padding     Number with pixel margins for all sides or datastructure with individual pixel paddings
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself
     */
    setPadding(padding: Partial<Margin> | number): this;
    /**
     * Get padding around Chart in pixels.
     * @return  Padding datastructure
     */
    getPadding(): Margin;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Interface that defines end user API for a 'Chart'.
 * @hidden  This interface is hidden because we don't want to bloat Typedoc.
 *          The actual API will still be visible via the actual implementation.
 */
export interface ChartAPI {
    /**
     * Set text of Chart title.
     * @param   title  Chart title as a string.
     * @returns        Object itself for fluent interface.
     */
    setTitle(title: string): this;
    /**
     * Get text of Chart title.
     * @returns         Chart title as a string.
     */
    getTitle(): string;
    /**
     * Set fill style of Chart Title.
     *
     * Example usage:
     *```javascript
     * // Create a new style
     * setTitleFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * setTitleFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * setTitleFillStyle(emptyFill)
     * ```
     * @param   value   Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns         Chart itself
     */
    setTitleFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Chart Title.
     * @returns FillStyle object
     */
    getTitleFillStyle(): FillStyle;
    /**
     * Set font of Chart Title.
     *
     * Example usage:
     *```javascript
     * // Create a new FontSettings
     * setTitleFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Change existing settings
     * setTitleFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     *
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Chart itself
     */
    setTitleFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Chart title.
     * @return  FontSettings object
     */
    getTitleFont(): FontSettings;
    /**
     * Specifies padding before chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap between the top of chart and its title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginTop(marginPixels: pixel): this;
    /**
     * @returns Padding before Chart title
     */
    getTitleMarginTop(): number;
    /**
     * Specifies padding after chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap after the chart title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginBottom(marginPixels: pixel): this;
    /**
     * @returns Padding after Chart title
     */
    getTitleMarginBottom(): number;
    /**
     * Set padding around Chart in pixels.
     * @param   padding     Number with pixel margins for all sides or datastructure with individual pixel paddings
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself for fluent interface
     */
    setPadding(padding: Partial<Margin> | number): this;
    /**
     * Get padding around Chart in pixels.
     * @return              Padding datastructure
     */
    getPadding(): Margin;
    /**
     * Set fillStyle of panel background.
     * @param   value       FillStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillstyle of chart background.
     * @return              FillStyle
     */
    getBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke style of panel background.
     * @param   value       LineStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of chart background.
     * @return              LineStyle
     */
    getBackgroundStrokeStyle(): LineStyle;
}
/**
 * Abstract base class for "Chart components".
 * Chart component is defined as a mouse-interactable component of a Chart.
 * ChartComponent is a public class, so users can have access to it.
 * @hidden Internal class
 */
export declare abstract class ChartComponent<VisualType extends ChartVisual = ChartVisual> implements Interactable, Attachable {
    /**
     * Sets the name of the Component
     * updating attached LegendBox entries
     * @param   name    Name of the Component
     * @return          Object itself
     */
    setName(name: string): this;
    /**
     * Get the name of the Component.
     * @returns     The name of the Component.
     */
    getName(): string;
    /**
     * @returns  TODO: True for enabled and false for disabled
     */
    isDisposed(): boolean;
    /**
     * Tell the owning chart to remove this component.
     * @return  Object itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this component.
     * @return  Object itself.
     */
    restore(): this;
    /**
     * Enable or disable forced highlighting of component
     * @param highLight True for enabled and false for disabled
     * @returns         component itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * @returns the state of highlighted flag
     */
    getHighlighted(): boolean;
    /**
     * Set mouse interactions enabled or disabled.
     * Disabling mouse-interactions will naturally prevent mouse-driven highlighting from ever happening.
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * Get mouse interactions enabled or disabled.
     * Disabled mouse-interactions will naturally prevent mouse-driven highlighting from ever happening.
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * Get boolean flag for whether object is currently under mouse or not
     * @return  Boolean for is object under mouse currently
     */
    getIsUnderMouse(): boolean;
    /**
     * Set highlight on mouse hover enabled or disabled
     * @param state True if highlighting on mouse hover, false if no highlight on mouse hover
     * @return      Object itself for fluent interface.
     */
    setHighlightOnHover(state: boolean): this;
    /**
     * Get boolean flag for whether object should highlight on mouse hover
     * @return Boolean for if object should highlight on mouse hover or not.
     */
    getHighlightOnHover(): boolean;
    /**
     * On LegendBox entry mouse enter event listener
     */
    private onEntryMouseEnter;
    /**
     * On LegendBox entry mouse leave event listener
     */
    private onEntryMouseLeave;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Add event listener to Enter Event
     * @param   clbk    Event listener for Mouse Enter Event
     * @return          Token of the event listener
     */
    onMouseEnter: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Leave Event
     * @param   clbk    Event listener for Mouse Leave Event
     * @return          Token of the event listener
     */
    onMouseLeave: (clbk: AbruptMouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Click Event
     * @param   clbk    Event listener for Mouse Click Event
     * @return          Token of the event listener
     */
    onMouseClick: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Double Click Event
     * @param   clbk    Event listener for Mouse Double Click Event
     * @return          Token of the event listener
     */
    onMouseDoubleClick: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Down Event
     * @param   clbk    Event listener for Mouse Down Event
     * @return          Token of the event listener
     */
    onMouseDown: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Up Event
     * @param   clbk    Event listener for Mouse Up Event
     * @return          Token of the event listener
     */
    onMouseUp: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Add event listener to Mouse Move Event
     * @param   clbk    Event listener for Mouse Move Event
     * @return          Token of the event listener
     */
    onMouseMove: (clbk: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to Mouse Drag Start event
     */
    onMouseDragStart(clbk: MouseDragStartEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag event
     */
    onMouseDrag(clbk: MouseDragEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag Stop event
     */
    onMouseDragStop(clbk: MouseDragStopEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Wheel event
     * @param   clbk        Event handler function
     * @returns             Token of subscription
     */
    onMouseWheel(clbk: MouseWheelEventHandler<this>): Token;
    /**
     * Subscribe to Touch Start event
     * @param   clbk        Event handler function
     * @returns             Token of subscription
     */
    onTouchStart(clbk: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch Move event
     * @param   clbk        Event handler function
     * @returns             Token of subscription
     */
    onTouchMove(clbk: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch End event
     * @param   clbk        Event handler function
     * @returns             Token of subscription
     */
    onTouchEnd(clbk: TouchEventHandler<this>): Token;
    /**
     * Remove event listener from Mouse Enter Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseEnter: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Leave Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseLeave: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseClick: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Double Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDoubleClick: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Down Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDown: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Up Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseUp: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseMove: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Drag Start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStart: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Drag Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDrag: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Drag Stop Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStop: (token: Token) => boolean;
    /**
     * Remove event listener from Mouse Wheel Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseWheel: (token: Token) => boolean;
    /**
     * Remove event listener from Touch Start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchStart(token: Token): boolean;
    /**
     * Remove event listener from Touch Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchMove(token: Token): boolean;
    /**
     * Remove event listener from Touch End Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchEnd(token: Token): boolean;
}
/**
 * Interface for ChartVisual.
 * ChartVisuals are a building block which links rendering Engine to a ChartComponent.
 *
 * Examples: An Engine Shape or an UI-element.
 * @hidden
 */
export interface ChartVisual extends Disposable {
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
}
/**
 * Enum for selecting behaviour of user-interaction-triggered highlighting of *Series*.
 *
 * This is currently only usable on *FigureSeries*:
 * - BoxSeries
 * - RectangleSeries
 * - SegmentSeries
 * - ...
 */
export declare enum HighlightModes {
    /**
     * Highlighting is not affected by user-interactions.
     */
    noHighlighting = 0,
    /**
     * When any part of a *Series* is interacted with, the whole *Series* is highlighted.
     */
    onHover = 1,
    /**
     * When a part of a *Series* is interacted with, that part will be highlighted.
     */
    onHoverIndividual = 2
}
/**
 * @hidden
 */
export interface ChartWithScrollingAnimations {
    /**
     * Set if mouse and cursor interactions should be disabled during scrolling animations for the chart's series.
     * @param   state   True if mouse and cursor interactions should be disabled during scrolling animations, false if not.
     * @return          Chart itself for fluent interface.
     */
    setMouseInteractionsWhileScrolling(state: boolean): this;
    /**
     * Get if mouse and cursor interactions are disabled during scrolling animations for the chart's series.
     * @return True if interactions with series are disabled, false if not.
     */
    getMouseInteractionsWhileScrolling(): boolean;
}
/**
 * @hidden
 */
export interface ChartWithZoomingAnimations {
    /**
     * Set if mouse and cursor interactions should be disabled during zooming animations for the chart's series.
     * @param   state   True if mouse and cursor interactions should be disabled during zooming animations, false if not.
     * @return          Chart itself for fluent interface.
     */
    setMouseInteractionsWhileZooming(state: boolean): this;
    /**
     * Get if mouse and cursor interactions are disabled during zooming animations for the chart's series.
     * @return True if interactions with series are disabled, false if not.
     */
    getMouseInteractionsWhileZooming(): boolean;
}
/**
 * Type requirement for Charts that own Axes.
 * @hidden
 */
export interface ChartWithAxis<AxisType extends GenericAxis<any, any, any, any, any, any>> extends ChartWithSeries {
    /**
     * Iterate over each Axis of Chart.
     * @param   clbk    Callback function for each Axis.
     */
    forEachAxis(clbk: (axis: AxisType) => void): void;
}
/**
 * Enum for selecting behavior of *AutoCursor* in *Chart*s.
 *
 * Use with [[setAutoCursor]]
 */
export declare enum AutoCursorModes {
    /**
     * *AutoCursor* should be disabled.
     */
    disabled = 0,
    /**
     * *AutoCursor* will be active whenever users mouse is inside the *Chart*.
     *
     * It will snap to point at the closest data-point of a *Series* inside the *Chart*.
     */
    snapToClosest = 1,
    /**
     * *AutoCursor* will only be active when users mouse is directly pointing at a *Series* inside the *Chart*.
     */
    onHover = 2
}
/**
 * Class abstraction layer for Charts that have Series.
 *
 * Currently logic relies on the fact that the Chart has an explicit "chartBackground" shape, that is used for AutoCursor events.
 * @hidden Internal class
 */
export declare abstract class ChartWithCursor<SeriesType extends Series2D = Series2D, CursorPointMarkerType extends PointMarker = PointMarker, CursorResultTableBackgroundType extends UIBackground = UIBackground, AutoCursorType extends AutoCursor<CursorPointMarkerType, CursorResultTableBackgroundType> = AutoCursor<CursorPointMarkerType, CursorResultTableBackgroundType>> extends ChartWithSeries<SeriesType> {
    /**
     * Mutator function for charts auto cursor.
     * @param   mutator     Mutator function for a Cursor
     * @return              Object itself for fluent interface
     * @hidden
     */
    setAutoCursor(mutator: Mutator<AutoCursorType>): this;
    /**
     * @returns Auto cursor object
     * @hidden
     */
    getAutoCursor(): AutoCursorType;
    /**
     * Set mode of charts Auto cursor
     * @param   mode    Value from enum AutoCursorMode
     * @returns         Object itself for fluent interface
     * @hidden
     */
    setAutoCursorMode(mode: AutoCursorModes): this;
    /**
     * Get current mode of charts Auto cursor
     * @returns         Value from enum AutoCursorMode
     * @hidden
     */
    getAutoCursorMode(): AutoCursorModes;
    /**
     * Set fillStyle of chart background.
     * This is the area enclosed by the axis'.
     * @param   fillStyle   FillStyle or mutator to modify existing one
     * @return              Object itself
     */
    setChartBackgroundFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillstyle of chart background.
     * This is the area enclosed by the axis'.
     * @return              FillStyle
     */
    getChartBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke of chart background.
     * This is the area enclosed by the axis'.
     * @param   value       LineStyle or mutator to modify existing one
     * @return              Object itself
     */
    setChartBackgroundStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of chart background.
     * This is the area enclosed by the axis'.
     * @return              LineStyle
     */
    getChartBackgroundStrokeStyle(): LineStyle;
    /**
     * Solves the nearest data-point from series inside Chart of a given coordinate on screen
     * @param   location    Location on screen or omit for cur mouse location
     * @return              Undefined or data-structure for positioning of markers (and cursors)
     */
    solveNearest(location?: Point | undefined): undefined | CursorPoint;
    /**
     * Subscribe to mouse-enter event on Chart background
     */
    onChartBackgroundMouseEnter: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-leave event on Chart background
     */
    onChartBackgroundMouseLeave: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-move event on Chart background
     */
    onChartBackgroundMouseMove: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-down event on Chart background
     */
    onChartBackgroundMouseDown: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-up event on Chart background
     */
    onChartBackgroundMouseUp: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-click event on Chart background
     */
    onChartBackgroundMouseClick: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-doubleClick event on Chart background
     */
    onChartBackgroundMouseDoubleClick: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag start event on Chart background
     */
    onChartBackgroundMouseDragStart: (handler: MouseDragStartEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag event on Chart background
     */
    onChartBackgroundMouseDrag: (handler: MouseDragEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag stop event on Chart background
     */
    onChartBackgroundMouseDragStop: (handler: MouseDragStopEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-wheel event on Chart background
     */
    onChartBackgroundMouseWheel: (handler: MouseWheelEventHandler<this>) => Token;
    /**
     * Subscribe to touch start event on Chart background
     */
    onChartBackgroundTouchStart: (handler: TouchEventHandler<this>) => Token;
    /**
     * Subscribe to touch move event on Chart background
     */
    onChartBackgroundTouchMove: (handler: TouchEventHandler<this>) => Token;
    /**
     * Subscribe to touch end event on Chart background
     */
    onChartBackgroundTouchEnd: (handler: TouchEventHandler<this>) => Token;
    /**
     * Remove event listener from mouse-enter event on Chart background
     */
    offChartBackgroundMouseEnter: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-leave event on Chart background
     */
    offChartBackgroundMouseLeave: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-move event on Chart background
     */
    offChartBackgroundMouseMove: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-down event on Chart background
     */
    offChartBackgroundMouseDown: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-up event on Chart background
     */
    offChartBackgroundMouseUp: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-click event on Chart background
     */
    offChartBackgroundMouseClick: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-doubleClick event on Chart background
     */
    offChartBackgroundMouseDoubleClick: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-drag start event on Chart background
     */
    offChartBackgroundMouseDragStart: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-drag event on Chart background
     */
    offChartBackgroundMouseDrag: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-drag stop event on Chart background
     */
    offChartBackgroundMouseDragStop: (token: Token) => boolean;
    /**
     * Remove event listener from mouse-wheel event on Chart background
     */
    offChartBackgroundMouseWheel: (token: Token) => boolean;
    /**
     * Remove event listener from touch start event on Chart background
     */
    offChartBackgroundTouchStart: (token: Token) => boolean;
    /**
     * Remove event listener from touch move event on Chart background
     */
    offChartBackgroundTouchMove: (token: Token) => boolean;
    /**
     * Remove event listener from touch end event on Chart background
     */
    offChartBackgroundTouchEnd: (token: Token) => boolean;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Temporary interface for "Series".
 *
 * Future class structure will be:
 *  ChartComponent
 *      Series (currently Series2D, to be renamed)
 *          SeriesXY
 *          Series3D
 *
 * This is a temporary solution until 3D cursor is implemented.
 * @hidden
 */
export interface SeriesInternal {
}
/**
 * Class abstraction layer for Charts that have Series.
 *
 * NOTE: Sub classes are responsible for calling series_.beforePlot and series._afterPlot !!
 * @hidden Internal class
 */
export declare abstract class ChartWithSeries<SeriesType extends ChartComponent & SeriesInternal = ChartComponent & SeriesInternal> extends Chart {
    /**
     * Set the state for all Series in the Chart to highlight on mouse hover.
     * @param   state   True if all Series should be highlighted on mouse hover, false if not.
     * @return          Object itself for fluent interface.
     */
    setSeriesHighlightOnHover(state: boolean): this;
}
/**
 * File contains interface of a "Control".
 *
 * Meaning a stand-alone Charting component, which owns a rendering Engine.
 * Eq. Panel, Dashboard, ...
 */
/**
 * Abstract super class for a Control.
 * Meaning a stand-alone Charting component, which owns a rendering Engine.
 * Eq. Panel, Dashboard, ...
 * @hidden Internal class
 */
export interface Control {
    /**
     * Public, safe interface of rendering engine.
     */
    readonly engine: PublicEngine;
    /**
     * Add a stand-alone *UIElement* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *UIElementBuilder*. If omitted, *TextBoxBuilder* will be selected. Use [[UIElementBuilders]] for selection.
     * @param       scale   Optional custom scale to position UIElement on. Defaults to whole component in percentages [0, 100].
     * @returns             Object that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addUIElement<UIElementType extends UIPart = UITextBox>(uiElementBuilder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
     * Add a stand-alone *LegendBox* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *LegendBoxBuilder*. If omitted, *HorizontalLegendBox* will be selected. Use [[LegendBoxBuilders]] for selection.
     * @param       scale   Optional custom scale to position LegendBox on. Defaults to whole chart in percentages [0, 100].
     * @returns             LegendBox that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addLegendBox<UIElementType extends UIPart = UILegendBox>(builder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
    * Capture rendered state in an image file. Prompts the browser to download the created file.
    *
    * **NOTE: The download might be blocked by browser/plugins as harmful.**
    * To prevent this, only call the method in events tied to user-interactions.
    * From mouse-event handlers, for example.
    *
    * Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL.
    * For supported image formats, compression quality, Etc. refer to:
    *
    * https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
    *
    * Example usage:
    *```javascript
    * // Download 'screenshot.png'
    * saveToFile('screenshot')
    * // Attempt download 'maybeNotSupported.bmp'
    * saveToFile('maybeNotSupported', 'image/bmp')
    * // Attempt download jpeg.file with specified compression quality
    * saveToFile('fileName', 'image/jpeg', 0.50)
    * ```
    *
    * @sideEffect              **If 'type' is not supported by browser, an Error will be thrown.**
    *
    * @param   fileName        Name of prompted download file as string. **File extension shouldn't be included**
    *                          as it is automatically detected from 'type'-argument.
    * @param   type            A DOMString indicating the image format. The default format type is image/png.
    * @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
    *                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
    *                          the default value for image quality is used. The default value is 0.92.
    */
    saveToFile(fileName: string, type?: string, encoderOptions?: number): this;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
* Capture rendered state in an image file. Prompts the browser to download the created file.
*
* **NOTE: The download might be blocked by browser/plugins as harmful.**
* To prevent this, only call the method in events tied to user-interactions.
* From mouse-event handlers, for example.
*
* Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL.
* For supported image formats, compression quality, Etc. refer to:
*
* https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
*
* Example usage:
*```javascript
* // Download 'screenshot.png'
* saveToFile('screenshot')
* // Attempt download 'maybeNotSupported.bmp'
* saveToFile('maybeNotSupported', 'image/bmp')
* // Attempt download jpeg.file with specified compression quality
* saveToFile('fileName', 'image/jpeg', 0.50)
* ```
*
* @sideEffect              **If 'type' is not supported by browser, an Error will be thrown.**
*
* @param   fileName        Name of prompted download file as string. **File extension shouldn't be included**
*                          as it is automatically detected from 'type'-argument.
* @param   type            A DOMString indicating the image format. The default format type is image/png.
* @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
*                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
*                          the default value for image quality is used. The default value is 0.92.
*/
export declare const saveToFile: (engine: PublicEngine, fileName: string, type?: string, encoderOptions?: number | undefined) => void;
/**
 * Utility Factory for building UI Element from builder.
 * @hidden
 */
export declare const _UIElementFactory: <UiElementType extends UIPart>(uiElementBuilder: UIElementBuilder<UiElementType>, layer: LayerXY<Engine>, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme) => any;
/**
 * Interface specifies the amount of rows and columns a [[Dashboard]] should have.
 *
 * Example usage:
 *```javascript
 * // Dashboard with 2 columns and 3 rows
 * {numberOfColumns: 2, numberOfRows: 3}
 * ```
 */
export interface DashboardOptions {
    /**
     * Number of columns the dashboard should allocate - horizontal amount of cells.
     */
    readonly numberOfColumns: number;
    /**
     * Number of rows the dashboard should allocate - vertical amount of cells.
     */
    readonly numberOfRows: number;
    /**
     * Theme to use for styling the dashboard and all Panels and Charts inside it.
     * Charts can override this theme individually if they're given their own theme.
     */
    readonly theme?: Theme;
    /**
     * Disable animations by default
     */
    readonly disableAnimations?: boolean;
}
/**
 *  Interface specifies basic options which all Dashboard.create methods have to implement.
 *
 *  Example usage:
 *```javascript
 * // 1x1 component at top left cell
 * { columnIndex: 0, rowIndex: 0, columnSpan: 1, rowSpan: 1 }
 * // 4x1 component at top row
 * { columnIndex: 0, rowIndex: 0, columnSpan: 4, rowSpan: 1 }
 * ```
 */
export interface DashboardBasicOptions {
    /**
     * Column index on dashboard (X location, 0 = left)
     */
    columnIndex: number;
    /**
     * Row index on dashboard (Y location, 0 = top)
     */
    rowIndex: number;
    /**
     * Column span (X width), default = 1
     */
    columnSpan?: number;
    /**
     * Row span (Y height), default = 1
     */
    rowSpan?: number;
}
/**
 * Interface that can be used to define [[UIPanel]] configurations, when inside a [[Dashboard]],
 * that can't be changed after creation.
 */
export interface UIPanelOptions extends DashboardBasicOptions {
    /**
     * Theme used to style all elements inside the Panel.
     * See [[Themes]] for pre-made options.
     */
    theme?: Theme;
}
/**
 * Interface that can be used to define [[ChartXY]] configurations, when inside a [[Dashboard]],
 * that can't be changed after creation. For example:
 *
 * - Specifying TickStrategies for default X or Y Axes'. This is mostly used for creating DateTime Axes.
 *
 * - Supplying a custom Builder for the AutoCursor of Chart. This can be used to modify the AutoCursor on a level,
 * which can't be done during runtime. For example, changing the shape of ResultTable Background, Etc.
 *
 *
 *  Example usage:
 *```javascript
 * // Default
 * undefined
 * // Specified AutoCursor ResultTable Background
 * { chartXYOptions: { autoCursorBuilder: AutoCursorBuilders.XY.setResultTableBackground(UIBackgrounds.Circle) } }
 * ```
 */
export interface ChartOptions<CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground, CursorTickMarkerXBackgroundType extends PointableBackground, CursorTickMarkerYBackgroundType extends PointableBackground> extends DashboardBasicOptions, ChartXYOptions<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerXBackgroundType, CursorTickMarkerYBackgroundType> {
}
/**
 * Interface that can be used to define [[SpiderChart]] configurations, when inside a  [[Dashboard]],
 * that can't be changed after creation.
 *
 *  Example usage:
 *```javascript
 * // Specified AutoCursor ResultTable Background
 * { spiderChartOptions: { autoCursorBuilder: AutoCursorBuilders.Spider.setResultTableBackground(UIBackgrounds.Circle) } }
 * ```
 */
export interface SpiderOptions<CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground> extends DashboardBasicOptions, SpiderChartOptions<CursorPointMarkerType, CursorResultTableBackgroundType> {
}
/**
 * Interface that can be used to define [[PieChart]]configurations, when inside a [[Dashboard]], that can't be changed after creation.
 *
 *  Example usage:
 *```javascript
 * // Pie Chart with default type
 * undefined
 * // Pie Chart* with specified type
 * { pieChartOptions: { type: PieChartTypes.PieChartWithLabelsOnSides } }
 * ```
 */
export interface PieOptions<PieChartType extends PieChartTypes> extends DashboardBasicOptions, PieChartOptions<PieChartType> {
}
/**
 * Interface that can be used to define [[FunnelChart]] configurations, when inside a [[Dashboard]], that can't be changed after creation.
 *
 *  Example usage:
 *```javascript
 * // Funnel Chart with default type
 * undefined
 * // Funnel Chart with specified type
 * { funnelOptions: { type: FunnelChartTypes.LabelsOnSides } }
 * ```
 */
export interface FunnelOptions<FunnelChartType extends FunnelChartTypes> extends DashboardBasicOptions, FunnelChartOptions<FunnelChartType> {
}
/**
 * Interface that can be used to define [[PyramidChart]] configurations, when inside a [[Dashboard]], that can't be changed after creation.
 *
 * Example usage:
 * ```javascript
 * // Pyramid Chart with default type
 * undefined
 * // Pyramid Chart with specified type
 * { pyramidOptions: { type: PyramidChartTypes.LabelsInsideSlices } }
 * ```
 */
export interface PyramidOptions<PyramidChartType extends PyramidChartTypes> extends DashboardBasicOptions, PyramidChartOptions<PyramidChartType> {
}
/**
 * Interface that can be used to define [[GaugeChart]] configurations, when inside a [[Dashboard]], that can't be changed after creation.
 *
 *  Example usage:
 *```javascript
 * // Gauge Chart* with default type
 * undefined
 * // Gauge Chart* with specified type
 * { gaugeOptions: { **type:** *GaugeChartTypes*.Solid } }
 * ```
 */
export interface GaugeOptions<GaugeChartType extends GaugeChartTypes> extends DashboardBasicOptions, GaugeChartOptions<GaugeChartType> {
}
/**
 *  Interface specifies the options for creating a LegendBox inside a [[Dashboard]].
 *
 *  Example usage:
 *```javascript
 * // Create a Horizontal LegendBox
 * { legendBoxBuilder: UIElementBuilders.HorizontalLegendBox }
 * ```
 */
export interface LegendBoxOptions<TitleType extends UITextBox = UITextBox, EntryType extends LegendBoxEntry = LegendBoxEntry> extends DashboardBasicOptions {
    /**
     * Builder that specifies functionality of created LegendBox.
     */
    legendBoxBuilder?: UILegendBoxBuilder<UIEmptyBackground, TitleType, EntryType>;
    theme?: Theme;
}
/**
 * Interface that can be used to define *ZoomBandChart* configurations, when inside a *Dashboard*, that can't be changed after creation.
 */
export interface ZoomBandChartOptions extends DashboardBasicOptions {
    /**
     * *Axis* that the created *ZoomBandChart* is attached to.
     */
    axis: Axis;
}
/**
 * *Dashboard* is a component for flexible positioning of multiple *Chart*s efficiently.
 *
 * Upon its creation an amount of *columns* and *rows* is specified. *Charts* and other components can
 * then be placed in cells with given *column* and *row*-locations and sizes
 * (using methods of *Dashboard*. For example: [[Dashboard.createChartXY]].
 *
 * The *Dashboard* will distribute the available space for *columns* and *rows*, which users can resize
 * with mouse and touch interactions.
 */
export declare class Dashboard implements Control, Validatable {
    private readonly _disposeEngine;
    /**
     * Public, safe interface for Dashboards rendering engine.
     */
    readonly engine: PublicEngine;
    /**
     * @param   dashboardOptions    Settings union used to define dashboard.
     * @param   engine              Injectable engine
     * @param   _disposeEngine      Handler used to dispose the engine when Dashboard.dispose() is called.
     * @param   logoFactory         Logo factory.
     * @hidden
     */
    constructor(dashboardOptions: DashboardOptions, engine: Engine, _disposeEngine: () => void, logoFactory?: LogoFactory);
    /**
     * Set the minimum and maximum boundaries for dashBoard horizontal size.
     * @param boundary  Single value for static engine size, or a tuple for size range [min, max] in pixels.
     */
    setWidth(boundary: number | [number | undefined, number | undefined] | undefined): this;
    /**
     * Set the minimum and maximum boundaries for dashBoard vertical size.
     * @param boundary  Single value applied to both minimum and maximum size, or a tuple for [min, max] size in pixels.
     */
    setHeight(boundary: number | [number | undefined, number | undefined] | undefined): this;
    /**
     * Get the minimum and maximum horizontal boundaries used for the Dashboard.
     * @return Horizontal boundaries as a tuple [minSize, maxSize]
     */
    getWidth(): [number | undefined, number | undefined] | undefined;
    /**
     * Get the minimum and maximum vertical boundaries used for the Dashboard.
     * @return Vertical boundaries as a tuple [minSize, maxSize]
     */
    getHeight(): [number | undefined, number | undefined] | undefined;
    /**
     * Set fillStyle of dashboard background.
     * @param   fillStyle   FillStyle or mutator to modify existing one
     * @return              Object itself
     */
    setBackgroundFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillStyle of dashboard
     * @return              FillStyle
     */
    getBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke style of dashboard background.
     * @param   value       LineStyle
     * @return              Object itself
     */
    setBackgroundStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of dashboard background.
     * @return              LineStyle
     */
    getBackgroundStrokeStyle(): LineStyle;
    /**
     * Get theme used for the dashboard.
     * @return  Theme
     */
    getTheme(): Theme;
    /**
     * Set style of Dashboard splitters.
     *
     * Example usage:
     *```javascript
     * // Specified LineStyle
     * Dashboard.setSplitterStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * Dashboard.setSplitterStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden
     * Dashboard.setSplitterStyle(emptyLine)
     * ```
     * @param   value   Either a LineStyle object or a function, which will be used to create a new LineStyle based on current value.
     * @returns         Chart itself
     */
    setSplitterStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Dashboard splitters.
     * @return  LineStyle object
     */
    getSplitterStyle(): LineStyle;
    /**
     * Set style of Dashboard splitters when highlighted.
     *
     * Example usage:
     *```javascript
     * // Specified LineStyle
     * Dashboard.setSplitterStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * Dashboard.setSplitterStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden
     * Dashboard.setSplitterStyle(emptyLine)
     * ```
     * @param   value   Either a LineStyle object or a function, which will be used to modify current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setSplitterStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get style of Dashboard splitters when highlighted.
     * @return  LineStyle object
     */
    getSplitterStyleHighlight(): LineStyle;
    /**
     * Set width of a column. By default column widths are equal.
     *
     * Example usage:
     *```javascript
     * // Dashboard with 3 columns with widths (20%, 20%, 60%) of dashboard width
     * dashboard.setColumnWidth( 0, 1 )
     * dashboard.setColumnWidth( 1, 1 )
     * dashboard.setColumnWidth( 2, 3 )
     * ```
     * @param index             Index of the column (starts from 0)
     * @param relativeWidth     Relative width of the column
     */
    setColumnWidth(index: number, relativeWidth: number): this;
    /**
     * Set height of a row. By default row heights are equal.
     *
     * Example usage:
     *```javascript
     * // Dashboard with 3 rows with heights (20%, 20%, 60%) of dashboard height
     * dashboard.setRowHeight( 0, 1 )
     * dashboard.setRowHeight( 1, 1 )
     * dashboard.setRowHeight( 2, 3 )
     * ```
     * @param index             Index of the row (starts from 0)
     * @param relativeHeight    Relative height of the row
     */
    setRowHeight(index: number, relativeHeight: number): this;
    /**
     * Disable all animations for all charts in the dashboard.
     *
     * After calling this function, animations (Zooming, scaling) for all Charts will be disabled.
     * Animations must be recreated manually for each chart afterwards.
     * @return  Dashboard itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Use mapping function on all charts inside dashboard.
     * Dashboard filters any other types of cells out.
     * @param   clbk Map function for Chart
     */
    mapCharts<T>(clbk: (chart: Chart) => T): T[];
    /**
     * Use forEach function on charts inside dashboard.
     * Dashboard filters any other types of cells out.
     * @param   clbk forEach function for Chart
     */
    forEachChart(clbk: (chart: Chart) => void): void;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Capture rendered state in an image file. Prompts the browser to download the created file.
     *
     * **NOTE: The download might be blocked by browser/plugins as harmful.**
     * To prevent this, only call the method in events tied to user-interactions.
     * From mouse-event handlers, for example.
     *
     * Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL.
     * For supported image formats, compression quality, Etc. refer to:
     *
     * https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
     *
     * Example usage:
    *```javascript
    * // Download 'screenshot.png'
    * Dashboard.saveToFile('screenshot')
    * // Attempt download 'maybeNotSupported.bmp'
    * Dashboard.saveToFile('maybeNotSupported', 'image/bmp')
    * // Attempt download jpeg.file with specified compression quality
    * Dashboard.saveToFile('fileName', 'image/jpeg', 0.50)
    * ```
     * @sideEffect              **If 'type' is not supported by browser, an Error will be thrown.**
     *
     * @param   fileName        Name of prompted download file as string. **File extension shouldn't be included**
     *                          as it is automatically detected from 'type'-argument.
     * @param   type            A DOMString indicating the image format. The default format type is image/png.
     * @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
     *                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
     *                          the default value for image quality is used. The default value is 0.92.
     */
    saveToFile(fileName: string, type?: string, encoderOptions?: number): this;
    /**
     * Add a stand-alone *UIElement* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param   uiElementBuilder    *UIElementBuilder*. If omitted, *TextBoxBuilder* will be selected.
     *                              Use [[UIElementBuilders]] for selection.
     * @param   scale               Optional custom scale to position UIElement on. Defaults to whole Dashboard in percentages [0, 100].
     * @returns                     Object that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addUIElement<UiElementType extends UIPart = UITextBox>(uiElementBuilder?: UIElementBuilder<UiElementType>, scale?: Vec2<Scale>): UiElementType & UIElement;
    /**
     * Add a stand-alone *LegendBox* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       legendBoxBuilder    *UIElementBuilder*. If omitted, *Horizontal LegendBoxBuilder* will be selected.
     *                                  Use [[LegendBoxBuilders]] for selection.
     * @param       scale               Optional custom scale to position UIElement on. Defaults to whole Dashboard in percentages [0, 100].
     * @returns                         Object that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addLegendBox<UiElementType extends UIPart = UILegendBox>(legendBoxBuilder?: UIElementBuilder<UiElementType>, scale?: Vec2<Scale>): UiElementType & UIElement;
    /**
     * Add new ChartXY to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a chartXY.
     * @return             ChartXY.
     */
    createChartXY: <CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground, CursorTickMarkerXBackgroundType extends PointableBackground, CursorTickMarkerYBackgroundType extends PointableBackground>(options: ChartOptions<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerXBackgroundType, CursorTickMarkerYBackgroundType>) => ChartXY<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerXBackgroundType, CursorTickMarkerYBackgroundType>;
    /**
     * Add new SpiderChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a Spider chart.
     * @return             SpiderChart.
     */
    createSpiderChart: <CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground>(options: SpiderOptions<CursorPointMarkerType, CursorResultTableBackgroundType>) => SpiderChart<CursorPointMarkerType, CursorResultTableBackgroundType>;
    /**
     * Add new PieChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a PieChart.
     * @return             PieChart.
     */
    createPieChart: <PieChartType extends PieChartTypes = typeof PieChartWithLabelsOnSides>(options: PieOptions<PieChartType>) => InstanceType<PieChartType>;
    /**
     * Add new FunnelChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a FunnelChart.
     * @return             FunnelChart.
     */
    createFunnelChart: <FunnelChartType extends FunnelChartTypes = typeof FunnelChartWithLabelsOnSides>(options: FunnelOptions<FunnelChartType>) => InstanceType<FunnelChartType>;
    /**
     * Add new PyramidChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboard's numberOfColumns/Rows.
     * @param   options     Options object for creating a PyramidChart.
     * @returns             PyramidChart
     */
    createPyramidChart: <PyramidChartType extends PyramidChartTypes = typeof PyramidChartWithLabelsOnSides>(options: PyramidOptions<PyramidChartType>) => InstanceType<PyramidChartType>;
    /**
     * Create a container for UI objects on dashboard with specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a UIPanel.
     * @return             Panel.
     */
    createUIPanel: (options: DashboardBasicOptions) => UIPanel;
    /**
     * Create a new LegendBoxPanel to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a LegendBox.
     * @return             LegendBoxPanel.
     */
    createLegendBoxPanel: <TitleType extends UITextBox = UITextBox, EntryType extends LegendBoxEntry = LegendBoxEntry>(options: LegendBoxOptions<TitleType, EntryType>) => UILegendBoxPanel<TitleType, EntryType>;
    /**
     * Add new GaugeChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a GaugeChart.
     * @return             GaugeChart.
     */
    createGaugeChart: <GaugeChartType extends GaugeChartTypes = typeof SolidGauge>(options?: GaugeOptions<GaugeChartType>) => InstanceType<GaugeChartType>;
    /**
     * Add new ZoomBandChart to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a ZoomBandChart.
     * @return             ZoomBandChart.
     */
    createZoomBandChart: (options: ZoomBandChartOptions) => ZoomBandChart;
    /**
     * Add new Chart3D to dashboard at specified location and span.
     *
     * Throws an error if either column/row index is less than 0 or index + span is more than Dashboards numberOfColumns/Rows.
     * @param    options   Options object for creating a Chart3D.
     * @return             Chart3D.
     */
    createChart3D: (options: DashboardBasicOptions) => Chart3D;
}
/**
 * Interface for type requirements of a component that can be put inside a Dashboard.
 * @hidden
 */
export interface DashboardPanel {
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Point minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
}
/**
 * Dedicated *Panel* for *LegendBox*.
 *
 * Can also house other *UIElements*, just like any other *Panel* or *Chart*.
 */
export declare class UILegendBoxPanel<TitleType extends UITextBox = UITextBox, DefaultEntryType extends LegendBoxEntry = LegendBoxEntry> extends UIPanel implements LegendBox<TitleType, DefaultEntryType> {
    protected removeChart: (chart: Panel) => void;
    /**
     * @param   layerSupplier           Layer supplier
     * @param   logoFactory             Logo factory
     * @param   removeChart             Injectable Chart remove method
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @param   legendBoxBuilder        Builder for creation of LegendBox.
     * @param   theme                   Theme used to style elements in the Panel.
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, legendBoxBuilder?: UILegendBoxBuilder<InternalBackground, TitleType, DefaultEntryType>, theme?: Theme);
    /**
     * @return Legendbox minimum x & y dimensions as Vec2.
     */
    getMinimumSize(): undefined;
    /**
     * Add a dynamic value to LegendBox, creating a group and entries for it depending on type of value.
     * Supports series, charts and dashboards.
     * @param value             Series, Chart or Dashboard
     * @param disposeOnClick    Optional flag that determines whether clicking the LegendBoxEntry will dispose the Attached objects
     * @param tag               Optional group name
     * @param builder           Optional builder for custom entry
     * @return                  Entry attached to a Series or Collection of Entries in case of Chart or Dashboard
     */
    add<EntryType extends LegendBoxEntry = DefaultEntryType>(value: Attachable | Chart | Dashboard, disposeOnClick?: boolean, tag?: string, builder?: UIElementBuilder<EntryType>): EntryType | EntryType[] | EntryType[][];
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Cursor-based visual that can be plotted on a Chart.
 * Like Cursors its built of two parts:
 * PointMarker and ResultTable, first of which
 * shows the location of the Marker clearly and the second
 * to display information about the pointed DataPoint.
 * @hidden
 */
export interface Marker<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, CursorType extends Cursor<PointMarkerType, ResultTableBackgroundType>> extends Draggable {
    /**
     * Set visibility mode for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setPointMarkerVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position.
     * @return                  VisibilityMode
     */
    getPointMarkerVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setResultTableVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location.
     * @return                  VisibilityMode
     */
    getResultTableVisibility(): UIVisibilityModes;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * Set auto-fit strategy of Cursor.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @param   autoFitStrategy     AutoFitStrategy factory or undefined to disable auto-fitting
     * @returns                     Object itself for fluent interface
     */
    setAutoFitStrategy(autoFitStrategy?: AutoFitStrategyFactory<ResultTableBackgroundType>): this;
    /**
     * Get is auto-fit enabled.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @returns                     Boolean flag whether auto-fit is enabled
     */
    getAutoFitStrategy(): boolean;
}
/**
 * Cursor-based visual that can be plotted on a Chart.
 * Like Cursors its built of two parts:
 * PointMarker and ResultTable, first of which
 * shows the location of the Marker clearly and the second
 * to display information about the pointed DataPoint.
 * @hidden Internal class
 */
export declare abstract class ChartMarker<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, CursorType extends InternalStaticCursor<PointMarkerType, ResultTableBackgroundType> = InternalStaticCursor<PointMarkerType, ResultTableBackgroundType>> implements Marker<PointMarkerType, ResultTableBackgroundType, CursorType>, Disposable {
    /**
     * Set the position of Annotation on its scale.
     * @param   position    Position on Annotations scale.
     */
    setPosition(position: Point): this;
    /**
     * Get current position of Annotation
     * @return              Position on Annotations scale
     */
    getPosition(): Point;
    /**
     * This event is called whenever the position of the Marker is changed
     * @param   handler         Function that is called when event is triggered.
     * @param   position        New position of Marker.
     * @return                  Token that can be used to unsubscribe from the event.
     */
    onPositionChange(handler: (marker: this, position: Point) => void): Token;
    /**
     * This event is called whenever the position of the Marker is changed
     * @param   token       Token that was received when the subscription was created.
     * @return              True if unsubscription was successful.
     */
    offPositionChange(token: Token): boolean;
    /**
     * Set visibility mode for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setPointMarkerVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position.
     * @return                  VisibilityMode
     */
    getPointMarkerVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location.
     * NOTE: ResultTable is only visible when it has displayable content, regardless of its VisibilityMode!
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setResultTableVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location.
     * @return                  VisibilityMode
     */
    getResultTableVisibility(): UIVisibilityModes;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * Set auto-fit strategy of Cursor.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @param   autoFitStrategy     AutoFitStrategy factory or undefined to disable auto-fitting
     * @returns                     Object itself for fluent interface
     */
    setAutoFitStrategy(autoFitStrategy?: AutoFitStrategyFactory<ResultTableBackgroundType>): this;
    /**
     * Get is auto-fit enabled.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @returns                     Boolean flag whether auto-fit is enabled
     */
    getAutoFitStrategy(): boolean;
    /**
     * @returns True if object is attached or not attachable, false if it is not attached and attachable
     */
    isAttached(): boolean;
    /**
     * Points the Marker at a given CursorPoint.
     * Updating its position and displayed data.
     */
    pointAt(cursorPoint: CursorPoint): this;
    /**
     * Dispose this Marker from owner's collection.
     */
    dispose(): this;
    /**
     * Restore the marker to parent and the marker's cursor ( and its elements ).
     * @return Marker itself.
     */
    restore(): this;
    /**
     * @return True if Cursor has been disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Mutator function for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position
     * @param   mutator     Mutator function for PointMarker
     * @return              Object itself for fluent interface
     */
    setPointMarker(mutator: Mutator<PointMarkerType>): this;
    /**
     * Get PointMarker object.
     * PointMarker is a visual that is displayed at the Cursors position
     * @returns             PointMarker object
     */
    getPointMarker(): PointMarkerType;
    /**
     * Mutator function for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @param   mutator     Mutator function for ResultTable
     * @return              Object itself for fluent interface
     */
    setResultTable(mutator: Mutator<ResultTable<ResultTableBackgroundType>>): this;
    /**
     * Get ResultTable object.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @returns             ResultTable object
     */
    getResultTable(): ResultTable<ResultTableBackgroundType>;
    /**
     * Set dragging mode of object. Defines how the object can be dragged by mouse.
     *
     * See [[UIDraggingModes]] collection for options.
     * @param       draggingMode    DraggingMode or undefined to disable dragging
     * @returns                     Object itself
     */
    setDraggingMode(draggingMode?: UIDraggingModes): this;
    /**
     * Get dragging mode of object.
     * Defines how the object can be dragged by mouse.
     * @returns                     Object itself
     */
    getDraggingMode(): UIDraggingModes;
}
/**
 * Simple ChartMarker implementation for 2D Charts.
 * Like Cursors its built of two parts:
 * PointMarker and ResultTable, first of which
 * shows the location of the Marker clearly and the second
 * to display information about the pointed DataPoint.
 * @hidden Internal class
 */
export declare class ChartMarker2D<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> extends ChartMarker<PointMarkerType, ResultTableBackgroundType, InternalStaticCursor<PointMarkerType, ResultTableBackgroundType>> {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected _removeMarker: (marker: ChartMarker) => void;
    protected _restoreMarker: (marker: ChartMarker) => void;
    readonly _theme: Theme;
    /**
     * @param _layer        Rendering layer
     * @param scale         Rendering scale
     * @param CursorBuilder CursorBuilder that defines look of chartMarker
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, CursorBuilder: StaticCursor2DBuilder<PointMarkerType, ResultTableBackgroundType>, _removeMarker: (marker: ChartMarker) => void, _restoreMarker: (marker: ChartMarker) => void, _theme: Theme);
}
/**
 * Type of factory for a Scale
 * @return              Scale
 * @hidden
 */
export declare type ScaleFactory = () => Scale;
/**
 * Abstract base class for charts and UI panels
 * @hidden Internal class
 */
export declare abstract class Panel implements Control, DashboardPanel {
    /**
     * Public, safe interface for Panels rendering engine.
     */
    readonly engine: PublicEngine;
    /**
     * Scale for panel area in percentages (0-100).
     * Margin should be set according to panel margin (currently constant).
     */
    uiScale: Vec2<Scale>;
    /**
     * Scale for panel area in pixels.
     * Margin should be set according to panel margin (currently constant).
     */
    pixelScale: Vec2<Scale>;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Point minimum size or undefined if unimplemented
     */
    abstract getMinimumSize(): Point | undefined;
    /**
     * Set fillStyle of panel background.
     * @param   value       FillStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillstyle of chart background.
     * @return              FillStyle
     */
    getBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke style of panel background.
     * @param   value       LineStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of chart background.
     * @return              LineStyle
     */
    getBackgroundStrokeStyle(): LineStyle;
    /**
     * Add a stand-alone *UIElement* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *UIElementBuilder*. If omitted, *TextBoxBuilder* will be selected. Use [[UIElementBuilders]] for selection.
     * @param       scale   Optional custom scale to position UIElement on. Defaults to whole chart in percentages [0, 100].
     * @returns             Object that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addUIElement<UIElementType extends UIPart = UITextBox>(builder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
     * Add a stand-alone *LegendBox* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *LegendBoxBuilder*. If omitted, *HorizontalLegendBox* will be selected. Use [[LegendBoxBuilders]] for selection.
     * @param       scale   Optional custom scale to position LegendBox on. Defaults to whole chart in percentages [0, 100].
     * @returns             LegendBox that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addLegendBox<UIElementType extends UIPart = UILegendBox>(builder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
    /**
    * Capture rendered state in an image file. Prompts the browser to download the created file.
    *
    * **NOTE: The download might be blocked by browser/plugins as harmful.**
    * To prevent this, only call the method in events tied to user-interactions.
    * From mouse-event handlers, for example.
    *
    * Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL.
    * For supported image formats, compression quality, Etc. refer to:
    *
    * https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
    *
    * Example usage:
    *```javascript
    * // Download 'screenshot.png'
    * Panel.saveToFile('screenshot')
    * // Attempt download 'maybeNotSupported.bmp'
    * Panel.saveToFile('maybeNotSupported', 'image/bmp')
    * // Attempt download jpeg.file with specified compression quality
    * Panel.saveToFile('fileName', 'image/jpeg', 0.50)
    * ```
    * @sideEffect              **If 'type' is not supported by browser, an Error will be thrown.**
    *
    * @param   fileName        Name of prompted download file as string. **File extension shouldn't be included**
    *                          as it is automatically detected from 'type'-argument.
    * @param   type            A DOMString indicating the image format. The default format type is image/png.
    * @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
    *                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
    *                          the default value for image quality is used. The default value is 0.92.
    */
    saveToFile(fileName: string, type?: string, encoderOptions?: number): this;
    /**
     * Subscribe to mouse-enter event on Panel background
     */
    protected onPanelBackgroundMouseEnter: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-leave event on Panel background
     */
    protected onPanelBackgroundMouseLeave: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-down event on Panel background
     */
    protected onPanelBackgroundMouseDown: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-up event on Panel background
     */
    protected onPanelBackgroundMouseUp: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-click event on Panel background
     */
    protected onPanelBackgroundMouseClick: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-doubleClick event on Panel background
     */
    protected onPanelBackgroundMouseDoubleClick: (handler: MouseEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag start event on Panel background
     */
    protected onPanelBackgroundMouseDragStart: (handler: MouseDragStartEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag event on Panel background
     */
    protected onPanelBackgroundMouseDrag: (handler: MouseDragEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-drag stop event on Panel background
     */
    protected onPanelBackgroundMouseDragStop: (handler: MouseDragStopEventHandler<this>) => Token;
    /**
     * Subscribe to mouse-wheel event on Panel background
     */
    protected onPanelBackgroundMouseWheel: (handler: MouseWheelEventHandler<this>) => Token;
    /**
     * Subscribe to touch-start event on Panel background
     */
    protected onPanelBackgroundTouchStart: (handler: TouchEventHandler<this>) => Token;
    /**
     * Subscribe to touch-move event on Panel background
     */
    protected onPanelBackgroundTouchMove: (handler: TouchEventHandler<this>) => Token;
    /**
     * Subscribe to touch-end event on Panel background
     */
    protected onPanelBackgroundTouchEnd: (handler: TouchEventHandler<this>) => Token;
    /**
     * Subscribe to resize event of Panel.
     * @param   handler         Handler function for event
     * @param   obj             Panel itself
     * @param   width           Width of panel in pixels
     * @param   height          Height of panel in pixels
     * @param   engineWidth     Width of panels rendering engine in pixels
     * @param   engineHeight    Height of panels rendering engine in pixels
     * @return                  Token of subscription
     */
    onResize: (handler: (obj: this, width: number, height: number, engineWidth: number, engineHeight: number) => void) => Token;
    /**
     * Remove event listener from resize event.
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offResize: (token: Token) => boolean;
}
/**
 * Type of Dashboard resize-event interface. This interface is injected into Panels created by Dashboard.
 * The Panel should use it to subscribe to Dashboard-resize events.
 */
export declare type DashboardResizeEventInterface = AbstractEventInterface;
/**
 * Class for a panel that can have UI elements added into it.
 */
export declare class UIPanel extends Panel {
    /**
     * @param   layerSupplier           Layer supplier
     * @param   logoFactory             Logo factory.
     * @param   removeChart 	        Injectable panel/chart remove method
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @param   logoLayer               Layer to use for logo, if the chart was created on a dashboard.
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (panel: Panel) => void, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, theme?: Theme);
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Set minimum size of UIPanel in pixels.
     * This will affect its resizability by dragging dashboard splitters.
     * @param   minimumSize Minimum size as Point pixels
     */
    setMinimumSize(minimumSize: Point): this;
    /**
     * Get minimum size of UIPanel in pixels as set by user.
     * @return  Point minimum size in pixels or undefined
     */
    getMinimumSize(): Point | undefined;
}
/**
 * Base class for all Series. Series are chart components which support cursors, basically.
 * @hidden Internal class
 */
export declare abstract class Series2D<VisualType extends ChartVisual = ChartVisual, CursorPointInterface extends CursorPoint<Series2D> = any> extends ChartComponent<VisualType> implements SeriesInternal {
    /**
     * Scale of the Series.
     * Necessary for translation of datapoints
     */
    abstract readonly scale: Vec2<Scale>;
    /**
     * Abstract method that solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    abstract solveNearestFromScreen(location: Point): undefined | CursorPointInterface;
    /**
     * Abstract method that solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    abstract solveNearestFromSegment(location: Point, segment: ChartVisual): undefined | CursorPointInterface;
    /**
     * Set whether Cursor is enabled or not
     */
    setCursorEnabled(state: boolean): this;
    /**
     * @returns Whether Cursor is enabled or not
     */
    getCursorEnabled(): boolean;
    /**
     * Add event listener to Series Hover Event.
     * Hover event is a custom mouse-event designed for Series that is the main link between Cursors and Series.
     * @param   clbk            Callback function that is called whenever mouse enters / moves or leaves the Series
     *
     * @param   series          Series itself
     * @param   cursorPoint     Interface for positioning Cursors on Series or undefined if mouse left Series.
     * @return                  Token of the event listener
     */
    onHover: (clbk: (series: this, cursorPoint: CursorPointInterface | undefined) => void) => Token;
    /**
     * Remove event listener from Series Hover Event.
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offHover: (token: Token) => boolean;
}
/**
 * Type of Animation Factory
 * @param   values          Array of start and end animation values
 * @param   action          Function for handling of interframe modification
 * @param   customDuration  Override default duration of animation
 */
export declare type AnimationFactory = (values: Array<[number, number]>, action: AnimationFrameCallback, customDuration?: number) => Animation;
/**
 * Animator factory.
 *
 * **Unpolished API, usage can be copied from Examples set but it is not further encouraged**.
 * @param afterUpdate   After all animation update callback
 * @param fps           Desirable frame rate for all animations (Limited to around 60fps by browser)
 */
export declare const Animator: (afterUpdate: () => void, fps?: number) => (duration?: number, easing?: AnimationEasing) => AnimationFactory;
/**
 * Class for animation handling
 * @property    delta           Delta time from start of animation
 * @property    eases           Array of Eases animation functions
 * @property    nextAnimations  Queue of future animations
 * @property    action          Function for handling of interframe modification
 * @property    duration        Animation duration in milliseconds
 * @property    easing          Ease animation function factory
 */
export declare class Animation {
    private readonly _values;
    readonly action: AnimationFrameCallback;
    readonly duration: number;
    readonly easing: AnimationEasing;
    private readonly _animations;
    delta: number;
    eases: Array<Ease>;
    /**
     * @param   _values      Array of start and end animation values
     * @param   action      Function for handling of interframe modification
     * @param   duration    Animation Duration in milliseconds
     * @param   easing      Ease Animation function factory. See [[AnimationEasings]] for a collection of options.
     */
    constructor(_values: Array<[number, number]>, action: AnimationFrameCallback, duration: number, easing: AnimationEasing, _animations: Array<Animation>);
    /**
     * Starts an animation
     * @return Object itself for fluent interface
     */
    start(): this;
    /**
     * Add animations which has to be executed subsequently
     * @param   animations  Subsequent Animation or Array of them
     * @return           Object itself for fluent interface
     */
    addNextAnimations(animations: Animation | Array<Animation>): this;
    /**
     * Add and create animation which has to be executed subsequently
     * @param   values      Array of start and end animation values
     * @param   action      Function for handling of interframe modification
     * @return              new Animation
     */
    NextAnimation(values: Array<[number, number]>, action: AnimationFrameCallback, duration?: number): Animation;
    /**
     * Subscribe on current animation end event
     * @param action Event listener
     * @return       Token of the event listener
     */
    onAnimationEnd(action: (nextAnimation?: Animation) => void, token?: Token): Token;
    /**
     * Subscribe on every subsequent animations end event
     * @param action Event listener
     * @return       Token of the event listener
     */
    onEveryAnimationEnd(action: (nextAnimation?: Animation) => void, token?: Token): Token;
    /**
     * Subscribe on all subsequent animations end event
     * @param action Event listener
     * @return       Token of the event listener
     */
    onAllAnimationEnd(action: VoidFunction, token?: Token): Token;
    /**
     * Remove all listeners from Animation End Event
     * @return  Object itself for fluent interface
     */
    allOffAnimationEnd(): this;
    /**
     * Remove all listeners from Every Animation End Event
     * @return  Object itself for fluent interface
     */
    allOffEveryAnimationEnd(): this;
    /**
     * Remove all listeners from All Animation End Event
     * @return  Object itself for fluent interface
     */
    allOffAllAnimationEnd(): this;
    /**
     * Remove a listener from Animation End Event
     * @param   token   Token of the listener
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offAnimationEnd(token: Token): boolean;
    /**
     * Remove a listener from Every Animation End Event
     * @param   token   Token of the listener
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offEveryAnimationEnd(token: Token): boolean;
    /**
     * Remove a listener from All Animation End Event
     * @param   token   Token of the listener
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offAllAnimationEnd(token: Token): boolean;
    /**
     * Finish current animation and start the next one on the sequence
     * @param   emitEvents   Flag that tells whether the function should emit any events
     * @return  Future animations or undefined
     */
    finish(emitEvents?: boolean): Animation | undefined;
    /**
     * Finish all animations
     * @param   emitEvents   Flag that tells whether the function should emit any events
     */
    finishAll(emitEvents?: boolean): void;
    /**
     * Get is animation over and there are no queued animations
     */
    isOver: () => boolean;
    /**
     * Get final value of queued animations
     * @returns Final values of the animations
     */
    getFinalValues(): number[];
    /**
     * Get time until all queued animations will finish
     */
    getTimeUntilFinish(): number;
}
/**
 * Function for handling of interframe modification
 * @param   values  Values calculated by Ease function
 */
export declare type AnimationFrameCallback = (values: Array<number>) => void;
/**
 * Ease Animation function
 * @param   delta   Delta time from start of animation
 * @hidden
 */
export declare type Ease = (delta: number) => number;
/**
 * Interface for [[AnimationEasing]].
 *
 * See  [[AnimationEasings]] for a collection of default options.
 * @param   start       Starting value of the animation
 * @param   end         End value of the animation
 * @param   duration    Animation Duration in milliseconds
 */
export declare type AnimationEasing = (start: number, end: number, duration: number) => Ease;
/**
 * [[AnimationEasing]] collection to use with [[Animator]].
 */
export declare const AnimationEasings: {
    linear: AnimationEasing;
    easeIn: AnimationEasing;
    easeOut: AnimationEasing;
    ease: AnimationEasing;
};
/**
 * Interface that can be used to configure rendering Engine of *Charts* and other *LCJS* components.
 *
 * Example usage:
 *```javascript
 * // Automatically generated DIV on document
 * undefined
 * // Embed Engine in a DOM element
 * { container: 'dashboard_div_id' }
 * ```
 */
export declare type EngineOptions = EngineSettings & (FitEngineToDiv | DimensionalEngineSize);
/**
 * Interface specifies settings for Engine.
 */
export interface EngineSettings {
    /**
     * Max FPS (frames-per-second).
     * Setting this will postpone rendering events that would otherwise happen, if it would result in FPS higher than the value.
     *
     * NOTE: This property can't be used to accurately specify actual FPS as it is dictated by the browser. The purpose for 'maxFps' is
     * to limit unnecessary rendering loads where they are not needed.
     */
    readonly maxFps?: number;
    /**
     * Set preference for anti-aliasing.
     *
     * If set to true or undefined and browser supports anti-aliasing then the chart will be anti-aliased. If set to false or browser
     * doesn't support anti-aliasing then the chart will not be anti-aliased.
     */
    readonly antialias?: boolean;
    /**
     * Set device pixel ratio.
     *
     * This ratio is used to support high DPI devices. This should be set to true when the meta tag "viewport"
     * has been set to "width=device-width" and you want to let the chart automatically determine the device pixel ratio to use.
     * ```html
     * <meta name="viewport" content="width=device-width, initial-scale=1.0">
     * ```
     *
     * Set this to a specific number if you want to use a specific device pixel ratio.
     *
     * By default, device pixel ratio of **1** will be used.
     *
     * If this option is not specified the ratio will be automatically decided based on the existence of the viewport meta tag
     * and the content of the tag if found.
     */
    readonly devicePixelRatio?: boolean | number;
}
/**
 * Interface specifies that Engine should not think about its own size and simply fit itself into
 * an existing element on the document, which should be created by user.
 */
export interface FitEngineToDiv {
    /**
     * The DOM Element or its ID that will contain Engine.
     * If there is no such element found, an uncatchable error will be thrown.
     * If nothing was provided, a new DOM Element will be created by the Engine.
     */
    readonly container?: HTMLDivElement | string;
}
/**
 * Check if element is of the FitEngineToDiv interface.
 * @param element Element to check
 * @hidden
 */
export declare const _isFitEngineToDiv: (element?: (EngineSettings & FitEngineToDiv) | (EngineSettings & DimensionalEngineSize) | undefined) => element is FitEngineToDiv;
/**
 * Interface specifies individual sizes for each dimension - width and height.
 */
export interface DimensionalEngineSize {
    /**
     * Specifies width of engine.
     */
    readonly width?: EngineDimension;
    /**
     * Specifies height of engine.
     */
    readonly height?: EngineDimension;
}
/**
 * Type of dimension for engine; can be a tuple of boundaries, a single static dimension or undefined for container size.
 * When using a tuple to specify boundaries [min, max], actual size for engine will be the size of its container clamped to the specified
 * pixel boundaries. Any of the values inside the tuple can be undefined.
 * Using a single number will set a static size for engine dimension, meaning no resizing of engine will take effect.
 */
export declare type EngineDimension = [number | undefined, number | undefined] | undefined | number;
/**
 * Object that represents a range of values.
 */
export interface FormattingRange {
    /**
     * Get first value on range.
     *
     * This can be higher than the *end* value, for example, in the case of a *inverted Axis*.
     * @return  Number
     */
    getInnerStart(): number;
    /**
     * Get final value on range.
     *
     * This can be smaller than the *start* value, for example, in the case of a *inverted Axis*.
     * @return  Number
     */
    getInnerEnd(): number;
}
/**
 * Type definition for a *pure* *formatting function*.
 *
 * The formatter is supplied a numeric value, and it formats it into a *string*, that can be displayed
 * on an *Axis tick*, for example.
 * @param   value           Numeric value.
 * @param   range           Object that represents the possible range for *value*.
 *                          For example, the start-end range of an *Axis*.
 * @return                  Value formated as string
 */
export declare type FormattingFunction = (value: number, range: FormattingRange, locale?: string) => string;
/**
 * Enum-like object for implementations of default Formatting functions.
 */
export declare const FormattingFunctions: {
    /**
     * Formats a number.
     * @param   value           Value on range to format
     * @param   range           FormatingRange
     * @return                  Value formated as string
     */
    Numeric: (value: number, range: FormattingRange) => string;
    /**
     * Formats a number by range-dependant rounding and usage of units.
     * @param   value           Value on range to format
     * @param   range           FormatingRange
     * @return                  Value formated as string with units
     */
    NumericUnits: (value: number, range: FormattingRange) => string;
};
/**
 * Interface for a immutable data-structure which represents a 2-dimensional location.
 */
export interface Point {
    /**
     * Location in X-dimension.
     */
    readonly x: number;
    /**
     * Location in Y-dimension.
     */
    readonly y: number;
}
/**
 * Interface for a mutable data-structure which represents a 2-dimensional location.
 */
export interface MPoint {
    /**
     * Location in X-dimension.
     */
    x: number;
    /**
     * Location in Y-dimension.
     */
    y: number;
}
/**
 * Interface for immutable data-structure which contains a color.
 */
export interface ColorValue {
    /**
     * Color for the fill.
     */
    readonly color: Color;
}
/**
 * Interface for mutable data-structure which contains a color.
 */
export interface MColorValue {
    /**
     * Color for the fill.
     */
    color: Color;
}
/**
 * Interface for immutable data-structure which represents a 2-dimensional location and an associated Color.
 *
 * This can be used for Point-based series for coloring each point individually, when combined with usage of IndividualPointFill-style.
 */
export interface ColorPoint extends Point, ColorValue {
}
export interface SizePoint extends Point {
    size: number;
}
export interface RotationPoint extends Point {
    rotation: number;
}
/**
 * Interface for a mutable data-structure which represents a 2-dimensional location and an associated Color.
 *
 * This can be used for Point-based series for coloring each point individually, when combined with usage of IndividualPointFill-style.
 */
export interface MColorPoint extends MPoint, MColorValue {
}
/**
 * Interface for a data-structure which represents a 2-dimensional location, but with one of the planes
 * having two values instead of just one to create an area in the given location.
 *
 * Used to supply points to AreaRangeSeries.
 */
export interface AreaPoint {
    /**
     * Position of Point.
     */
    readonly position: number;
    /**
     * High value of Point in the given position.
     */
    readonly high: number;
    /**
     * Low value of Point in the given position.
     */
    readonly low: number;
}
/**
 * Interface for a data-structure which represents a 3-dimensional location.
 */
export interface Point3D {
    /**
     * Location in X-dimension.
     */
    readonly x: number;
    /**
     * Location in Y-dimension.
     */
    readonly y: number;
    /**
     * Location in Z-dimension.
     */
    readonly z: number;
}
/**
 * Interface for immutable data-structure which represents an intensity value in the situation.
 */
export interface IntensityValue {
    /**
     * Intensity value in the situation.
     */
    readonly intensity: number;
}
/**
 * Interface for mutable data-structure which represents an intensity value in the situation.
 */
export interface MIntensityValue {
    /**
     * Intensity value in the situation.
     */
    intensity: number;
}
/**
 * Interface for mutable data-structure which represents a 2-dimensional location and an associated Intensity value.
 *
 * This can be used for Point-based series for coloring each point individually, when combined with usage of IndividualPointFill-style.
 */
export interface MIntensityPoint extends MPoint, MIntensityValue {
}
/**
 * Interface for mutable data-structure which represents a 2-dimensional location and an associated Color and Intensity value.
 * This structure is used for IntensityMesh series for modification of the Mesh topology, coloring, and paletting.
 * A cell can be colored either:
 * - with a provided color for coloring each cell individually, when combined with usage of IndividualPointFill-style.
 * - with a color fetched from value range palette based on *intensity* value, when combined with usage of PalettedFill-style.
 */
export interface MIntensityColorPoint extends MColorPoint, MIntensityValue {
}
/**
 * Interface for mutable data-structure which represents a Color and Intensity value in the situation.
 * This structure is used for IntensityGrid series for coloring and paletting only.
 * A cell can be colored either:
 * - with a provided color for coloring each cell individually, when combined with usage of IndividualPointFill-style.
 * - with a color fetched from value range palette based on *intensity* value, when combined with usage of PalettedFill-style.
 */
export interface MIntensityColorValue extends MColorValue, MIntensityValue {
}
/**
 * @property columns    Horizontal resolution of the Heatmap.
 * @property rows       Vertical resolution of the Heatmap.
 * @property start      Starting point position of the Heatmap.
 * @property end        End point position of the Heatmap.
 * @property pixelated  Data definition per cell / per vertex of the Heatmap.
 */
export interface IntensityOptions {
    /**
     * Horizontal resolution of the Heatmap.
     */
    columns: number;
    /**
     * Vertical resolution of the Heatmap.
     */
    rows: number;
    /**
     * Starting point position of the Heatmap.
     */
    start: Point;
    /**
     * End point position of the Heatmap.
     */
    end: Point;
    /**
     * Data definition per cell / per vertex of the Heatmap.
     *
     * | Value                     | Desired result                        |
     * | :------------------------ | :------------------------------------ |
     * | *pixelate:* ***true***    | Intensity / Color applies per cell    |
     * | *pixelate:* ***false***   | Intensity / Color applies per vertex  |
     */
    pixelate: boolean;
}
/**
 * Interface describes the range interval between two numeric values.
 */
export interface NumericInterval {
    /**
     * Start interval.
     */
    start: number;
    /**
     * End interval.
     */
    end: number;
}
/**
 * Interface describes the range interval.
 * Contains information about the staring index and how many elements in the group.
 */
export interface NumericGroup {
    /**
     * Start interval.
     */
    start: number;
    /**
     * Amount of items.
     */
    count: number;
}
/**
 * Interface for storing the information about grid resolution range
 * e.g. start and end for columns and rows.
 */
export interface GridRangeOptions {
    /**
     * Column range. Start column number ... End column number.
     */
    column: NumericInterval;
    /**
     * Row range. Start row number ... End row number.
     */
    row: NumericInterval;
}
/**
 *
 * @hidden
 */
export interface IntensityUpdateEventMap {
    color: Matrix<Color>;
    value: Matrix<number>;
}
/**
 * Generic multi-dimensional array of specified type.
 */
export declare type Matrix<T> = Array<Array<T>>;
export declare type UpdateColorCallback = (row?: number, column?: number, current?: IntensityValue & Partial<ColorValue>) => Color | undefined;
export declare type UpdateValueCallback = (row?: number, column?: number, current?: IntensityValue) => number | undefined;
export declare type UpdateGeometryCallback = (row: number, column: number, current: Point) => Point | undefined;
/**
 * Interface for a data-structure which represents a measurement of four sides.
 * Has number properties for:
 * - left
 * - top
 * - right
 * - bottom
 *
 * This data-structure is mainly used for specifying Chart paddings and UIElement paddings/margins.
 *
 * Duplicate of Padding.
 */
export interface Margin {
    /**
     * Left value.
     */
    readonly left: number;
    /**
     * Top value.
     */
    readonly top: number;
    /**
     * Right value.
     */
    readonly right: number;
    /**
     * Bottom value.
     */
    readonly bottom: number;
}
/**
 * Interface for a data-structure which represents a measurement of four sides.
 * Has number properties for:
 * - left
 * - top
 * - right
 * - bottom
 *
 * This data-structure is mainly used for specifying Chart paddings and UIElement paddings/margins.
 *
 * Duplicate of Margin.
 */
export declare type Padding = Margin;
/**
 * Interface that just specifies the ability to remove shapes.
 */
export interface Removable {
    /**
     * Remove everything related to the object from all collections associated
     * with rendering cycle and allows the object to be collected by GC
     * @return Object itself for fluent interface
     */
    dispose: () => this;
    /**
     * @return True if object and all of its sub-objects/elements have been disposed, false if not.
     */
    isDisposed: () => boolean;
}
/**
 * Interface that just specifies the ability to remove and restore shapes.
 * @hidden
 */
export interface Disposable extends Removable {
    /**
     * Restore everything required for correct life cycle of the object
     * @return Object itself for fluent interface
     */
    restore: () => this;
}
/**
 * Decoration for normal number. Indicates that the value should be interpreted as amount of pixels.
 * @hidden
 */
export declare type pixel = number;
/**
 * Type of a mutator function for abstract object.
 * Function provides functionality for modifying an object.
 * @param   object  Object to mutate
 */
export declare type Mutator<T> = (object: T) => void;
/**
 * Type of a mutator function for abstract, immutable object.
 * Function provides functionality for creating a new object based on an existing one.
 * @param   object  Reference object
 * @return          New object
 */
export declare type ImmutableMutator<T, B = T> = (object: T) => B;
/**
 * Enum for selecting shape of points for Point-based *Series*.
 * Supported by:
 * - [[PointSeries]]
 * - [[PointLineSeries]]
 * - [[SpiderSeries]]
 *
 * This must be specified when the *Series* is created, and can't be changed afterwards.
 */
export declare enum PointShape {
    /**
     * Square shape.
     */
    Square = 0,
    /**
     * Circle shape.
     */
    Circle = 1,
    /**
     * Triangle shape.
     */
    Triangle = 2
}
/**
 * Chart options that are common to all charts.
 */
export interface CommonChartOptions {
    /**
     * Theme used to style all elements inside the Chart.
     * See **Themes** for pre-made options.
     */
    theme?: Theme;
    /**
     * Disable animations by default
     */
    disableAnimations?: boolean;
}
/**
 * Type of an abstract Palette function.
 * NOTE: It is common for applications dealing with Palettes to assume that they are continuous,
 * meaning that when supplied an overflowing index, it will return loop back to start.
 * @param   index   Index of item to pick from Palette
 * @return          Generated item
 */
export declare type Palette<T> = (index: number) => T;
/**
 * Type of an abstract Palette factory.
 * @param   length  Length of Palette
 * @return          Palette of specified length
 */
export declare type PaletteFactory<T> = (length: number) => Palette<T>;
/**
 * Collection of default *Color* *PaletteFactories*.
 *
 * Items are mostly functions that take a single argument, *length*, and return a *Color* [[Palette]] of that given length.
 *
 * *Color* *Palettes* are functions that give a *Color* based on a given *index*.
 */
export declare const ColorPalettes: {
    warm: PaletteFactory<Color>;
    cold: PaletteFactory<Color>;
    fullSpectrum: PaletteFactory<Color>;
    reverseSpectrum: PaletteFactory<Color>;
    flatUI: PaletteFactory<Color>;
    arction: PaletteFactory<Color>;
    arctionWarm: PaletteFactory<Color>;
    sector: (start: number, end: number, saturation?: number, vibrance?: number) => PaletteFactory<Color>;
};
/**
 * Object that handles transformations between a virtual numeric range and pixels.
 */
export declare class Scale extends Validator implements Validatable, FormattingRange {
    /**
     * @return Size of cell which scale represents
     */
    getCellSize(): number;
    /**
     * @return Inner scale end value
     */
    getInnerEnd(): number;
    /**
     * @return Inner scale start value
     */
    getInnerStart(): number;
    /**
     * @returns Scale pixel size
     */
    getPixelSize(): number;
    /**
     * @return distance between min and max value with out margins
     */
    getInnerInterval(): number;
}
/**
 * Special type of "Scale" used with 3D Axes. Basically equal to Scale,
 * except most of its functionality has been stripped, as there is no
 * concept of "pixels" in a 3D Scale.
 *
 * This class only serves as a container for FormattingRange values, and associated invalidation logic.
 *
 * @hidden  Internal class
 */
export declare class UnitScale extends Validator implements Validatable, FormattingRange {
    /**
     * Get min value on range
     * @return  Number
     */
    getInnerStart(): number;
    /**
     * Get max value on range
     * @return  Number
     */
    getInnerEnd(): number;
    /**
     * Get absolute range of Scale interval as
     *
     * ```javascript
     * Math.abs( this.getInnerEnd() - this.getInnerStart() )
     * ```
     * @return  Number
     */
    getInnerInterval(): number;
}
/**
 * Translates a *Point* from one *Scale* to another.
 * @param   value           Point
 * @param   originScale     Scale of value
 * @param   targetScale     Target Scale for translation
 * @return                  value translated to targetScale
 */
export declare const translatePoint: (value: Point, originScale: Vec2<Scale>, targetScale: Vec2<Scale>) => Point;
/**
* Factory for creating a SolidFill palette.
* @param  colorPalettes   Collection of default colors from PaletteFactory
* @param  amount          Amount of colors in the palette
* @return                 A new SolidFill palette
*/
export declare const SolidFillPalette: (colorPalettes: PaletteFactory<Color>, amount: number) => Palette<FillStyle<any>>;
/**
 * Function for initializing the LightningChart library.
 *
 * Returns an *object*, with properties for creating different *Charts* and components.
 * See [[LightningChart]] interface for all available properties.
 *
 * @param   license Optional development or deployment license. If omitted, a community license will be used.
 * @param   licenseInformation Additional information for license verification. Only required by Application Deployment license.
 * @return          A *LightningChart* object for creating *Charts* and components.
 */
export declare const lightningChart: (license?: string | undefined, licenseInformation?: AppDeploymentLicenseInformation | undefined) => LightningChart;
/**
 * File contains interfaces of charting component factories.
 */
/**
 * Interface for factories of Charting components.
 *
 * Each property of this interface is a Factory for creating LCJS components.
 * They are functions which all have one parameter (might be optional), which is used to pass options to the created component.
 *
 * All components are able to handle the options defined by interface: EngineOptions, which can be used to setup the rendering environment
 * for the component. Most 
 */
export interface LightningChart {
    /**
     * Factory for Dashboard.
     * Dashboard allows placement of multiple Charts, sharing a common rendering engine between them.
     * It also enables users to resize the cells with mouse/touch interaction.
     *
     * Example usage:
     *```javascript
     * // Dashboard with 2 columns and 3 rows
     * Dashboard({ numberOfColumns: 2, numberOfRows: 3 })
     * // Dashboard embedded in a DOM element
     * Dashboard({ ..., container: 'dashboard_div_id' })
     * ```
     * When creating a Dashboard the Factory MUST be supplied with an object which fulfills the DashboardOptions-interface.
     * This object can also optionally contain properties of EngineOptions.
     * @param   options     Options for creation of Dashboard and optionally also for its rendering Engine.
     * @return              Dashboard
     */
    Dashboard: (options: EngineOptions & DashboardOptions) => Dashboard;
    /**
     * Factory for ChartXY.
     * This chart visualizes the data using the Cartesian coordinate system.
     * It has a multitude of methods for adding various types of Series.
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * ChartXYOptions-interface, which can be used for:
     *  - Selecting a preset color Theme.
     *  - Supplying a custom Builder for the AutoCursor of Chart.
     *    This can be used to modify the AutoCursor on a level, which can't be done during runtime.
     *    For example, changing the shape of ResultTable Background, Etc.
     *
     * Example usage:
     *```javascript
     * // ChartXY with default AutoCursor and Axes
     * ChartXY()
     * // ChartXY embedded in a DOM element
     * ChartXY({ container: 'chart_div_id' })
     * ```
     * More [[ChartXY]] specific examples can be found in documentation of [[ChartXYOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              ChartXY
     */
    ChartXY: <CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground, CursorTickMarkerBackgroundTypeX extends PointableBackground, CursorTickMarkerBackgroundTypeY extends PointableBackground>(options?: EngineOptions & ChartXYOptions<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerBackgroundTypeX, CursorTickMarkerBackgroundTypeY>) => ChartXY<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerBackgroundTypeX, CursorTickMarkerBackgroundTypeY>;
    /**
     * Factory for SpiderChart.
     * This chart visualizes data in a radial form as dissected by named axes.
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * SpiderChartOptions-interface, which can be used for:
     *  - Selecting a preset color Theme.
     *  - Supplying a custom Builder for the AutoCursor of Chart.
     *    This can be used to modify the AutoCursor on a level, which can't be done during runtime.
     *    For example, changing the shape of ResultTable Background, Etc.
     *
     * Example usage:
*```javascript
     * // Spider chart with default AutoCursor and Axes
     * Spider()
     * // Spider chart embedded in a DOM element
     * Spider({ container: 'chart_div_id' })
     * ```
     * More [[SpiderChart]] specific examples can be found in documentation of [[SpiderChartOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              SpiderChart
     */
    Spider: <CursorPointMarkerType extends PointMarker, CursorResultTableBackgroundType extends UIBackground>(options?: EngineOptions & SpiderChartOptions<CursorPointMarkerType, CursorResultTableBackgroundType>) => SpiderChart<CursorPointMarkerType, CursorResultTableBackgroundType>;
    /**
     * Factory for PieChart.
     * This chart visualizes proportions and percentages between categories,
     * by dividing a circle into proportional segments.
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * PieChartOptions-interface, which can be used for:
     * - Selecting a preset color Theme.
     * - Specifying "type" for Pie Chart.
     *
     * Example usage:
     *```javascript
     * // Pie Chart with default type
     * Pie()
     * // Pie Chart with specified type
     * Pie({ type: PieChartTypes.PieChartWithLabelsOnSides })
     * // Pie Chart embedded in a DOM element
     * Pie({ container: 'chart_div_id' })
     * ```
     * More [[PieChart]] specific examples can be found in documentation of [[PieChartOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              PieChart with type specified via 'options'
     */
    Pie: <PieChartType extends PieChartTypes = typeof PieChartWithLabelsOnSides>(options?: EngineOptions & PieChartOptions<PieChartType>) => InstanceType<PieChartType>;
    /**
     * Factory for GaugeChart.
     * Gauge charts indicate where your data point(s) falls over a particular range.
     * This chart type is often used in executive dashboard reports to show key business indicators.
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * GaugeChartOptions-interface, which can be used for:
     * - Selecting a preset color Theme.
     * - Specifying "type" for Gauge Chart.
     *
     * Example usage:
     *```javascript
     * // Gauge Chart with default type
     * Gauge()
     * // Gauge Chart with specified type
     * Gauge({ type: GaugeChartTypes.Solid })
     * // Gauge Chart embedded in a DOM element
     * Gauge({ container: 'chart_div_id' })
     * ```
     * More [[GaugeChart]] specific examples can be found in documentation of [[GaugeChartOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              GaugeChart with type specified via 'options'
     */
    Gauge: <GaugeChartType extends GaugeChartTypes = typeof SolidGauge>(options?: EngineOptions & GaugeChartOptions<GaugeChartType>) => InstanceType<GaugeChartType>;
    /**
     * Factory for FunnelChart.
     * This chart visualizes proportions and percentages between categories,
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * FunnelChartOptions-interface, which can be used for:
     * - Selecting a preset color Theme.
     * - Specifying "type" for Funnel Chart.
     *
     * Example usage:
     *```javascript
     * // Funnel Chart with default type
     * Funnel()
     * // Funnel Chart with specified type
     * Funnel({ type: FunnelChartTypes.LabelsOnSides })
     * // Funnel Chart embedded in a DOM element
     * Funnel({ container: 'chart_div_id' })
     * ```
     * More [[FunnelChart]] specific examples can be found in documentation of [[FunnelChartOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              FunnelChart with type specified via 'options'
     */
    Funnel: <FunnelChartType extends FunnelChartTypes = typeof FunnelChartWithLabelsOnSides>(options?: EngineOptions & FunnelChartOptions<FunnelChartType>) => InstanceType<FunnelChartType>;
    /**
     * Factory for PyramidChart.
     * This chart visualizes proportions and percentages between categories,
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * PyramidChartOptions-interface, which can be used for:
     * - Selecting a preset color Theme.
     * - Specifying "type" for Pyramid Chart.
     *
     * Example usage:
     *```javascript
     * // Pyramid Chart with default type
     * Pyramid()
     * // Pyramid Chart with specified type
     * Pyramid({ type: PyramidChartTypes.LabelsOnSides })
     * // Pyramid Chart embedded in a DOM element
     * Pyramid({ container: 'chart_div_id' })
     * ```
     * More [[PyramidChart]] specific examples can be found in documentation of [[PyramidChartOptions]].
     * @param   options     Optional options for creation of Chart and its rendering engine
     * @return              PyramidChart with type specified by 'options'
     */
    Pyramid: <PyramidChartType extends PyramidChartTypes = typeof PyramidChartWithLabelsOnSides>(options?: EngineOptions & PyramidChartOptions<PyramidChartType>) => InstanceType<PyramidChartType>;
    /**
     * Factory for UIPanel.
     * This component simply allows the anchoring of user-made UIElements.
     *
     * Can optionally be supplied with an options object that fulfills the
     * EngineOptions-interface. This can be used to setup the rendering environment of the Panel.
     *
     * Example usage:
     *```javascript
     * // UIPanel
     * UIPanel()
     * // UIPanel embedded in a DOM element
     * UIPanel({ container: 'panel_div_id' })
     * ```
     * @param   options     Optional options for creation of Panels rendering engine
     * @return              UIPanel
     */
    UIPanel: (options?: EngineOptions) => UIPanel;
    /**
     * Factory for Chart3D.
     * This Chart visualizes data in a 3-dimensional scene, with camera and light source(s).
     * Currently supports only Point Series, but more series types will be added later on.
     *
     * This Factory can be supplied with an options object, which - along with EngineOptions - can also contain properties of
     * Chart3DOptions-interface, which can be used for:
     * - Selecting a preset color Theme.
     *
     * Example usage:
     *
     * | Desired result                             | Usage                                             |
     * | :----------------------------------------- | :------------------------------------------------ |
     * | Chart3D with default AutoCursor and Axes   | *Chart3D*()                                       |
     * | Chart3D embedded in a DOM element          | *Chart3D*({ **container:** 'chart_div_id' })    |
     * @param   options     Optional options for creation of the Charts rendering engine
     * @return              Chart3D
     */
    Chart3D: (options?: EngineOptions & ChartOptions3D) => Chart3D;
}
/**
 * Application deployment license information.
 */
export interface AppDeploymentLicenseInformation {
    /**
     * Company name
     */
    company: string;
    /**
     * Application title
     */
    appTitle: string;
    [key: string]: string;
}
/**
 * Factory for creation of Engine.
 * Handles application of different engine restrictions based on whether suite is for development or production
 * @param   engineOptions  Settings union for Engine.
 * @return                  Engine object.
 */
export declare type EngineFactory = (engineOptions?: EngineOptions) => Engine;
/**
 * Type of LayerSupplier factory.
 * @param   componentIndex  Index of component to create layer supplier for
 * @return                  LayerSupplier object
 * @hidden
 */
export declare type LayerSupplierFactory = (componentIndex: number) => LayerSupplier;
/**
 * Interface for object that is used for supplying rendering layers for charting components.
 * @hidden
 */
export interface LayerSupplier {
}
export {};
/**
 * Interface which can be used to interact with a created Logo.
 */
export interface LogoHandle {
}
/**
 * Logo factory. Takes scale used by a chart to properly render the logo for that chart.
 * @return  LogoHandle interface for interacting with created Logo.
*/
export declare type LogoFactory = (scale: Vec2<Scale>) => LogoHandle;
/**
 * Interface for public parts of engine.
 */
export interface PublicEngine {
    /**
     * HTML Div element that contains the rendering Engine.
     */
    container: HTMLDivElement;
    /**
     * Scale of Engine. (Screen)
     */
    scale: Vec2<Scale>;
    /**
     * Set Mouse style.
     * @param   presetName  Name of a Mouse preset in js.
     * @param   existingKey Key for existing request to refresh
     * @return              Key that can be used to restore Mouse style
     */
    setMouseStyle: (presetName: string, existingKey?: number) => number;
    /**
     * Restore Mouse style.
     * @param   key     Key generated using 'setMouseStyle'
     */
    restoreMouseStyle: (key: number) => void;
    /**
     * Translates client location (that originates at top-left of browser) to engines
     * space (originated at engine canvas' bottom-left)
     * @param   x   Location of X in browser
     * @param   y   Location of Y in browser
     */
    clientLocation2Engine(x: number, y: number): Point;
    /**
     * Translates engine location (originated at engine canvas' bottom-left) to client space (that originates at top-left of browser).
     * @param   x   Location of X in engine
     * @param   y   Location of Y in engine
     */
    engineLocation2Client(x: number, y: number): Point;
    /**
     * Capture state of rendering Engines canvas. Returns the captured image as a Blob-object.
     *
     * Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL:
     *
     * https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
     *
     * @param   type            A DOMString indicating the image format. The default format type is image/png.
     * @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
     *                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
     *                          the default value for image quality is used. The default value is 0.92. Other arguments are ignored.
     * @return                  JavaScript Blob whose 'type' depends on what was passed to 'type' parameter of this method.
     *                          Defaults to image/png
     */
    captureFrame(type?: string, encoderOptions?: number): Blob;
    /**
     * Render a frame of specific size to a ArrayBuffer.
     *
     * Mainly for Node JS usage. In browser the chart itself will not be resized correctly.
     * @param width Horizontal resolution
     * @param height Vertical resolution
     * @param noFlip Leave the image upside down
     */
    renderFrame(width: number, height: number, noFlip?: boolean): Uint8Array;
    /**
    * Calculate the layout again. This should be called when the container of chart is resized.
    */
    layout(): void;
}
/**
 * Constants
 * @hidden Internal class
 */
export declare abstract class Engine implements Validatable {
    /**
     * @param options   EngineOptions
     */
    constructor(options?: EngineOptions);
}
/**
 * Enum for choosing of right mouse click event type
 */
export declare enum MouseClickEventType {
    click = 0,
    dbclick = 1,
    mouseDown = 2,
    mouseUp = 3,
    contextmenu = 4,
    wheel = 5
}
/**
 * Enum for choosing of right touch event type
 */
export declare enum TouchEventType {
    touchStart = 0,
    touchMove = 1,
    touchEnd = 2
}
/**
 * Any kind of object which can be rendered by Engine
 * @hidden Internal class
 */
export declare abstract class Element<T extends Engine> {
    protected readonly _engine: T;
    /**
    * @param   _engine      Rendering engine
    * @param   depthIndex   Number of depth layer there the object is located
    */
    constructor(_engine: T);
}
/**
 * Any kind of object which can be rendered by Engine
 * @hidden Internal class
 */
export declare abstract class Entity<T extends Engine = Engine> extends Element<T> implements Disposable {
    readonly _engine: T;
    protected readonly _remove: RemoveHandler<Entity<T>>;
    protected readonly _restore: RestoreHandler<Entity<T>>;
    /**
    * @param   _engine      Rendering engine
    */
    constructor(_engine: T, _remove: RemoveHandler<Entity<T>>, _restore: RestoreHandler<Entity<T>>);
    /**
     * Dispose this Entity from the collection of entities in the layer it belongs to.
     */
    dispose(): this;
    /**
     * Restore this Entity back to the collection of entities in the layer it belonged to.
     */
    restore(): this;
    /**
     * Get the current state of this Entity's isDisposed flag.
     * @return True if Entity is disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Set are shapes mouse interactions enabled.
     * @param isMouseInteractionEnabled Boolean
     */
    setMouseInteractions(isMouseInteractionEnabled: boolean): this;
    /**
     * Get are shapes mouse interactions enabled.
     * @return  Boolean
     */
    getMouseInteractions(): boolean;
    /**
     * Get if entity is under mouse
     * @return Boolean
     */
    getIsUnderMouse(): boolean;
    /**
     * Returns a boolean that describes if this Entity is currently 'grabbed' by the mouse (ex. pressed down on mouse)
     */
    getIsGrabbed(): boolean;
    /**
     * Set if entity is under mouse
     * @param state
     */
    setIsUnderMouse(state: boolean): this;
    /**
     * Set handler for Mouse Move Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseMoveEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Enter Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseEnterEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Leave Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseLeaveEventHandler(callback: AbruptMouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Click Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseClickEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Double Click Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseDoubleClickEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Down Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseDownEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Up Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseUpEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Wheel Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseWheelEventHandler(callback: MouseWheelEventHandler<this>): this;
    /**
     * Set handler for Mouse ContextMenu Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseContextMenuEventHandler(callback: MouseEventHandler<this>): this;
    /**
     * Set handler for Mouse Drag Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseDragEventHandler(callback: MouseDragEventHandler<this>): this;
    /**
     * Set handler for Mouse Drag Start Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseDragStartEventHandler(callback: MouseDragStartEventHandler<this>): this;
    /**
     * Set handler for Mouse DragRelease Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setMouseDragStopEventHandler(callback: MouseDragEventHandler<this>): this;
    /**
     * Set handler for Touch Start Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setTouchStartEventHandler(callback: TouchEventHandler<this>): this;
    /**
     * Set handler for Touch Move Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setTouchMoveEventHandler(callback: TouchEventHandler<this>): this;
    /**
     * Set handler for Touch End Event
     * @param callback Event listener
     * @return     Entity itself for fluent interface
     */
    setTouchEndEventHandler(callback: TouchEventHandler<this>): this;
}
/**
 * Class extension for 2D Entities.
 */
export declare abstract class Entity2D<T extends Engine = Engine> extends Entity<T> {
}
/**
 * Collection of Entities inside the same viewport.
 *
 * Handles event propagation and isOver checks.
 *
 * Common superclass for 2D and 3D Layers.
 *
 * @hidden  Internal class
 */
declare abstract class Layer<S extends Engine, E extends Entity<S> = Entity<S>> extends Element<S> {
    readonly _engine: S;
    private readonly _zIndex;
    /**
     * @param   _engine     Rendering engine
     * @param   _zIndex     Z index of Layer. Specifies position in rendering and mouse picking order.
     */
    constructor(_engine: S, _zIndex: number);
}
/**
 * Collection of 2D Entities inside the same viewport AND Z-index.
 *
 * Implements 2D isOver logic. (Currently 2D and 3D use same logic, might be optimizable by separating them)
 *
 * @hidden  Internal class
 */
export declare abstract class Layer2D<S extends Engine> extends Layer<S, Entity2D<S>> {
}
/**
 * Class extension for 3D Entities.
 */
export declare abstract class Entity3D<T extends Engine = Engine, LayerType extends Layer3D<T> = Layer3D<T>> extends Entity<T> {
    readonly _layer: LayerType;
    /**
     * @param   _layer              Rendering layer. 3D Entities need Layer to compute 3D projections in mouse-picking.
     * @param   _remove             Remove handler
     * @param   _restore            Restore handler
     */
    constructor(_layer: LayerType, _remove: RemoveHandler<Entity<T>>, _restore: RestoreHandler<Entity<T>>);
}
/**
 * Collection of 3D Entities inside the same viewport.
 *
 * Implements 3D isOver logic. (Currently 2D and 3D use same logic, might be optimizable by separating them)
 *
 * @hidden  Internal class
 */
export declare abstract class Layer3D<S extends Engine = Engine> extends Layer<S, Entity3D<S>> {
    readonly _scale: Vec3<UnitScale>;
    /**
     * @param   _engine     Rendering engine
     * @param   _zIndex     Z index of Layer. Specifies position in rendering and mouse picking order.
     * @param   _scale      Rendering scale for all Shapes inside Layer.
     *                      All shapes inside a 3D layer must have the same scale, for proper mouse picking.
     */
    constructor(_engine: S, _zIndex: number, _scale: Vec3<UnitScale>);
    /**
     * Set Camera location in Scene3D.
     * @param   cameraLocation  Camera location in 3D Space.
     * @return                  Object itself for fluent interface
     */
    setCameraLocation(cameraLocation: Point3D): this;
    /**
     * Get Camera location in Scene3D.
     * @return                  Camera location in 3D Space.
     */
    getCameraLocation(): Point3D;
    /**
     * Set Camera direction in Scene3D.
     * @param   cameraDirection Camera direction in 3D Space. Will be normalized.
     * @return                  Object itself for fluent interface
     */
    setCameraDirection(cameraDirection: Point3D): this;
    /**
     * Get Camera direction in Scene3D.
     * @return                  Camera direction in 3D Space.
     */
    getCameraDirection(): Point3D;
    /**
     * Set location of Light source.
     * @param   lightLocation       Location of light source in 3D Space.
     * @return                      Object itself for fluent interface
     */
    setLightLocation(lightLocation: Point3D): this;
    /**
     * Get location of Light source.
     * @return                      Location of light source in 3D Space.
     */
    getLightLocation(): Point3D | undefined;
    /**
     * Set power of Light source.
     * @param   lightPower          Power of light source in 3D Space.
     *                              Reference value range [0, 100]
     * @return                      Object itself for fluent interface
     */
    setLightPower(lightPower: number): this;
    /**
     * Get power of Light source.
     * @return                      Power of light source in 3D Space.
     */
    getLightPower(): number | undefined;
    /**
     * Set color of Light source.
     * @param   lightColor          Color of light source.
     * @return                      Object itself for fluent interface
     */
    setLightColor(lightColor: Color): this;
    /**
     * Get color of Light source.
     * @return                      Color of light source in 3D Space.
     */
    getLightColor(): Color | undefined;
}
/**
 * Interface that specifies flags that can be used to modify behaviour of mouse picking per 3D entity.
 *
 * This is used for mouse picking optimizations.
 * @hidden
 */
export interface MousePickingFlags3D {
    /**
     * When *overrideFollowing* is true:
     * - Entity doesn't solve nearest collision location, but instead takes the first collision as is.
     * - If a collision is found from the Entity, any other Entities of the Layer are not checked for closer collisions.
     */
    overrideFollowing?: boolean;
    /**
     * When *skipMousePicking* is true:
     * - Entity mouse picking is skipped.
     *
     * This behaves exactly like setting mouse interactions enabled on an Entity. The purpose behind this is, that
     * this doesn't affect any optimizations done in Shape rendering logic that might be based on mouse interactions being enabled.
     * This flag can be toggled on/off without any fear of it having performance effects.
     */
    skipMousePicking?: boolean;
}
export {};
/**
 * WebGL implementation of Text object in 2D space.
 * This object uses Offscreen Canvas for rendering Text to Texture.
 * Internal class
 */
export declare class GlText extends Text<GlEngine> {
    /**
     * @param engine  Rendering engine
     * @param scale   Scale of the Shape's space
     * @param remove  Injected method to remove the shape from layer.
     * @param restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: GlEngine, scale: Vec2<Scale>, remove: RemoveHandler<GlText>, restore: RestoreHandler<GlText>);
}
/**
 * Implementation of Layer2D for GlEngine.
 *
 * @hidden  Internal class
 */
export declare class GlLayer2D extends Layer2D<GlEngine> implements XY<GlEngine> {
    readonly gl: GlUtils;
    /**
     * @param engine Rendering engine. NOTE: Layer must NOT cache the actual engine!
     * @param zIndex Depth index of the layer
     */
    constructor(engine: GlEngine, zIndex: number);
}
/**
 * Implementation of Layer3D for GlEngine.
 * *
 * @hidden Internal class.
 */
export declare class GlLayer3D extends Layer3D<GlEngine> implements XYZ<GlEngine> {
    readonly gl: GlUtils;
    /**
     * @param   engine      Rendering engine. NOTE: Layer must NOT cache the actual engine!
     * @param   zIndex      Depth index of the layer
     * @param   _scale      Rendering scale for all Shapes inside Layer.
     *                      All shapes inside a 3D layer must have the same scale, for proper mouse picking.
     */
    constructor(engine: GlEngine, zIndex: number, _scale: Vec3<UnitScale>);
}
export declare class GlEngine extends Engine {
    /**
     * @param options               EngineOptions
     * @param GlUtilsConstructor    Injection of GlUtils constructor
     */
    constructor(options?: EngineOptions, GlUtilsConstructor?: typeof GlUtils);
}
/**
 * High level api for WebGL handling
 * @hidden Internal class
 */
export declare class GlUtils {
    readonly gl: WebGLRenderingContext;
    constructor(gl: WebGLRenderingContext, enableAlphaBlending?: boolean);
}
export declare type WebGLDrawMode = number;
export declare class Uniforms {
}
/**
 * Helper class for grouping 3D Scale Uniform values.
 */
export declare class Uniforms3D {
}
/**
 * Internal webgl helper class for rendering offscreen (into Framebuffer to Texture).
 *
 * NOTE: WebGL Framebuffer has a full support of all browsers.
 * Framebuffer can be created with null, only based of Hardware Limitations / GPU Memory
 * @hidden Internal class
 */
export declare class GLOffscreenHelper {
    private _glUtils;
    /**
     * Create offscreen renderer helper.
     * Rendering to Texture using Framebuffer.
     * @param _glUtils WebGL utils.
     */
    constructor(_glUtils: GlUtils);
}
/**
 * Request object to specify the LUT and its Texture for rendering.
 * Each represented as a pair object {lut: LUT, texture: Texture}.
 * @hidden
 */
export interface LUTRequest {
    readonly lut: LUT;
    readonly texture?: WebGLTexture | null;
}
/**
 * Class to control the shared LUTs results (Textures of LUTs) within the rendering engine.
 * Rendering Engine contains shapes accepts Palette fillstyles, which contains LUT for Paletting.
 * The same fillstyle can be shared between multiple engine shapes.
 * The following class helps to optimize the rendering, preventing unnecessary drawing of a LUT to Texture.
 * @hidden
 */
export declare class SharedLUTs {
    private _gl;
    constructor(_gl: WebGLRenderingContext);
}
/**
 * Factory to initialize a storage of shared LUTs.
 * @returns Shared LUTs object.
 * @hidden
 */
export declare const SharedLuts: (gl: WebGLRenderingContext) => SharedLUTs;
/**
 * Vertex Shader type enumerator
 */
export declare enum VertexShaderType {
    Basic = "Basic",
    BasicInstanced = "BasicInstanced",
    PointSize = "PointSize",
    Texture = "Texture",
    PointSizePointColor = "PointSizePointColor",
    PointColor = "PointColor",
    PointColorInstanced = "PointColorInstanced",
    Paletted = "Paletted",
    /**
     * Gouraud shading.
     */
    Gouraud3D = "Gouraud3D",
    /**
     * Gouraud shading, with thickness scaled in shader.
     */
    Gouraud3DThickness = "Gouraud3DThickness",
    /**
     * Phong shading.
     */
    Phong3D = "Phong3D",
    /**
     * Phong shading, with thickness scaled in shader.
     */
    Phong3DThickness = "Phong3DThickness",
    /**
     * 3D points without normals / shading, with uniform size.
     */
    PointSize3D = "PointSize3D"
}
/**
 * Fragment Shader type enumerator
 */
export declare enum FragmentShaderType {
    Basic = "Basic",
    Texture = "Texture",
    PointColor = "PointColor",
    Paletted = "Paletted",
    Phong3D = "Phong3D"
}
export declare enum GeneratedShaderType {
    RadialGradient = "GRadialGradient",
    LinearGradient = "GLinearGradient",
    RadialGradientText = "GRadialGradientText",
    LinearGradientText = "GLinearGradientText"
}
/**
 * Abstract class for WebGL Shader
 * @property   shaderType  Shader type enum value
 * @property   shader      WebGL shader
 * @property   gl          WebGL context
 * Internal class
 */
declare abstract class ShaderStage {
    readonly shaderType: VertexShaderType | FragmentShaderType | GeneratedShaderType;
    readonly shader: WebGLShader | null;
    readonly gl: WebGLRenderingContext;
    /**
     * @param source        Shader source code
     * @param shaderType    Shader type enum value
     * @param shader        WebGL shader
     * @param gl            WebGL context
     */
    constructor(source: string | undefined, shaderType: VertexShaderType | FragmentShaderType | GeneratedShaderType, shader: WebGLShader | null, gl: WebGLRenderingContext);
}
/**
 * WebGL Vertex Shader
 * Internal class
 */
declare class VertexShader extends ShaderStage {
    /**
     * @param shaderType    Shader type enum value
     * @param gl            WebGL context
     */
    constructor(shaderType: VertexShaderType, gl: WebGLRenderingContext);
}
/**
 * WebGL Fragment Shader
 * Internal class
 */
declare class FragmentShader extends ShaderStage {
    /**
     * @param shaderType    Shader type enum value
     * @param gl            WebGL context
     */
    constructor(shaderType: FragmentShaderType, gl: WebGLRenderingContext);
}
/**
 * Shader Program representation
 * @property    vertex      WebGL Vertex Shader
 * @property    fragment    WebGL Fragment Shader
 * @property    gl          WebGL context
 * @property    shader      WebGL Shader Program
 * Internal class
 */
export declare class Shader {
    readonly _gl: WebGLRenderingContext;
    readonly _shader: WebGLProgram | null;
    /**
     * @param _vertex    WebGL Vertex Shader
     * @param _fragment  WebGL Fragment Shader
     * @param _gl        WebGL context
     * @param _shader    WebGL Shader Program
     */
    constructor(_vertex: VertexShader, _fragment: FragmentShader, _gl: WebGLRenderingContext, _shader?: WebGLProgram | null);
}
/**
 * Create Shader Factory
 * @param   gl  WebGL Context
 */
export declare const Shaders: (gl: WebGLRenderingContext) => (vertType: VertexShaderType, fragType: FragmentShaderType) => Shader;
/**
 * Generate shader from a generated shader.
 *
 * Shaders are cached to a map to reduce the amount of shader generation
 * @param gl WebGL Rendering context
 */
export declare const GenerateShader: (gl: WebGLRenderingContext) => (vertType: VertexShaderType | GeneratedShaderType, fragType: FragmentShaderType | GeneratedShaderType, fillStyle: FillStyle<any>) => Shader;
export {};
/**
 * File contains utilities for implementation of touch event interactions.
 */
export {};
/**
 * XY API for Layer.
 */
export declare type LayerXY<S extends Engine = Engine> = Layer2D<S> & XY<S>;
/**
 * XY API for Engine.
 */
export interface XY<T extends Engine> {
}
/**
 * Interface for a single part of a renderable object.
 *
 * Rendered objects are split into segments according to Integer index limitations.
 */
export interface Segment<VerticesList> {
}
/**
 * Interface for a type of Segment that can be connected to another one (eq. Line).
 *
 * Adds methods for managing Joint points properly.
 */
export interface ConnectableSegment<VerticesList> extends Segment<VerticesList> {
}
/**
 * Interface for Shape with a multiple points located in certain boundaries.
 */
export interface Region {
}
/**
 * Any kind of 2D objects.
 * @property    engine  Rendering Engine for XY.
 * @property    scale   X and Y Scale of the Shape's space.
 * Internal class
 */
export declare abstract class Shape<T extends Engine = Engine> extends Entity2D<T> {
    readonly _engine: T;
    protected readonly _scale: Vec2<Scale>;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(_engine: T, _scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class for all types of shapes, which intends to have different fill style property.
 * @property    fillStyle       Fill style object, stored inside validatable container and defines how the 2D primitive is drawn.
 * Internal class
 */
export declare abstract class FilledShape<T extends Engine = Engine> extends Shape<T> {
    readonly _engine: T;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(_engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class for all types of shapes, which intends to have different line style property. Requires extra draw calls for border.
 * @property    lineStyle     Line style object, stored inside validatable container and
 *                            defines how the Border of 2D primitive is drawn.
 * Internal class
 */
export declare abstract class StyledShape<T extends Engine = Engine> extends FilledShape<T> {
    readonly _engine: T;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(_engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/****************** Sizable Shapes ******************/
/**
 * Abstract class for all types of shapes, which have size property
 * @property    size   Size of the shape stored inside validatable container as a number to keep track of changes
 * Internal class
 */
export declare abstract class SizableShape<T extends Engine> extends FilledShape<T> {
    readonly size: Val<number>;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     * @param   size     Size of Shape, stored inside validatable container as a number to keep track of changes
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>, size?: Val<number>);
}
/**
 * Text object in 2D space
 * @property    text        Text is a string which is stored as validatable container to keep track of its changes
 * @property    position    Position of the text in world coordinates stored as validatable container to keep track of changes
 * @property    font        Font of the text is stored as validatable container to keep track of changes
 * Internal class
 */
export declare abstract class Text<T extends Engine = Engine> extends FilledShape<T> {
    readonly font: ValConstructor<any>;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the shape from layer.
     * @param   font     Font of the text
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>, font?: ValConstructor<any>);
}
/**
 * Abstract class for a mutable set of points
 * @property    shape       The shape of points to draw ("Square", "Circle", "Triangle")
 * Internal class
 */
export declare abstract class PointSet<T extends Engine = Engine> extends SizableShape<T> implements Region, Segment<Point[] | ColorPoint[]> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     * @param   size     Optional parameter to set the size of each point
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>, size?: number);
}
/**
 * Abstract class is used to create a rectangle and variations of a rectangle shape
 * @property    position   The coordinates of Top-Left corner.
 * @property    size       X - the width of the rectangle, Y - the height of the rectangle.
 * @property    rotation   Rectangle rotation in degree
 * @property    origin     Rotation origin
 * Internal class
 */
export declare abstract class Rect<T extends Engine = Engine> extends StyledShape<T> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract Polygon class.
 * Internal class
 */
export declare abstract class Polygon<T extends Engine = Engine> extends StyledShape<T> {
}
/**
 * Abstract class is used to create a convex polygon
 * Internal class
 */
export declare abstract class ConvexPolygon<T extends Engine> extends Polygon<T> {
}
/**
 * Abstract class is used to create a simple polygon (never intersect itself)
 * Internal class
 */
export declare abstract class SimplePolygon<T extends Engine> extends Polygon<T> {
}
/**
 * Abstract class is used to create a complex polygon
 * Internal class
 */
export declare abstract class ComplexPolygon<T extends Engine> extends Polygon<T> {
}
/**
 * Abstract class for a mutable Junction.
 * Internal class
 */
export declare abstract class Junction<T extends Engine = Engine> extends FilledShape<T> implements Region, ConnectableSegment<[Point[], Point[]]> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class is used to create an arc.
 * @property position       The middle point of the circle containing the arc
 * @property begin          Beginning angle of the arc (0 - 360 degrees)
 * @property end            Ending angle of the arc (0 - 360 degrees)
 * @property outerRadius    Radius of the arc's outer side in pixels
 * @property innerRadius    Radius of the arc's inner side in pixels
 * Internal class
 */
export declare abstract class Arc<T extends Engine = Engine> extends StyledShape<T> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Enum defines type of Polygon at factory
 */
export declare enum PolygonType {
    Complex = 0,
    Simple = 1,
    Convex = 2
}
/**
 * Abstract class for all types of lines
 * @property    thickness   Thickness of the line stored inside validatable container as a number to keep track of changes
 * Internal class
 */
export declare abstract class LineLike<T extends Engine> extends Shape<T> {
    readonly engine: T;
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class for a single line
 * Internal class
 */
export declare abstract class Line<T extends Engine = Engine> extends LineLike<T> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class for a line collection
 * Internal class
 */
export declare abstract class LineCollection<T extends Engine = Engine> extends LineLike<T> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Abstract class for a mutable set of lines
 * Internal class
 */
export declare abstract class LineSet<T extends Engine = Engine> extends LineLike<T> implements Region, ConnectableSegment<Point[]> {
    /**
     * @param   engine   Rendering engine
     * @param   scale    Scale of the Shape's space
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
    /**
     * @return  Point bounds of the data set
     */
    abstract getPointsBounds(): Interval<Point>;
}
/**
 * The shape contains common implementation for grid-like shapes, e.g. IntensityGrid and IntensityMesh.
 * For the following shapes the rows and columns should be defined
 * to simplify the pre-allocation to store the data-matrix, as well as
 * to apply other Rendering & Memory optimization techniques to efficiently update the shape.
 *
 * ***Possible shapes:***
 * - Grid has a fixed rectangular topology structure is represented as an array of squares or rectangles of equal size.
 * - Mesh has a flexible topology structure is represented as an array of 4-points polygons.
 * Mesh can also be visualized as a grid with squares or rectangles of equal size cells.
 *
 * Extends StyledShape class contains FillStyle, StrokeStyle setters and getters.
 * FillStyle is used to fill the IntensityShape, e.g. None, Paletted, etc.
 * StrokeStyle is used to colorize the Wireframe of the IntensityShape.
 * Requires two draw calls: IntensityShape and Wireframe drawing.
 * Internal class.
 */
export declare abstract class Intensity<T extends Engine = Engine> extends FilledShape<T> implements Region {
    readonly engine: T;
    /**
     * @param   engine   Rendering engine.
     * @param   scale    Scale of the Shape's space.
     * @param   _remove  Injected method to remove the shape from layer.
     * @param   _restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: T, scale: Vec2<Scale>, _remove: RemoveHandler<Entity>, _restore: RestoreHandler<Entity>);
}
/**
 * Type that combines 3D Layer and its supported rendering capabilities.
 */
export declare type LayerXYZ<S extends Engine = Engine> = Layer3D<S> & XYZ<S>;
/**
 * Interface that defines the supported capabilities of the prototype 3D rendering Layer.
 */
export interface XYZ<T extends Engine> {
}
/**
 * Interface for Shape with a multiple points located in certain boundaries
 */
export interface Region3D extends Region {
}
/**
 * Abstract base class for a 3D Shape.
 *
 * @hidden  Internal class
 */
export declare abstract class Shape3D<T extends Engine = Engine, LayerType extends Layer3D<T> = Layer3D<T>> extends Entity3D<T, LayerType> {
    protected readonly _optimizationFlag: ShapeOptimizationFlag3D;
    /**
     * @param   _layer              Rendering layer. 3D Entities need Layer to compute 3D projections in mouse-picking.
     * @param   _remove             Remove handler
     * @param   _restore            Restore handler
     */
    constructor(_layer: LayerType, _remove: RemoveHandler<Entity<T>>, _restore: RestoreHandler<Entity<T>>, _optimizationFlag: ShapeOptimizationFlag3D);
}
/**
 * Interface that specifies options that allow Shape3D optimizations for different usage cases.
 */
export declare enum ShapeOptimizationFlag3D {
    /**
     * As stable performance as possible. Not really necessary, but might be useful for debugging.
     */
    Normal = 0,
    /**
     * Shape can be optimized for a minimal vertex number.
     */
    SmallShape = 1,
    /**
     * All the optimizations.
     */
    Dynamic = 2
}
/**
 * Type union of Point Styles supported by PointSet3D.
 * @hidden
 */
export declare type PointSetStyle3D = TriangulatedPoints3D | PixelatedPoints3D;
/**
 * @hidden
 */
export interface PointSet3D<T extends Engine = Engine> extends Shape3D<T>, Region3D, Segment<Point3D[]> {
}
/**
 * @hidden
 */
export interface LineSet3D<T extends Engine = Engine> extends Shape3D<T>, Region3D, ConnectableSegment<Point3D[]> {
}
/**
 * Interface for progressive packager
 */
export interface ColumnPackager {
    /**
     * Type of column packaging
     */
    type: 'horizontalProgressive' | 'horizontalRegressive' | 'verticalProgressive' | 'verticalRegressive' | 'disabled';
    /**
     * Function type for column packager
     * @param vertices         Array of vertices
     * @param pixelSize        Pixel size
     * @param thickness        Line thickness
     * @return                 Packed array
     */
    packager: (vertices: Point[], pixelSize: Point, thickness: number) => Point[];
}
/**
 * Class keep track of private state's validation status by invalid flag.
 */
export declare class Validator {
}
/**
 * Generic container keeps track of private state's validation status by invalid flag.
 * Enclosed object is only accessible via getter and setter
 * @property    value   internal state
 */
export declare class ValConstructor<T> extends Validator {
    private _value;
    /**
     * @param _value     Value which has to be placed at the container
     * @param isInvalid State of value
     */
    constructor(_value: T, isInvalid: boolean);
}
/**
 * Type requirement for class that can be used with HighlightableValue.
 * @hidden
 */
export interface HighlightableType {
    /**
     * Creates default highlight style based on object itself
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Class that is a container for some value that can have both normal & highlighted values.
 * Handles automatic computation of default highlight value when needed.
 * @hidden
 */
export declare class HighlightableValue<T extends HighlightableType> {
    /**
     * @param   initNormal      Initial value for normal state
     * @param   initHighlighted Initial value for highlighted state
     */
    constructor(initNormal: T, initHighlighted?: T);
}
/**
 * @hidden
 * Internal class
 */
export declare class PanelError extends Error {
    constructor(m: string, owner?: any);
}
/**
 * @hidden
 * Internal class
 */
export declare class AxisError extends Error {
    constructor(m: string, owner?: any);
}
/**
 * @hidden
 * Internal class
 */
export declare class EngineError extends Error {
    constructor(m: string, owner?: any, riseAlert?: boolean);
}
/**
 * @hidden
 * Internal class
 */
export declare class ShaderError extends EngineError {
    constructor(m: string);
}
/**
 * @hidden
 * Internal class
 */
export declare class UnImplementedError extends Error {
    constructor(name: string);
}
/**
 * move to common/interfaces.
 * use for Point
 */
export interface Vec2<T> {
    readonly x: T;
    readonly y: T;
}
/**
 * Type definition of a generic 3-dimensional Vector datastructure.
 */
export interface Vec3<T> {
    readonly x: T;
    readonly y: T;
    readonly z: T;
}
/**
 * internal/interfaces
 */
export interface MVec2<T> {
    x: T;
    y: T;
}
/**
 * Type definition of a mutable, generic 3-dimensional Vector datastructure.
 */
export interface MVec3<T> {
    x: T;
    y: T;
    z: T;
}
/**
 * internal/interfaces
 */
export declare type MPoint = MVec2<number>;
/**
 * Factory for Points. Should be used whenever creating immutable Vec2<numbers>.
 *
 * Not currently exported to users, since it doesn't give any benefit - might be very nice after we add recycling logic, which is
 * designed to be added HERE.
 * @param   x   X value
 * @param   y   Y value
 * @return      Immutable Point data-structure
 */
export declare const point: (x: number, y: number) => Point;
/**
 * Factory for Immutable Points. This is used in a few places around the library,
 * but not very much. It is premature optimization, and would ideally not exist at this point in time.
 *
 * @param   x   X value
 * @param   y   Y value
 * @return      Mutable Point data-structure
 */
export declare const mPoint: (x: number, y: number) => MPoint;
/**
 * Factory for Colored Points.
 *
 * Not currently exported to users, but might be in future.
 * @param   x       X value
 * @param   y       Y value
 * @param   color   Color value
 * @return          Immutable ColorPoint datastructure
 */
export declare const colorPoint: (x: number, y: number, color: Color) => ColorPoint;
/**
 * Factory for Area Points.
 *
 * Not currently exported to users, but might be in future.
 * @param   position    Position value
 * @param   high        High value
 * @param   low         Low value
 * @return              Immutable AreaPoint datastructure
 */
export declare const areaPoint: (position: number, high: number, low: number) => AreaPoint;
/**
 * Factory for 3D Points. Should be used whenever creating immutable Vec3<numbers>.
 *
 * @param   x   X value
 * @param   y   Y value
 * @param   z   Z value
 * @return      Immutable Point3D datastructure
 */
export declare const point3D: (x: number, y: number, z: number) => Point3D;
/**
 * Factory for **mutable** 3D Points.
 *
 * @param   x   X value
 * @param   y   Y value
 * @param   z   Z value
 * @return      **Mutable** Point3D datastructure
 */
export declare const mPoint3D: (x: number, y: number, z: number) => MVec3<number>;
/**
 * Convert array points for Junction into an object with two arrays of Vec2 for High and Low points respectively.
 * @param areaPoints   Array of area points with X-coordinate and double Y-coordinates.
 */
export declare const areaPoint2PointArrays: (areaPoints: AreaPoint[]) => [Point[], Point[]];
/**
 * Factory for Interval
 * @param   min     Start of interval
 * @param   max     End of interval
 * @return          Immutable Interval datastructure
 */
export declare const interval: <T>(min: T, max: T) => Interval<T>;
/**
 * Factory for rectangular area in cartesian coordinates
 * @param x      X position of the area
 * @param y      Y position of the area
 * @param width  Width of the area
 * @param height Height of the area
 */
export declare const area: (x: number, y: number, width: number, height: number) => {
    x: number;
    y: number;
    width: number;
    height: number;
};
/**
 * Factory for Val
 * @param    value      Internal state
 * @param    isInvalid  Validness state
 */
export declare const val: <T>(value: T, isInvalid?: boolean) => ValConstructor<T>;
/**
 * Factory for creating mutable margin-datastructures.
 * @param   left    Left margin in pixels. Defaults to 0
 * @param   top     Top margin in pixels. Defaults to 0
 * @param   right   Right margin in pixels. Defaults to 0
 * @param   bottom  Bottom margin in pixels. Defaults to 0
 * @return          Mutable margin-datastructure
 */
export declare const mmargin: (left?: number, top?: number, right?: number, bottom?: number) => MMargin;
/**
 * Factory for creating Margin data-structures, which combine four numeric values by sides:
 * - left
 * - top
 * - right
 * - bottom
 *
 * Functionally equal to padding.
 * @param   left    Left margin in pixels or 0 if omitted/undefined.
 * @param   top     Top margin in pixels or 0 if omitted/undefined.
 * @param   right   Right margin in pixels or 0 if omitted/undefined.
 * @param   bottom  Bottom margin in pixels or 0 if omitted/undefined.
 * @return          Margin
 */
export declare const margin: (left?: number, top?: number, right?: number, bottom?: number) => Margin;
/**
 * Factory for creating Padding data-structures, which combine four numeric values by sides:
 * - left
 * - top
 * - right
 * - bottom
 *
 * Functionally equal to margin.
 * @param   left    Left margin in pixels or 0 if omitted/undefined.
 * @param   top     Top margin in pixels or 0 if omitted/undefined.
 * @param   right   Right margin in pixels or 0 if omitted/undefined.
 * @param   bottom  Bottom margin in pixels or 0 if omitted/undefined.
 * @return          Padding
 */
export declare const padding: (left?: number | undefined, top?: number | undefined, right?: number | undefined, bottom?: number | undefined) => Margin;
/**
 * Utility function for creating a new Margin based on two others.
 * Override a Margin datastructure with another.
 *
 * Functionally equal to overridePadding.
 * @param   previous    Existing Margin object
 * @param   override    Partial Margin object containing all properties/values to be overridden
 * @return              New Margin object that is same as 'previous', but with values overridden by those of 'override'
 */
export declare const overrideMargin: (previous: Margin, override: Partial<Margin>) => Margin;
/**
 * Utility function for creating a new Margin based on two others.
 * Override a Margin datastructure with another.
 *
 * Functionally equal to overrideMargin.
 * @param   previous    Existing Padding object
 * @param   override    Partial Padding object containing all properties/values to be overridden
 * @return              New Padding object that is same as 'previous', but with values overridden by those of 'override'
 */
export declare const overridePadding: (previous: Margin, override: Partial<Margin>) => Margin;
/**
 * Radial gradient rendering information
 */
export interface RadialGradientGLInfo {
    /**
     * Gradient Area boundaries
     */
    bounds: [number, number, number, number];
    /**
     * Distance from the selected extent
     */
    distance: [number, number];
    /**
     * Position of the Gradient center
     */
    center: [number, number];
    /**
     * Aspect ratio of the Gradient Area
     */
    aspectRatio: number;
}
/**
 * Rendering information for Linear gradient fragment shader
 */
export interface LinearGradientGLInfo {
    /**
     * Gradient Area Boundaries
     */
    bounds: [number, number, number, number];
    /**
     * Gradient Line starting point
     */
    startPoint: [number, number];
    /**
     * Gradient Line ending point
     */
    endPoint: [number, number];
}
/**
 * Generic Interval
 * @property    min   Start of interval
 * @property    max   End of interval
 */
export interface Interval<T> {
    readonly min: T;
    readonly max: T;
}
/**
 * Generic mutable Interval
 * @property    min   Start of interval
 * @property    max   End of interval
 */
export interface MInterval<T> {
    min: T;
    max: T;
}
/**
 * Rectangular area in cartesian coordinates
 * @property x      X position of the area
 * @property y      Y position of the area
 * @property width  Width of the area
 * @property height Height of the area
 */
export interface Area {
    x: number;
    y: number;
    width: number;
    height: number;
}
/**
 * Generic container keeps track of private state's validation status by invalid flag.
 * Enclosed object is only accessible via getter and setter
 * @property    value   internal state
 */
export declare type Val<T> = ValConstructor<T>;
/**
 * Interface for a mutable margin-datastructure.
 */
export interface MMargin {
    left: number;
    top: number;
    right: number;
    bottom: number;
}
/**
 * Interface for a generic *Ray*.
 *
 * A ray is composed of a location and direction.
 * @hidden
 */
export interface Ray<T> {
    /**
     * Point somewhere along the Ray.
     */
    origin: T;
    /**
     * Direction of the Ray.
     */
    direction: T;
}
/**
 * Interface defines methods for invalidation and validation of private state
 */
export interface Validatable {
}
/**
 * An abstract event subscription interface.
 *
 * Can be used just like Eventer, but without the need to specify the event identifier. This is useful, when
 * the event interface is injected into a component, and the component doesn't really need to know about the implementation specifics.
 */
export interface AbstractEventInterface<T extends any[] = any[]> {
    /**
     * Subscribe to the abstract event.
     * @param   listener    Callback function that is called when the event is triggered.
     * @return              Token that can be used to unsubscribe from the event.
     */
    on: (listener: (args: T) => void) => Token;
    /**
     * Unsubscribe from the abstract event.
     * @param   token       Token that was received when **on()** was called.
     * @return              True if the listener is successfully removed and false if it is not found.
     */
    off: (token: Token) => boolean;
}
/**
 * Utility function for abstracting a single topic from an Eventer.
 * @param   eventer     Eventer
 * @param   topic       Topic of event (eq. 'resize', 'whatever').
 * @return              AbstractEventInterface for pub/sub capabilities over this single topic.
 */
export declare const abstractEventInterface: <T extends any[] = any[]>(eventer: Eventer, topic: string) => AbstractEventInterface<T>;
/**
 * Pointer event interface with extra information
 */
export interface ExtendedPointerEvent extends PointerEvent {
    /**
     * All current interaction locations
     */
    interactions: Point[];
}
export {};
/**
 * Type definition for 4x4 number Matrix (flattened Array).
 */
export declare type Matrix4 = number[];
/**
 * Collection of 4x4 number Matrix utility methods.
 */
export declare const m4: {
    translation(tx: number, ty: number, tz: number): number[];
    xRotation(angleInRadians: number): number[];
    yRotation(angleInRadians: number): number[];
    zRotation(angleInRadians: number): number[];
    scaling(sx: number, sy: number, sz: number): number[];
    translate(m: Matrix4, tx: number, ty: number, tz: number): number[];
    xRotate(m: Matrix4, angleInRadians: number): number[];
    yRotate(m: Matrix4, angleInRadians: number): number[];
    zRotate(m: Matrix4, angleInRadians: number): number[];
    scale(m: Matrix4, sx: number, sy: number, sz: number): number[];
    multiply(a: Matrix4, b: Matrix4): number[];
    inverse(m: Matrix4): Matrix4;
    /**
     * Create 4x4 Matrix for a perspective projection.
     */
    projectionPerspective(fovDeg: number, aspectRatio: number, near: number, far: number): Matrix4;
    /**
     * Create 4x4 Matrix for a orthographic projection.
     */
    projectionOrthographic(left: number, right: number, bottom: number, top: number, near: number, far: number): Matrix4;
};
/**
 * Container class for a value that can be observed.
 * (event which is triggered when value is set)
 * Internal class
 */
export declare class ObservableValue<T> {
    private _value;
    /**
     * @param   _value   Initial value
     */
    constructor(_value: T);
}
/**
 * Decorator for a remove handler function.
 * Calling this indicates that reference to passed object should be removed.
 */
export declare type RemoveHandler<T> = (obj: T) => void;
/**
 * Decorator for a restore handler function.
 * Calling this indicates that reference to passed object should be restored.
 */
export declare type RestoreHandler<T> = (obj: T) => void;
export declare type BoundaryCorner<T> = (boundary: Interval<Vec2<T>>) => T;
declare type Vec3f = Vec3<number>;
/**
 * Collection of math utilities for numeric Vec3s.
 * @hidden
 */
export declare const _vec3f: {
    add(v1: Vec3f, v2: Vec3f): Vec3f;
    subtract(v1: Vec3f, v2: Vec3f): Vec3f;
    multiply(v: Vec3f, multiplier: number): Vec3f;
    divide(v: Vec3f, divisor: number): Vec3f;
    multiplyVec(v1: Vec3f, v2: Vec3f): Vec3f;
    divideVec(v1: Vec3f, v2: Vec3f): Vec3f;
    length(v: Vec3f): number;
    normalize(v: Vec3f): Vec3f;
    dot(v1: Vec3f, v2: Vec3f): number;
    cross(v1: Vec3f, v2: Vec3f): Vec3f;
    /**
     * @returns     Radian angle between v1 and v2.
     */
    angle(v1: Vec3f, v2: Vec3f): number;
    /**
     * Rotate vector around another arbitrary axis, by amount 'theta' in radians.
     * @param   v       Vector to rotate
     * @param   axis    Vector of arbitrary rotation axis
     * @param   theta   Rotation amount in radians
     */
    rotateAroundAxis(v: Vec3f, axis: Vec3f, theta: number): Vec3f;
};
export {};
/**
 * File contains internal default style factories for all of library.
 * These are also intended to be public so user can easily replicate them and perhaps mutate them somehow in the future.
 */
/**
 * Collection of some useful cursor styles.
 *
 * Uses HTML DOM Style cursor property, so supported values are specified by browser.
 *
 * https://www.w3schools.com/jsref/prop_style_cursor.asp
 *
 * Use with [[UIElement.setMouseStyle]]
 */
export declare enum MouseStyles {
    Move = "move",
    ResizeColumn = "col-resize",
    ResizeRow = "row-resize",
    Horizontal = "ew-resize",
    Vertical = "ns-resize",
    NorthWest = "nw-resize",
    NorthEast = "ne-resize",
    Copy = "copy",
    CrossHair = "crosshair",
    Default = "default",
    Help = "help",
    Restricted = "not-allowed",
    None = "none",
    Point = "pointer",
    Text = "text",
    Wait = "wait",
    ZoomIn = "zoom-in",
    ZoomOut = "zoom-out"
}
/**
 * Collection of fast-access *arguments* for [[UIElement.setOrigin]]
 */
export declare const UIOrigins: {
    LeftBottom: Point;
    CenterBottom: Point;
    RightBottom: Point;
    LeftCenter: Point;
    Center: Point;
    RightCenter: Point;
    LeftTop: Point;
    CenterTop: Point;
    RightTop: Point;
};
/**
 * A [[SolidFill]] singleton for a completely transparent fill.
 * Can be useful in at least following cases:
 *
 * 1) User wants to hide something but still have it interactable by mouse/touch
 *
 * 2) User wants to hide something that does not support [[emptyFill]]
 *
 * Otherwise, [[emptyFill]] should be preferred for better performance.
 */
export declare const transparentFill: SolidFill;
/**
 * A [[SolidLine]] singleton for a completely transparent line.
 * Can be useful in at least following cases:
 *
 * 1) User wants to hide something but still have it interactable by mouse/touch
 *
 * 2) User wants to hide something that does not support [[emptyFill]]
 *
 * Otherwise, [[emptyLine]] should be preferred for better performance.
 */
export declare const transparentLine: SolidLine<SolidFill>;
/**
 * Interface which supplies library components with their default styles.
 * @hidden
 */
export interface LibraryStyle {
    /**
     * Default fill style for Dashboard background
     */
    readonly dashboardBackgroundFillStyle: SolidFill;
    /**
     * Default stroke style for Dashboard background.
     */
    readonly dashboardBackgroundStrokeStyle: LineStyle;
    /**
     * Default fill style for Dashboard splitter lines
     */
    readonly dashboardSplitterStyle: SolidLine;
    /**
     * Default fill style for Panel background
     */
    readonly panelBackgroundFillStyle: SolidFill;
    /**
     * Default stroke style for Panel background.
     */
    readonly panelBackgroundStrokeStyle: LineStyle;
    /**
     * Default fill style for chart background fill.
     */
    readonly chartBackgroundFillStyle: SolidFill;
    /**
     * Default stroke style for chart background stroke.
     */
    readonly chartBackgroundStrokeStyle: LineStyle;
    /**
     * Default FontSettings for Spider Chart title.
     */
    readonly spiderChartTitleFont: FontSettings;
    /**
     * Fill style using a opaque white color.
     */
    readonly spiderSeriesFillStyle: SolidFill;
    /**
     * Default web line style for Spider Chart.
     */
    readonly spiderWebStyle: SolidLine;
    /**
     * Default axis line style for Spider Chart.
     */
    readonly spiderAxisStyle: SolidLine;
    /**
     * Default series fill style for Spider Chart.
     */
    readonly spiderSeriesStrokeStyle: SolidLine;
    /**
     * Default FillStyle for Spider scale labels.
     */
    readonly spiderScaleLabelFillStyle: SolidFill;
    /**
     * Default FontSettings for Spider scale labels.
     */
    readonly spiderScaleLabelFont: FontSettings;
    /**
     * Default FillStyle for Spider axis labels.
     */
    readonly spiderAxisLabelFillStyle: SolidFill;
    /**
     * Default FontSettings for Spider axis labels.
     */
    readonly spiderAxisLabelFont: FontSettings;
    /**
     * Default FontSettings for Pie Chart title.
     */
    readonly pieChartTitleFont: FontSettings;
    /**
     * Default FillStyle Palette for Pie Slices.
     */
    readonly pieSliceFillStylePalette: Palette<FillStyle>;
    /**
     * Default LineStyle for Pie Slices stroke.
     */
    readonly pieSliceStrokeStyle: LineStyle;
    /**
     * Default fillStyle for Pie Labels.
     */
    readonly pieLabelFillStyle: SolidFill;
    /**
     * Default FontSettings for Pie Labels.
     */
    readonly pieLabelFont: FontSettings;
    /**
     * Default LineStyle for Pie Label connectors.
     */
    readonly pieLabelConnectorStyle: SolidLine;
    /**
     * Default FontSettings for Funnel Chart title.
     */
    readonly funnelChartTitleFont: FontSettings;
    /**
     * Default FillStyle Palette for Funnel Slices.
     */
    readonly funnelSliceFillStylePalette: Palette<FillStyle>;
    /**
     * Default LineStyle for Funnel Slices Stroke.
     */
    readonly funnelSliceStrokeStyle: LineStyle;
    /**
     * Default fillStyle for Funnel Labels.
     */
    readonly funnelLabelFillStyle: SolidFill;
    /**
     * Default FontSettings for Funnel Labels.
     */
    readonly funnelLabelFont: FontSettings;
    /**
     * Default LineStyle for Funnel Label connectors.
     */
    readonly funnelLabelConnectorStyle: SolidLine;
    /**
     * Default FontSettings for Pyramid Chart title.
     */
    readonly pyramidChartTitleFont: FontSettings;
    /**
     * Default FillStyle Palette for Pyramid Slices.
     */
    readonly pyramidSliceFillStylePalette: Palette<FillStyle>;
    /**
     * Default LineStyle for Pyramid Slices Stroke.
     */
    readonly pyramidSliceStrokeStyle: LineStyle;
    /**
     * Default fillStyle for Pyramid Labels.
     */
    readonly pyramidLabelFillStyle: SolidFill;
    /**
     * Default FontSettings for Pyramid Labels.
     */
    readonly pyramidLabelFont: FontSettings;
    /**
     * Default LineStyle for Pyramid Label connectors.
     */
    readonly pyramidLabelConnectorStyle: SolidLine;
    /**
     * Get default font for chart XY title
     */
    readonly chartXYTitleFont: FontSettings;
    /**
     * Default fill style for chart XY zooming rectangle
     */
    readonly chartXYZoomingRectangleFillStyle: FillStyle;
    /**
     * Default fill style for chart XY zooming rectangle stroke
     */
    readonly chartXYZoomingRectangleStrokeStyle: SolidLine;
    /**
     * Default fill style for chart XY fitting rectangle
     */
    readonly chartXYFittingRectangleFillStyle: FillStyle;
    /**
     * Default fill style for chart XY fitting rectangle stroke
     */
    readonly chartXYFittingRectangleStrokeStyle: SolidLine;
    /**
     * Default fill style for axis title
     */
    readonly axisTitleFillStyle: SolidFill;
    /**
     * Default font for axis title
     */
    readonly axisTitleFont: FontSettings;
    /**
     * Default fill style for axes
     */
    readonly axisStyle: SolidLine;
    /**
     * Default fill style for highlighted axes (mouse-picking area)
     */
    readonly axisOverlayStyle: SolidFill;
    /**
     * Default line style for axis nibs
     */
    readonly axisNibStyle: SolidLine;
    /**
     * Default fill style for highlighted axis nibs (mouse-picking area)
     */
    readonly axisNibOverlayStyle: SolidFill;
    /**
     * Default font for custom tick labels.
     */
    readonly customTickLabelFont: FontSettings;
    /**
     * Default style for custom tick grid stroke.
     */
    readonly customTickGridStrokeStyle: SolidLine;
    /**
     * Default fill style for Series
     */
    readonly seriesStyle: SolidFill;
    /**
     * Default line series line style
     */
    readonly defaultLineSeriesStyle: SolidLine;
    /**
     * Default fill style for point line series points
     */
    readonly pointLinePointFillStyle: SolidFill;
    /**
     * Default style for strokes of mountain-series (Area AreaRange).
     */
    readonly defaultMountainsStrokeStyle: SolidLine;
    /**
     * Default style for filling of mountain-series (Area AreaRange).
     */
    readonly defaultMountainsFillStyle: SolidFill;
    /**
     * Default style for inverted strokes of mountain-series (Area AreaRange).
     */
    readonly defaultMountainsInvertedStrokeStyle: SolidLine;
    /**
     * Default style for inverted filling of mountain-series (Area AreaRange).
     */
    readonly defaultMountainsInvertedFillStyle: SolidFill;
    /**
     * Default line style for segment series
     */
    readonly segmentSeriesStyle: SolidLine;
    /**
     * Default line style for OHLC candle sticks
     */
    readonly defaultCandleStickStyle: SolidLine;
    /**
     * Default line style for positive OHLC Bars
     */
    readonly defaultOHLCBarPositiveStyle: SolidLine;
    /**
     * Default line style for negative OHLC Bars
     */
    readonly defaultOHLCBarNegativeStyle: SolidLine;
    /**
     * Default positive fill style for OHLC candle sticks
     */
    readonly defaultCandleStickPositiveStyle: SolidFill;
    /**
     * Default negative fill style for OHLC candle sticks
     */
    readonly defaultCandleStickNegativeStyle: SolidFill;
    /**
     * Default fill style for Box Figures
     */
    readonly defaultBoxFigureStyle: SolidFill;
    /**
     * Default line style for Box Figures stroke
     */
    readonly defaultBoxFigureStrokeStyle: SolidLine;
    /**
     * Default line style for Box Figures Line
     */
    readonly defaultBoxFigureLineStyle: SolidLine;
    /**
     * Default line style for Box Figures Median Line
     */
    readonly defaultBoxFigureMedianLineStyle: SolidLine;
    /**
     * Default fill style for Cursor PointMarker
     */
    readonly pointMarkerFillStyle: SolidFill;
    /**
     * Default line style for Cursor PointMarker
     */
    readonly pointMarkerStrokeStyle: LineStyle;
    /**
     * Default fill style for Cursor ResultTable
     */
    readonly resultTableFillStyle: SolidFill;
    /**
     * Default line style for Cursor ResultTable
     */
    readonly resultTableStrokeStyle: SolidLine;
    /**
     * Default fill style for Cursor ResultTable text
     */
    readonly resultTableTextStyle: SolidFill;
    /**
     * Default fill style for UI Element Background
     */
    readonly uiBackgroundFillStyle: FillStyle;
    /**
     * Default stroke style for UI Element Background
     */
    readonly uiBackgroundStrokeStyle: LineStyle;
    /**
     * Default fill style for UI Text
     */
    readonly uiTextFillStyle: SolidFill;
    /**
     * Default fill style for UI Button
     */
    readonly uiButtonFillStyle: SolidFill;
    /**
     * Default size for UI Button
     */
    readonly uiButtonSize: number;
    /**
     * Default fill style for Axis Band
     */
    readonly defaultBandFillStyle: FillStyle;
    /**
     * Default stroke style for Axis Band
     */
    readonly defaultBandStrokeStyle: LineStyle;
    /**
     * Default stroke style for Axis ConstantLine
     */
    readonly defaultConstantLineStrokeStyle: SolidLine;
    /**
     * Default styles for 3D Charts Axes.
     */
    readonly axesStyles3D: Vec3<SolidLine>;
    /**
     * Default style for 3D Charts bounding box.
     */
    readonly boundingBoxStyle3D: SolidLine;
    /**
     * Default point series 3D style.
     */
    readonly defaultPointSeriesStyle3D: TriangulatedPoints3D | PixelatedPoints3D;
    /**
     * Function that styles a 'Button' given a single FillStyle (default design for Buttons).
     */
    readonly styleButton: (button: StylableButton, fillStyle: FillStyle) => void;
}
/**
 * Themes used to set the coloring scheme of all elements in Dashboard, Charts, UIElements.
 * A Theme can be passed to a Dashboard or Chart as a parameter upon creation.
 */
export declare const Themes: {
    /**
     * A predominantly dark theme.
     */
    dark: Theme;
    /**
    * Theme with light backgrounds.
    */
    light: Theme;
};
/**
 * Structure for Themes. Themes are used to set the style of all elements in a Chart / Dashboard.
 * @hidden
 */
export interface Theme {
    /**
     * FillStyle for Dashboard background
     */
    dashboardBackgroundFillStyle: FillStyle;
    /**
     * StrokeStyle for Dashboard background.
     */
    dashboardBackgroundStrokeStyle: LineStyle;
    /**
     * FillStyle for Dashboard splitter lines
     */
    dashboardSplitterStyle: LineStyle;
    /**
     * FillStyle for Panel background
     */
    panelBackgroundFillStyle: FillStyle;
    /**
     * StrokeStyle for Panel background.
     */
    panelBackgroundStrokeStyle: LineStyle;
    /**
     * FontSettings for Chart title
     */
    chartTitleFont: FontSettings;
    /**
     * FillStyle for Chart title
     */
    chartTitleFillStyle: FillStyle;
    /**
     * FillStyle for chart background fill.
     */
    chartBackgroundFillStyle: FillStyle;
    /**
     * StrokeStyle for chart background stroke.
     */
    chartBackgroundStrokeStyle: LineStyle;
    /**
     * FillStyle for Spider Chart Series.
     */
    spiderSeriesFillStyle: FillStyle;
    /**
     * StrokeStyle for Web line of Spider Chart.
     */
    spiderWebStyle: LineStyle;
    /**
     * StrokeStyle for Axis of Spider Chart.
     */
    spiderAxisStyle: SolidLine;
    /**
     * StrokeStyle for Axis Nib of Spider Chart.
     */
    spiderAxisNibStyle: SolidLine;
    /**
     * StrokeStyle for Spider Chart Series.
     */
    spiderSeriesStrokeStyle: LineStyle;
    /**
     * FillStyle for Spider scale labels.
     */
    spiderScaleLabelFillStyle: FillStyle;
    /**
     * FontSettings for Spider scale labels.
     */
    spiderScaleLabelFont: FontSettings;
    /**
     * FillStyle for Spider axis labels.
     */
    spiderAxisLabelFillStyle: FillStyle;
    /**
     * FontSettings for Spider axis labels.
     */
    spiderAxisLabelFont: FontSettings;
    /**
     * FillStyle Palette for Sliced Chart (Pie, Funnel, Pyramid) Slices.
     */
    sliceChartFillStylePalette: Palette<FillStyle>;
    /**
     * StrokeStyle for Sliced Chart (Pie, Funnel, Pyramid) Slices.
     */
    sliceChartStrokeStyle: LineStyle;
    /**
     * FillStyle for Sliced Chart (Pie, Funnel, Pyramid) Labels.
     */
    sliceLabelFillStyle: FillStyle;
    /**
     * FontSettings for Sliced Chart (Pie, Funnel, Pyramid) Labels.
     */
    sliceLabelFont: FontSettings;
    /**
     * LineStyle for Sliced Chart (Pie, Funnel, Pyramid) Label connectors.
     */
    sliceLabelConnectorStyle: LineStyle;
    /**
     * FillStyle for GaugeChart Slice
     */
    gaugeSliceFillStyle: FillStyle;
    /**
     * FillStyle for Gauge Chart area background
     */
    gaugeBackgroundFillStyle: FillStyle;
    /**
     * StrokeStyle for Gauge Chart area background
     */
    gaugeBackgroundStrokeStyle: LineStyle;
    /**
     * FillStyle for Chart XY zooming rectangle
     */
    chartXYZoomingRectangleFillStyle: FillStyle;
    /**
     * Style for Chart XY zooming rectangle stroke
     */
    chartXYZoomingRectangleStrokeStyle: LineStyle;
    /**
     * FillStyle for Chart XY fitting rectangle
     */
    chartXYFittingRectangleFillStyle: FillStyle;
    /**
     * Style for Chart XY fitting rectangle stroke
     */
    chartXYFittingRectangleStrokeStyle: LineStyle;
    /**
     * FillStyle for Axis title
     */
    axisTitleFillStyle: FillStyle;
    /**
     * FontSettings for Axis title
     */
    axisTitleFont: FontSettings;
    /**
     * FillStyle for Axis labels
     */
    axisLabelFillStyle: FillStyle;
    /**
     * FontSettings for Axis title
     */
    axisLabelFont: FontSettings;
    /**
     * FillStyle for Axis
     */
    axisStyle: LineStyle;
    /**
     * FillStyle for highlighted Axes (mouse-picking area)
     */
    axisOverlayStyle: FillStyle;
    /**
     * Style for Axis Nibs
     */
    axisNibStyle: LineStyle;
    /**
     * FillStyle for highlighted Axis Nibs (mouse-picking area)
     */
    axisNibOverlayStyle: FillStyle;
    /**
     * Default Numeric tick strategy configuration.
     */
    numericTickStrategy: NumericTickStrategy;
    /**
     * Default DateTime tick strategy configuration.
     */
    dateTimeTickStrategy: DateTimeTickStrategy;
    /**
     * Style for Custom Tick Grid line.
     */
    customTickGridStrokeStyle: LineStyle;
    /**
     * FillStyle for CustomTick Marker.
     */
    customTickMarkerFillStyle: FillStyle;
    /**
     * FillStyle for Custom Tick Marker Text
     */
    customTickMarkerTextFillStyle: FillStyle;
    /**
     * StrokeStyle for CustomTick Marker.
     */
    customTickMarkerStrokeStyle: LineStyle;
    /**
     * Font Settings for CustomTick Marker.
     */
    customTickMarkerFont: FontSettings;
    /**
     * Length for CustomTick pointer.
     */
    customTickPointerLength: number;
    /**
     * Default fill style for UI Band
     */
    bandFillStyle: FillStyle;
    /**
     * Default stroke style for UI Band
    */
    bandStrokeStyle: LineStyle;
    /**
     * Default stroke style for Axis ConstantLine
     */
    constantLineStrokeStyle: SolidLine;
    /**
     * FillStyle for a Chart XY Series
     */
    seriesFillStyle: FillStyle;
    /**
     * StrokeStyle for a Chart XY Series
     */
    seriesStrokeStyle: SolidLine;
    /**
     * FillStyle for a Chart XY Series Point.
     */
    seriesPointFillStyle: FillStyle;
    /**
     * StrokeStyle for a Chart XYZ Series.
     */
    seriesStrokeStyle3D: SolidLine<SolidFill>;
    /**
     * PointStyle for 3D Series with triangulated Points.
     */
    seriesTriangulatedPointStyle3D: TriangulatedPoints3D;
    /**
     * PointStyle for 3D series with non-triangulated Points.
     */
    seriesNontriangulatedPointStyle3D: PixelatedPoints3D;
    /**
     * StrokeStyle for mountain-series (Area, AreaRange).
     */
    mountainsStrokeStyle: SolidLine;
    /**
     * FillStyle for mountain-series (Area, AreaRange).
     */
    mountainsFillStyle: FillStyle;
    /**
     * StrokeStyle for inverted part of mountain-series (Area, AreaRange).
     */
    mountainsInvertedStrokeStyle: SolidLine;
    /**
     * FillStyle for inverted part of mountain-series (Area, AreaRange).
     */
    mountainsInvertedFillStyle: FillStyle;
    /**
     * StrokeStyle for segment series
     */
    segmentSeriesStyle: LineStyle;
    /**
     * StrokeStyle for OHLC candle sticks
     */
    candleStickStyle: LineStyle;
    /**
     * StrokeStyle for OHLC candle sticks when highlighted
     */
    candleStickStyleHighlight: LineStyle;
    /**
     * StrokeStyle for positive OHLC Bars
     */
    OHLCBarPositiveStyle: LineStyle;
    /**
     * Highlighted StrokeStyle for positive OHLC Bars
     */
    OHLCBarPositiveHighlightStyle: LineStyle;
    /**
     * StrokeStyle for negative OHLC Bars
     */
    OHLCBarNegativeStyle: LineStyle;
    /**
     * Highlighted StrokeStyle for negative OHLC Bars
     */
    OHLCBarNegativeHighlightStyle: LineStyle;
    /**
     * FillStyle for Positive OHLC candle sticks
     */
    candleStickPositiveStyle: FillStyle;
    /**
     * FillStyle for Positive OHLC candle sticks when highlighted
     */
    candleStickPositiveStyleHighlight: FillStyle;
    /**
     * StrokeStyle for Positive OHLC candle sticks
     */
    candleStickPositiveStrokeStyle: LineStyle;
    /**
     * StrokeStyle for Positive OHLC candle sticks when highlighted
     */
    candleStickPositiveStrokeStyleHighlight: LineStyle;
    /**
     * FillStyle for Negative OHLC candle sticks
     */
    candleStickNegativeStyle: FillStyle;
    /**
     * FillStyle for Negative OHLC candle sticks when highlighted
     */
    candleStickNegativeStyleHighlight: FillStyle;
    /**
     * StrokeStyle for Negative OHLC candle sticks
     */
    candleStickNegativeStrokeStyle: LineStyle;
    /**
     * StrokeStyle for Negative OHLC candle sticks when highlighted
     */
    candleStickNegativeStrokeStyleHighlight: LineStyle;
    /**
     * FillStyle for Box Figures
     */
    boxFigureStyle: FillStyle;
    /**
     * StrokeStyle for Box Figures
     */
    boxFigureStrokeStyle: LineStyle;
    /**
     * StrokeStyle for Box Figures Line
     */
    boxFigureLineStyle: LineStyle;
    /**
     * StrokeStyle for Box Figures Median Line
     */
    boxFigureMedianLineStyle: LineStyle;
    /**
     * FillStyle for Cursor PointMarker
     */
    pointMarkerFillStyle: FillStyle;
    /**
     * StrokeStyle for Cursor PointMarker
     */
    pointMarkerStrokeStyle: LineStyle;
    /**
     * StrokeStyle for Horizontal Grid originating from Cursor PointMarker
     */
    pointMarkerHorizontalGridStrokeStyle: LineStyle;
    /**
     * StrokeStyle for Vertical Grid originating from Cursor PointMarker
     */
    pointMarkerVerticalGridStrokeStyle: LineStyle;
    /**
     * FillStyle for Cursor PointMarker Text
     */
    pointMarkerTextFillStyle: FillStyle;
    /**
     * FillStyle for Cursor ResultTable
     */
    resultTableFillStyle: FillStyle;
    /**
     * StrokeStyle for Cursor ResultTable
     */
    resultTableStrokeStyle: LineStyle;
    /**
     * FillStyle for Cursor ResultTable text
     */
    resultTableTextFillStyle: FillStyle;
    /**
     * FillStyle for UI Element Background
     */
    uiBackgroundFillStyle: FillStyle;
    /**
     * StrokeStyle for UI Element Background
     */
    uiBackgroundStrokeStyle: LineStyle;
    /**
     * FillStyle for UI Text
     */
    uiTextFillStyle: FillStyle;
    /**
     * FillStyle for UI Button
     */
    uiButtonFillStyle: FillStyle;
    /**
     * Size for UI Button
     */
    uiButtonSize: number;
    /**
     * Default styles for 3D Charts Axes.
     */
    axesStyles3D: Vec3<LineStyle>;
    /**
     * Default style for 3D Charts bounding box.
     */
    boundingBoxStyle3D: LineStyle;
}
/**
 * Collection of default styles used for the whole library.
 *
 * Can be referenced in applications for mimicking style, or just fast access to some styles.
 */
export declare const DefaultLibraryStyle: LibraryStyle;
/**
 * PUBLIC !
 * File contains interfaces and enums used in UI system.
 */
/**
 * Enum that is used to specify a relative area inside an UI element.
 *
 * Probably not needed in user applications.
 */
export declare enum UISpace {
    /**
     * Smallest area, equal to the UiElements respective visual content
     */
    Content = 0,
    /**
     * Content + Padding, area that should be contained within Backgrounds border
     */
    PaddedContent = 1,
    /**
     * Content + Padding + Background padding
     */
    PaddedBackground = 2,
    /**
     * Content + Padding + Background padding + Margin
     */
    Everything = 3
}
/**
 * Enum for selecting visibility of parts of *Marker*s. Each part can be configured individually:
 *
 * Example usage:
 * ```javascript
 * // Hide part
 * SeriesMarkerXY.setTickMarkerYVisibility( UIVisibilityModes.never )
 * // Show part when pointed
 * ChartMarkerXY.setResultTableVisibility( UIVisibilityModes.whenHovered )
 * ```
 */
export declare enum UIVisibilityModes {
    /**
     * Part is never visible
     */
    never = 0,
    /**
     * Part is always visible
     */
    always = 1,
    /**
     * Part is visible when Marker is hovered with mouse and not being dragged
     */
    whenHovered = 2,
    /**
     * Part is visible when Marker is being dragged with mouse
     */
    whenDragged = 3,
    /**
     * Part is visible when Marker is not being dragged with mouse
     */
    whenNotDragged = 4,
    /**
     * Part is visible when Marker is hovered with mouse or dragged
     */
    whenHoveredOrDragged = 5
}
/**
 * Enum for selecting behavior of dragging interactions of *UIElements*. Dragging can be done by both mouse and touch.
 *
 * Use with [[UIElement.setDraggingMode]]
 */
export declare enum UIDraggingModes {
    /**
     * *UIElement* is not draggable.
     */
    notDraggable = 0,
    /**
     * *UIElement* is draggable.
     */
    draggable = 1,
    /**
     * *UIElement* is only draggable on horizontal plane.
     */
    onlyHorizontal = 2,
    /**
     * *UIElement* is only draggable on vertical plane.
     */
    onlyVertical = 3
}
/**
 * Interface for object that can be dragged by mouse.
 * @hidden
 */
export interface Draggable {
    /**
     * Set dragging mode of object. Defines how the object can be dragged by mouse.
     *
     * See [[UIDraggingModes]] collection for options.
     * @param       draggingMode    DraggingMode or undefined to disable dragging
     * @returns                     Object itself
     */
    setDraggingMode(draggingMode?: UIDraggingModes): this;
    /**
     * Get dragging mode of object.
     * Defines how the object can be dragged by mouse.
     * @returns                     Object itself
     */
    getDraggingMode(): UIDraggingModes;
}
/**
 * Enum for specifying a direction. Used for styling *Pointable* *UIElements*.
 */
export declare enum UIDirections {
    Up = 0,
    Right = 1,
    Down = 2,
    Left = 3
}
/**
 * Element that can be pointed at a direction (left,right,up or down)
 * @hidden
 */
export interface Pointable {
    /**
     * Set direction.
     * @param   direction   Enum Direction
     * @returns             Object itself for fluent interface
     */
    setDirection(direction: UIDirections): this;
    /**
     * Get direction.
     * @returns             Enum Direction
     */
    getDirection(): UIDirections;
    /**
     * Set length of Pointable head in pixels.
     * @param   length  Length of head in pixels.
     * @returns         Object itself for fluent interface
     */
    setPointerLength(length: pixel): this;
    /**
     * Get length of Pointable head in pixels.
     * @returns             Pixel length
     */
    getPointerLength(): pixel;
    /**
     * Set angle of Pointable in degrees. [0-90]
     * @param   angle   Angle of pointer or undefined to match head & body size
     * @returns         Object itself for fluent interface
     */
    setPointerAngle(angle?: number): this;
    /**
     * Get angle of Pointable in degrees.
     * @returns         Angle in degrees
     */
    getPointerAngle(): pixel;
}
/**
 * Interface for object that can be rendered as part of UI.
 * @hidden
 */
export interface Plotable {
}
/**
 * Event handler for mouse move
 * @param   obj             Object
 * @param   event           Browser MouseEvent that triggered the event
 */
export declare type MouseEventHandler<T> = (obj: T, event: MouseEvent) => void;
/**
 * Event handler for mouse event that is 'abrupt'.
 * Meaning that the event can be triggered as a side-effect of something totally unrelated, without an actual mouse-event.
 * ( Designed for making sure that mouse-leave is handled when hovered entity is disposed )
 * @param   obj             Object
 * @param   event           Browser MouseEvent that triggered the event of undefined if event is abrupt
 */
export declare type AbruptMouseEventHandler<T> = (obj: T, event?: MouseEvent) => void;
/**
 * Event handler for mouse drag start
 * @param   obj             Object
 * @param   event           Browser MouseEvent that triggered the event
 * @param   button          Button that is being held down
 */
export declare type MouseDragStartEventHandler<T> = (obj: T, event: MouseEvent, button: number) => void;
/**
 * Event handler for mouse drag
 * @param   obj             Object
 * @param   event           Browser MouseEvent that triggered the event
 * @param   button          Button that is being held down
 * @param   startLocation   Start location of mouse
 * @param   delta           Dragged delta
 */
export declare type MouseDragEventHandler<T> = (obj: T, event: MouseEvent, button: number, startLocation: Point, delta: Point) => void;
/**
 * Event handler for mouse drag
 * @param   obj             Object
 * @param   event           Browser MouseEvent that triggered the event
 * @param   button          Button that is being held down
 * @param   startLocation   Start location of mouse
 */
export declare type MouseDragStopEventHandler<T> = (obj: T, event: MouseEvent, button: number, startLocation: Point) => void;
/**
 * Event handler for mouse wheel
 * @param   obj             Object
 * @param   event           Browser WheelEvent that triggered the event
 */
export declare type MouseWheelEventHandler<T> = (obj: T, event: WheelEvent) => void;
/**
 * Event handler for pointer event (touch)
 * @param   obj             Object
 * @param   event           Browser PointerEvent that triggered the event
 */
export declare type TouchEventHandler<T> = (obj: T, event: ExtendedPointerEvent) => void;
/**
 * Interface for object that can have mouse-event-subscriptions.
 * @hidden
 */
export interface Interactable {
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * Subscribe on Mouse Enter event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseEnter(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe on Mouse Enter leave
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseLeave(listener: AbruptMouseEventHandler<this>): Token;
    /**
     * Subscribe on Mouse Enter click
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseClick(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Double Click event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseDoubleClick(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Down event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseDown(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Up event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseUp(listener: MouseEventHandler<this>): Token;
    /**
    * Subscribe to Mouse Move event
    * @param   listener    Event handler function
    * @returns             Token of subscription
    */
    onMouseMove(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag Start event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseDragStart(listener: MouseDragStartEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseDrag(listener: MouseDragEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag Stop event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseDragStop(listener: MouseDragStopEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Wheel event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseWheel(listener: MouseWheelEventHandler<this>): Token;
    /**
     * Subscribe to Touch Start event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchStart(listener: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch Move event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchMove(listener: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch End event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchEnd(listener: TouchEventHandler<this>): Token;
    /**
     * Remove event listener from Mouse Enter Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseEnter(token: Token): boolean;
    /**
     * Remove event listener from Mouse Leave Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseLeave(token: Token): boolean;
    /**
     * Remove event listener from Mouse Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseClick(token: Token): boolean;
    /**
     * Remove event listener from Mouse Double Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDoubleClick(token: Token): boolean;
    /**
     * Remove event listener from Mouse Down Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDown(token: Token): boolean;
    /**
     * Remove event listener from Mouse Up Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseUp(token: Token): boolean;
    /**
     * Remove event listener from Mouse Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseMove(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStart(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDrag(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag stop Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStop(token: Token): boolean;
    /**
     * Remove event listener from Mouse Wheel Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseWheel(token: Token): boolean;
    /**
     * Remove event listener from Touch Start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchStart(token: Token): boolean;
    /**
     * Remove event listener from Touch Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchMove(token: Token): boolean;
    /**
     * Remove event listener from Touch End Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchEnd(token: Token): boolean;
}
/**
 * Interface for object that can be switched on/off and that can have respective event-subscriptions
 * @hidden
 */
export interface Switchable {
    /**
     * Set state of switchable object.
     *
     * **NOTE: If *Switchable*.getLocked() == true, this method will not do anything.!**
     * @param isOn  State as boolean flag
     * @returns     Object itself for fluent interface
     */
    setOn(isOn: boolean): this;
    /**
     * @return State as boolean flag
     */
    getOn(): boolean;
    /**
     * Set whether *Switchable* is locked or not. When locked, *Switchable*.setOn() is disabled.
     * @param isLocked state
     * @returns State as boolean flag
     */
    setLocked(isLocked: boolean): this;
    /**
     * @returns State of isLocked boolean flag
     */
    getLocked(): boolean;
    /**
     * Subscribe to Switch event
     * @return      Token of subscription
     */
    onSwitch(listener: (obj: this, state: boolean) => void): Token;
    /**
     * Remove event listener from Switch event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offSwitch(token: Token): boolean;
}
/**
 * Interface for an object that can be highlighted.
 * @hidden
 */
export interface Highlightable {
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * @return True for highlighted state of object and false for basic
     */
    getHighlighted(): boolean;
}
/**
 * Indicates object which can have margin.
 * Margin is empty space around element content (including background if any)
 * @hidden
 */
export interface Marginable {
    /**
     * Set margin around object in pixels.
     * @param   margin      Number with pixel margins for all sides or datastructure with individual pixel margins
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself
     */
    setMargin(margin: Partial<MMargin> | number): this;
    /**
     * Get margin around object in pixels.
     * @return  Margin datastructure
     */
    getMargin(): Margin;
}
/**
 * Interface for an object that has stylable background.
 * @hidden
 */
export interface StylableBackground<BackgroundType extends UIBackground = UIBackground> extends Highlightable {
    /**
     * Method for mutating Background of object.
     *
     * Type of Background is generic, see [[UIBackground]] for minimum interface.
     * @param   mutator Mutator function for Background
     * @return          Object itself for fluent interface
     */
    setBackground(mutator: Mutator<BackgroundType>): this;
    /**
     * Get elements Background object
     *
     * Type of Background is generic, see [[UIBackground]] for minimum interface.
     * @returns     Background object
     */
    getBackground(): BackgroundType;
    /**
     * Set padding around object in pixels.
     * Padding is empty space between the UiElements content and Background
     * @param   padding     Number with pixel margins for all sides or datastructure with individual pixel paddings
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself
     */
    setPadding(padding: Partial<Margin> | number): this;
    /**
     * Get padding around object in pixels.
     * Padding is empty space between the UiElements content and Background
     * @return  Margin datastructure
     */
    getPadding(): Margin;
}
/**
 * Interface for object that has stylable text.
 * @hidden
 */
export interface StylableText {
    /**
     * Get the text of the entire shape.
     * @returns             The entire text string.
     */
    getText(): string;
    /**
     * Set text fill style object
     * @param value Fill style object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setTextFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return Current text fill style object
     */
    getTextFillStyle(): FillStyle;
    /**
     * Set text fill style object when highlighted
     * @param value Fill style object or mutator to modify existing one or undefined for auto assignment
     * @return      Object itself for fluent interface
     */
    setTextFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return Current text fill style object when highlighted or undefined for auto assignment
     */
    getTextFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set font of Label.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Label.
     * @return          FontSettings
     */
    getFont(): FontSettings;
}
/**
 * Interface for object that has stylable and settable text.
 * @hidden
 */
export interface CustomizableText extends StylableText {
    /**
     * Specify a text string.
     * @param text          The string to be rendered.
     * @returns             Object itself for fluent interface.
     */
    setText(text: string): this;
}
/**
 * Interface for object that has configurations for style of button.
 * @hidden
 */
export interface StylableButton {
    /**
     * Set fill style of Button when state is OFF
     * @param   value   Fill style object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setButtonOffFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Button when state is OFF
     * @return  Fill style object
     */
    getButtonOffFillStyle(): FillStyle;
    /**
     * Set highlighted fill style of Button when state is OFF
     * @param value     FillStyle for highlighted object or function which modifies it or undefined for auto assignment
     */
    setButtonOffFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get highlighted fill style of Button when state is OFF
     * @return  Fill style object or undefined for auto assignment
     */
    getButtonOffFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set style of Button when state is OFF
     * @param   lineStyle       Style object or function which modifies it
     * @return                  Object itself for fluent interface
     */
    setButtonOffStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Button when state is OFF
     * @return  Line style object
     */
    getButtonOffStrokeStyle(): LineStyle;
    /**
     * Set size of Button when state is OFF
     * @param   size    Point or pixel for squared button size
     * @return          Object itself
     */
    setButtonOffSize(size: Point | pixel): this;
    /**
     * Get size of Button when state is OFF
     * @return          Size of button as Point
     */
    getButtonOffSize(): Point;
    /**
     * Set fill style of Button when state is ON
     * @param   value   Fill style object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setButtonOnFillStyle(value: FillStyle | Mutator<FillStyle>): this;
    /**
     * Get fill style of Button when state is ON
     * @return  Fill style object
     */
    getButtonOnFillStyle(): FillStyle;
    /**
     * Set highlighted fill style of Button when state is ON
     * @param style     FillStyle for highlighted object or function which modifies it or undefined for auto assignment
     */
    setButtonOnFillStyleHighlight(style: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get highlighted fill style of Button when state is ON
     * @return  Fill style object or undefined for auto assignment
     */
    getButtonOnFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set style of Button when state is ON
     * @param   lineStyle       Line style object or function which modifies it
     * @return                  Object itself for fluent interface
     */
    setButtonOnStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Button when state is ON
     * @return  Line style object
     */
    getButtonOnStrokeStyle(): LineStyle;
    /**
     * Set size of Button when state is ON
     * @param   size    Point or pixel for squared button size
     * @return          Object itself
     */
    setButtonOnSize(size: Point | pixel): this;
    /**
     * Get size of Button when state is ON
     * @return          Size of button as Point
     */
    getButtonOnSize(): Point;
}
/**
 * Three-dimensional Axis, that resides inside Chart3D.
 * Can be either X, Y or Z. There is always exactly one Axis3D object for each dimension in a Chart3D.
 *
 * *Axes* have automatic scrolling logic to fit attached *Series*.
 * This can be modified with *Axis*.**setScrollStrategy()**
 *
 * *Axes* are associated with a title, which can be enabled with *Axis*.**setTitle()**
 */
export declare class Axis3D extends GenericAxis<UnitScale, Chart3D, Series3D, AxisStrategy3D, Tick3D, Tick3DPlottingVariables> {
    /**
     * Set style of Axis line.
     * @param   value   A LineStyle object, or a function which modifies the current style.
     * @returns         Object itself for fluent interface.
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * @return          Style of Axis line.
     */
    getStrokeStyle(): LineStyle;
    /**
     * Specifies scroll animation.
     * Scroll animations can cause slow-downs with 3D charts with large amounts of data shown in the 3D chart.
     * @param   enabled     Boolean flag for whether scrolling should be animated or not.
     */
    setAnimationScroll(enabled: boolean | undefined): this;
    /**
     * Enable / disable all interactions of Axis.
     * @param   enabled Interactions enabled or not.
     * @return          Object itself for fluent interface.
     */
    setMouseInteractions(enabled: boolean): this;
    /**
     * Debugging methods.
     */
    private isX;
    /**
     * Debugging method.
     */
    private isY;
    /**
     * Debugging method.
     */
    private isZ;
}
/**
 * Implementation specific values necessary for tick plotting.
 */
interface Tick3DPlottingVariables extends AbstractTickPlottingVariables {
    /**
     *
     */
    wuSize: Point3D;
    /**
     *
     */
    start: Point3D;
    /**
     *
     */
    end: Point3D;
    /**
     *
     */
    tickDirection3D: Point3D;
    /**
     *
     */
    tickDirection2D: Point;
}
/**
 * Implementation of 3D Axis Tick.
 *
 * Tick doesn't contain any positioning logic, that is done in Axis !
 */
export declare class Tick3D extends AbstractAxisTick {
    protected readonly _gridlineLayer: LayerXYZ;
    readonly gridStroke: LineSet3D;
    readonly tickStroke: LineSet3D;
    /**
     * @param   tickLevel       AxisTickLevel tick belongs to.
     * @param   value           Position of Tick on Axis.
     * @param   _removeFromAxis Remove handler for Tick.
     * @param   _restoreToAxis  Restore handler for Tick.
     * @param   _labelLayer     Layer for rendering Tick Label.
     * @param   _labelScale     Scale for rendering Tick label.
     * @param   _gridlineLayer  Rendering layer for 3D gridline.
     * @param   label           Optionally injectable Tick Label shape.
     *                          Injection can be useful to reuse Tick shapes for performance.
     * @param   gridStroke      Optionally injectable Tick Gridline shape.
     * @param   tickStroke      Optionally injectable Tick Tickline shape.
     */
    constructor(tickLevel: AxisTickLevel, value: number, _removeFromAxis: RemoveHandler<AbstractAxisTick>, _restoreToAxis: RestoreHandler<AbstractAxisTick>, _labelLayer: LayerXY, _labelScale: Vec2<Scale>, _gridlineLayer: LayerXYZ, label?: Text, gridStroke?: LineSet3D, tickStroke?: LineSet3D);
    /**
    * Restores all custom tick sub-elements
    * @returns This for fluid interface
    */
    restore(): this;
    /**
     * Disposes all tick sub-elements
     * @returns This for fluid interface
     */
    dispose(): this;
}
export {};
/**
 * Interface for a strategy which represents the logic that is different between X, Y and Z Axes.
 */
export interface AxisStrategy3D extends AbstractAxisStrategy<Series3D> {
}
/**
 * Chart for visualizing data in a 3-dimensional scene, with camera and light source(s).
 *
 * Camera can be moved around with user interactions (mouse & touch). It is always oriented to face the center of the scene.
 *
 * Light source is always located at the location of the Camera, and directed towards the center of *Axes*.
 *
 * Data can be added to the *Chart* via various *Series* types, each with their own method of visualization:
 *
 * ```javascript
 *  const pointLineSeries3D = chart3D.addPointLineSeries()
 *      .add( [
 *          { x: 0, y: 0, z: 0 },
 *          { x: 1, y: 0, z: 0 },
 *          { x: 2, y: 1, z: 0 }
 *      ] )
 * ```
 */
export declare class Chart3D extends ChartWithSeries<Series3D> implements ChartWithScrollingAnimations, ChartWithAxis<Axis3D> {
    /**
     * Create Series for visualization of data by different shapes.
     *
     * Example usage:
     *
     * - **By default, creates *PointSeries3D***
     * ```ts
     *  const pointSeries3D = Chart3D.addPointSeries()
     * ```
     *
     * - **By specifying options object with *type*-property, the returned *Series*' class can be selected**
     * ```ts
     *  const pointCloudSeries3D = Chart3D.addPointSeries({
     *      type: PointSeriesTypes3D.Pixelated
     *  })
     * ```
     *
     * @param   options     Optional object for passing readonly parameters to configure the created *Series*.
     * @return  Created *Series*. If *options* were omitted or undefined, the *Series* type defaults to [[PointSeries3D]], otherwise
     *          corresponds to class referenced by *options.type*.
     */
    addPointSeries<T extends PointSeriesTypes3D = typeof PointSeries3D>(options?: PointSeriesOptions3D<T>): InstanceType<T>;
    /**
     * Create Series for visualization of data by lines connected between data points.
     * @return  LineSeries3D.
     */
    addLineSeries(): LineSeries3D;
    /**
     * Create Series for visualization of data by lines connected between data points
     * as well as shapes rendered on the data points.
     * @return  PointLineSeries3D.
     */
    addPointLineSeries(options?: PointLineSeriesOptions3D): PointLineSeries3D;
    /**
     * Get Axis X.
     * @return  Axis3D object.
     */
    getDefaultAxisX(): Axis3D;
    /**
     * Get Axis Y.
     * @return  Axis3D object.
     */
    getDefaultAxisY(): Axis3D;
    /**
     * Get Axis Z.
     * @return  Axis3D object.
     */
    getDefaultAxisZ(): Axis3D;
    /**
     * Set the location of camera in 3D space.
     *
     * The camera always faces (0, 0, 0) coordinate.
     *
     * The light source is always a set distance behind the camera.
     * @param   cameraLocation  Camera location in 3D space. Valid values are in the range **[1, 5]**.
     *                          Note, that placing the camera too close to the bounding box is restricted.
     */
    setCameraLocation(cameraLocation: Point3D): void;
    /**
     * Get the location of camera in 3D space.
     * @return                  Camera location in 3D space.
     */
    getCameraLocation(): Point3D;
    /**
     * Get the direction of camera in 3D space.
     *
     * The direction is set according to the location of the camera, so that it is facing (0, 0, 0).
     * @return                  Camera direction in 3D space. Always an unit vector.
     */
    getCameraDirection(): Point3D;
    /**
     * Set the dimensions of the Scenes bounding box.
     *
     * The bounding box is a visual reference that all the data of the Chart is depicted inside of. The Axes of the
     * 3D chart are always positioned along the sides of the bounding box.
     *
     * Example usage:
     * - **Symmetric bounding box**
     * ```javascript
     *  setBoundingBox( { x: 1.0, y: 1.0, z: 1.0 } )
     * ```
     * - **Bounding box whose Y dimension is 4 times that of the others**
     * ```javascript
     *  setBoundingBox( { x: 1.0, y: 4.0, z: 1.0 } )
     * ```
     *
     * @param   dimensions  Dimensions of bounding box. These values do not represent any "unit", only their relative
     *                      ratios are considered.
     * @return              Object itself for fluent interface
     */
    setBoundingBox(dimensions: Point3D): this;
    /**
     * Get dimensions of Scenes "bounding box".
     * Bounding box defines the space allocated for the Charts 3D Axes.
     *
     * It is visualized with a wireframe, as well as 3D Axes on its sides.
     * @return              Dimensions of bounding box as World Units.
     */
    getBoundingBox(): Point3D;
    /**
     * Set if mouse and cursor interactions should be disabled during scrolling animations for the chart's series.
     * @param   state   True if mouse and cursor interactions should be disabled during scrolling animations, false if not.
     * @return          Chart itself for fluent interface.
     */
    setMouseInteractionsWhileScrolling(state: boolean): this;
    /**
     * Get if mouse and cursor interactions are disabled during scrolling animations for the chart's series.
     * @return True if interactions with series are disabled, false if not.
     */
    getMouseInteractionsWhileScrolling(): boolean;
    /**
     * Operate on each axis of chart, x and y
     * @param   clbk    Callback function for axis
     */
    forEachAxis(clbk: (axis: Axis3D) => void): void;
    /**
     * Get minimum size of Chart.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     * @hidden
     */
    getMinimumSize(): Point | undefined;
    /**
     * Disable all animations for the chart.
     *
     * After calling this function, animations (Zooming, scaling) for all Axes will be disabled.
     * Animations must be recreated manually afterwards.
     * @return          Chart itself for fluent interface.
     */
    disableAnimations(): this;
}
/**
 * Interface that can be used to define [[Chart3D]] configurations that can't be changed after creation. For example:
 *
 * - Specifying TickStrategies for default X or Y Axes'. This is mostly used for creating DateTime Axes.
 *
 * - Supplying a custom Builder for the AutoCursor of Chart. This can be used to modify the AutoCursor on a level,
 * which can't be done during runtime. For example, changing the shape of ResultTable Background, Etc.
 *
 * Example usage:
 *
 * | Desired result                                 | Value                                                                                                 |
 * | :--------------------------------------------- | :---------------------------------------------------------------------------------------------------- |
 * | Default                                        | *undefined*                                                                                           |
 * | Preset theme                                   | { **theme**: *Themes*.light }                                                                         |
 */
export interface ChartOptions3D {
    /**
     * Theme used to style all elements inside the Chart.
     * See **Themes** for pre-made options.
     */
    theme?: Theme;
}
/**
 * Interface that can be used to specify readonly parameters when creating a [[PointSeries3D]].
 */
export interface PointSeriesOptions3D<T extends PointSeriesTypes3D> {
    /**
     * Defines the type of *Point Series 3D*.
     *
     * See [[PointSeriesTypes3D]] for a collection of options.
     */
    type?: T;
    /**
     * Shape for points of series.
     *
     * Only eligible if [[PointSeriesOptions3D.type]] is set to [[PointSeriesTypes3D.Triangulated]].
     */
    pointShape?: 'cube' | 'sphere';
}
/**
 * Interface that can be used to specify readonly parameters when creating a [[PointLineSeries3D]].
 */
export interface PointLineSeriesOptions3D {
    /**
     * Shape for points of series.
     */
    pointShape?: 'cube' | 'sphere';
}
/**
 * Type union of LineStyle types supported by LineSeries3D.
 *
 * Equal to that of 2D lines.
 */
export declare type LineSeriesStyle3D = SolidLine<SolidFill>;
/**
 * Internal super class for LineSeries3D and PointLineSeries3D.
 *
 * Sub-classes only differ on styling logic. This class behaves just like PointLineSeries (2D),
 * rendering both Line and Point sets.
 * @hidden
 */
export declare abstract class LineAndPointSeries3D extends Series3D<LineSet3D> {
    /**
     * Set line style of Series.
     *
     * Example usage:
     *
     * - **Construct new SolidLine object**
     * ```javascript
     *  lineSeries3D.setLineStyle( new SolidLine({
     *      thickness: 5,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change thickness of existing SolidLine configuration**
     * ```javascript
     *  lineSeries.setLineStyle( (solidLine) => solidLine
     *      .setThickness( 5 )
     *  )
     * ```
     * @param   value   A LineSeries object, or a function which modifies the current style.
     * @return          Object itself for fluent interface
     */
    setLineStyle(value: LineSeriesStyle3D | ImmutableMutator<LineSeriesStyle3D>): this;
    /**
     * Get normal line style (not highlighted).
     * @return  LineSeriesStyle3D
     */
    getLineStyle(): LineSeriesStyle3D;
    /**
     * Set line style of Series when it is highlighted.
     *
     * Example usage:
     *
     * - **Construct new SolidLine object**
     * ```javascript
     *  lineSeries3D.setLineStyle( new SolidLine({
     *      thickness: 5,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change thickness of existing SolidLine configuration**
     * ```javascript
     *  lineSeries.setLineStyle( (solidLine) => solidLine
     *      .setThickness( 5 )
     *  )
     * ```
     * - **Assign highlight style automatically based on normal style**
     * ```javascript
     *  lineSeries.setLineStyleHighlight( undefined )
     * ```
     * @param   value   A LineSeries object, a function which modifies the current style or
     *                  **undefined** for automatic value based on normal style.
     * @returns         Object itself for fluent interface.
     */
    setLineStyleHighlight(value: LineSeriesStyle3D | ImmutableMutator<LineSeriesStyle3D> | undefined): this;
    /**
     * Get highlight style of line.
     * @return  LineSeriesStyle3D
     */
    getLineStyleHighlight(): LineSeriesStyle3D;
    /**
     * Enable or disable forced highlighting of component
     * @param highLight True for enabled and false for disabled
     * @returns         component itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * Clear all points and segments from the dataset.
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * Remove everything related to the object from all collections associated
     * with rendering cycle and allows the object to be collected by GC
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Object itself.
     */
    restore(): this;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Object itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
}
/**
 * 3D series type that renders a list of 3D points with connected lines.
 */
export declare class LineSeries3D extends LineAndPointSeries3D {
    /**
     * Set line style of Series.
     *
     * Example usage:
     *
     * - **Construct new SolidLine object**
     * ```javascript
     *  lineSeries3D.setLineStyle( new SolidLine({
     *      thickness: 5,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change thickness of existing SolidLine configuration**
     * ```javascript
     *  lineSeries.setLineStyle( (solidLine) => solidLine
     *      .setThickness( 5 )
     *  )
     * ```
     * @param   value   A LineSeries object, or a function which modifies the current style.
     * @return          Object itself for fluent interface
     */
    setLineStyle(value: LineSeriesStyle3D | ImmutableMutator<LineSeriesStyle3D>): this;
    /**
     * Set line style of Series when it is highlighted.
     *
     * Example usage:
     *
     * - **Construct new SolidLine object**
     * ```javascript
     *  lineSeries3D.setLineStyle( new SolidLine({
     *      thickness: 5,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change thickness of existing SolidLine configuration**
     * ```javascript
     *  lineSeries.setLineStyle( (solidLine) => solidLine
     *      .setThickness( 5 )
     *  )
     * ```
     * - **Assign highlight style automatically based on normal style**
     * ```javascript
     *  lineSeries.setLineStyleHighlight( undefined )
     * ```
     * @param   value   A LineSeries object, a function which modifies the current style or
     *                  **undefined** for automatic value based on normal style.
     * @returns         Object itself for fluent interface.
     */
    setLineStyleHighlight(value: LineSeriesStyle3D | ImmutableMutator<LineSeriesStyle3D> | undefined): this;
}
/**
 * 3D series type that renders a list of 3D points with connected lines.
 */
export declare class PointLineSeries3D extends LineAndPointSeries3D {
    /**
     * Set point style of Series.
     *
     * Example usage:
     *
     * - **New TriangulatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyle( new PointStyle3D.Triangulated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyle( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * @param   value   A TriangulatedPoints3D object, or a function which modifies the current style.
     * @return          Object itself for fluent interface
     */
    setPointStyle(value: TriangulatedPoints3D | ImmutableMutator<TriangulatedPoints3D>): this;
    /**
     * Get normal points style.
     * @return  TriangulatedPoints3D
     */
    getPointStyle(): TriangulatedPoints3D;
    /**
     * Set point style of Series when it is highlighted.
     *
     * Example usage:
     *
     * - **New TriangulatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( new PointStyle3D.Triangulated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * - **Assign highlight style automatically based on normal style**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( undefined )
     * ```
     * @param   value   A TriangulatedPoints3D object, or a function which modifies the current style or
     *                  **undefined** for automatic value based on normal style.
     * @returns         Object itself for fluent interface.
     */
    setPointStyleHighlight(value: TriangulatedPoints3D | ImmutableMutator<TriangulatedPoints3D> | undefined): this;
    /**
     * Get highlight style of points.
     * @return  TriangulatedPoints3D
     */
    getPointStyleHighlight(): TriangulatedPoints3D;
}
/**
 * Abstract base class for Point Series 3D implementations.
 *
 * Implements full series logic except for Point Style API and segment length.
 */
declare abstract class AbstractPointSeries3D<Style extends TriangulatedPoints3D | PixelatedPoints3D> extends Series3D<PointSet3D> {
    /**
     * @param _chart            Chart to which the component belongs
     * @param _removeFromChart  Handler to remove component from chart's collection it belongs to.
     * @param _restoreFromChart Handler to restore component from chart's collection it belongs to.
     * @param _layer3D          3D Rendering layer.
     * @param _pointShape       Shape of points. Only relevant for PointSeries with triangulated point style (not point cloud).
     * @hidden
     */
    constructor(_chart: Chart3D, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer3D: LayerXYZ, _pointShape: 'cube' | 'sphere');
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Object itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
}
/**
 * Class for visualization of 3D points inside a Chart3D, by shaded geometry.
 */
export declare class PointSeries3D extends AbstractPointSeries3D<TriangulatedPoints3D> {
    /**
     * @param _chart            Chart to which the component belongs
     * @param _removeFromChart  Handler to remove component from chart's collection it belongs to.
     * @param _restoreFromChart Handler to restore component from chart's collection it belongs to.
     * @param _layer3D          3D Rendering layer.
     * @param _pointShape       Shape of points.
     * @param theme             Theme.
     * @hidden
     */
    constructor(_chart: Chart3D, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer3D: LayerXYZ, _pointShape: 'cube' | 'sphere', theme: Theme);
    /**
     * Set point style of Series.
     *
     * Example usage:
     *
     * - **New TriangulatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyle( new PointStyle3D.Triangulated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyle( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * @param   value   A TriangulatedPoints3D object, or a function which modifies the current style.
     * @return          Object itself for fluent interface
     */
    setPointStyle(value: TriangulatedPoints3D | ImmutableMutator<TriangulatedPoints3D>): this;
    /**
     * Get normal points style.
     * @return  TriangulatedPoints3D
     */
    getPointStyle(): TriangulatedPoints3D;
    /**
     * Set point style of Series when it is highlighted.
     *
     * Example usage:
     *
     * - **New TriangulatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( new PointStyle3D.Triangulated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * - **Assign highlight style automatically based on normal style**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( undefined )
     * ```
     * @param   value   A TriangulatedPoints3D object, or a function which modifies the current style or
     *                  **undefined** for automatic value based on normal style.
     * @returns         Object itself for fluent interface.
     */
    setPointStyleHighlight(value: TriangulatedPoints3D | ImmutableMutator<TriangulatedPoints3D> | undefined): this;
    /**
     * Get highlight style of points.
     * @return  TriangulatedPoints3D
     */
    getPointStyleHighlight(): TriangulatedPoints3D;
}
/**
 * Class for visualization of 3D points inside a Chart3D, by pixelated points.
 */
export declare class PointCloudSeries3D extends AbstractPointSeries3D<PixelatedPoints3D> {
    /**
     * @param _chart            Chart to which the component belongs
     * @param _removeFromChart  Handler to remove component from chart's collection it belongs to.
     * @param _restoreFromChart Handler to restore component from chart's collection it belongs to.
     * @param _layer3D          3D Rendering layer.
     * @param _pointShape       Point shape (OBSOLETE, SHOULD NOT EXIST FOR POINT CLOUD BUT TEMPORARY SOLUTION ATM).
     * @param theme             Theme.
     * @hidden
     */
    constructor(_chart: Chart3D, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer3D: LayerXYZ, _pointShape: 'cube' | 'sphere', theme: Theme);
    /**
     * Set point style of Series.
     *
     * Example usage:
     *
     * - **New PixelatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyle( new PointStyle3D.Pixelated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyle( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * @param   value   A PixelatedPoints3D object, or a function which modifies the current style.
     * @return          Object itself for fluent interface
     */
    setPointStyle(value: PixelatedPoints3D | ImmutableMutator<PixelatedPoints3D>): this;
    /**
     * Get normal points style.
     * @return  PixelatedPoints3D
     */
    getPointStyle(): PixelatedPoints3D;
    /**
     * Set point style of Series when it is highlighted.
     *
     * Example usage:
     *
     * - **New PixelatedPoints3D object**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( new PointStyle3D.Pixelated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHEX('#FFF') })
     *  }) )
     * ```
     * - **Change point size**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( (pointStyle) => pointStyle
     *      .setSize( 10 )
     *  )
     * ```
     * - **Assign highlight style automatically based on normal style**
     * ```ts
     *  pointSeries3D.setPointStyleHighlight( undefined )
     * ```
     * @param   value   A PixelatedPoints3D object, or a function which modifies the current style or
     *                  **undefined** for automatic value based on normal style.
     * @returns         Object itself for fluent interface.
     */
    setPointStyleHighlight(value: PixelatedPoints3D | ImmutableMutator<PixelatedPoints3D> | undefined): this;
    /**
     * Get highlight style of points.
     * @return  PixelatedPoints3D
     */
    getPointStyleHighlight(): PixelatedPoints3D;
}
/**
 * Available Point Series 3D types.
 *
 * Used internally for proper type casting. Should not be included in docs,
 * as it overrides the selection object just below, that has the same name.
 * @hidden
 */
export declare type PointSeriesTypes3D = typeof PointSeriesTypes3D[keyof typeof PointSeriesTypes3D];
/**
 * Collection of *PointSeries3D* implementations.
 *
 * Used when creating an *PointSeries3D* with [[Chart3D.addPointSeries]].
 * Selected option tells what the returned *Series* type will be - *PointSeries3D* implementations are otherwise equal, but
 * their styling APIs expect different *Style* objects.
 *
 * - Select PointSeriesTypes3D.Triangulated for shaded geometries styled with [[PointStyle3D.Triangulated]].
 * - Select PointSeriesTypes3D.Pixelated for pixels styled with [[PointStyle3D.Pixelated]].
 */
export declare const PointSeriesTypes3D: {
    /**
     * Type of *Point Series 3D* that visualized points by shaded geometry styled using [[PointStyle3D.Triangulated]].
     */
    Triangulated: typeof PointSeries3D;
    /**
     * Type of *Point Series 3D* that visualized points by pixels styled using [[PointStyle3D.Pixelated]].
     */
    Pixelated: typeof PointCloudSeries3D;
};
export {};
/**
 * Type requirement for Shapes which are used to render a Series3D.
 * @hidden
 */
export declare type Series3DVisual = ChartVisual & Segment<unknown> & Region3D;
/**
 * Abstract base class for 3D series.
 *
 * TODO: Should extends Series, but for initial implementation state 3D series will
 * not support AutoCursor. Series basically adds only AutoCursors, so the class tree
 * will be fixed at the same time when AutoCursors are implemented for 3D series.
 * Also, remove implements SeriesTODO at the same time.
 * @hidden  Internal class
 */
export declare abstract class Series3D<VisualType extends Series3DVisual = Series3DVisual> extends ChartComponent<VisualType> implements SeriesInternal {
    /**
     * Add point or array of points to the series.
     * @param    data    Point3D or array of points
     * @returns          Object itself for fluent interface
     */
    add(data: Point3D | Point3D[]): this;
    /**
     * Clear all data from the series.
     * @returns         Object itself for fluent interface
     */
    clear(): this;
    /**
     * Get amount of points that series currently has.
     * @return  Number of points
     */
    getPointAmount(): number;
    /**
     * @return Max X value of the series
     */
    getXMax(): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin(): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number | undefined;
    /**
     * @return Max Z value of the series
     */
    getZMax(): number | undefined;
    /**
     * @return Min Z value of the series
     */
    getZMin(): number | undefined;
}
/**
 * Abstract super class for 2D/3D Axis implementations.
 * @hidden
 */
export declare abstract class GenericAxis<ScaleType extends AxisScale, ChartType extends ChartWithAxis<GenericAxis<any, any, any, any, any, any>>, SeriesType extends Series, StrategyType extends AbstractAxisStrategy<SeriesType>, TickType extends AbstractAxisTick, TickPlottingVariables extends AbstractTickPlottingVariables> {
    /**
     * Scale of Axis.
     */
    readonly scale: ScaleType;
    /**
     * @returns Axis title string
     */
    getTitle(): string;
    /**
     * Specifies an Axis title string
     * @param   title  Axis title as a string
     * @returns        Axis itself for fluent interface
     */
    setTitle(title: string): this;
    /**
     * @returns Axis title fillstyle
     */
    getTitleFillStyle(): FillStyle;
    /**
     * Specifies Axis title FillStyle
     * @param   fillStyle   FillStyle of Axis title or mutator to modify existing one
     * @returns             Axis itself for fluent interface
     */
    setTitleFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get font of axis labels.
     * @return          FontSettings
     */
    getTitleFont(): FontSettings;
    /**
     * Set font of Axis title.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setTitleFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Set *TickStrategy* of *Axis*.
     *
     * The *TickStrategy* defines the positioning and formatting logic of *Axis* ticks
     * as well as the style of created ticks.
     *
     * **Example usage**:
     *
     * **DateTime Axis**:
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.DateTime )
     * ```
     *
     * **Disable automatic ticks completely**:
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.Empty )
     * ```
     *
     * **Customized TickStrategy**:
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.Numeric, ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *      .setNumericUnits( true )
     *      .setMajorTickStyle( ( tickStyle ) => tickStyle
     *          .setLabelFont( ( font ) => font
     *              .setWeight( 'bold' )
     *          )
     *      )
     *  )
     * ```
     *
     * **Type table for optional second parameter ('styler')**:
     *
     * | tickStrategy   | styler                                                        |
     * | :------------- | :------------------------------------------------------------ |
     * | 'Numeric'      | ( tickStrategy: **NumericTickStrategy** ) => tickStrategy     |
     * | 'DateTime'     | ( tickStrategy: **DateTimeTickStrategy** ) => tickStrategy    |
     * | 'Empty'        | **undefined**                                                 |
     *
     *
     * @param   tickStrategy    Selected TickStrategy.
     *                          See [[AxisTickStrategies]] for a collection of options.
     * @param   styler          Optional callback that can be used to customize the *TickStrategy*.
     *                          The type of supplied *TickStrategy* object depends on what was supplied to 'tickStrategy' parameter;
     *                          See the above method documentation for a value table.
     * @return                  Object itself for fluent interface.
     */
    setTickStrategy<TickStrategy extends TickStrategyType>(tickStrategy: TickStrategy, styler?: TickStrategyStyler<TickStrategyParameters, TickStrategy>): this;
    /**
     * Get the currently used tick strategy
     */
    getTickStrategy(): TickStrategyType;
    setTickStyle<TickStrategy extends TickStrategyType>(styler: TickStrategyStyler<TickStrategyParameters, TickStrategy>): this;
    getTickStyle(): NumericTickStrategy | DateTimeTickStrategy | undefined;
    /**
     * Set axis scale interval.
     * @param  start                Start scale value
     * @param  end                  End scale value
     * @param  animate              Boolean for animation enabled, or number for animation duration in milliseconds
     * @param  disableScrolling     If true, disables automatic scrolling after setting interval
     * @returns                     Object itself for fluent interface
     */
    setInterval(start: number, end: number, animate?: number | boolean, disableScrolling?: boolean): this;
    /**
     * Stop scrolling of axis until restored.
     */
    stop(): this;
    /**
     * Undo effects of 'stop'.
     */
    readonly release: () => void;
    /**
     * Get is axes' scrolling currently prevented by usage of mouse-interactions or 'stop()' method.
     * @return  Boolean flag
     */
    isStopped(): boolean;
    /**
     * Fit axis view to attached series.
     * @param   animate Boolean for animation enabled, or number for animation duration in milliseconds
     * @param   freeze  Freeze axis to fitted view? False by default.
     */
    fit(animate?: number | boolean, freeze?: boolean): this;
    /**
     * Specify *ScrollStrategy* of the *Axis*. This decides where the *Axis* scrolls based on current view and series boundaries.
     * @param   scrollStrategy  *AxisScrollStrategy* or undefined to disable automatic scrolling.
     *                          See [[AxisScrollStrategies]] for all options.
     * @return                  Object itself for fluent interface.
     */
    setScrollStrategy(scrollStrategy: AxisScrollStrategy): this;
    /**
     * @return Current *AxisScrollStrategy*
     */
    getScrollStrategy(): AxisScrollStrategy | undefined;
    /**
     * Specifies scroll animation.
     * @param   enabled     Boolean flag for whether scrolling should be animated or not.
     */
    setAnimationScroll(enabled: boolean | undefined): this;
    /**
     * Specifies zoom animation to use.
     *
     * Example usage:
     *
     * | Desired result              | Argument                                         | Parameters                                                                                                                            |
     * | :-------------------------  | :----------------------------------------------- | :------------------------------------------------------------------------------------------------------------------------------------ |
     * | Change animation            | setAnimationZoom(AnimationEasings.easeOut, 500)  | First parameter defines the easing to use for the animation. Second parameter is optional, and defines the duration for the animation |
     * | Disable zooming animations  | axis.setAnimationZoom(undefined)                 | Passing **undefined** as the parameter will disable the zooming animations for the Axis.                                              |
     *
     * @param   easing      Easing of animation. Undefined disables zoom animations. See 'engine/animator.Easings' for defaults
     * @param   duration    Optional default duration for zooming animations in milliseconds
     */
    setAnimationZoom(easing: AnimationEasing | undefined, duration?: number): this;
    /**
     * Disable all animations for the Axis.
     *
     * After calling this function, animations (Zooming, scaling) will be disabled.
     * Animations must be recreated manually afterwards.
     * @return          Axis itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Subscribe to on scale change event
     * @param listener  Event listener
     * @param min       Scale start value
     * @param max       Scale end value
     * @returns         Token that is used to unsubscribe from the event
     */
    onScaleChange(listener: (start: number, end: number) => void): Token;
    /**
     * Remove subscription from scale change event
     * @param token Event listener
     * @returns True if the listener is successfully removed and false if it is not found
     */
    offScaleChange(token: Token): boolean;
    /**
     * Enable / disable all interactions of Axis.
     * @param   enabled Interactions enabled or not.
     * @return          Object itself for fluent interface.
     */
    abstract setMouseInteractions(enabled: boolean): this;
    /**
     * Format a value along axis to string. Behavior depends on the Axis' TickStrategy.
     * Eq. A DateTime-Axis will interpret 'value' as a Date.
     * @param   value   Value along axis
     * @return          Value formated to string
     */
    formatValue: (value: number) => string;
}
/**
 * Minimum interface for implementation specific values necessary for tick plotting.
 * @hidden
 */
export interface AbstractTickPlottingVariables {
    /**
     * Physical (visible) axis size as pixels.
     */
    physicalAxisSize: number;
}
/**
 * Lazy type union that combines scales of 2D and 3D Axes.
 * There's really no reason why Scale and UnitScale wouldn't have a common superclass / interface, but Scale is
 * public API so I'll be lazy about touching that.
 */
declare type AxisScale = Scale | UnitScale;
/**
 * Abstract super class for 2D/3D Axis ticks implementations.
 *
 * Tick doesn't contain any positioning logic, that is done in Axis !
 * @hidden
 */
export declare abstract class AbstractAxisTick implements Disposable {
    tickLevel: AxisTickLevel;
    value: number;
    private _removeFromAxis;
    private _restoreToAxis;
    protected readonly _labelLayer: LayerXY;
    protected readonly _labelScale: Vec2<Scale>;
    readonly label: Text;
    /**
     * @param   tickLevel       AxisTickLevel tick belongs to.
     * @param   value           Position of Tick on Axis.
     * @param   _removeFromAxis Remove handler for Tick.
     * @param   _restoreToAxis  Restore handler for Tick.
     * @param   _labelLayer     Layer for rendering Tick Label.
     * @param   _labelScale     Scale for rendering Tick label.
     * @param   label           Optionally injectable Tick Label shape.
     *                          Injection can be useful to reuse Tick shapes for performance.
     */
    constructor(tickLevel: AxisTickLevel, value: number, _removeFromAxis: RemoveHandler<AbstractAxisTick>, _restoreToAxis: RestoreHandler<AbstractAxisTick>, _labelLayer: LayerXY, _labelScale: Vec2<Scale>, label?: Text);
    /**
     * Restores all custom tick sub-elements
     * @returns This for fluid interface
     */
    restore(): this;
    /**
     * Disposes all tick sub-elements
     * @returns This for fluid interface
     */
    dispose(): this;
    /**
     * @return True if all sub-elements are disposed, false if not.
     */
    isDisposed(): boolean;
}
/**
 * Type union of AxisTickLevel types that have physical ticks.
 * @hidden
 */
export declare type AxisTickLevel = IndependentAxisTickLevel | PhysicalLayeredAxisTickLevel;
/**
 * Type of a scroll-easing function.
 * Defines how Axis scroll animation looks.
 * @hidden
 */
export declare type ScrollEasing = (cur: number, target: number, px: number) => number;
export {};
/**
 * Temporary duplicate definition of "Series2D". Necessary because 3D series do not implement Cursor yet.
 *
 * After implementing Cursor, this would be removed like follows:
 * - Remove Series2D from here.
 * - Replicate its usage with Series2D from chart/series2D.ts
 * - Rename Series2D to "Series"
 *      * Sub classes are: "Series2D" (current SeriesXY) and "Series3D"
 * @hidden
 */
export declare type Series = Series2D | Series3D;
/**
 * @hidden
 */
export interface AbstractAxisStrategy<SeriesType extends Series> {
}
/**
 * Type of a scroll strategy.
 * Consists of two scrolling functions:
 * 'start' and 'end'
 * @hidden
 */
export interface AxisScrollStrategy {
    /**
     * Scroll function for 'start' value.
     * Scrolls from interval 'scaleStart' - 'scaleEnd' according to 'contentMin' - 'contentMax' taking 'interpolation' into account
     * @param   scaleStart      'start' value of starting scale (not necessarily min!)
     * @param   scaleEnd        'end' value of starting scale (not necessarily max!)
     * @param   contentMin      Minimum value of content to scroll according to
     * @param   contentMax      Maximum value of content to scroll according to
     * @return                  'start' of resulting scale
     */
    start: (scaleStart: number, scaleEnd: number, contentMin: number, contentMax: number) => number;
    /**
     * Scroll function for 'end' value.
     * Scrolls from interval 'scaleStart' - 'scaleEnd' according to 'contentMin' - 'contentMax' taking 'interpolation' into account
     * @param   scaleStart      'start' value of starting scale (not necessarily min!)
     * @param   scaleEnd        'end' value of starting scale (not necessarily max!)
     * @param   contentMin      Minimum value of content to scroll according to
     * @param   contentMax      Maximum value of content to scroll according to
     * @return                  'end' of resulting scale
     */
    end: (scaleStart: number, scaleEnd: number, contentMin: number, contentMax: number) => number;
}
/**
 * Collection of available *AxisScrollStrategies*.
 *
 * *AxisScrollStrategies* can be used to customize the behavior of *Axis scrolling*.
 *
 * Use with [[Axis.setScrollStrategy]]
 */
export declare const AxisScrollStrategies: {
    /**
     * *Axis* will constantly scroll to fit attached *Series*.
     */
    fitting: AxisScrollStrategy;
    /**
     * *Axis* will scroll to fit *Series* that are out of view, but it won't shrink even if there is empty space (like "fitting" does).
     */
    expansion: AxisScrollStrategy;
    /**
     * *Axis* will scroll to show new, **progressive** data, but will keep its interval constant - leaving older data out of view.
     */
    progressive: AxisScrollStrategy;
    /**
     * *Axis* will scroll to show new, **regressive** data, but will keep its interval constant - leaving older data out of view.
     */
    regressive: AxisScrollStrategy;
};
/**
 * Properties of a (visible) TickStyle.
 */
export interface TickStyleProperties {
    /**
     * Length of GridStroke, where 1 = full and 0 = zero.
     */
    gridStrokeLength: number;
    /**
     * Style of GridStroke as a SolidLine object.
     */
    gridStrokeStyle: LineStyle;
    /**
     * Length of Tick itself as pixels.
     */
    tickLength: pixel;
    /**
     * Style of Tick itself as a SolidLine object.
     */
    tickStyle: LineStyle;
    /**
     * Padding after Tick as pixels.
     */
    tickPadding: pixel;
    /**
     * Font of Label as FontSettings.
     */
    labelFont: FontSettings;
    /**
     * FillStyle of Label.
     */
    labelFillStyle: FillStyle;
    /**
     * Padding after label as pixels.
     */
    labelPadding: pixel;
    /**
     * Horizontal alignment of Label respective to tick line.
     *
     * **left**: -1
     *
     * **center**: 0
     *
     * **right**: +1
     */
    labelAlignment: number;
}
/**
 * Abstract base class of an immutable Settings object for Axis Ticks.
 *
 * For implementations, see [[VisibleTicks]] and [[emptyTick]].
 * @hidden Internal class
 */
export declare abstract class TickStyle {
}
/**
 * Class which is used to style *Axis* *Ticks*. Use with [[Axis.setTickStyle]]
 *
 * Instances of VisibleTicks are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 *
 * When creating a new VisibleTicks object from scratch, parameters can be passed like follows:
 * - new VisibleTicks({ labelFillStyle: new SolidFill({ color: ColorHEX('#F00'), tickLength: 8 })
 */
export declare class VisibleTicks extends TickStyle {
    /**
     * When creating a new VisibleTicks object from scratch, parameters can be passed like follows:
     * - new VisibleTicks({ labelFillStyle: new SolidFill({ color: ColorHEX('#F00'), tickLength: 8 })
     * @param   props   Optional object containing parameters for creation of VisibleTicks
     */
    constructor(props?: Partial<TickStyleProperties>);
    /**
     * Construct a new VisibleTicks object based on this one, but with modified gridstroke length.
     * @param   length  Length of GridStroke, where 1 = full and 0 = zero.
     * @return          New VisibleTicks object
     */
    setGridStrokeLength(length: number): this;
    /**
     * Get length of GridStroke.
     * @return  Length of GridStroke, where 1 = full and 0 = zero.
     */
    getGridStrokeLength(): number;
    /**
     * Construct a new VisibleTicks object based on this one, but with modified GridStroke style.
     *
     * Example usage:
     *```javascript
     * // Specified SolidLine
     * VisibleTicks.setGridStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * VisibleTicks.setGridStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden
     * VisibleTicks.setGridStrokeStyle(emptyLine)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @return          New VisibleTicks object
     */
    setGridStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of GridStrokes.
     * @return  LineStyle object
     */
    getGridStrokeStyle(): LineStyle;
    /**
     * Set length of Ticks.
     * @param   length  Length of Ticks as pixels.
     * @return          New VisibleTicks object
     */
    setTickLength(length: pixel): this;
    /**
     * Get length of Ticks.
     * @return  Length of Ticks as pixels
     */
    getTickLength(): pixel;
    /**
     * Construct a new VisibleTicks object based on this one, but with modified Tick style.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * VisibleTicks.setGridStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * VisibleTicks.setGridStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden
     * VisibleTicks.setGridStrokeStyle(emptyLine)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @return          New VisibleTicks object
     */
    setTickStyle(style: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Ticks.
     * @return  LineStyle object
     */
    getTickStyle(): LineStyle;
    /**
     * Set padding after Tick as pixels.
     * @param   padding Padding after Tick as pixels.
     * @return          New VisibleTicks object with modified Tick padding
     */
    setTickPadding(padding: pixel): this;
    /**
     * Get padding after Tick as pixels.
     * @return  Padding after Tick as pixels.
     */
    getTickPadding(): pixel;
    /**
     * Set fill style of Labels.
     *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * VisibleTicks.setLabelFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * VisibleTicks.setLabelFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden
     * VisibleTicks.setLabelFillStyle(emptyFill)
     * ```
     * @param   value   Either a VisibleFill object or a function, which will be used to create a new VisibleFill based on current value.
     * @returns         New VisibleTicks object
     */
    setLabelFillStyle(style: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Label.
     * @return  Fill style of Label as a VisibleFill object
     */
    getLabelFillStyle(): FillStyle;
    /**
     * Construct a new VisibleTicks object based on this one, but with modified Label font.
     *
     * Example usage:
     *```javascript
     * // Specified FontSettings
     * VisibleTicks.setLabelFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Set to bold
     * VisibleTicks.setLabelFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @return          New VisibleTicks object
     */
    setLabelFont(font: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Labels.
     * @return  FontSettings object
     */
    getLabelFont(): FontSettings;
    /**
     * Set padding after label as pixels.
     * @param   padding Padding after label as pixels.
     * @return          New VisibleTicks object with modified Label padding
     */
    setLabelPadding(padding: pixel): this;
    /**
     * Get padding after label as pixels.
     * @return  Padding after label as pixels.
     */
    getLabelPadding(): pixel;
    /**
     * Set alignment of Label respective to tick line.
     *
     * **after**: -1
     *
     * **center**: 0
     *
     * **before**: +1
     * @param   alignment   Label alignment [-1, 1].
     * @return              New VisibleTicks object with modified Label alignment
     */
    setLabelAlignment(alignment: number): this;
    /**
     * Get horizontal alignment of Label respective to tick line.
     * @return  Horizontal alignment [-1, 1].
     */
    getLabelAlignment(): number;
}
/**
 * *TickStyle* singleton, which can be used to indicate that *Ticks* shouldn't be displayed.
 *
 * Can be used with *TickStrategies*.
 *
 * Example usage:
 * ```javascript
 * // Get Default Y Axis of XY Chart.
 * chart.getDefaultAxisY()
 *   // Modify the Axis' TickStrategy.
 *   .setTickStrategy(
 *      // Using a Numeric TickStrategy, modify it's Styler.
 *      AxisTickStrategies.Numeric, ( numericTickStrategy ) => numericTickStrategy
 *          // Set the Minor TickStyle of the TickStrategy as EmptyTick.
 *          .setMinorTickStyle( emptyTick )
 * )
 * ```
 */
export declare const emptyTick: TickStyle;
/**
 * Contains strategies for auto-fitting of Cursors.
 */
/**
 * Type of factory for AutoFitStrategy.
 *
 * This is the type passed to Cursors to set auto-fitting strategy.
 * @param   resultTable ResultTable object to operate with
 * @param   scale       Scale that ResultTable should fit inside
 * @hidden  Excluded from API document, even though it is public API.
 *          The types involved are not required and just reveal inside information.
 */
export declare type AutoFitStrategyFactory<ResultTableBackgroundType extends UIBackground> = (resultTable: ResultTable<ResultTableBackgroundType>, scale: Vec2<Scale>) => AutoFitStrategy<ResultTableBackgroundType>;
/**
 * Strategy that tries to automatically fit the ResultTable of Cursors into an arbitrary scale somehow.
 * AutoFitStrategy keeps track of its changes to the ResultTable and as such is aware if user has modified some relevant trait of it.
 * @hidden Internal class
 */
export declare abstract class AutoFitStrategy<ResultTableBackgroundType extends UIBackground> {
    protected _resultTable: InternalResultTable<ResultTableBackgroundType>;
    protected _scale: Vec2<Scale>;
    /**
     * @param   _resultTable ResultTable object to operate with
     * @param   _scale       Scale that ResultTable should fit inside
     * @hidden
     */
    constructor(_resultTable: InternalResultTable<ResultTableBackgroundType>, _scale: Vec2<Scale>);
    /**
     * Attempt to auto-fit ResultTable to scale.
     * @returns True, when ResultTable fits the scale after auto-fit
     */
    update(): boolean;
    /**
     * Restore any changes that strategy has made to ResultTable.
     */
    resetTable(): this;
}
/**
 * Auto fitting strategy that tries to fit ResultTable by flipping its origin.
 * @hidden Internal class
 */
declare class Flip<ResultTableBackgroundType extends UIBackground> extends AutoFitStrategy<ResultTableBackgroundType> {
}
/**
 * Auto fitting strategy that tries to fit ResultTable by reducing its fontSize
 * @hidden Internal class
 */
declare class FontSize<ResultTableBackgroundType extends UIBackground> extends AutoFitStrategy<ResultTableBackgroundType> {
    protected _minimumFontSize: number;
    protected _stepCount: number;
    /**
     * @param   resultTable     ResultTable object to operate with
     * @param   scale           Scale that ResultTable should fit inside
     * @param   _minimumFontSize Minimum font size that must be retained at all times
     */
    constructor(resultTable: InternalResultTable<ResultTableBackgroundType>, scale: Vec2<Scale>, _minimumFontSize: number, _stepCount: number);
}
interface AutoFitStrategies {
    Flip: <ResultTableBackgroundType extends UIBackground>(resultTable: InternalResultTable<ResultTableBackgroundType>, scale: Vec2<Scale>) => Flip<ResultTableBackgroundType>;
    FontSize: (minimumFontSize: number, stepCount: number) => (resultTable: InternalResultTable, scale: Vec2<Scale>) => FontSize<UIBackground>;
}
/**
 * Collection of *AutoFitStrategyFactories*.
 *
 * Used with *AutoCursor*s and *Marker*s **setAutoFitStrategy()** to customize logic for keeping *ResultTable* in view.
 */
export declare const AutoFitStrategies: AutoFitStrategies;
export {};
/**
 * File contains definition of a 'Cursor' + builder for their creation
 */
/**
 * Interface that is used to point a Cursor to a specific data-point.
 */
export interface CursorPoint<T extends Series2D = Series2D> {
    /**
     * Location of point
     */
    location: Point;
    /**
     * Scale where point is located
     */
    scale: Vec2<Scale>;
    /**
     * Contents for ResultTable
     */
    resultTableContent: ResultTableContent;
    /**
     * Series that contains point
     */
    series: T;
    /**
     * Optional attached fillStyle
     */
    fillStyle?: FillStyle;
}
/**
 * Cursor is a hidable element that can be positioned on a point using a
 * data-structure called 'DataPoint'. Cursors are formed from two
 * distinct parts, PointMarker and ResultTable, first of which
 * shows the location of the Cursor clearly and the second
 * to display information about the pointed DataPoint.
 */
export interface Cursor<PointMarkerType extends PointMarker = any, ResultTableBackgroundType extends UIBackground = any> extends Plotable, Disposable, Removable {
    /**
     * Points the Cursor at a given CursorPoint.
     * Updating its position and displayed data.
     */
    pointAt: (point: CursorPoint) => this;
    /**
     * Get current position of Cursor on its scale
     * @return              Position on Cursors scale
     */
    getPosition: () => Point;
    /**
     * Dispose PointMarker
     * @return Object itself for fluent interface
     */
    restorePointMarker(): this;
    /**
     * Restore PointMarker
     * @return Object itself for fluent interface
     */
    disposePointMarker(): this;
    /**
     * @return Weather PointMarker is disposed
     */
    isDisposedPointMarker: () => boolean;
    /**
     * Mutator function for PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position
     * @param   mutator     Mutator function for PointMarker
     * @return              Object itself for fluent interface
     */
    setPointMarker: (mutator: Mutator<PointMarkerType>) => this;
    /**
     * Get PointMarker object.
     * PointMarker is a visual that is displayed at the Cursors position
     * @returns             PointMarker object
     */
    getPointMarker: () => PointMarkerType;
    /**
     * Dispose ResultTable
     * @return Object itself for fluent interface
     */
    disposeResultTable: () => this;
    /**
     * Restore ResultTable
     * @return Object itself for fluent interface
     */
    restoreResultTable: () => this;
    /**
     * @return Weather ResultTable is disposed
     */
    isDisposeResultTable: () => boolean;
    /**
     * Mutator function for ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @param   mutator     Mutator function for ResultTable
     * @return              Object itself for fluent interface
     */
    setResultTable: (mutator: Mutator<ResultTable<ResultTableBackgroundType>>) => this;
    /**
     * Get ResultTable object.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @returns             ResultTable object
     */
    getResultTable: () => ResultTable<ResultTableBackgroundType>;
    /**
     * Set AutoFitStrategy of Cursor. Customizable logic which attempts to fit ResultTable to view.
     *
     * See [[AutoFitStrategies]] for available options.
     * @param   autoFitStrategy     AutoFitStrategy or undefined to disable auto-fitting
     * @returns                     Object itself for fluent interface
     */
    setAutoFitStrategy(autoFitStrategy?: AutoFitStrategyFactory<ResultTableBackgroundType>): this;
    /**
     * Get is AutoFitStrategy enabled. Customizable logic which attempts to fit ResultTable to view.
     * @returns                     Boolean flag whether auto-fit is enabled
     */
    getAutoFitStrategy(): boolean;
}
/**
 * Internal type for cursor
 * @hidden
 */
export declare type InternalCursor<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> = Cursor<PointMarkerType, ResultTableBackgroundType>;
/**
 * DynamicCursors can change their positioning scale whenever.
 */
export interface AutoCursor<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground> extends Cursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Set is ResultTable auto text fill style enabled.
     * When enabled, text of ResultTable will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on ResultTable might get overridden
     */
    setResultTableAutoTextStyle(enabled: boolean): this;
    /**
     * Get is ResultTable auto text fill style enabled.
     * When enabled, text of ResultTable will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getResultTableAutoTextStyle(): boolean;
}
/**
 * StaticCursors are always positioned on the same scale.
 */
export interface StaticCursor<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> extends Cursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Set the position of the Cursor,
     * moving it without modifying displayed data.
     */
    setPosition: (position: Point) => this;
}
/**
 * Base class for all cursors.
 * @hidden Internal class
 */
declare abstract class CursorBase<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> implements InternalCursor<PointMarkerType, ResultTableBackgroundType> {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>;
    protected _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>;
    /**
     * @param _layer                                Top layer of the rendering Engine
     * @param scale                                 Rendering scale of cursor. For dynamic cursor this is naturally not based on any axis
     * @param _pointMarkerConstructor               Constructor for PointMarker
     * @param _resultTableBackgroundConstructor     Constructor for ResultTableBackground
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>, _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>, _theme: Theme);
    /**
     * Points the Cursor at a given CursorPoint.
     * Updating its position and displayed data.
     * @param   cursorPoint Specifies new cursor location and content of result table
     */
    pointAt(cursorPoint: CursorPoint): this;
    /**
     * Get current position of Cursor
     * @return              Position on Cursors scale
     */
    getPosition(): Point;
    /**
     * Dispose of the owned pointMarker and resultTable.
     * @return  Object itself.
     */
    dispose(): this;
    /**
     * Restore the owned pointMarker and resultTable, restoring their child objects.
     * @return Object itself.
     */
    restore(): this;
    /**
     * @return True if all of this Cursor's child objects are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Dispose PointMarker
     * @return Object itself for fluent interface
     */
    disposePointMarker(): this;
    /**
     * Restore PointMarker
     * @return Object itself for fluent interface
     */
    restorePointMarker(): this;
    /**
     * @return Weather PointMarker is disposed
     */
    isDisposedPointMarker(): boolean;
    /**
     * Mutator function for Cursors PointMarker.
     * PointMarker is a visual that is displayed at the Cursors position
     * @param   mutator     Mutator function for PointMarker
     * @return              Object itself for fluent interface
     */
    setPointMarker(mutator: Mutator<PointMarkerType>): this;
    /**
     * Get PointMarker object.
     * PointMarker is a visual that is displayed at the Cursors position
     * @returns             PointMarker object
     */
    getPointMarker(): PointMarkerType;
    /**
     * Dispose ResultTable
     * @return Object itself for fluent interface
     */
    restoreResultTable(): this;
    /**
     * Restore ResultTable
     * @return Object itself for fluent interface
     */
    disposeResultTable(): this;
    /**
     * @return Weather ResultTable is disposed
     */
    isDisposeResultTable(): boolean;
    /**
     * Mutator function for Cursors ResultTable.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @param   mutator     Mutator function for ResultTable
     * @return              Object itself for fluent interface
     */
    setResultTable(mutator: Mutator<ResultTable<ResultTableBackgroundType>>): this;
    /**
     * Get ResultTable object.
     * ResultTable is a visual that displays currently pointed data next to its location
     * @returns             ResultTable object
     */
    getResultTable(): ResultTable<ResultTableBackgroundType>;
    /**
     * Set auto-fit strategy of Cursor.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @param   autoFitStrategy     AutoFitStrategy factory or undefined to disable auto-fitting
     * @returns                     Object itself for fluent interface
     */
    setAutoFitStrategy(autoFitStrategy?: AutoFitStrategyFactory<ResultTableBackgroundType>): this;
    /**
     * Get is auto-fit enabled.
     * Affects logic of automatic fitting of Cursors ResultTable to the screen.
     * @returns                     Boolean flag whether auto-fit is enabled
     */
    getAutoFitStrategy(): boolean;
}
/**
 * Base class for Auto cursors.
 * Users should create only using builders, not with constructor
 * @hidden Internal class
 */
export declare class InternalAutoCursor<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> extends CursorBase<PointMarkerType, ResultTableBackgroundType> implements AutoCursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Points the Cursor at a given CursorPoint.
     * Updating its position and displayed data.
     */
    pointAt(cursorPoint: CursorPoint): this;
    /**
     * Set is ResultTable auto text fill style enabled.
     * When enabled, text of ResultTable will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on ResultTable might get overridden
     */
    setResultTableAutoTextStyle(enabled: boolean): this;
    /**
     * Get is ResultTable auto text fill style enabled.
     * When enabled, text of ResultTable will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getResultTableAutoTextStyle(): boolean;
}
/**
 * Base class for Static cursors.
 * Users should create only using builders, not with constructor
 * @hidden Internal class
 */
export declare class InternalStaticCursor<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> extends CursorBase<PointMarkerType, ResultTableBackgroundType> implements StaticCursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Set position of cursor,
     * moving it without modifying displayed data.
     * @param   position    Position on Cursors scale
     * @return              Object itself
     */
    setPosition(position: Point): this;
}
/**
 * Mutator function that is used for modifying a Cursor during runtime.
 */
export declare type CursorStyler<T extends Cursor> = Mutator<T>;
/**
 * Base class for cursor builders.
 * Cursor builders build cursors with parts of types as indicated by the builders type.
 * All setters of Cursor builders create new builders based on their current state and don't modify the actual object.
 * @hidden Internal class. At the moment we do not allow users to create own cursors.
 */
export declare abstract class CursorBuilder<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, CursorType extends Cursor<PointMarkerType, ResultTableBackgroundType>> {
    protected _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>;
    protected _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>;
    protected _stylers: CursorStyler<CursorType>[];
    /**
     * @param _pointMarkerConstructor            Constructor for PointMarker
     * @param _resultTableBackgroundConstructor  Constructor for Background of ResultTable
     * @param _stylers                           List of stylers
     * @hidden
     */
    constructor(_pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>, _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>, _stylers?: CursorStyler<CursorType>[]);
    /**
     * Create new CursorBuilder with an additional styler.
     * @param   cursorStyler    Cursor styler function
     * @returns                 CursorBuilder of same type
     */
    abstract addStyler: (cursorStyler: CursorStyler<CursorType>) => CursorBuilder<PointMarkerType, ResultTableBackgroundType, Cursor<PointMarkerType, ResultTableBackgroundType>>;
    /**
     * Create new CursorBuilder with a different PointMarker.
     * @param   pointMarkerConstructor  Constructor for PointMarker. See [[PointMarkers]] for a collection of options.
     * @returns                         CursorBuilder of same type
     */
    abstract setPointMarker: <T extends InternalPointMarker & PointMarkerType>(pointMarkerConstructor: PointMarkerConstructor<T>) => CursorBuilder<T, ResultTableBackgroundType, Cursor<T, ResultTableBackgroundType>>;
    /**
     * Create new CursorBuilder with a different ResultTable Background.
     * @param   resultTableBackgroundConstructor    Constructor for Background
     * @returns                                     CursorBuilder of same type
     */
    abstract setResultTableBackground: <T extends InternalBackground & ResultTableBackgroundType>(resultTableBackgroundConstructor: BackgroundConstructor<T>) => CursorBuilder<PointMarkerType, T, Cursor<PointMarkerType, T>>;
}
/**
 * Builder for auto cursors
 * @hidden
 */
export interface AutoCursorBuilder<CursorType extends Cursor> {
}
/**
 * Builder for auto-cursors without axes.
 */
export declare class AutoCursor2DBuilder<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground> extends CursorBuilder<PointMarkerType, ResultTableBackgroundType, AutoCursor<PointMarkerType, ResultTableBackgroundType>> implements AutoCursorBuilder<AutoCursor<PointMarkerType, ResultTableBackgroundType>> {
    /**
     * Create new CursorBuilder with an additional styler.
     * @param   cursorStyler    Cursor styler function
     * @returns                 CursorBuilder of same type
     */
    addStyler: (cursorStyler: Mutator<AutoCursor<PointMarkerType, ResultTableBackgroundType>>) => AutoCursor2DBuilder<PointMarkerType, ResultTableBackgroundType>;
    /**
     * Create new CursorBuilder with a different PointMarker.
     * @param   pointMarkerConstructor  Constructor for PointMarker. See [[PointMarkers]] for a collection of options.
     * @returns                         CursorBuilder of same type
     */
    setPointMarker: <T extends UIElement & PointMarker & PointMarkerType>(pointMarkerConstructor: PointMarkerConstructor<T>) => AutoCursor2DBuilder<T, ResultTableBackgroundType>;
    /**
     * Create new CursorBuilder with a different ResultTable Background.
     * @param   resultTableBackgroundConstructor Constructor for Background
     * @returns                                  CursorBuilder of same type
     */
    setResultTableBackground: <T extends InternalBackground & ResultTableBackgroundType>(resultTableBackgroundConstructor: BackgroundConstructor<T>) => AutoCursor2DBuilder<PointMarkerType, T>;
}
/**
 * Builder for static cursors without axes.
 */
export declare class StaticCursor2DBuilder<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground> extends CursorBuilder<PointMarkerType, ResultTableBackgroundType, StaticCursor<PointMarkerType, ResultTableBackgroundType>> {
    /**
     * Create new CursorBuilder with an additional styler.
     * @param   cursorStyler    Cursor styler function
     * @returns                 CursorBuilder of same type
     */
    addStyler: (cursorStyler: Mutator<StaticCursor<PointMarkerType, ResultTableBackgroundType>>) => StaticCursor2DBuilder<PointMarkerType, ResultTableBackgroundType>;
    /**
     * Create new CursorBuilder with a different PointMarker.
     * @param   pointMarkerConstructor  Constructor for PointMarker. See [[PointMarkers]] for a collection of options.
     * @returns                         CursorBuilder of same type
     */
    setPointMarker: <T extends UIElement & PointMarker & PointMarkerType>(pointMarkerConstructor: PointMarkerConstructor<T>) => StaticCursor2DBuilder<T, ResultTableBackgroundType>;
    /**
     * Create new CursorBuilder with a different ResultTable Background.
     * @param   resultTableBackgroundConstructor    Constructor for Background
     * @returns                                     CursorBuilder of same type
     */
    setResultTableBackground: <T extends InternalBackground & ResultTableBackgroundType>(resultTableBackgroundConstructor: BackgroundConstructor<T>) => StaticCursor2DBuilder<PointMarkerType, T>;
}
export {};
/**
 * File contains definition and default implementations of PointMarker,
 * a purely decorative visual part of all Cursors
 */
/**
 * Visual that is displayed at the Cursors position.
 * Has customizable fill and border.
 */
export interface PointMarker extends Marginable {
    /**
     * Set origin position of PointMarker
     * @param   origin  (-1 to 1 which specifies position of origin, 0 is center of the object)
     * @returns         Object itself for fluent interface
     */
    setOrigin: (origin: Point) => this;
    /**
     * Get origin position of PointMarker
     * @returns         (-1 to 1 which specifies position of origin, 0 is center of the object)
     */
    getOrigin: () => Point;
    /**
     * Set size of PointMarker
     * @param   size        Size of PointMarker in pixels
     * @returns             Object itself
     */
    setSize: (size: Point) => this;
    /**
     * Get size of PointMarker
     * @returns             Size of PointMarker in pixels
     */
    getSize: () => Point;
    /**
     * Set fillStyle of PointMarker
     * @param   fillStyle   FillStyle object or mutator to modify existing one
     * @returns             Object itself
     */
    setFillStyle: (fillStyle: FillStyle | ImmutableMutator<FillStyle>) => this;
    /**
     * Get fillStyle of PointMarker
     * @returns             FillStyle object
     */
    getFillStyle: () => FillStyle;
    /**
     * Set stroke style of PointMarker
     * @param   value   LineStyle object
     * @returns         Object itself
     */
    setStrokeStyle: (value: LineStyle | ImmutableMutator<LineStyle>) => this;
    /**
     * Get stroke style of PointMarker
     * @returns         LineStyle object
     */
    getStrokeStyle: () => LineStyle;
    /**
     * @return True if all child objects are disposed, false if not.
     */
    isDisposed(): boolean;
}
/**
 * Internal type used to limit access to PointMarker
 * @hidden
 */
export declare type InternalPointMarker = UIElement & PointMarker;
/**
 * Type of constructor for PointMarker
 * @hidden
 */
export declare type PointMarkerConstructor<T extends InternalPointMarker = InternalPointMarker> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme) => T;
/**
 * File contains definition and implementations of ResultTable,
 * a visual part of all Cursors whose purpose is to show information about the data-point the Cursor is pointing at.
 */
/**
 * Interface that represents content displayable by a ResultTable.
 *
 * Currently simply a grid of strings, but in the future this could be extended to contain images or such.
 */
export declare type ResultTableContent = Array<string | undefined>[];
/**
 * Class for user customizable building of 'TableContent'.
 * Basically the way users modify what cursors show (on level of a single series), is to
 * set a function that builds TableContent based on information given by the series.
 * Internal class
 */
export declare abstract class TableContentBuilder {
    /**
     * Add a row to built content.
     * @param   cells   Any amount of cells row should contain. Undefined or '' marks a "gap", which will occupy any extra space of row.
     * @return          Object itself
     */
    addRow(...cells: (string | undefined)[]): this;
}
/**
 * Internal class for TableContentBuilder.
 * This contains the methods that are not visible to users.
 * @hidden Internal class
 */
export declare class InternalTableContentBuilder extends TableContentBuilder {
}
/**
 * Public interface for ResultTable.
 * Part of Cursor that displays information about current data-point.
 */
export interface ResultTable<BackgroundType extends UIBackground = UIBackground> extends Marginable {
    /**
     * Set displayed data of ResultTable
     * @param   data    TableContent
     * @returns         Object itself for fluent interface
     */
    setContent: (data: ResultTableContent) => this;
    /**
     * Set origin position of ResultTable
     * @param   origin  (-1 to 1 which specifies position of origin, 0 is center of the object)
     * @returns         Object itself for fluent interface
     */
    setOrigin: (origin: Point) => this;
    /**
     * Get origin position of v
     * @returns         (-1 to 1 which specifies position of origin, 0 is center of the object)
     */
    getOrigin: () => Point;
    /**
     * Set text fillStyle of ResultTable text
     * @param   fillStyle   FillStyle object or mutator to modify existing one
     * @returns             Object itself
     */
    setTextFillStyle: (fillStyle: FillStyle | ImmutableMutator<FillStyle>) => this;
    /**
     * Get text fillStyle of ResultTable
     * @returns             FillStyle object
     */
    getTextFillStyle: () => FillStyle;
    /**
     * Set font of ResultTable.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself for fluent interface
     */
    setFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of ResultTable.
     * @return          FontSettings
     */
    getFont(): FontSettings;
    /**
     * Mutator function for Background of ResultTable.
     * @param   mutator Mutator function
     * @return          Object itself for fluent interface
     */
    setBackground(mutator: Mutator<BackgroundType>): this;
    /**
     * Get background object of ResultTable
     * @return          Background object
     */
    getBackground(): BackgroundType;
}
/**
 * Internal ResultTable class.
 * @hidden Internal class
 */
export declare class InternalResultTable<BackgroundClass extends UIBackground = UIBackground> extends UIRowGrid<BackgroundClass> implements ResultTable<BackgroundClass> {
    /**
     * Set displayed data of ResultTable
     * @param   content TableContent
     * @returns         Object itself for fluent interface
     */
    setContent(content: ResultTableContent): this;
    restore(): this;
    /**
     * Set text fill style
     * @param value Fill style object or mutator to modify existing one
     * @return      Object itself for fluent interface
     */
    setTextFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return Current fill style object
     */
    getTextFillStyle(): FillStyle;
    /**
     * Set font of Label.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Label.
     * @return          FontSettings
     */
    getFont(): FontSettings;
}
/**
 * Enum that defines layer indices of PieChart.
 * @hidden
 */
export declare enum LayerIndices {
    bg = 0,
    bottom = 1,
    top = 2,
    ui = 3
}
declare type SliceTypes = PieSlice | FunnelSlice;
/**
 * SliceLabelIndices enum defines types of Slice labels .
 */
export declare enum SliceLabelIndices {
    LabelsInsideSlices = 0,
    LabelsOnSides = 1
}
/**
 * Interface exists for enforcing shared APIs between Pie, Funnel and Pyramid Charts.
 */
export interface SlicedCharts<T extends SliceTypes> {
    /**
     * Set lookup table
     * @value lookup table
     * @return Chart itself
     */
    setLUT(value: LUT): this;
    /**
     * Set fill style of Slices Labels.
     * @param   value   FillStyle object or function which creates a new style based on previous
     * @return          Chart itself
     */
    setLabelFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Slice Labels.
     * @return  FillStyle object
     */
    getLabelFillStyle(): FillStyle;
    /**
     * Set font of Slice Labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Chart itself
     */
    setLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Slice Labels.
     * @return  FontSettings
     */
    getLabelFont(): FontSettings;
    /**
     * Set formatter of Slice Labels.
     *
     * See [[SliceLabelFormatters]] for a collection of default options.
     * @param   labelFormatter  SliceLabelFormatter - function which generates text of Labels per Slice.
     * @return                  Chart itself
     */
    setLabelFormatter(labelFormatter: SliceLabelFormatter<T>): this;
    /**
     * Get formatter of Slice Labels.
     * @return  SliceLabelFormatter - function which generates text of Labels per Slice.
     */
    getLabelFormatter(): SliceLabelFormatter<T>;
    /**
     * Set style of Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Chart will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Sliced Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @param   sliceFillStylePalette   Palette for FillStyle objects
     * @return                          Chart itself
     */
    setSliceFillStyle(sliceFillStylePalette: Palette<FillStyle>): this;
    /**
     * Get style of Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Chart will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Sliced Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @return  Palette<FillStyle>
     */
    getSliceFillStyle(): Palette<FillStyle>;
    /**
     * Set style of Slices Stroke.
     * @param   value   LineStyle object or function which creates a new style based on previous
     * @return          Chart itself
     */
    setSliceStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Slices Stroke.
     * @return  LineStyle object
     */
    getSliceStrokeStyle(): LineStyle;
    /**
     * Set sorter of Slices as a comparator-function.
     *
     * For some commonly needed default implementations, can refer to [[SliceSorters]] collection.
     * @param   sliceSorter SliceSorter - function which sorts Slices of the Chart with JavaScript API: Array.sort.
     * @return              Chart itself
     */
    setSliceSorter(sliceSorter: SliceSorter<T>): this;
    /**
     * Get sorter of Slices as a comparator-function.
     * @return  SliceSorter - function which sorts Slices of the Chart with JavaScript API: Array.sort.
     */
    getSliceSorter(): SliceSorter<T>;
    /**
     * This method is used for the adding slices in the Chart.
     * @param title Slice title
     * @param value  Slice value
     */
    addSlice(title: string, value: number): T;
    /**
     * This method is used for the adding multiple slices in the Chart.
     * @param multiSlice Array of slices
     */
    addSlices(multiSlice: {
        name: string;
        value: number;
    }[]): Array<T>;
    /**
     * Set if Slice should be highlighted when hovered over for all Slices.
     * @param state True if Slice should highlight on hover, false if not.
     * @return      Chart itself
     */
    setSliceHighlightOnHover(state: boolean): this;
}
/**
 * Type of function which is used to sort Slices of a Chart with Slices.
 * It is a comparator function used with JavaScript API: Array.sort.
 *
 * See [[SliceSorters]] collection for quick access to some example implementations.
 *
 * Use with [[SlicedCharts.setSliceSorter]]
 *
 * Example usage:
 *```javascript
 * // Use a default implementation
 * SlicedCharts.setSliceSorter(SliceSorters.SortByValueDescending)
 * // Use a custom implementation
 * SlicedCharts.setSliceSorter((a, b) => a.getValue() - b.getValue())
 * ```
 * @param   sliceA  Slice A
 * @param   sliceB  Slice B
 * @return          Number which implies the sorted order between Slices A and B.
 *                  For more details, refer to Array documentation.
 */
export declare type SliceSorter<T extends SliceTypes> = (sliceA: T, sliceB: T) => number;
/**
 * Collection of some example implementations of [[SliceSorter]]
 *
 * Use with [[SlicedCharts.setSliceSorter]]
 *
 * Example usage:
 *```javascript
 * // Use a default implementation
 * SlicedCharts.setSliceSorter(SliceSorters.SortByValueDescending)
 * // Use a custom implementation
 * SlicedCharts.setSliceSorter((a, b) => a.getValue() - b.getValue())
 * ```
 */
export declare const SliceSorters: {
    /**
     * SliceSorter that sorts Slices based on their names using JS API: String.localeCompare.
     */
    SortByName: SliceSorter<SliceTypes>;
    /**
     * SliceSorter that sorts Slices to ascending value order.
     */
    SortByValueAscending: SliceSorter<SliceTypes>;
    /**
     * SliceSorter that sorts Slices to descending value order.
     */
    SortByValueDescending: SliceSorter<SliceTypes>;
    /**
     * Disabled Slice sorting.
     */
    None: SliceSorter<SliceTypes>;
};
/**
 * Type of function which is used to format text of Slice Labels.
 * It is a function which generates a string based on a Slice along with some additional information.
 *
 * See [[SliceLabelFormatters]]-collection for quick access to some example implementations.
 *
 * Use with [[SlicedCharts.setLabelFormatter]]
 *
 * Example usage:
 *```javascript
 * // Use a default implementation
 * SlicedCharts.setLabelFormatter(SliceLabelFormatters.NamePlusRelativeValue)
 * // Use a custom implementation
 * SlicedCharts.setLabelFormatter((slice, relativeValue) => slice.getValue() + ' €')
 * ```
 * @param   slice           Slice
 * @param   relativeValue   Value of the Slice as a % of all Slice values
 * @return                  String text for Label
 */
export declare type SliceLabelFormatter<T extends SliceTypes> = (slice: T, relativeValue: number) => string;
/**
 * Collection of some example implementations of [[SliceLabelFormatters]].
 *
 * Use with [[SlicedCharts.setLabelFormatter]]
 *
 * Example usage:
*```javascript
 * // Use a default implementation
 * SlicedCharts.setLabelFormatter(SliceLabelFormatters.NamePlusRelativeValue)
 * // Use a custom implementation
 * SlicedCharts.setLabelFormatter((slice, relativeValue) => slice.getValue() + ' €')
 * ```
 */
export declare const SliceLabelFormatters: {
    /**
     * Slice Label formatter for `${name}`.
     */
    Name: SliceLabelFormatter<SliceTypes>;
    /**
     * Slice Label formatter for `${name}: ${Math.round(animatedValue)}`.
     */
    NamePlusValue: SliceLabelFormatter<SliceTypes>;
    /**
     * Slice Label formatter for `${name}: ${(relativeValue * 100).toFixed(1)}%`.
     */
    NamePlusRelativeValue: SliceLabelFormatter<SliceTypes>;
};
export {};
/**
 * Class that represents a single Slice of a Pie Chart.
 */
export declare abstract class Slice<SliceVisual extends ChartVisual> extends ChartComponent<SliceVisual> {
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    abstract setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    abstract getValue(): number;
    /**
     * Get animated value of Slice.
     *
     * This always returns the currently **rendered value** of the Slice, which might be delayed by animations.
     * @return          Numeric value
     */
    abstract getAnimatedValue(): number;
}
/**
 * Type of data-structure that defines how an axis label is positioned.
 */
export interface SpiderAxisLabelPosition {
    /**
     * Alignment X [-1, 1], where -1 is left and 1 is right extreme
     */
    alignmentX: number;
    /**
     * Alignment Y [-1, 1], where -1 is bottom and 1 is top extreme
     */
    alignmentY: number;
    /**
     * Padding in X direction as pixels
     */
    paddingX: number;
    /**
     * Padding in Y direction as pixels
     */
    paddingY: number;
}
/**
 * Type of an axis label strategy function.
 * Defines how axis labels are aligned.
 * @param   result              DataStructure that is used to pass result
 * @param   axisIndex           Index of axis. 0 is always directly up
 * @param   axisCount           Amount of axes in chart
 * @param   axisTag             Name of axis
 * @param   axisAngle           Angle of axis in radians
 * @param   labelPadding        Label padding as set in chart
 * @return                      SpiderAxisLabelPosition (modified first parameter of function)
 */
export declare type SpiderAxisLabelStrategy = (result: SpiderAxisLabelPosition, axisIndex: number, axisCount: number, axisTag: string, axisAngle: number, labelPadding: number) => SpiderAxisLabelPosition;
/**
 * Default axis label strategy for spider charts.
 * @hidden
 */
export declare const _defaultSpiderAxisLabelStrategy: SpiderAxisLabelStrategy;
/**
 * Type of data-structure that defines how an axis label is positioned on a Spider Chart.
 */
export interface SpiderScaleLabelPosition {
    /**
     * Alignment X [-1, 1], where -1 is left and 1 is right extreme
     */
    alignmentX: number;
    /**
     * Alignment Y [-1, 1], where -1 is bottom and 1 is top extreme
     */
    alignmentY: number;
    /**
     * Padding in X direction as pixels
     */
    paddingX: number;
    /**
     * Padding in Y direction as pixels
     */
    paddingY: number;
}
/**
 * Type of a scale label strategy function.
 * Defines how scale labels are aligned.
 * @param   result              DataStructure that is used to pass result
 * @param   axisIndex           Index of axis. 0 is always directly up
 * @param   axisCount           Amount of axes in chart
 * @param   axisTag             Name of axis
 * @param   axisAngle           Angle of axis in radians
 * @param   webIndex            Index of web. 0 is always the outer-edge of spider
 * @param   webCount            Amount of webs in chart
 * @param   labelPadding        Label padding as set in chart
 * @return                      SpiderScaleLabelPosition (modified first parameter of function) or undefined to not display label
 */
export declare type SpiderScaleLabelStrategy = (result: SpiderScaleLabelPosition, axisIndex: number, axisCount: number, axisTag: string, axisAngle: number, webIndex: number, webCount: number, labelPadding: number) => SpiderScaleLabelPosition | undefined;
/**
 * Default scale label strategy for spider charts.
 * Displays scale labels only on first axis of spider chart.
 * @hidden
 */
export declare const _defaultSpiderScaleLabelStrategy: SpiderScaleLabelStrategy;
/**
 * Container for shapes of spider axes and drawing logic.
 * @hidden Internal class
 */
export declare class SpiderAxis {
    readonly gridLayer: LayerXY<Engine>;
    readonly labelLayer: LayerXY<Engine>;
    readonly scale: Vec2<Scale>;
    readonly chart: SpiderChart;
    readonly tag: string;
    readonly axisScale: Scale;
    private _setupMouseInteractions;
    private readonly _remove;
    private readonly _restore;
    /**
     * Axis line
     */
    shapeAxis: Line;
    /**
     * Axis tag label
     */
    shapeTag: Text;
    /**
     * Nib shape
     */
    shapeNib: LineSet;
    /**
     * @param  gridLayer                Rendering layer for axis line
     * @param  labelLayer               Rendering layer for axis labels and nib
     * @param  scale                    Scale object used in rendering axis shapes. Must be in pixels!
     * @param  chart                    SpiderChart object which would contain this axis. Is used to query chart margins
     * @param  tag                      String tag of the axis
     * @param  axisScale                Reference to axisScale of chart. Mainly used for cursor formating
     * @param  _setupMouseInteractions   Injected method that adds mouse-interactions to axis nib
     * @param  _remove                   Injected remove method from owner, used to remove Axis from the collection it's in.
     */
    constructor(gridLayer: LayerXY<Engine>, labelLayer: LayerXY<Engine>, scale: Vec2<Scale>, chart: SpiderChart, tag: string, axisScale: Scale, _setupMouseInteractions: (axis: SpiderAxis, nib: LineSet) => LineSet, _remove: RemoveHandler<SpiderAxis>, _restore: RestoreHandler<SpiderAxis>);
    /**
     * Update axis label style and return its computed size.
     * Used for computation of chart margins before drawing.
     */
    getLabelSize(): Point;
    /**
     * Disposes SpiderAxis' shapes from its rendering engine, then tell owner to remove this SpiderAxis from its collections.
     */
    dispose(): void;
    /**
     * Restore the SpiderAxis back to the SpiderChart it belongs to.
     */
    restore(): void;
    /**
     * Get the isDisposed state of child objects.
     * @return  True if all child objects are disposed, false if any are not.
     */
    isDisposed(): boolean;
}
/**
 * Interface that can be used to define *Spider Chart* configurations that can't be changed after creation.
 *
 * Example usage:
 *
 * | Desired result                                 | Value                                                                                                     |
 * | :--------------------------------------------- | :-------------------------------------------------------------------------------------------------------- |
 * | Default                                        | *undefined*                                                                                               |
 * | Preset theme                                   | { **theme**: *Themes*.light }                                                                         |
 * | Specified AutoCursor ResultTable Background    | { **autoCursorBuilder:** *AutoCursorBuilders*.Spider.setResultTableBackground(*UIBackgrounds*.Circle) }   |
 */
export interface SpiderChartOptions<CursorPointMarkerType extends PointMarker = PointMarker, CursorResultTableBackgroundType extends UIBackground = UIBackground> extends CommonChartOptions {
    /**
     * Builder for the Charts AutoCursor. If omitted, a default one will be used.
     * AutoCursorBuilders.Spider can be used to build a custom one from scratch.
     */
    autoCursorBuilder?: AutoCursor2DBuilder<CursorPointMarkerType, CursorResultTableBackgroundType>;
}
/**
 * Chart for visualizing data in a radial form as dissected by named axes.
 *
 * *Charts* are created by methods of [[LightningChart]] interface or a [[Dashboard]].
 *
 * A **SpiderChart** can have any number of [[SpiderSeries]] added to it using [[SpiderChart.addSeries]].
 * Data can then be pushed in with [[SpiderSeries.addPoints]]
 *
 * By default, *SpiderChart* automatically creates *Axes* based on the data that are pushed to its *Series*.
 */
export declare class SpiderChart<CursorPointMarkerType extends PointMarker = PointMarker, CursorResultTableBackgroundType extends UIBackground = UIBackground> extends ChartWithCursor<SpiderSeries, CursorPointMarkerType, CursorResultTableBackgroundType, AutoCursor<CursorPointMarkerType, CursorResultTableBackgroundType>> {
    /**
     * Scale of axes. Used for formatting and scaling series
     */
    readonly axisScale: Scale;
    /**
     * @param   layerSupplier           Rendering layer supplier
     * @param   logoFactory             Logo factory.
     * @param   autoCursorBuilder       AutoCursorBuilder. If undefined or omitted, auto cursor will be disabled
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @param   theme                   Theme used to style elements in the Chart.
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, spiderChartOptions?: SpiderChartOptions<CursorPointMarkerType, CursorResultTableBackgroundType>, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface);
    /**
     * Add a new axis to Spider Chart
     * @param axis  Axis tag
     * @returns     Object itself
     */
    addAxis(tagOrAxis: string): this;
    /**
     * Remove axis from Spider Chart
     * @param tagOrAxis     Axis or tag of an Axis which has to be removed
     * @returns             Object itself for fluent interface
     */
    removeAxis: (tagOrAxis: string | SpiderAxis) => this;
    /**
     * Restore given axis to the Spider Chart.
     * @param   axis    Axis to restore.
     * @return          This.
     */
    restoreAxis: (axis: SpiderAxis) => this;
    /**
    * Check if Chart has an Axis with specified tag
    * @param tag   Name of desirable axis
    * @returns     True if axis exists, false if not.
    */
    hasAxis: (tag: string) => boolean;
    /**
     * Format value along an axis.
     * @param   value       Value along an axis
     * @param   formatter   Optional explicit formating function
     * @return              Value formated to string
     */
    formatValue: (value: number) => string;
    /**
     * Adds a new SpiderSeries to the SpiderChart.
     * @param   pointShape  Shape of points for SpiderSeries. Defaults to PointShape.Circle
     *
     * @returns             SpiderSeries instance
     */
    addSeries(pointShape?: PointShape): SpiderSeries;
    /**
     * Get number of series inside chart.
    * @return Amount of series inside chart
     */
    getSeriesCount(): number;
    /**
     * Get series of a chart
     * @return  series
     */
    getSeries(): SpiderSeries[];
    /**
     * Set mode of SpiderCharts web and background.
     * @param   webMode     Enum SpiderWebMode
     * @return              Object itself
     */
    setWebMode(webMode: SpiderWebMode): this;
    /**
     * Get mode of SpiderCharts web and background.
     * @return              Enum SpiderWebMode
     */
    getWebMode(): SpiderWebMode;
    /**
     * Set count of 'webs' displayed.
     * @param   webCount    Count of web lines
     * @return              Object itself
     */
    setWebCount(webCount: number): this;
    /**
     * Get count of 'webs' displayed
     * @return              Count of web lines
     */
    getWebCount(): number;
    /**
     * Set style of spider charts webs as LineStyle.
     * @param   value   LineStyle object or mutator to modify existing one
     * @return          Object itself
     */
    setWebStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get fill style of web lines.
     * @return              LineStyle object
     */
    getWebStyle(): LineStyle;
    /**
     * Set fill style of scale labels.
     * @param   value   FillStyle object or mutator to modify existing one
     */
    setScaleLabelStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of scale labels.
     * @return              FillStyle object
     */
    getScaleLabelStyle(): FillStyle;
    /**
     * Set font of scale labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setScaleLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of scale labels.
     * @return          FontSettings
     */
    getScaleLabelFont(): FontSettings;
    /**
     * Set padding of scale labels.
     * @param   padding     Padding in pixels
     * @return              Object itself
     */
    setScaleLabelPadding(padding: pixel): this;
    /**
     * Get padding of scale labels.
     * @return              Padding in pixels
     */
    getScaleLabelPadding(): pixel;
    /**
     * Set strategy for drawing scale labels.
     * Defines on which positions labels are drawn and whether they are flipped or not.
     * @param   scaleLabelStrategy  SpiderScaleLabelStrategy or undefined to never show scale labels
     * @return                      Object itself
     */
    setScaleLabelStrategy(scaleLabelStrategy?: SpiderScaleLabelStrategy): this;
    /**
     * Set fill style of axis labels.
     * @param   value   FillStyle object or mutator to modify existing one
     * @return                      Object itself
     */
    setAxisLabelStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of axis labels.
     * @return              FillStyle object
     */
    getAxisLabelStyle(): FillStyle;
    /**
     * Set font of axis labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setAxisLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of axis labels.
     * @return          FontSettings object
     */
    getAxisLabelFont(): FontSettings;
    /**
     * Set padding of axis labels.
     * NOTE: The value of this padding is simply passed to the axis label strategy of chart,
     * so overriding the default strategy will naturally leave the handling of padding logic up to you.
     * @param   padding     Padding in pixels
     * @return              Object itself
     */
    setAxisLabelPadding(padding: pixel): this;
    /**
     * Get padding of axis labels.
     * NOTE: The value of this padding is simply passed to the axis label strategy of chart,
     * so overriding the default strategy will naturally leave the handling of padding logic up to you.
     * @return              Padding in pixels
     */
    getAxisLabelPadding(): pixel;
    /**
     * Set strategy for drawing axis labels.
     * Defines how axis labels are aligned.
     * @param   axisLabelStrategy   SpiderAxisLabelStrategy or undefined to never show axis labels
     * @return                      Object itself
     */
    setAxisLabelStrategy(axisLabelStrategy?: SpiderAxisLabelStrategy): this;
    /**
     * Set style of axes as SolidLine.
     * @param   value       SolidLine object or mutator to modify existing one
     * @return              Object itself
     */
    setAxisStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Get style of axes as SolidLine.
     * @return              SolidLine object
     */
    getAxisStyle(): SolidLine;
    /**
     * Set style of axis nibs as SolidLine.
     * @param   value       SolidLine object or mutator to modify existing one
     * @return              Object itself
     */
    setNibStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Get style of axis nibs as SolidLine.
     * @return              SolidLine object
     */
    getNibStyle(): SolidLine;
    /**
     * Set length of axis nibs in pixels.
     * @param   length      Sum length of nibs in pixels (both directions)
     */
    setNibLength(length: number): this;
    /**
     * Get length of axis nibs in pixels.
     * @return              Length of nibs in pixels
     */
    getNibLength(): number;
    /**
     * Specifies if auto creation of axis is turned on or not
     * @param   createAxesAutomatically     State of automatic axis creation
     * @returns                             Object itself for fluent interface
     */
    setAutoAxis(createAxesAutomatically: boolean): this;
    /**
     * @return Automatic axis creation state
     */
    getAutoAxis(): boolean;
    /**
     * Sets if animations are enabled or not
     */
    setAnimationsEnabled(animationsEnabled: boolean): this;
    /**
     * Gets if animations are enabled or not
     */
    getAnimationsEnabled(): boolean;
    /**
     * Disable all animations for the chart.
     *
     * All animations have to be re-enabled individually if you wish to re-enable animations.
     * @return  Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Set if mouse-interactions on chart are enabled or not
     * @param   enabled     Boolean flag
     * @return              Object itself
     */
    setMouseInteractions(enabled: boolean): this;
    /**
     * Get are mouse-interactions on chart enabled or not
     * @return              Boolean flag
     */
    getMouseInteractions(): boolean;
    /**
     * Sets the AxisScrollStrategy of Charts Axes
     * @param scrollStrategy    AxisScrollStrategy or undefined to disable automatic scrolling.
     *                          See [[AxisScrollStrategies]] for a collection of options.
     * @returns                 Object itself
     */
    setAxisScrollStrategy(scrollStrategy?: AxisScrollStrategy): this;
    /**
     * Gets the AxisScrollStrategy of Charts Axes
     */
    getAxisScrollStrategy(): AxisScrollStrategy | undefined;
    /**
     * Set interval of Charts Axes
     * @param   edge    Value at edges of chart
     * @param   center  Value at center of chart. Defaults to zero
     * @return          Object itself
     */
    setAxisInterval(edge: number, center?: number): this;
    /**
     * Get axis value at center of chart
     * @return          Value at center of chart
     */
    getOriginValue(): number;
    /**
     * Get axis value at edges of chart
     * @return          Value at edges of chart
     */
    getEdgeValue(): number;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
}
/**
 * Interface for data-structure that is used to pass data-points to SpiderSeries.
 */
export interface SpiderPoint {
    /**
     * Name of Axis in SpiderChart.
     */
    axis: string;
    /**
     * Numeric data value.
     */
    value: number;
}
/**
 * Type of visual plotted by SpiderSeries.
 * @hidden
 */
export declare type SpiderChartVisual = Polygon | PointSet;
/**
 * Class that represents a collection of linked data-points inside a [[SpiderChart]].
 *
 * Given data is visualized in the form of a *polygon*, where each [[SpiderPoint]] is an edge
 * along an *Axis*. This *polygon* can be styled with 3 independent areas:
 * - fill
 * - border
 * - points
 *
 * Data is pushed with [[SpiderSeries.addPoints]] in form: **{ axis: string, value: number }**
 */
export declare class SpiderSeries extends Series2D<SpiderChartVisual> implements Pointed {
    /**
     * Adds an arbitrary amount of SpiderPoints to the Series.
     *
     * Animates transition if its enabled on owning chart.
     * @param   points  List of SpiderPoints as {'axis': string, 'value': number}
     * @returns         Object itself
     */
    addPoints(...points: SpiderPoint[]): this;
    /**
     * Returns the respective value of a data-point with the given tag (if any)
     * @param   animated    If set to true, will take series animating into account for result
     */
    getValue(tag: string, animated?: boolean): number | undefined;
    /**
     * Set animation for adding points.
     * @param   easing      Type of easing for animation or undefined to disable animations
     * @param   duration    Custom duration for animation in milliseconds.
     * @return              Object itself
     */
    setAnimationAddPoints(easing?: AnimationEasing, duration?: number): this;
    /**
     * Set animation for disabling/enabling series.
     * @param   easing      Type of easing for animation or undefined to disable animations
     * @param   duration    Custom duration for animation in milliseconds.
     * @return              Object itself
     */
    setDisposeAnimation(easing?: AnimationEasing, duration?: number): this;
    /**
     * Method for customizing contents of ResultTables when pointing at this Series.
     * @param   formatter   Function which builds ResultTable content.
     *                      See definition of [[SpiderSeriesFormatter]] for supplied formatting information.
     * @return              Object itself
     */
    setResultTableFormatter(formatter: SpiderSeriesFormatter): this;
    /**
     * Get ResultTable Formatter.
     * @return  Function which builds ResultTable content for SpiderSeries.
     */
    getResultTableFormatter(): SpiderSeriesFormatter;
    /**
     * Set fill style of the Polygon that represents the shape of the Series.
     *
     * Example use:
     *```javascript
     * // Create a new style
     * SpiderSeries.setFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * SpiderSeries.setFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * SpiderSeries.setFillStyle(emptyFill)
     * ```
     *
     * @param value  FillStyle which has to be used for recoloring or mutator to modify existing one.
     * @returns      Series itself for fluent interface.
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return  Current series fill style
     */
    getFillStyle(): FillStyle;
    /**
     * Set fill style of the highlighted Polygon that represents the shape of the Series.
     *
     * Example use:
     *```javascript
     * // Create a new style
     * SpiderSeries.setFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * SpiderSeries.setFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Set hidden
     * SpiderSeries.setFillStyleHighlight(emptyFill)
     * // Automatic
     * SpiderSeries.setFillStyleHighlight(undefined)
     * ```
     *
     * @param value  FillStyle which has to be used for recoloring or mutator to modify existing one.
     * @returns      Series itself for fluent interface.
     */
    setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Gets the highlighted fillStyle of the Polygon that represents the shape of this Series
     */
    getFillStyleHighlight(): FillStyle | undefined;
    /**
    * Set stroke style of the Polygon that represents the shape of the Series.
    *
    * Example usage:
    *```javascript
    * // Specified LineStyle
    * SpiderSeries.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
    * // Changed thickness
    * SpiderSeries.setStrokeStyle((solidLine) => solidLine.setThickness(5))
    * // Hidden
    * SpiderSeries.setStrokeStyle(emptyLine)
    * ```
    * @param   value        Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
    * @returns              Chart itself
    */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Gets the stroke style of the Polygon that represents the shape of this Series
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of the highlighted Polygon that represents the shape of the Series.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
    *```javascript
    * // Specified LineStyle
    * SpiderSeries.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
    * // Changed thickness
    * SpiderSeries.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
    * // Hidden
    * SpiderSeries.setStrokeStyleHighlight(emptyLine)
    * // Automatic
    * SpiderSeries.setStrokeStyleHighlight(undefined)
    * ```
     * @param   value       Either a SolidLine object or a function, which will be used to modify current value.
     * @returns             Chart itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of highlighted polygon.
     * @return              LineStyle or undefined for auto assignment
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set point fill style of Series.
     * Use [[IndividualPointFill]] object to enable individual coloring of points.
     *
     * Example usage:
     *```javascript
     * // Create a new style
     * SpiderSeries.setPointFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * SpiderSeries.setPointFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * SpiderSeries.setPointFillStyle(emptyFill)
     * ```
     *
     * @param fillStyle     FillStyle which has to be used for recoloring or mutator to modify existing one.
     * @returns             Series itself for fluent interface.
     */
    setPointFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return  Current point fill style
     */
    getPointFillStyle(): FillStyle;
    /**
     * Set point fill style of Series when it is highlighted.
     *
    * Example usage:
     *```javascript
     * // Create a new style
     * SpiderSeries.setPointFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * SpiderSeries.setPointFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Set hidden
     * SpiderSeries.setPointFillStyleHighlight(emptyFill)
     * // Automatic
     * SpiderSeries.setPointFillStyleHighlight(undefined)
     * ```
     * @param value FillStyle which has to be used during highlighting or mutator to modify existing one or undefined for auto.
     * @returns     Series itself for fluent interface.
     */
    setPointFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return  Current highlight point fill style
     */
    getPointFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set size of point in pixels
     * @param   size    Size of point in pixels
     * @returns         Object itself for fluent interface
     */
    setPointSize(size: number): this;
    /**
     * @returns Size of point in pixels
     */
    getPointSize(): number;
    /**
     * Get shape of points.
     *
     * This is defined upon creation of series, and cannot be changed afterwards.
     * @returns PointShape
     */
    getPointShape(): PointShape;
    /**
     * Set the rotation of points in degrees.
     * @param angle Rotation angle in degrees
     */
    setPointRotation(angle: number): this;
    /**
     * Get the current rotation of points.
     */
    getPointRotation(): number;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point): undefined | CursorPoint;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: SpiderChartVisual): undefined | CursorPoint;
    /**
     * Enable or disable the series
     * @param enabled True for enabled and false for disabled
     * @returns       Series itself for fluent interface
     */
    dispose(): this;
    /**
     * Enable or disable the series
     * @param enabled True for enabled and false for disabled
     * @returns       Series itself for fluent interface
     */
    restore(): this;
    /**
     * Enable or disable forced highlighting of series
     * @param highLight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
}
/**
 * Interface for a function which builds ResultTable content when pointing at a SpiderSeries.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable.
 *                                  Use addRow() method for adding content.
 * @param   series                  SpiderSeries
 * @param   value                   Value along axis
 * @param   axis                    Name of axis
 * @param   formatValue             Formating function for values along axis
 * @return                          TableContentBuilder that was supplied
 */
export declare type SpiderSeriesFormatter = <T extends TableContentBuilder>(tableContentBuilder: T, series: SpiderSeries, value: number, axis: string, formatValue: (value: number) => string) => T;
/**
 * Enum for selecting shape of [[SpiderChart]] "webs" - background, GridStrokes and nibs.
 *
 * Use with [[SpiderChart.setWebMode]]
 */
export declare enum SpiderWebMode {
    /**
     * Traditional Spider Chart with non-curved edges.
     */
    Normal = 0,
    /**
     * Background, GridStrokes and nibs will be drawn circular.
     */
    Circle = 1
}
/**
 * Includes the so-called "BasicSeries"
 * Which is a XY-Series that relies on ShapeSet's as its segments.
 * Extends to CurveSeries, PointSeries and their combination PointLineSeries
 *
 */
/**
 * Type requirement for Shapes which are used to render a SeriesXY.
 * @hidden
 */
export declare type BasicChartVisual = ChartVisual & Region & Shape;
/**
 * Type requirement for Shapes which are used to render a BasicSeries and implements ShapeSet interface.
 * @hidden
 */
export declare type BasicChartVisualShapeSet = BasicChartVisual & Segment<Point[]>;
/**
 * The class implements the most part of logic general for point and line series
 * @typeparam   InputType           Implementations should use Point here if they only accept Points, otherwise pass
 *                                  ONLY the additionally supported input type. For example, PointSeries will give "ColorPoint".
 *
 * @hidden      Internal class
 */
export declare abstract class BasicSeries<VisualType extends BasicChartVisualShapeSet = BasicChartVisualShapeSet, InputType extends Point = Point> extends SeriesXY<VisualType> implements DataInputXY, DataInput, DataInputX, DataInputY, ObservableXYData<Point> {
    protected readonly _dataPattern: DataPattern;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param xAxis                 Axis X
     * @param yAxis                 Axis Y
     * @param xAxisAttachHandler    Attach handler for Axis X
     * @param yAxisAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _dataPattern          Data-Pattern for enabling case-specific optimizations
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, xAxis: Axis, yAxis: Axis, xAxisAttachHandler: AxisAttachHandler, yAxisAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _dataPattern: DataPattern, _theme: Theme);
    /**
     * Add *Point* or Array of *Point*s.
     * @param    points  *Point* or Array of *Point*s.
     * @returns          Object itself for fluent interface.
     */
    add(points: InputType | InputType[]): this;
    /**
     * Each X-value will be paired with an automatically generated Y-value, based on *step*-argument.
     * This method will cause some overhead based on amount of data added, using *add* method is recommended.
     * @param   arrayX  Array of X-values.
     * @param   step    Optional step between each Y coordinate. Defaults to 1.
     * @param   start   Optional value for first generated Y-value. If undefined, will continue after last point's Y value in series,
     *                  or 0 if there are no points in series.
     * @return          Object itself for fluent interface.
     */
    addArrayX(arrayX: number[], step?: number, start?: number): this;
    /**
     * Each Y-value will be paired with an automatically generated X-value, based on *step*-argument.
     * @param   arrayY  Array of Y-values.
     * @param   step    Optional step between each X coordinate. Defaults to 1.
     * @param   start   Optional value for first generated X-value. If undefined, will continue after last point's X value in series,
     *                  or 0 if there are no points in series.
     * @return          Object itself for fluent interface.
     */
    addArrayY(arrayY: number[], step?: number, start?: number): this;
    /**
     * Add two individual Arrays, one for X-values, and another for Y-values.
     * @param   arrayX  Array of X-values.
     * @param   arrayY  Array of Y-values. Length should be equal to length of *arrayX*.
     * @return          Object itself for fluent interface.
     */
    addArraysXY(arrayX: number[], arrayY: number[]): this;
    /**
     * Method for customizing contents of ResultTables when pointing at this Series.
     * @param   formatter   Function which builds ResultTable content.
     *                      See definition of [[SeriesXYFormatter]] for supplied formatting information.
     * @return              Object itself
     */
    setResultTableFormatter(formatter: SeriesXYFormatter): this;
    /**
     * Get ResultTable Formatter.
     * @return  Function which builds ResultTable content for SeriesXY.
     */
    getResultTableFormatter(): SeriesXYFormatter;
    /**
     * Set amount of points that should be kept around at all times (data-cleaning won't touch them).
     * NOTE: The actual data cleaning can only be started if there is at least 1 full segment (about 8000 points).
     * @param   maxPointCount   Guaranteed amount of visible points. If undefined or 0 is passed, data-cleaning will be disabled.
     * @returns                 Object itself
     */
    setMaxPointCount(maxPointCount: number | undefined): this;
    /**
     * Get amount of points that series should keep around at all times (data-cleaning won't touch them).
     * @return  Number of points, or undefined if data-cleaning is disabled
     */
    getMaxPointCount(): number | undefined;
    /**
     * Get amount of points that series currently has.
     * @return  Number of points
     */
    getPointAmount(): number;
    /**
     * Clear all points and segments from the dataset.
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * @return Copy of last point added to the Series or undefined if it doesn't exist.
     */
    getLastPoint(): Point | undefined;
    /**
     * @return Max X value of the series
     */
    getXMax(): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin(): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number | undefined;
}
/**
 * Interface for a function which builds ResultTable content when pointing at a SeriesXY.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable.
 *                                  Use addRow() method for adding content.
 * @param   series                  SeriesXY
 * @param   x                       X coordinate
 * @param   y                       Y coordinate
 * @return                          TableContentBuilder that was supplied
 */
export declare type SeriesXYFormatter = <T extends TableContentBuilder>(tableContentBuilder: T, series: SeriesXY, x: number, y: number) => T;
/**
 * Interface that can be used to define [[ChartXY]] configurations that can't be changed after creation. For example:
 *
 * - Supplying a custom Builder for the AutoCursor of Chart. This can be used to modify the AutoCursor on a level,
 * which can't be done during runtime. For example, changing the shape of ResultTable Background, Etc.
 *
 * Example usage:
 *
 * | Desired result                                 | Value                                                                                                 |
 * | :--------------------------------------------- | :---------------------------------------------------------------------------------------------------- |
 * | Default                                        | *undefined*                                                                                           |
 * | Preset theme                                   | { **theme**: *Themes*.light }                                                                         |
 * | Specified AutoCursor ResultTable Background    | { **autoCursorBuilder:** *AutoCursorBuilders*.XY.setResultTableBackground(*UIBackgrounds*.Circle) }   |
 */
export interface ChartXYOptions<CursorPointMarkerType extends PointMarker = PointMarker, CursorResultTableBackgroundType extends UIBackground = UIBackground, CursorTickMarkerBackgroundTypeX extends PointableBackground = PointableBackground, CursorTickMarkerBackgroundTypeY extends PointableBackground = PointableBackground> extends CommonChartOptions {
    /**
     * Builder for the Charts AutoCursor. If omitted, a default one will be used.
     * AutoCursorBuilders.XY can be used to build a custom one from scratch.
     */
    autoCursorBuilder?: AutoCursorXYBuilder<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerBackgroundTypeX, CursorTickMarkerBackgroundTypeY>;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to.
 */
export interface SeriesOptions {
    /**
    * X Axis to attach the series to.
    */
    xAxis?: Axis;
    /**
    * Y Axis to attach the series to.
    */
    yAxis?: Axis;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * and define Shape for points of series.
 */
export interface PointSeriesOptions extends SeriesOptions {
    /**
     * PointShape Shape for points of series.
     */
    pointShape?: PointShape;
    /**
     * Optional property to enable optimizations for data that follows a certain pattern.
     *
     * See [[DataPatterns]] for a collection of options.
     * If the Series is supplied with data that does not respect the given [[DataPattern]], it might behave unexpectedly.
     */
    dataPattern?: DataPattern;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * and define Shape for points of series.
 */
export interface SplineSeriesOptions extends SeriesOptions {
    /**
     * PointShape Shape for points of series.
     */
    pointShape?: PointShape;
    /**
     * Optional property to enable optimizations for data that follows a certain pattern.
     *
     * Supported [[DataPatterns]]:
     * - [[DataPatterns.horizontalProgressive]]
     * - [[DataPatterns.horizontalRegressive]]
     * - [[DataPatterns.freeform]]
     *
     * If the Series is supplied with data that does not respect the given [[DataPattern]], it might behave unexpectedly.
     */
    dataPattern?: HorizontalPattern | FreeFormPattern;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * and define Shape for points of series, indicate typeS of line step.
 */
export interface StepSeriesOptions extends SeriesOptions {
    /**
     * PointShape Shape for points of series.
     */
    pointShape?: PointShape;
    /**
     * Step behavior for [[StepSeries]].
     */
    mode?: StepOptions;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * and define type of dataPattern.
 */
export interface LineSeriesOptions extends SeriesOptions {
    /**
     * Optional property to enable optimizations for data that follows a certain pattern.
     *
     * See [[DataPatterns]] for a collection of options.
     * If the Series is supplied with data that does not respect the given [[DataPattern]], it might behave unexpectedly.
     */
    dataPattern?: DataPattern;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * define type of StatisticFigure and type of dimensionStrategy.
 */
export interface BoxSeriesOptions<FigureType extends BoxFigure> extends SeriesOptions {
    /**
     * Figure type of StatisticFigure used for visualizing segments.
     *
     * Currently only [[BoxAndWhiskers]] is implemented.
     */
    figure?: BoxFigureConstructor<FigureType>;
    /**
     * DimensionStrategy Strategy used for selecting between vertical and horizontal Box Series.
     */
    dimensionStrategy?: MultidimensionalStrategy;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * a reference number used for comparison and type of area series.
 */
export interface AreaSeriesOptions<AreaType extends AreaSeriesTypes> extends SeriesOptions {
    /**
     * A fixed reference number.
     */
    baseline?: number;
    /**
     * Defines the type of area series. Selected option can enable/disable specific APIs!
     *
     * See [[AreaSeriesTypes]] for a collection of options.
     */
    type?: AreaType;
}
/**
 * Interface can be used to define:
 * - X and Y Axes that a series should be attached to
 * - Resolution (rows & columns)
 * - Start and End points of boundary box
 * - Pixelation mode to draw per cell or per point colouring
 * - Type of intensity series
 */
export interface IntensitySeriesOptions<IntensityType extends IntensitySeriesTypes> extends IntensityOptions, SeriesOptions {
    /**
     * Defines the type of intensity series. The API can vary for each selected series type.
     *
     * See [[IntensitySeriesTypes]] for a collection of options.
     */
    type?: IntensityType;
}
/**
 * Interface can be used to define the X and Y Axis that a series should be attached to,
 * type of OHLCFigure used for positive segments, negative segments and series.
 */
export interface OHLCSeriesOptions<PositiveFigure extends OHLCFigure, NegativeFigure extends OHLCFigure, OHLCSeriesType extends OHLCSeriesTypes<PositiveFigure, NegativeFigure>> extends SeriesOptions {
    /**
     * Type of OHLCFigure used for positive segments.
     */
    positiveFigure?: OHLCFigureConstructor<PositiveFigure>;
    /**
     * Type of OHLCFigure used for negative segments.
     */
    negativeFigure?: OHLCFigureConstructor<NegativeFigure>;
    /**
     * Type of OHLCSeries created.
     */
    seriesConstructor?: OHLCSeriesConstructor<PositiveFigure, NegativeFigure, OHLCSeriesType>;
}
/**
 * Chart for visualizing data using the *Cartesian coordinate system*, across any number of *Axes*.
 * It has a multitude of methods for adding various types of Series.
 *
 * *Charts* are created by methods of [[LightningChart]] interface or a [[Dashboard]].
 *
 * The *Axes* of a ChartXY* can be manipulated with a variety of methods:
 *```javascript
 * // Get automatically created X Axis
 * ChartXY.getDefaultAxisX()
 * // Add a new Y Axis to right side of *ChartXY
 * ChartXY.addAxisY(true)
 * // Remove an Axis
 * Axis.dispose()
 * ```
 */
export declare class ChartXY<CursorPointMarkerType extends PointMarker = PointMarker, CursorResultTableBackgroundType extends UIBackground = UIBackground, CursorTickMarkerBackgroundTypeX extends PointableBackground = PointableBackground, CursorTickMarkerBackgroundTypeY extends PointableBackground = PointableBackground> extends ChartWithCursor<SeriesXY, CursorPointMarkerType, CursorResultTableBackgroundType, AutoCursorXY<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerBackgroundTypeX, CursorTickMarkerBackgroundTypeY>> implements ChartWithScrollingAnimations, ChartWithZoomingAnimations, ChartWithAxis<Axis> {
    /**
     * @param   layerSupplier           Rendering layer supplier
     * @param   logoFactory             Flag for drawing LC logo
     * @param   removeChart 	        Injectable panel/chart remove method
     * @param   chartXYOptions          Settings union used to define ChartXY.
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, chartXYOptions?: ChartXYOptions<CursorPointMarkerType, CursorResultTableBackgroundType, CursorTickMarkerBackgroundTypeX, CursorTickMarkerBackgroundTypeY>, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface);
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
    /**
     * Get series of a chart
     * @return  series
     */
    getSeries(): SeriesXY[];
    /**
     * Create new XY Chart Marker to be rendered as part of UI.
     * @param   cursorBuilder   Optional StaticCursorBuilderXY to customize structure/style of chartMarker.
     *                          MarkerBuilders.XY can be used to build a custom one from scratch.
     * @param   axisX           Optional arbitrary X axis to attach ChartMarker on
     * @param   axisY           Optional arbitrary Y axis to attach ChartMarker on
     * @return                  Created ChartMarker
     */
    addChartMarkerXY<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerBackgroundTypeX extends PointableBackground = PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground = PointableBackground>(cursorBuilder?: StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>, axisX?: Axis, axisY?: Axis): ChartMarkerXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>;
    /**
     * Add new *X Axis* to the *Chart*.
     * @param   addTop              Position of X axis. **false = bottom, true = top**.
     *                              **Defaults to bottom**.
     * @return                      *Axis* object.
     */
    addAxisX(addTop?: boolean): Axis;
    /**
     * Add new *Y Axis* to the *Chart*.
     * @param   addRight            Position of Y axis. **false = left, true = right**.
     *                              **Defaults to left**.
     * @return                      *Axis* object.
     */
    addAxisY(addRight?: boolean): Axis;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
    /**
     * @returns Primary X axis is the bottom one. If there is no bottom axis, the top one became default.
     */
    getDefaultAxisX(): Axis;
    /**
     * @returns Primary Y axis is the left one. If there is no left axis, the right one became default.
     */
    getDefaultAxisY(): Axis;
    /**
     * @param  axisPositions    array of axis positions which have to be included to the output
     *                          empty array indicates all of positions are included
     * @returns                 An array of axis
     */
    getAxes(...axisPositions: AxisPosition[]): Axis[];
    /**
     * Operate on each x axis of chart
     * @param   clbk    Callback function for axis
     */
    forEachAxisX(clbk: (axis: Axis, i: number, arr: Axis[]) => void): void;
    /**
     * Operate on each y axis of chart
     * @param   clbk    Callback function for axis
     */
    forEachAxisY(clbk: (axis: Axis, i: number, arr: Axis[]) => void): void;
    /**
     * Create Series for visualization of data by continuous lines.
     * @param options Options to attach series to axes and define the type of data pattern.
     *
     * @return                  LineSeries.
     */
    addLineSeries(options?: LineSeriesOptions): LineSeries;
    /**
     * Create Series for visualization of data by points.
     * @param   options Options to attach series to axes and define the shape for points of series.
     * @return              Created series.
     */
    addPointSeries(options?: PointSeriesOptions): PointSeries;
    /**
     * Create Plot for visualization of data by points and lines
     * @param   options Options to attach series to axes and define the shape for points of series.
     * @return              Created plot
     */
    addPointLineSeries(options?: PointSeriesOptions): PointLineSeries;
    /**
     * Create Series for visualization of data by points and lines. Apply steps to the line curve.
     * @param   options Options to attach series to axes and define the shape for points of series,
     *                            step behavior for [[StepSeries]].
     *                      Possible values are 'before', 'middle' and 'after', defaults to StepOptions.before.
     * @return              Created series
     */
    addStepSeries(options?: StepSeriesOptions): StepSeries;
    /**
     * Create Series for visualization of data by points and lines, where the segments between the data points are smoothed.
     * @param   options Options to attach series to axes and define the shape for points of series.
     * @return              Created series
     */
    addSplineSeries(options?: SplineSeriesOptions): SplineSeries;
    /**
     * Create Series for drawing rectangles.
     * @param      options Options to attach series to axes.
     * @return     Created series
     */
    addRectangleSeries(options?: SeriesOptions): RectangleSeries;
    /**
     * Create Series for visualization of data by individual line-segments
     * @param      options Options to attach series to axes.
     * @return                           Created series
     */
    addSegmentSeries(options?: SeriesOptions): SegmentSeries;
    /**
     * Create Series for drawing ellipses.
     * @param      options Options to attach series to axes.
     * @return           Created series
     */
    addEllipseSeries(options?: SeriesOptions): EllipseSeries;
    /**
     * Create Series for visualization of OHLC segments.
     * @param options    Options to attach series to axes,
     *                   define type of OHLCFigure used for positive segments, negative segments and series.
     * @return           Created OHLCSeries whose interface is related to value of 'seriesConstructor' parameter
     */
    addOHLCSeries<PositiveFigure extends OHLCFigure = OHLCCandleStick, NegativeFigure extends OHLCFigure = PositiveFigure, OHLCSeriesType extends OHLCSeriesTypes<PositiveFigure, NegativeFigure> = OHLCSeriesTraditional<PositiveFigure, NegativeFigure>>(options?: OHLCSeriesOptions<PositiveFigure, NegativeFigure, OHLCSeriesType>): OHLCSeriesType;
    /**
     * Create Series for visualization of data with quartiles.
     * @param options Options to attach series to axes, type of StatisticFigure and type of dimensionStrategy.
     * @return                  Created series
     */
    addBoxSeries<FigureType extends BoxFigure = BoxAndWhiskers>(options?: BoxSeriesOptions<FigureType>): BoxSeries<FigureType>;
    /**
     * Creates area series for visualization of data between the given line and base line limit.
     * @param options Options to attach series to axes, a number for comparisons and defines the type of area series.
     * @return          Created series
     */
    addAreaSeries: <AreaType extends typeof AreaSeriesPositive | typeof AreaSeriesNegative | typeof AreaSeriesBipolar = typeof AreaSeriesPositive>(options?: AreaSeriesOptions<AreaType> | undefined) => InstanceType<AreaType>;
    /**
     * Creates range area series for visualization bands of data between the two given lines.
     * Each point in the chart is specified by two y values.
     * @param      options Options to attach series to axes.
     * @return               Created series
     */
    addAreaRangeSeries: (options?: SeriesOptions | undefined) => AreaRangeSeries;
    /**
     * Creates heatmap intensity series for visualization of magnitude.
     * @param options Options to attach series to axes, major settings and defines the type of area series.
     * @return          Created series
     */
    addHeatmapSeries: <IntensityType extends typeof IntensityGridSeries | typeof IntensityMeshSeries = typeof IntensityGridSeries>(options: IntensitySeriesOptions<IntensityType>) => InstanceType<IntensityType>;
    /**
     * Set mouse style when hovering over chart background.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setMouseBackgroundStyle(mouseStyle?: string): this;
    /**
     * Set mouse style when zooming over chart background.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setMouseZoomStyle(mouseStyle?: string): this;
    /**
     * Set mouse style when fitting over chart background.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setMouseFitStyle(mouseStyle?: string): this;
    /**
     * Set mouse style when panning over chart background.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setMousePanStyle(mouseStyle?: string): this;
    /**
     * Set all mouse-interaction flags at once.
     * @param   enabled     Are mouse-interactions enabled
     * @return              Object itself
     */
    setMouseInteractions(enabled: boolean): this;
    /**
     * Set is mouse-interaction enabled:
     * Zooming axes by capturing rectangle on frame.
     * @param   enabled     Boolean flag
     * @return              Object itself
     */
    setMouseInteractionRectangleZoom(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming axes by capturing rectangle on frame.
     * @return  Boolean flag
     */
    getMouseInteractionRectangleZoom(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Fitting axes by capturing rectangle on frame.
     * @param   enabled     Boolean flag
     * @return              Object itself
     */
    setMouseInteractionRectangleFit(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Fitting axes by capturing rectangle on frame.
     * @return  Boolean flag
     */
    getMouseInteractionRectangleFit(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Panning axes by dragging mouse on frame.
     * @param   enabled     Boolean flag
     * @return              Object itself
     */
    setMouseInteractionPan(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Panning axes by dragging mouse on frame.
     * @return  Boolean flag
     */
    getMouseInteractionPan(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Zooming axes with mouse-wheel on frame (also touch pinch currently).
     * @param   enabled     Boolean flag
     * @return              Object itself
     */
    setMouseInteractionWheelZoom(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming axes with mouse-wheel on frame.
     * @return  Boolean flag
     */
    getMouseInteractionWheelZoom(): boolean;
    /**
     * Set fillStyle for zooming rectangle when zooming.
     * @param   value   FillStyle or mutator to modify existing one
     * @return          Object itself
     */
    setZoomingRectangleFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillStyle for zooming rectangle when zooming.
     * @return  FillStyle
     */
    getZoomingRectangleFillStyle(): FillStyle;
    /**
     * Set stroke style for zooming rectangle when zooming.
     * @param   value   LineStyle or mutator to modify existing one
     * @return          Object itself
     */
    setZoomingRectangleStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style for zooming rectangle when zooming.
     * @return  LineStyle
     */
    getZoomingRectangleStrokeStyle(): LineStyle;
    /**
     * Set fillStyle for zooming rectangle when fitting.
     * @param   value       FillStyle or mutator to modify existing one
     * @return              Object itself
     */
    setFittingRectangleFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillStyle for fitting rectangle when fitting.
     * @return  FillStyle
     */
    getFittingRectangleFillStyle(): FillStyle;
    /**
     * Set stroke style for zooming rectangle when fitting.
     * @param   value       LineStyle or mutator to modify existing one
     * @return              Object itself
     */
    setFittingRectangleStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style for fitting rectangle when fitting.
     * @return  LineStyle
     */
    getFittingRectangleStrokeStyle(): LineStyle;
    /**
     * Disable all animations for the chart.
     *
     * After calling this function, animations (Zooming, scaling) for all Axes will be disabled.
     * Animations must be recreated manually afterwards.
     * @return          Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Set if mouse and cursor interactions should be disabled during scrolling animations for the chart's series.
     * @param   state   True if mouse and cursor interactions should be disabled during scrolling animations, false if not.
     * @return          Chart itself for fluent interface.
     */
    setMouseInteractionsWhileScrolling(state: boolean): this;
    /**
     * Get if mouse and cursor interactions are disabled during scrolling animations for the chart's series.
     * @return True if interactions with series are disabled, false if not.
     */
    getMouseInteractionsWhileScrolling(): boolean;
    /**
     * Set if mouse and cursor interactions should be disabled during zooming animations for the chart's series.
     * @param   state   True if mouse and cursor interactions should be disabled during zooming animations, false if not.
     * @return          Chart itself for fluent interface.
     */
    setMouseInteractionsWhileZooming(state: boolean): this;
    /**
     * Get if mouse and cursor interactions are disabled during zooming animations for the chart's series.
     * @return True if interactions with series are disabled, false if not.
     */
    getMouseInteractionsWhileZooming(): boolean;
    /**
     * Operate on each axis of chart, x and y
     * @param   clbk    Callback function for axis
     */
    forEachAxis(clbk: (axis: Axis) => void): void;
}
/**
 * Axis positioning Enum
 * @hidden
 */
export declare enum AxisPosition {
    Top = 0,
    Bottom = 1,
    Left = 2,
    Right = 3
}
/**
 * Type of Axis attach handler.
 * Essentially this is a more advanced Restore-handler, for handling case with 3-way-dispose/restore-relationship (chart,axis,series).
 * TODO: Should be unified with rest of dispose/restore system somehow.
 * @hidden
 */
export declare type AxisAttachHandler = (series: SeriesXY) => ((series: SeriesXY) => void);
/**
 * A type of Cursor that is plotted along two axes.
 * Adds customizable gridStrokes and tickMarkers
 */
export interface CursorXY<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerBackgroundTypeX extends PointableBackground = PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground = PointableBackground> extends Cursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Set is GridStrokeX cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXCut: (cut: boolean) => this;
    /**
     * Get is GridStrokeX cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeXCut: () => boolean;
    /**
     * Set is GridStrokeY cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYCut: (cut: boolean) => this;
    /**
     * Get is GridStrokeY cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeYCut: () => boolean;
    /**
     * Set style of x gridstroke
     * @param   value      LineStyle object
     * @returns            Object itself for fluent interface
     */
    setGridStrokeXStyle: (value: LineStyle | ImmutableMutator<LineStyle>) => this;
    /**
     * Get style of x gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeXStyle: () => LineStyle;
    /**
     * Set style of y gridstroke
     * @param   value       LineStyle object
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYStyle: (value: LineStyle | ImmutableMutator<LineStyle>) => this;
    /**
     * Get style of y gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeYStyle: () => LineStyle;
    /**
     * Set TickMarkerX.
     * @param   mutator     Mutator function for cursors X tickMarker
     * @return              Object itself for fluent interface
     */
    setTickMarkerX: (mutator: Mutator<TickMarker<TickMarkerBackgroundTypeX>>) => this;
    /**
     * Set TickMarkerY.
     * @param   mutator     Mutator function for cursors Y tickMarker
     * @return              Object itself for fluent interface
     */
    setTickMarkerY: (mutator: Mutator<TickMarker<TickMarkerBackgroundTypeY>>) => this;
    /**
     * Dispose TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerY(): this;
    /**
     * Restore TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerY(): this;
    /**
     * @return Whether TickMarker part of Y CustomTick is disposed
     */
    isDisposedTickMarkerY(): boolean;
    /**
     * Dispose TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerX(): this;
    /**
     * Restore TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerX(): this;
    /**
     * @return Whether TickMarker part of X CustomTick is disposed
     */
    isDisposedTickMarkerX(): boolean;
}
/**
 * A type of CursorXY that can be plotted dynamically between different axes.
 */
export interface AutoCursorXY<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerBackgroundTypeX extends PointableBackground = PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground = PointableBackground> extends CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>, AutoCursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Set is TickMarkerX auto text fill style enabled.
     * When enabled, text of TickMarkerX will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on TickMarkerX might get overridden
     */
    setTickMarkerXAutoTextStyle(enabled: boolean): this;
    /**
     * Get is TickMarkerX auto text fill style enabled.
     * When enabled, text of TickMarkerX will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getTickMarkerXAutoTextStyle(): boolean;
    /**
     * Set is TickMarkerY auto text fill style enabled.
     * When enabled, text of TickMarkerY will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on TickMarkerY might get overridden
     */
    setTickMarkerYAutoTextStyle(enabled: boolean): this;
    /**
     * Get is TickMarkerY auto text fill style enabled.
     * When enabled, text of TickMarkerY will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getTickMarkerYAutoTextStyle(): boolean;
}
/**
 * Static XY cursor interface
 */
export interface StaticCursorXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground> extends StaticCursor<PointMarkerType, ResultTableBackgroundType>, CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY> {
    /**
     * Get x tick marker
     * @returns             X customTick of cursor
     */
    getTickMarkerX: () => TickMarker<TickMarkerBackgroundTypeX>;
    /**
     * Get y tick marker
     * @returns             Y customTick of cursor
     */
    getTickMarkerY: () => TickMarker<TickMarkerBackgroundTypeY>;
}
/**
 * Internal class for static xy cursors.
 * Static cursors are attached to a pair of axes on creation
 * and don't move from there.
 * @hidden Internal class
 */
export declare class InternalStaticCursorXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground> extends InternalStaticCursor<PointMarkerType, ResultTableBackgroundType> implements CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>, StaticCursor<PointMarkerType, ResultTableBackgroundType> {
    /**
     * Points the Cursor at a given CursorPoint.
     * Updating its position and displayed data.
     */
    pointAt(cursorPoint: CursorPoint): this;
    /**
     * Set the position of the Cursor,
     * moving it without modifying displayed data.
     */
    setPosition(position: Point): this;
    /**
     * Dispose of the cursor and its custom ticks.
     */
    dispose(): this;
    /**
     * Dispose of the cursor and its custom ticks.
     */
    restore(): this;
    /**
     * Set is GridStrokeX cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXCut(cut: boolean): this;
    /**
     * Get is GridStrokeX cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeXCut(): boolean;
    /**
     * Set is GridStrokeY cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYCut(cut: boolean): this;
    /**
     * Get is GridStrokeY cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeYCut(): boolean;
    /**
     * Set style of x gridstroke
     * @param   value       LineStyle object
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of x gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeXStyle(): LineStyle;
    /**
     * Set style of y gridstroke
     * @param   value       LineStyle object
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYStyle: (value: LineStyle | ImmutableMutator<LineStyle, LineStyle>) => this;
    /**
     * Get style of y gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeYStyle: () => LineStyle;
    /**
     * Dispose TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerX(): this;
    /**
     * Restore TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerX(): this;
    /**
     * @return Whether TickMarker part of X CustomTick is disposed
     */
    isDisposedTickMarkerX(): boolean;
    /**
     * Dispose TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerY(): this;
    /**
     * Restore TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerY(): this;
    /**
     * @return Whether TickMarker part of Y CustomTick is disposed
     */
    isDisposedTickMarkerY(): boolean;
    /**
     * Mutator function for x tick marker
     * @param   mutator     TickMarker mutator function
     * @returns             Object itself for fluent interface
     */
    setTickMarkerX(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeX & InternalBackground>>): this;
    /**
     * Mutator function for y tick marker
     * @param   mutator     TickMarker mutator function
     * @returns              Object itself for fluent interface
     */
    setTickMarkerY(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeY & InternalBackground>>): this;
    /**
     * Get x tick marker
     * @returns             X customTick of cursor
     */
    getTickMarkerX(): TickMarker<TickMarkerBackgroundTypeX>;
    /**
     * Get y tick marker
     * @returns             Y customTick of cursor
     */
    getTickMarkerY(): TickMarker<TickMarkerBackgroundTypeY>;
}
/**
 * Internal class for dynamic xy cursors.
 * Dynamic cursors can be positioned to any pair of axes at any time.
 * @hidden Internal class
 */
export declare class InternalAutoCursorXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground> extends InternalAutoCursor<PointMarkerType, ResultTableBackgroundType> implements CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>, AutoCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY> {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>;
    protected _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>;
    protected _tickMarkerXBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeX & InternalBackground>;
    protected _tickMarkerYBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeY & InternalBackground>;
    readonly _theme: Theme;
    /**
     * @param _layer                             Top layer of the rendering Engine
     * @param scale                              Rendering scale of cursor. For dynamic cursor this is naturally not based on any axis
     * @param _pointMarkerConstructor            Constructor for PointMarker
     * @param _resultTableBackgroundConstructor  Constructor for Background of ResultTable
     * @param _tickMarkerXBuilder                Builder for TickMarkerX
     * @param _tickMarkerYBuilder                Builder for TickMarkerY
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>, _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>, _tickMarkerXBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeX & InternalBackground>, _tickMarkerYBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeY & InternalBackground>, _theme: Theme);
    /**
     * Tell the cursor to restore of its ticks.
     */
    restore(): this;
    /**
     * Tell the cursor to dispose of its ticks.
     */
    dispose(): this;
    /**
     * Points the Cursor at a given CursorPoint.
     * Updating its position and displayed data.
     */
    pointAt(cursorPoint: CursorPoint<SeriesXY>): this;
    /**
     * Set is GridStrokeX cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXCut(cut: boolean): this;
    /**
     * Get is GridStrokeX cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeXCut(): boolean;
    /**
     * Set is GridStrokeY cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYCut(cut: boolean): this;
    /**
     * Get is GridStrokeY cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeYCut(): boolean;
    /**
     * Set style of x gridstroke
     * @param   value       LineStyle object
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of x gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeXStyle(): LineStyle;
    /**
     * Set lineStyle of y gridstroke
     * @param   lineStyle   LineStyle object
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYStyle(lineStyle: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of y gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeYStyle(): LineStyle;
    /**
     * Dispose TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerX(): this;
    /**
     * Restore TickMarker part of X CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerX(): this;
    /**
     * @return Whether TickMarker part of X CustomTick is disposed
     */
    isDisposedTickMarkerX(): boolean;
    /**
     * Dispose TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    disposeTickMarkerY(): this;
    /**
     * Restore TickMarker part of Y CustomTick
     * @return Object itself for fluent interface
     */
    restoreTickMarkerY(): this;
    /**
     * @return Whether TickMarker part of Y CustomTick is disposed
     */
    isDisposedTickMarkerY(): boolean;
    /**
     * Mutator function for x tick marker.
     * Applies function to current tick marker if it exists and for any newly created
     * tick marker in order of adding.
     * @param   mutator     Mutator function for TickMarker
     * @return              Object itself
     * @sideEffect          Method can't currently be implemented in a clean way so its usage currently will consume unneeded memory.
     *                      It's repeating usage should be avoided for now.
     */
    setTickMarkerX(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeX & InternalBackground>>): this;
    /**
     * Mutator function for y tick marker.
     * Applies function to current tick marker if it exists and for any newly created
     * tick marker in order of adding.
     * @param   mutator     Mutator function for TickMarker
     * @return              Object itself
     * @sideEffect          Method can't currently be implemented in a clean way so its usage currently will consume unneeded memory.
     *                      It's repeating usage should be avoided for now.
     */
    setTickMarkerY(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeY & InternalBackground>>): this;
    /**
     * Set is TickMarkerX auto text fill style enabled.
     * When enabled, text of TickMarkerX will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on TickMarkerX might get overridden
     */
    setTickMarkerXAutoTextStyle(enabled: boolean): this;
    /**
     * Get is TickMarkerX auto text fill style enabled.
     * When enabled, text of TickMarkerX will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getTickMarkerXAutoTextStyle(): boolean;
    /**
     * Set is TickMarkerY auto text fill style enabled.
     * When enabled, text of TickMarkerY will be automatically filled based on pointed data.
     * @param   enabled     Boolean flag
     * @return              Object itself
     * @sideEffect          When enabled, any fill style set operation on TickMarkerY might get overridden
     */
    setTickMarkerYAutoTextStyle(enabled: boolean): this;
    /**
     * Get is TickMarkerY auto text fill style enabled.
     * When enabled, text of TickMarkerY will be automatically filled based on pointed data.
     * @return              Boolean flag
     */
    getTickMarkerYAutoTextStyle(): boolean;
}
/**
 * Base class for cursorXY builders
 */
export declare abstract class CursorBuilderXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground, CursorType extends CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>> extends CursorBuilder<PointMarkerType, ResultTableBackgroundType, CursorType> {
    protected _pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>;
    protected _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>;
    protected _tickMarkerXBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeX & InternalBackground>;
    protected _tickMarkerYBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeY & InternalBackground>;
    protected _stylers: CursorStyler<CursorType>[];
    /**
     * @param _pointMarkerConstructor            Constructor for PointMarker
     * @param _resultTableBackgroundConstructor  Constructor for Background of ResultTable
     * @param _tickMarkerXBuilder                Builder for TickMarkerX
     * @param _tickMarkerYBuilder                Builder for TickMarkerY
     * @param _stylers                           List of stylers
     * @hidden
     */
    constructor(_pointMarkerConstructor: PointMarkerConstructor<PointMarkerType & InternalPointMarker>, _resultTableBackgroundConstructor: BackgroundConstructor<ResultTableBackgroundType & InternalBackground>, _tickMarkerXBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeX & InternalBackground>, _tickMarkerYBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundTypeY & InternalBackground>, _stylers: CursorStyler<CursorType>[]);
    /**
     * Create new CursorBuilder with a different TickMarkerX Background.
     * @param   tickMarkerXBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     CursorBuilder of same type
     */
    abstract setTickMarkerXBackground: <T extends TickMarkerBackgroundTypeX & InternalBackground>(tickMarkerXBackgroundConstructor: PointableBackgroundConstructor<T>) => CursorBuilderXY<PointMarkerType, ResultTableBackgroundType, T, TickMarkerBackgroundTypeY, CursorXY<PointMarkerType, ResultTableBackgroundType, T, TickMarkerBackgroundTypeY>>;
    /**
     * Create new CursorBuilder with a different TickMarkerY Background.
     * @param   tickMarkerYBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     CursorBuilder of same type
     */
    abstract setTickMarkerYBackground: <T extends TickMarkerBackgroundTypeY & InternalBackground>(tickMarkerYBackgroundConstructor: PointableBackgroundConstructor<T>) => CursorBuilderXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, T, CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, T>>;
}
/**
 * Builder for *AutoCursor* of [[ChartXY]].
 *
 * Used to modify structure of *AutoCursor*, by passing one when creating a [[ChartXY]].
 * Reference from [[AutoCursorBuilders.XY]]
 */
export declare class AutoCursorXYBuilder<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerXBackgroundType extends PointableBackground = PointableBackground, TickMarkerYBackgroundType extends PointableBackground = PointableBackground> extends CursorBuilderXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType, AutoCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>> implements AutoCursorBuilder<CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>> {
    /**
     * Create new CursorBuilder with an additional styler.
     * @param   cursorStyler    Cursor styler function
     * @returns                 New builder with extended style
     */
    addStyler: (cursorStyler: Mutator<AutoCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>>) => AutoCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different PointMarker.
     * @param   pointMarkerConstructor  Constructor for PointMarker
     * @returns                         New builder with different pointMarker
     */
    setPointMarker: <T extends UIElement & PointMarker & PointMarkerType>(pointMarkerConstructor: PointMarkerConstructor<T>) => AutoCursorXYBuilder<T, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different ResultTable Background.
     * @param   resultTableBackground   Constructor for Background
     * @returns                         New builder with different resultTable background
     */
    setResultTableBackground: <T extends InternalBackground & ResultTableBackgroundType>(resultTableBackground: BackgroundConstructor<T>) => AutoCursorXYBuilder<PointMarkerType, T, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different TickMarkerX Background.
     * @param   tickMarkerXBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     New builder with different tickMarkerX background
     */
    setTickMarkerXBackground: <T extends InternalBackground & TickMarkerXBackgroundType>(tickMarkerXBackgroundConstructor: PointableBackgroundConstructor<T>) => AutoCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, T, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different TickMarkerY Background.
     * @param   tickMarkerYBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     New builder with different tickMarkerY background
     */
    setTickMarkerYBackground: <T extends InternalBackground & TickMarkerYBackgroundType>(tickMarkerYBackgroundConstructor: PointableBackgroundConstructor<T>) => AutoCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, T>;
}
/**
 * Builder for static xy-cursors
 */
export declare class StaticCursorXYBuilder<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerXBackgroundType extends PointableBackground = PointableBackground, TickMarkerYBackgroundType extends PointableBackground = PointableBackground> extends CursorBuilderXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType, StaticCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>> {
    /**
     * Create new CursorBuilder with an additional styler.
     * @param   cursorStyler    Cursor styler function
     * @returns                 New builder with extended style
     */
    addStyler: (cursorStyler: Mutator<StaticCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>>) => StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different PointMarker.
     * @param   pointMarkerConstructor  Constructor for PointMarker
     * @returns                         New builder with different pointMarker
     */
    setPointMarker: <T extends UIElement & PointMarker & PointMarkerType>(pointMarkerConstructor: PointMarkerConstructor<T>) => StaticCursorXYBuilder<T, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different ResultTable Background.
     * @param   resultTableBackgroundConstructor    Constructor for Background
     * @returns                                     New builder with different resultTable background
     */
    setResultTableBackground: <T extends InternalBackground & ResultTableBackgroundType>(resultTableBackgroundConstructor: BackgroundConstructor<T>) => StaticCursorXYBuilder<PointMarkerType, T, TickMarkerXBackgroundType, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different TickMarkerX Background.
     * @param   tickMarkerXBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     New builder with different tickMarkerX background
     */
    setTickMarkerXBackground: <T extends InternalBackground & TickMarkerXBackgroundType>(tickMarkerXBackgroundConstructor: PointableBackgroundConstructor<T>) => StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, T, TickMarkerYBackgroundType>;
    /**
     * Create new CursorBuilder with a different TickMarkerY Background.
     * @param   tickMarkerYBackgroundConstructor    Constructor for TickMarker Background
     * @returns                                     New builder with different tickMarkerY background
     */
    setTickMarkerYBackground: <T extends InternalBackground & TickMarkerYBackgroundType>(tickMarkerYBackgroundConstructor: PointableBackgroundConstructor<T>) => StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, T>;
}
/**
 * Interface for supplying single XY data-points to a component.
 *
 * The primary way of adding points is the **add()** method. All other methods are for end user utility,
 * and simply transform given data to the format of *add()*. As such, they cause additional performance overhead,
 * so use *add()* whenever possible.
 */
export interface DataInput {
    /**
     * Add *Point* or Array of *Point*s.
     * @param    data    *Point* or Array of *Point*s.
     * @returns          Object itself for fluent interface.
     */
    add(points: Point | Point[]): this;
}
/**
 * Interface for supplying an Array of X data to a component.
 *
 * Given data is expected to be number values, which will be transformed into an array of XY-compatible points.
 * This method is for end user utility, and simply transform given data to the format of *add()*.
 * As such, they cause additional performance overhead, so use *add()* whenever possible.
 */
export interface DataInputX {
    /**
     * Add an Array of **X**-values.
     * Each X-value will be paired with an automatically generated Y-value, based on *step*-argument.
     *
     * **For optimal performance, use add() if possible.**
     * @param   arrayX  Array of X-values.
     * @param   step    Optional step between each Y coordinate. Defaults to 1.
     * @param   start   Optional value for first generated Y-value. Defaults to 0.
     * @return          Object itself for fluent interface.
     */
    addArrayX(arrayX: number[], step?: number, start?: number): this;
}
/**
 * Interface for supplying an Array of High Low data to a component.
 *
 * Given data is expected to be two number Arrays of equal length, which will be transformed into
 * a single array of AreaPoints.
 * This method is for end user utility, and simply transform given data to the format of *add()*.
 * As such, they cause additional performance overhead, so use *add()* whenever possible.
 */
export interface DataInputHighLow {
    /**
    * Add an Array of High Low values.
    * Each HighLow value will be paired with an automatically generated HighLow value, based on *step*-argument.
    * **For optimal performance, use add() if possible.**
    * @param   arrayHigh  Array of first High values.
    * @param   arrayLow  Array of Second Low values
    * @param   step    Optional step between each HighLow coordinate. Defaults to 1.
    * @param   start   Optional value for first generated HighLow value. Defaults to 0.
    * @return          Object itself for fluent interface.
    */
    addArraysHighLow(arrayHigh: number[], arrayLow: number[], step?: number, start?: number): this;
}
/**
 * Interface for supplying an Array of Y data to a component.
 *
 * Given data is expected to be number values, which will be transformed into an array of XY-compatible points.
 * This method is for end user utility, and simply transform given data to the format of *add()*.
 * As such, they cause additional performance overhead, so use *add()* whenever possible.
 */
export interface DataInputY {
    /**
     * Add an Array of **Y**-values.
     * Each Y-value will be paired with an automatically generated X-value, based on *step*-argument.
     *
     * **For optimal performance, use add() if possible.**
     * @param   arrayY  Array of Y-values.
     * @param   step    Optional step between each X coordinate. Defaults to 1.
     * @param   start   Optional value for first generated X-value. Defaults to 0.
     * @return          Object itself for fluent interface.
     */
    addArrayY(arrayY: number[], step?: number, start?: number): this;
}
/**
 * Interface for supplying Arrays of data to a component.
 *
 * Given data is expected to be two number Arrays of equal length, which will be transformed into a single Array of XY-compatible points.
 * This method is for end user utility, and simply transform given data to the format of *add()*.
 * As such, they cause additional performance overhead, so use *add()* whenever possible.
 */
export interface DataInputXY {
    /**
     * Add two individual Arrays, one for X-values, and another for Y-values.
     *
     * **The length of the Arrays must be equal, otherwise an Error will be thrown.**
     *
     * **For optimal performance, use add() if possible.**
     * @param   arrayX  Array of X-values.
     * @param   arrayY  Array of Y-values.
     * @return          Object itself for fluent interface.
     */
    addArraysXY(arrayX: number[], arrayY: number[]): this;
}
/**
 * Interface for an object that can be used to enable optimizations applicable only to data that follows a specific pattern.
 */
export interface DataPattern {
    /**
     * @return Max X value of the series
     */
    getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
}
/**
 * Base class for Freeform series
 */
export declare class FreeFormPattern implements DataPattern {
    /**
     * @return Max X value of the series
     */
    getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
}
/**
 * Progressive data pattern record properties
 */
interface ProgressivePatternRecordProperties {
}
/**
 * Progressive pattern record
 * @hidden
 */
declare const ProgressivePatternRecord: Record.Factory<ProgressivePatternRecordProperties>;
/**
 * Base class for Progressive DataPattern objects.
 * @noInheritDoc
 */
export declare abstract class ProgressivePattern extends ProgressivePatternRecord implements DataPattern {
    /**
     * @return Max X value of the series
     */
    abstract getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    abstract getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Max Y value of the series
     */
    abstract getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    abstract getYMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[], newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * Set precision of data packing optimization.
     *
     * Example usage:
     *
     * **Normal precision**
     * ```javascript
     *  DataPatterns.horizontalProgressive.setPrecision( 'normal' )
     * ```
     *
     * **High precision**
     *
     * Sometimes needed if data is very dense, yet still detailed.
     * ```javascript
     *  DataPatterns.horizontalProgressive.setPrecision( 'high' )
     * ```
     * @param precision     Data packing precision.
     * @return              New DataPattern object.
     */
    abstract setPrecision(precision: 'normal' | 'high'): this;
}
/**
 * Abstract class which contains a part of logic which is generic for Horizontal progressive and regressive Line Series
 *
 * Y Max and Min are found by iteration over entire collection of segments
 * @hidden
 */
export declare abstract class HorizontalPattern extends ProgressivePattern {
    /**
     * @return Max Y value of the series
     */
    getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
}
/**
 * DataPattern for horizontally progressive data
 * @hidden
 */
export declare class HorizontalProgressivePattern extends HorizontalPattern {
    constructor();
    /**
     * @return Max X value of the series
     */
    getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * Set precision of data packing optimization.
     * @param precision  Data packing precision.
     */
    setPrecision(precision: 'normal' | 'high'): this;
}
/**
 * DataPattern for horizontally regressive data
 * @hidden
 */
export declare class HorizontalRegressivePattern extends HorizontalPattern {
    constructor();
    /**
     * @return Max X value of the series
     */
    getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * Set precision of data packing optimization.
     * @param precision  Data packing precision.
     */
    setPrecision(precision: 'normal' | 'high'): this;
}
/**
 * Abstract class which contains a part of logic which is generic for Vertical progressive and regressive Line Series
 *
 * X Max and Min are found by iteration over entire collection of segments
 * @hidden
 */
export declare abstract class VerticalPattern extends ProgressivePattern {
    /**
     * @return Max X value of the series
     */
    getXMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
}
/**
 * DataPattern for vertically progressive data
 * @hidden
 */
export declare class VerticalProgressivePattern extends VerticalPattern {
    constructor();
    /**
     * @return Max Y value of the series
     */
    getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * Set precision of data packing optimization.
     * @param precision  Data packing precision.
     */
    setPrecision(precision: 'normal' | 'high'): this;
}
/**
 * DataPattern for vertically regressive data
 * @hidden
 */
export declare class VerticalRegressivePattern extends VerticalPattern {
    constructor();
    /**
     * @return Max Y value of the series
     */
    getYMax<VisualType extends BasicChartVisualShapeSet>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin<VisualType extends BasicChartVisual>(segments: VisualType[] | undefined, newPointsBound: Interval<Point> | undefined): number | undefined;
    /**
     * Set precision of data packing optimization.
     * @param precision  Data packing precision.
     */
    setPrecision(precision: 'normal' | 'high'): this;
}
/**
 * Options collection for selecting optimizations for data with a specific pattern.
 * Knowing the pattern of incoming data can enable massive optimizations.
 *
 * This must be specified when *Series* is created. Note, that not all *Series* support specifying pattern of data.
 *
 * Example usage:
 *```javascript
 * // Create LineSeries with progressive data on X
 * ChartXY.addLineSeries({ dataPattern: DataPatterns.horizontalProgressive })
 * ```
 * If the Series is supplied with data that does not respect the given [[DataPattern]], it might behave unexpectedly.
 */
export declare const DataPatterns: {
    /**
     * Indicates that incoming data always progresses in positive X direction and enables optimizations for this scenario.
     *
     * Example usage:
     *```javascript
     * // Create LineSeries with progressive data on X
     * ChartXY.addLineSeries({ dataPattern: DataPatterns.horizontalProgressive })
     * ```
     */
    horizontalProgressive: ProgressivePattern;
    /**
     * Indicates that incoming data always progresses in negative X direction and enables optimizations for this scenario.
     *
     * Example usage:
     *```javascript
     * // Create LineSeries with regressive data on X
     * ChartXY.addLineSeries({ dataPattern: DataPatterns.horizontalRegressive })
     * ```
     */
    horizontalRegressive: ProgressivePattern;
    /**
     * Indicates that incoming data always progresses in positive Y direction and enables optimizations for this scenario.
     *
     * Example usage:
     *```javascript
     * // Create LineSeries with progressive data on Y
     * ChartXY.addLineSeries({ dataPattern: DataPatterns.verticalProgressive })
     * ```
     */
    verticalProgressive: ProgressivePattern;
    /**
     * Indicates that incoming data always progresses in negative Y direction and enables optimizations for this scenario.
     *
     * Example usage:
     *```javascript
     * // Create LineSeries with progressive data on Y
     * ChartXY.addLineSeries({ dataPattern: DataPatterns.verticalRegressive })
     * ```
     */
    verticalRegressive: ProgressivePattern;
    /**
     * Indicates that incoming data has no pattern, and can go in any direction from any given point.
     * Data-point solving is EXTREMELY HEAVY for freeform data, consider using other *DataPattern*s if possible.
     *
     * Example usage:
     *```javascript
     * // Create freeform LineSeries
     * ChartXY.addLineSeries({ dataPattern: DataPatterns.freeform })
     * ```
     */
    freeform: FreeFormPattern;
};
/**
 * Type of constructor for DataPattern
 * @hidden
 */
export declare type DataPatternConstructor<T extends DataPattern = DataPattern> = new () => T;
export {};
/**
 * LineSeries, extension of BasicSeries using LineSets
 * + Lined -interface
 */
/**
 * Implementation of *SeriesXY* for visualizing a collection of *Points* with connected lines.
 *
 * *LineSeries* are created with [[ChartXY.addLineSeries]]
 */
export declare class LineSeries extends BasicSeries<LineSet, Point> implements Lined {
    /**
     * @param _chart                Parent Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param xAxis                 Axis X
     * @param yAxis                 Axis Y
     * @param xAxisAttachHandler    Attach handler for Axis X
     * @param yAxisAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _dataPattern          Data-Pattern for enabling case-specific optimizations
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<SeriesXY>, _restoreFromChart: RestoreHandler<SeriesXY>, _layer: LayerXY, xAxis: Axis, yAxis: Axis, xAxisAttachHandler: AxisAttachHandler, yAxisAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _dataPattern: DataPattern, _theme: Theme);
    /**
     * Set stroke style of Series.
     *
     * Example usage:
    *```javascript
    * // Specified LineStyle
    * LineSeries.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
    * // Changed thickness
    * LineSeries.setStrokeStyle((solidLine) => solidLine.setThickness(5))
    * // Hidden must be done with dispose() method, emptyLine is not supported
    * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns         Chart itself
     */
    setStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Get stroke style of Series.
     * @return  SolidLine object
     */
    getStrokeStyle(): SolidLine;
    /**
     * Set stroke style of Series when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
    *```javascript
    * // Specified LineStyle
    * LineSeries.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
    * // Changed thickness
    * LineSeries.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
    * // Hidden must be done with transparentLine, emptyLine is not supported
    * LineSeries.setStrokeStyleHighlight(transparentLine)
    * // Automatic
    * LineSeries.setStrokeStyleHighlight(undefined)
    * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get stroke style of Series when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     * @return  SolidLine object
     */
    getStrokeStyleHighlight(): SolidLine;
    /**
     * Set if cursor interpolates solved data-points along series by default.
     * @param   state   Boolean flag
     * @returns         Object itself for fluent interface
     */
    setCursorInterpolationEnabled(state: boolean): this;
    /**
     * Get if cursor interpolates solved data-points along series by default.
     * @returns         Boolean flag
     */
    getCursorInterpolationEnabled(): boolean;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point, interpolate?: boolean): undefined | CursorPoint;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: LineSet, interpolate?: boolean): undefined | CursorPoint;
}
/**
 * Interface for a series which contains lines
 * @hidden
 */
export interface Lined {
    /**
     * Set lines style
     * @param   value     Line style object or function which modifies it
     * @returns           Series object (self)
     */
    setStrokeStyle: (value: SolidLine | ImmutableMutator<SolidLine>) => this;
    /**
     * @return Current lines style
     */
    getStrokeStyle: () => SolidLine;
    /**
     * Set highlight line style
     * @param   lineStyle  SolidLine for highlighted line or mutator to modify existing one or undefined for auto
     * @return             Object itself for fluent interface
     */
    setStrokeStyleHighlight: (lineStyle: SolidLine | ImmutableMutator<SolidLine> | undefined) => this;
    /**
     * @return  Current highlight line style
     */
    getStrokeStyleHighlight: () => SolidLine | undefined;
}
/**
 * Cursor-based visual that can be plotted on a XY Chart.
 * Like CursorXYs its built of four parts:
 * PointMarker shows the location of the Marker,
 * ResultTable displays information of the point
 * and X&Y tickMarkers to show gridstroke on its axes.
 * @hidden
 */
export interface MarkerXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground> extends Marker<PointMarkerType, ResultTableBackgroundType, CursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>> {
    /**
     * Set visibility mode for gridstroke X.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setGridStrokeXVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for gridstroke X.
     * @return                  VisibilityMode
     */
    getGridStrokeXVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for gridstroke Y.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setGridStrokeYVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for gridstroke Y.
     * @return                  VisibilityMode
     */
    getGridStrokeYVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for tickMarker X.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setTickMarkerXVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for tickMarker X.
     * @return                  VisibilityMode
     */
    getTickMarkerXVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for tickMarker Y.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setTickMarkerYVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for tickMarker Y.
     * @return                  VisibilityMode
     */
    getTickMarkerYVisibility(): UIVisibilityModes;
}
/**
 * XY Marker that is basically a static cursor.
 * @hidden Internal class
 */
declare abstract class InternalChartMarkerXY<PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground> extends ChartMarker<PointMarkerType, ResultTableBackgroundType, InternalStaticCursorXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>> implements MarkerXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY> {
    protected readonly _layer: LayerXY;
    readonly axisX: Axis;
    readonly axisY: Axis;
    protected _removeMarker: RemoveHandler<SeriesMarkerXY>;
    protected _restoreMarker: RestoreHandler<SeriesMarkerXY>;
    private gridStrokeStyleX;
    private gridStrokeStyleY;
    /**
     * @param   _layer           Rendering layer
     * @param   axisX           X axis of Marker
     * @param   axisY           Y axis of Marker
     * @param   CursorBuilder   CursorBuilder that defines look of Marker
     * @hidden
     */
    constructor(_layer: LayerXY, axisX: Axis, axisY: Axis, CursorBuilder: StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>, _removeMarker: RemoveHandler<SeriesMarkerXY>, _restoreMarker: RestoreHandler<SeriesMarkerXY>, _theme: Theme);
    /**
     * Set visibility mode for gridstroke X.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setGridStrokeXVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for gridstroke X.
     * @return                  VisibilityMode
     */
    getGridStrokeXVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for gridstroke Y.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setGridStrokeYVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for gridstroke Y.
     * @return                  VisibilityMode
     */
    getGridStrokeYVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for tickMarker X.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setTickMarkerXVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for tickMarker X.
     * @return                  VisibilityMode
     */
    getTickMarkerXVisibility(): UIVisibilityModes;
    /**
     * Set visibility mode for tickMarker Y.
     * @param   visibilityMode   Defines when part is visible
     * @return                  Object itself
     */
    setTickMarkerYVisibility(visibilityMode: UIVisibilityModes): this;
    /**
     * Get visibility mode for tickMarker Y.
     * @return                  VisibilityMode
     */
    getTickMarkerYVisibility(): UIVisibilityModes;
    /**
     * Set is GridStrokeX cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXCut(cut: boolean): this;
    /**
     * Get is GridStrokeX cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeXCut(): boolean;
    /**
     * Set is GridStrokeY cut at cursor location.
     * @param   cut         Boolean flag
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYCut(cut: boolean): this;
    /**
     * Get is GridStrokeY cut at cursor location.
     * @returns             Boolean flag
     */
    getGridStrokeYCut(): boolean;
    /**
     * Set style of x gridstroke
     * @param   value       LineStyle object or mutator to modify existing one
     * @returns             Object itself for fluent interface
     */
    setGridStrokeXStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of x gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeXStyle(): LineStyle;
    /**
     * Set style of y gridstroke
     * @param   value       LineStyle object or mutator to modify existing one
     * @returns             Object itself for fluent interface
     */
    setGridStrokeYStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of y gridstroke
     * @returns             LineStyle of gridstroke
     */
    getGridStrokeYStyle(): LineStyle;
    /**
     * Mutator function for x tick marker
     * @param   mutator     TickMarker mutator function
     * @returns             Object itself for fluent interface
     */
    setTickMarkerX(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeX>>): this;
    /**
     * Get x tick marker
     * @returns             X customTick of cursor
     */
    getTickMarkerX(): TickMarker<TickMarkerBackgroundTypeX>;
    /**
     * Mutator function for y tick marker
     * @param   mutator     TickMarker mutator function
     * @returns             Object itself for fluent interface
     */
    setTickMarkerY(mutator: Mutator<TickMarker<TickMarkerBackgroundTypeY>>): this;
    /**
     * Get y tick marker
     * @returns             Y customTick of cursor
     */
    getTickMarkerY(): TickMarker<TickMarkerBackgroundTypeY>;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
}
/**
 * Simple XY Marker that is basically a static cursor.
 * Like CursorXYs its built of four parts:
 * PointMarker shows the location of the Marker,
 * ResultTable displays information of the point
 * and X&Y tickMarkers to show gridstroke on its axes.
 */
export declare class ChartMarkerXY<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerXBackgroundType extends PointableBackground = PointableBackground, TickMarkerYBackgroundType extends PointableBackground = PointableBackground> extends InternalChartMarkerXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType> {
}
/**
 * Marker that can be attached on a XY series.
 * Like CursorXYs its built of four parts:
 * PointMarker shows the location of the Marker,
 * ResultTable displays information of the point
 * and X&Y tickMarkers to show gridstroke on its axes.
 */
export declare class SeriesMarkerXY<PointMarkerType extends PointMarker = PointMarker, ResultTableBackgroundType extends UIBackground = UIBackground, TickMarkerXBackgroundType extends PointableBackground = PointableBackground, TickMarkerYBackgroundType extends PointableBackground = PointableBackground> extends ChartMarkerXY<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType> {
    protected readonly _layer: LayerXY;
    readonly owningSeries: SeriesXY;
    protected _removeMarker: RemoveHandler<SeriesMarkerXY>;
    protected _restoreMarker: RestoreHandler<SeriesMarkerXY>;
    /**
     * @param   _layer          Rendering layer
     * @param   owningSeries    Series that owns marker
     * @param   CursorBuilder   CursorBuilder that defines look of Marker
     * @param   _removeMarker   Injected method to remove marker from owner's collection.
     * @hidden
     */
    constructor(_layer: LayerXY, owningSeries: SeriesXY, CursorBuilder: StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerXBackgroundType, TickMarkerYBackgroundType>, _removeMarker: RemoveHandler<SeriesMarkerXY>, _restoreMarker: RestoreHandler<SeriesMarkerXY>, _theme: Theme);
    /**
     * Set position of SeriesMarker.
     * @param   position    Location on SeriesMarkers scale. Marker will be attached to closest datapoint on its series.
     * @returns             Object itself
     */
    setPosition(position: Point): this;
    /**
     * @returns True if object is attached or not attachable, false if it is not attached and attachable
     */
    isAttached(): boolean;
}
export {};
/**
 * PointLineSeries implementation of BasicSeries (actually extends PointSeries),
 * that uses both PointSets and LineSets as its segments
 */
/**
 * Implementation of *SeriesXY* for visualizing a collection of *Points* with a specifiable [[PointShape]]
 * and connected lines.
 *
 * *PointLineSeries* are created with [[ChartXY.addPointLineSeries]]
 */
export declare class PointLineSeries extends LineSeries implements Pointed, IndividualPointed {
    protected readonly _pointShape: PointShape;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _dataPattern          Data-Pattern for enabling case-specific optimizations
     * @param _dataPattern          Factory for creating setting the type of series like Freeform or Progressive
     * @param _pointShape           Shape of rendered points
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _dataPattern: DataPattern, _pointShape: PointShape, _theme: Theme);
    /**
     * @hidden
     */
    getPointAmount(): number;
    /**
     * Set point fill style of Series.
     * Use [[IndividualPointFill]] to enable individual coloring of points.
     *
     * Example usage:
     *```javascript
     * // Create a new style
     * PointLineSeries.setPointFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * PointLineSeries.setPointFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * PointLineSeries.setPointFillStyle(emptyFill)
     * ```
     * @param fillStyle     Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns             Series itself for fluent interface.
     */
    setPointFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get normal points fill style.
     * @return  Normal point fill style.
     */
    getPointFillStyle(): FillStyle;
    /**
     * Set point fill style of Series when it is highlighted.
     * Use [[IndividualPointFill]] to enable individual coloring of points.
     *
    * Example usage:
     *```javascript
     * // Create a new style
     * PointLineSeries.setPointFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * PointLineSeries.setPointFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Set hidden
     * PointLineSeries.setPointFillStyleHighlight(emptyFill)
     * // Automatic
     * PointLineSeries.setPointFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setPointFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return  Current highlight point fill style
     */
    getPointFillStyleHighlight(): FillStyle;
    /**
     * Set size of point in pixels
     * @param   size    Size of point in pixels
     * @returns         Object itself for fluent interface
     */
    setPointSize(size: number): this;
    /**
     * @returns Size of point in pixels
     */
    getPointSize(): number;
    /**
     * Get shape of points.
     *
     * This is defined upon creation of series, and cannot be changed afterwards.
     * @returns PointShape
     */
    getPointShape(): PointShape;
    /**
     * Set the rotation of points.
     * @param angle Rotation angle in degrees
     */
    setPointRotation(angle: number): this;
    /**
     * Get the current rotation of points.
     */
    getPointRotation(): number;
    /**
     * Enable or disable individual point sizing.
     *
     * When enabled, size for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, size: 10 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointSizeEnabled(enabled: boolean): this;
    /**
     * Gets if individual point sizing is enabled or not.
     */
    getIndividualPointSizeEnabled(): boolean;
    /**
     * Enable or disable individual point rotation.
     *
     * When enabled, rotation for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, rotation: 45 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointRotationEnabled(enabled: boolean): this;
    /**
     * Gets if individual point rotation is enabled or not.
     */
    getIndividualPointRotationEnabled(): boolean;
    /**
     * Enable or disable forced highlighting of series
     * @param highlight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highlight: boolean): this;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: LineSet | PointSet, interpolate?: boolean): undefined | CursorPoint;
    /**
     * Clear all points and segments from the dataset.
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * Remove everything related to the object from all collections associated
     * with rendering cycle and allows the object to be collected by GC
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Object itself.
     */
    restore(): this;
}
/**
 * PointSeries, extension of BasicSeries using PointSets
 */
/**
 * Implementation of *SeriesXY* for visualizing a collection of *Points* by filling them with a specifiable [[PointShape]].
 *
 * *PointSeries* are created with [[ChartXY.addPointSeries]]
 */
export declare class PointSeries extends BasicSeries<PointSet, Point | ColorPoint | SizePoint | RotationPoint> implements Pointed, IndividualPointed {
    protected readonly _pointShape: PointShape;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _pointShape           Shape of rendered points
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _pointShape: PointShape, _theme: Theme);
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Set point fill style of Series.
     * Use [[IndividualPointFill]] object to enable individual coloring of points.
     *
     * Example usage:
     *```javascript
     * // Create a new style
     * PointSeries.setPointFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * PointSeries.setPointFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * PointSeries.setPointFillStyle(emptyFill)
     * ```
     * @param fillStyle     Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns             Series itself for fluent interface.
     */
    setPointFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get normal points fill style.
     * @return  Normal point fillStyle
     */
    getPointFillStyle(): FillStyle;
    /**
     * Set point fill style of Series when it is highlighted.
     *
    * Example usage:
     *```javascript
     * // Create a new style
     * PointSeries.setPointFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * PointSeries.setPointFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Set hidden
     * PointSeries.setPointFillStyleHighlight(emptyFill)
     * // Automatic
     * PointSeries.setPointFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setPointFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get current highlight fill style of points.
     * @return  Current highlight point fill style
     */
    getPointFillStyleHighlight(): FillStyle;
    /**
     * Set size of point in pixels.
     * @param   size    Size of point in pixels.
     * @returns         Object itself for fluent interface.
     */
    setPointSize(size: number): this;
    /**
     * Get current size of points in pixels.
     * @returns Size of point in pixels.
     */
    getPointSize(): number;
    /**
     * Get shape of points.
     *
     * This is defined upon creation of series, and cannot be changed afterwards.
     * @returns PointShape
     */
    getPointShape(): PointShape;
    /**
     * Set the rotation of points in degrees.
     * @param angle Rotation angle in degrees
     */
    setPointRotation(angle: number): this;
    /**
     * Get the current rotation of points.
     */
    getPointRotation(): number;
    /**
     * Enable or disable individual point sizing.
     *
     * When enabled, size for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, size: 10 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointSizeEnabled(enabled: boolean): this;
    /**
     * Gets if individual point sizing is enabled or not.
     */
    getIndividualPointSizeEnabled(): boolean;
    /**
     * Enable or disable individual point rotation.
     *
     * When enabled, rotation for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, rotation: 45 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointRotationEnabled(enabled: boolean): this;
    /**
     * Gets if individual point rotation is enabled or not.
     */
    getIndividualPointRotationEnabled(): boolean;
    /**
     * Solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point): undefined | CursorPoint;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: PointSet): undefined | CursorPoint;
}
/**
 * Interface for a series which contains points
 * @hidden
 */
export interface Pointed {
    /**
     * Set point fill style
     * @param   pointColor FillStyle for points or mutator to modify existing one
     * @returns            Series object (self)
     */
    setPointFillStyle: (pointColor: FillStyle | ImmutableMutator<FillStyle>) => this;
    /**
     * @return  Current point fill style
     */
    getPointFillStyle: () => FillStyle;
    /**
     * Set highlight point fill style
     * @param   fillStyle  FillStyle for highlighted points or mutator to modify existing one
     * @return             Object itself for fluent interface
     */
    setPointFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return  Current highlight point fill style
     */
    getPointFillStyleHighlight: () => FillStyle | undefined;
    /**
     * Set size of point in pixels
     * @param   size    Size of point in pixels
     * @returns         Object itself for fluent interface
     */
    setPointSize(size: number): this;
    /**
     * @returns Size of point in pixels
     */
    getPointSize(): number;
    /**
     * Get shape of points.
     *
     * This is defined upon creation of Series, and cannot be changed afterwards.
     * @returns Shape of points
     */
    getPointShape(): PointShape;
    /**
     * Set the rotation of points.
     * @param angle Rotation angle in degrees
     */
    setPointRotation(angle: number): this;
    /**
     * Get the current rotation of points.
     */
    getPointRotation(): number;
}
/**
 * Interface for a series which contains individually sizeable an rotatable points
 * @hidden
 */
export interface IndividualPointed {
    /**
     * Enable or disable individual point sizing.
     *
     * When enabled, size for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, size: 10 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointSizeEnabled(enabled: boolean): this;
    /**
     * Gets if individual point sizing is enabled or not.
     */
    getIndividualPointSizeEnabled(): boolean;
    /**
     * Enable or disable individual point rotation.
     *
     * When enabled, rotation for each point can be provided with the location of the point.
     * ```js
     * pointSeries.add({x: 1, y: 2, rotation: 45 })
     * ```
     * @param enabled Boolean state for individual point size enabled
     */
    setIndividualPointRotationEnabled(enabled: boolean): this;
    /**
     * Gets if individual point rotation is enabled or not.
     */
    getIndividualPointRotationEnabled(): boolean;
}
/**
 * SeriesXY
 *
 * Extension of Series2D
 * Adds Axes, filling, setEnabled, CursorXY, abstract hover functionality (for highlighting/custom cursor logic)
 *
 */
/**
 * Abstract super-class for 2D-series with X&Y axes
 * @hidden Internal class
 */
export declare abstract class SeriesXY<VisualType extends ChartVisual = ChartVisual, CursorPointInterface extends CursorPoint = CursorPoint> extends Series2D<VisualType, CursorPointInterface> {
    readonly chart: ChartXY;
    protected readonly _layer: LayerXY;
    readonly axisX: Axis;
    readonly axisY: Axis;
    private axisXAttachHandler;
    private axisYAttachHandler;
    private readonly _newUILayer;
    /**
     * Scale of the series
     */
    readonly scale: Vec2<Scale>;
    /**
     * @param _chart                Parent Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _theme                Theme from owning Chart.
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _theme: Theme);
    /**
     * Attach and cache returned remove handler
     */
    private attacheAxis;
    /**
     * Add Marker to the Series.
     * @param   cursorBuilder   StaticCursorBuilderXY object for customized look of marker.
     *                          MarkerBuilders.XY can be used to build a custom one from scratch.
     * @returns                 SeriesMarkerXY
     */
    addMarker: <PointMarkerType extends PointMarker, ResultTableBackgroundType extends UIBackground, TickMarkerBackgroundTypeX extends PointableBackground, TickMarkerBackgroundTypeY extends PointableBackground>(cursorBuilder?: StaticCursorXYBuilder<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>) => SeriesMarkerXY<PointMarkerType, ResultTableBackgroundType, TickMarkerBackgroundTypeX, TickMarkerBackgroundTypeY>;
    /**
     * Remove everything related to the object from all collections associated
     * with rendering cycle and allows the object to be collected by GC
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
      * Tell the owning chart to restore this series.
      * @return  Object itself.
      */
    restore(): this;
    /**
     * Remove the given marker from the collection of markers this Series has.
     * @param   marker  Marker to remove.
     */
    private removeMarker;
    /**
     * Restores the given marker to the collection.
     * @param   marker  Marker to remove.
     */
    private restoreMarker;
    /**
     * @return Max X value of the series
     */
    abstract getXMax(): number | undefined;
    /**
     * @return Min X value of the series
     */
    abstract getXMin(): number | undefined;
    /**
     * @return Max Y value of the series
     */
    abstract getYMax(): number | undefined;
    /**
     * @return Min Y value of the series
     */
    abstract getYMin(): number | undefined;
    getBoundaries(): Interval<Point>;
}
/**
 * Interface for SeriesXY types whose data can be observed in detail.
 *
 * The intent is that all SeriesXY types implement this, apart from Figure series. It is used for ZoomBandChart functionality.
 * @typeparam   T   Type of data-point in Series (eq. Point, AreaPoint, XOHLC, ...).
 * @hidden
 */
export interface ObservableXYData<T> {
}
/**
 * Type union of Series supported by ZoomBandChart.
 */
declare type ZoomBandChartSupportedSeries = BasicSeries | AreaSeries | AreaRangeSeries | OHLCSeries;
/**
 * Type of a function that is used to override the style of all Series created by ZoomBandChart.
 *
 * @param   series              The Series created by ZoomBandChart. The type of Series depends on the referenced series.
 * @param   referencedSeries    The Series that is being referenced.
 *                              If [[AreaRangeSeries]], series is also [[AreaRangeSeries]].
 *                              Otherwise, series is always [[LineSeries]].
 */
export declare type ZoomBandChartSeriesStyler = {
    (series: LineSeries, referencedSeries: BasicSeries | AreaSeries | OHLCSeries): unknown;
    (series: AreaRangeSeries, referencedSeries: AreaRangeSeries): unknown;
};
/**
 * Chart that is attached to a single [[Axis]] of a [[ChartXY]].
 *
 * It shows a compilation of all data from all *Series* that are attached to that [[Axis]], and allows
 * the user to configure the view of the attached [[Axis]] easily by interacting with a [[Band]] on the *ZoomBandChart*.
 *
 * Created with [[Dashboard.createZoomBandChart]].
 * ```javascript
 *
 *  const dashboard = lightningChart().Dashboard( {
 *      numberOfColumns: 1,
 *      numberOfRows: 4
 *  } )
 *
 *  const chart = dashboard.createChartXY( {
 *      columnIndex: 0,
 *      columnSpan: 1,
 *      rowIndex: 0,
 *      rowSpan: 3
 *  })
 *
 *  const zoomBandChart = dashboard.createZoomBandChart({
 *      columnIndex: 0,
 *      columnSpan: 1,
 *      rowIndex: 3,
 *      rowSpan: 1,
 *      axis: chart.getDefaultAxisX()
 *  })
 *
 *  const line = chart.addLineSeries()
 *  createProgressiveTraceGenerator()
 *      .setNumberOfPoints( 1000 )
 *      .generate()
 *      .toPromise()
 *      .then( data => line.add( data ) )
 *
 * ```
 */
export declare class ZoomBandChart implements Control, DashboardPanel, ChartAPI {
    /**
     * Public, safe interface of rendering engine.
     */
    readonly engine: PublicEngine;
    /**
     * The Band of the ZoomBandChart.
     */
    readonly band: Band;
    /**
     * Dispose a Series reference from the ZoomBandChart.
     *
     * This ensures that all resources that were previously allocated for this series instance are released for Garbage Collection.
     * @param   series  Series object.
     * @return          Object itself.
     */
    disposeSeries(series: ZoomBandChartSupportedSeries): this;
    /**
     * Set style of Series of ZoomBandChart.
     *
     * ZoomBandChart creates series automatically based on the Series attached to the ZoomBandCharts reference Axis,
     * that is specified when it is created. This method lets the user specify a function that is called on each Series created by
     * ZoomBandChart, allowing the full configuration of these Series.
     */
    setSeriesStyle(styler: ZoomBandChartSeriesStyler): this;
    /**
     * Get the X Axis of the ZoomBandChart.
     * @returns Axis
     */
    getDefaultAxisX(): Axis;
    /**
     * Get the Y Axis of the ZoomBandChart.
     * @returns Axis
     */
    getDefaultAxisY(): Axis;
    /**
     * Set fillStyle of chart background.
     * This is the area enclosed by the axis'.
     * @param   fillStyle   FillStyle or mutator to modify existing one
     * @return              Object itself
     */
    setChartBackgroundFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillstyle of chart background.
     * This is the area enclosed by the axis'.
     * @return              FillStyle
     */
    getChartBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke of chart background.
     * This is the area enclosed by the axis'.
     * @param   value       LineStyle or mutator to modify existing one
     * @return              Object itself
     */
    setChartBackgroundStroke(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of chart background.
     * This is the area enclosed by the axis'.
     * @return              LineStyle
     */
    getChartBackgroundStroke(): LineStyle;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Point minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
    /**
     * Set text of Chart title.
     * @param   title  Chart title as a string.
     * @returns        Object itself for fluent interface.
     */
    setTitle(title: string): this;
    /**
     * Get text of Chart title.
     * @returns         Chart title as a string.
     */
    getTitle(): string;
    /**
     * Set fill style of Chart Title.
     *
    * Example usage:
     *```javascript
     * // Create a new style
     * ZoomBandChart.setTitleFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Change transparency
     * ZoomBandChart.setTitleFillStyle((solidFill) => solidFill.setA(80))
     * // Set hidden
     * ZoomBandChart.setTitleFillStyle(emptyFill)
     * ```
     * @param   value   Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns         Chart itself
     */
    setTitleFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Chart Title.
     * @returns FillStyle object
     */
    getTitleFillStyle(): FillStyle;
    /**
     * Set font of Chart Title.
     *
     * Example usage:
     *```javascript
     * // Create a new FontSettings
     * ZoomBandChart.setTitleFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Change existing settings
     * ZoomBandChart.setTitleFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Chart itself
     */
    setTitleFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Chart title.
     * @return  FontSettings object
     */
    getTitleFont(): FontSettings;
    /**
     * Specifies padding before chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap between the top of chart and its title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginTop(marginPixels: pixel): this;
    /**
     * @returns Padding before Chart title
     */
    getTitleMarginTop(): number;
    /**
     * Specifies padding after chart title.
     *
     * This does not have an effect if title is hidden (empty FillStyle).
     * @param  marginPixels Gap after the chart title in pixels.
     * @returns             Chart itself for fluent interface
     */
    setTitleMarginBottom(marginPixels: pixel): this;
    /**
     * @returns Padding after Chart title
     */
    getTitleMarginBottom(): number;
    /**
     * Set padding around Chart in pixels.
     * @param   padding     Number with pixel margins for all sides or datastructure with individual pixel paddings
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself for fluent interface
     */
    setPadding(padding: Partial<Margin> | number): this;
    /**
     * Get padding around Chart in pixels.
     * @return              Padding datastructure
     */
    getPadding(): Margin;
    /**
     * Set fillStyle of panel background.
     * @param   value       FillStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fillstyle of chart background.
     * @return              FillStyle
     */
    getBackgroundFillStyle(): FillStyle;
    /**
     * Set stroke style of panel background.
     * @param   value       LineStyle or function which modifies it
     * @return              Object itself
     */
    setBackgroundStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of chart background.
     * @return              LineStyle
     */
    getBackgroundStrokeStyle(): LineStyle;
    /**
     * Add a stand-alone *UIElement* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *UIElementBuilder*. If omitted, *TextBoxBuilder* will be selected. Use [[UIElementBuilders]] for selection.
     * @param       scale   Optional custom scale to position UIElement on. Defaults to whole component in percentages [0, 100].
     * @returns             Object that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addUIElement<UIElementType extends UIPart = UITextBox>(uiElementBuilder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
     * Add a stand-alone *LegendBox* using a *builder*.
     *
     * @typeparam   UIElementType   Type of *UIElement* that is specified by 'builder'-*parameter*.
     *
     * @param       builder *LegendBoxBuilder*. If omitted, *HorizontalLegendBox* will be selected. Use [[LegendBoxBuilders]] for selection.
     * @param       scale   Optional custom scale to position LegendBox on. Defaults to whole chart in percentages [0, 100].
     * @returns             LegendBox that fulfills *interfaces*:  *UIElementType* (typeparam) and *UIElement*
     */
    addLegendBox<UIElementType extends UIPart = UILegendBox>(builder?: UIElementBuilder<UIElementType>, scale?: Vec2<Scale>): UIElementType & UIElement;
    /**
    * Capture rendered state in an image file. Prompts the browser to download the created file.
    *
    * **NOTE: The download might be blocked by browser/plugins as harmful.**
    * To prevent this, only call the method in events tied to user-interactions.
    * From mouse-event handlers, for example.
    *
    * Has two optional parameters which directly reference JavaScript API HTMLCanvasElement.toDataURL.
    * For supported image formats, compression quality, Etc. refer to:
    *
    * https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL
    *
    * Example usage:
    *```javascript
    * // Download 'screenshot.png'
    * saveToFile('screenshot')
    * // Attempt download 'maybeNotSupported.bmp'
    * saveToFile('maybeNotSupported', 'image/bmp')
    * // Attempt download jpeg.file with specified compression quality
    * saveToFile('fileName', 'image/jpeg', 0.50)
    * ```
    *
    * @sideEffect              **If 'type' is not supported by browser, an Error will be thrown.**
    *
    * @param   fileName        Name of prompted download file as string. **File extension shouldn't be included**
    *                          as it is automatically detected from 'type'-argument.
    * @param   type            A DOMString indicating the image format. The default format type is image/png.
    * @param   encoderOptions  A Number between 0 and 1 indicating the image quality to use for image formats
    *                          that use lossy compression such as image/jpeg and image/webp. If this argument is anything else,
    *                          the default value for image quality is used. The default value is 0.92.
    */
    saveToFile(fileName: string, type?: string, encoderOptions?: number): this;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...ChartXY()
     * let axisX = chart.getDefaultAxisX()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * axisX = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
export {};
/**
 * Interface for defining an RGBA Color with channels ranging [0, 1].
 *
 * This should be internal, as usage of Color constructor is ill-advised to promote usage of Factories.
 */
interface ColorProperties {
    /**
    * Red value from 0 to 1
    */
    r: number;
    /**
     * Green value from 0 to 1
     */
    g: number;
    /**
     * Blue value from 0 to 1
     */
    b: number;
    /**
     * Alpha value from 0 to 1
     */
    a: number;
}
/**
 * Record class for ColorProperties,
 * Used as base for Color
 * @hidden
 */
declare const ColorRecord: Record.Factory<ColorProperties>;
/**
 * Class for specifying a color.
 *
 * Instances of Color are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 *
 * Creation of Colors should be done with *Factories*, which affect various formats:
 * - ColorHEX
 * - ColorRGBA
 * - ColorHSV
 *
 * Watch out though, the color information is always stored in RGBA format with channels ranging [0, 255],
 * regardless of how the information is supplied when created !
 * @noInheritDoc
 */
export declare class Color extends ColorRecord {
    /**
     * Cached highlight color
     */
    private _highlightColor?;
    /**
     * Color constructor should be hidden, even though the class is public in order to promote usage of Factories.
     * @hidden
     */
    constructor(color: Partial<ColorProperties>);
    /**
     * Creates a new color that is equal to this but with a certain alpha value
     * @param   alpha   Value of alpha channel [0-255]
     * @return          New Color object
     */
    setA(alpha: number): Color;
    /**
     * Creates a new color that is equal to this but with a certain red value
     * @param   red   Value of red channel [0-255]
     * @return        New Color object
     */
    setR(red: number): Color;
    /**
     * Creates a new color that is equal to this but with a certain green value
     * @param   green   Value of green channel [0-255]
     * @return          New Color object
     */
    setG(green: number): Color;
    /**
     * Creates a new color that is equal to this but with a certain blue value
     * @param   blue   Value of blue channel [0-255]
     * @return         New Color object
     */
    setB(blue: number): Color;
    /**
     * @returns Value of alpha channel [0-255]
     */
    getA(): number;
    /**
     * @returns Value of red channel [0-255]
     */
    getR(): number;
    /**
     * @returns Value of green channel [0-255]
     */
    getG(): number;
    /**
     * @returns Value of blue channel [0-255]
     */
    getB(): number;
    /**
     * Compute a highlighted version of this Color.
     * @returns New Color object
     */
    getHighlight(): Color;
}
/**
 * Factory for creating a Color object given individual values for Red, Green, Blue and optionally Alpha -channels.
 * Values are from 0 to 255.
 *
 * Color objects are seldom used independently, but rather used to form more sophisticated Settings-objects, such as:
 * - FillStyles
 * - LineStyles
 * @param     r     Red from 0 to 255
 * @param     g     Green from 0 to 255
 * @param     b     Blue from 0 to 255
 * @param     a     Alpha from 0 to 255
 * @return          Color object
 */
export declare const ColorRGBA: (r: number, g: number, b: number, a?: number) => Color;
/**
 * Factory for creating a Color object given a hexadecimal-formatted string. Supports the following input formats (value
 * after '#' or '0x' is case insensitive):
 *
 * - #RRGGBBaa or 0xRRGGBBaa
 * - #RRGGBB or 0xRRGGBB
 * - #RGBa or 0xRGBa
 * - #RGB or 0xRGB
 *
 * Other formats will throw an Error!
 *
 * Example:
 * ```javascript
 * let color = ColorHex('0xFF00AABB')
 * color = ColorHex('0xff00aabb')
 * color = ColorHex('#FF00AABB')
 * color = ColorHex('#ff00aabb')
 * color = ColorHex('0xF0AB')
 * color = ColorHex('#F0AB')
 * ```
 *
 * Color objects are seldom used independently, but rather used to form more sophisticated Settings-objects, such as:
 * - FillStyles
 * - LineStyles
 * @param   hexColor    Hexadecimal value for constructing a Color. Eq. #FF0000 = Red
 * @return              Color object
 */
export declare const ColorHEX: (hexColor: string) => Color;
/**
 * Factory for creating a Color object from HSV values.
 *
 * Color objects are seldom used independently, but rather used to form more sophisticated Settings-objects, such as:
 * - FillStyles
 * - LineStyles
 * @param   hue         Hue in range [0, 360].
 * @param   saturation  Saturation in range [0, 1]. Defaults to 1
 * @param   value       Value in range [0, 1]. Defaults to 1
 * @return              Color object
 */
export declare const ColorHSV: (hue: number, saturation?: number, value?: number) => Color;
/**
 * Linear interpolation between two Colors.
 * @param start  Color to start from.
 * @param target Color to interpolate towards.
 * @param amount Amount to interpolate [0-1].
 * @returns      Color in between start and target colors.
 */
export declare const lerpRGBA: (start: Color, target: Color, amount: number) => Color;
export {};
/**
 * Base interface for fillstyles.
 */
export interface FillStyle<Properties extends {} = any> extends Record<Properties> {
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Interface for all properties of a empty FillStyle.
 * @hidden
 */
declare const EmptyFillRecord: Record.Factory<{}>;
/**
 * Abstract class which indicates that shape should not be filled.
 *
 * When *emptyFill* is used, the area that would be filled does **NOT** trigger mouse / touch -events, and
 * its rendering process is skipped, which results in saved performance.
 * @hidden
 */
export declare class EmptyFill extends EmptyFillRecord implements FillStyle {
    /**
     * @returns Object itself, because the entire style does not have any color information.
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Singleton object which indicates that shape should not be filled.
 *
 * When *emptyFill* is used, the area that would be filled does **NOT** trigger mouse / touch -events, and
 * its rendering process is skipped, which results in saved performance.
 */
export declare const emptyFill: EmptyFill;
/**
 * Interface for all properties of a visible FillStyle.
 */
export interface VisibleFillStyleProperties {
    /**
     * For SolidFill: Color which is used to fill shape.
     *
     * For IndividualPointFill: Fallback Color for filling shape if individual Color was not given.
     *
     * For PalettedFill: Fallback Color for filling shape if palette was not given.
     */
    color: Color;
}
/**
 * Record contractor for VisibleFillStyleProperties.
 * @hidden
 */
declare const VisibleFillRecord: Record.Factory<VisibleFillStyleProperties>;
/**
 * Abstract class that indicates some visible Filling.
 * Used only for instanceOf check at Engine
 * @hidden Internal class
 */
export declare abstract class VisibleFill extends VisibleFillRecord implements FillStyle<VisibleFillStyleProperties> {
    /**
     * Cache default highlight style to prevent recreation
     */
    private _defaultHighlightStyle?;
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
    /**
     * @return Newly created default highlight style of this one, with lighter fill color
     */
    protected abstract createDefaultHighlightStyle(): this;
}
/**
 * Class for specifying fillstyle with a single, solid Color.
 *
 * Instances of SolidFill are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 */
export declare class SolidFill extends VisibleFill {
    /**
     * Create a new SolidFill to fill the object with a single solid Color.
     *
     * Example:
     * ```javascript
     * // create fillstyle from RGBA
     * const solidfill = new SolidFill({
     *  // A (alpha) is optional - 255 by default
     *  color: ColorRGBA(255, 0, 0)
     * })
     *
     * // create fillstyle from HEX string
     * const solidfill = new SolidFill({
     *  color: ColorHEX('#F00')
     * })
     *
     * // create fillstyle from HSV
     * const solidfill = new SolidFill({
     *  color: ColorHSV(0, 1, 0.49)
     * })
     * ```
     * @param   props   Optional object containing parameters for creation of fill style.
     */
    constructor(props?: Partial<VisibleFillStyleProperties>);
    /**
     * Construct a new SolidFill object based on this one, but with modified color.
     *
     * Example:
     * ```javascript
     * // specify new color
     * solidfill.setColor( ColorHEX('#F00') )
     *
     * // change individual color properties
     * solidfill.setColor( color => color.setA(80) )
     * ```
     * @param   value   Either a Color object or a function, which will be used to create a new Color based on current value.
     * @return          New SolidFill object
     */
    setColor(value: Color | ImmutableMutator<Color>): this;
    /**
     * Get color of SolidFill.
     * @return  Color object
     */
    getColor(): Color;
    /**
     * Construct a new SolidFill object based on this one, but with a modified Alpha value.
     *
     * @param  alpha    Value of Alpha channel [0-255]
     * @return          New SolidFill object
     */
    setA(alpha: number): SolidFill;
    /**
     * Construct a new SolidFill object based on this one, but with a modified Red value.
     *
     * @param  alpha    Value of Red channel [0-255]
     * @return          New SolidFill object
     */
    setR(red: number): SolidFill;
    /**
     * Construct a new SolidFill object based on this one, but with a modified Green value.
     *
     * @param  green    Value of Green channel [0-255]
     * @return          New SolidFill object
     */
    setG(green: number): SolidFill;
    /**
     * Construct a new SolidFill object based on this one, but with a modified Blue value.
     *
     * @param  blue     Value of Blue channel [0-255]
     * @return          New SolidFill object
     */
    setB(blue: number): SolidFill;
    /**
     * @return Newly created default highlight style of this one, with lighter fill color
     */
    protected createDefaultHighlightStyle(): this;
}
/**
 * Class for enabling individual fillstyle for Series.
 *
 * PointSeries:
 * When this fillstyle is set, the Series will allow using *PointColor*s instead of normal *Point*s when adding data.
 * If *Point* is still used, the configurable Fallback Color is used.
 *
 * IntensitySeries:
 * When this fillstyle is set, the Series will treat the data of the matrix as *ColorValue*-based type of points.
 * If *IntensityValue* is still used, the configurable Fallback Color is used.
 *
 * Instances of IndividualPointFill are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 */
export declare class IndividualPointFill extends VisibleFill {
    /**
     * Create a new IndividualPointFill to apply individual Color per object.
     * The fallback Color would be used for object without specified color.
     *
     * Example:
     * ```javascript
     * // create fillstyle from RGBA
     * const individualfill = new IndividualPointFill({
     *  // A (alpha) is optional - 255 by default
     *  color: ColorRGBA(255, 0, 0)
     * })
     *
     * // create fillstyle from HEX string
     * const individualfill = new IndividualPointFill({
     *  color: ColorHEX('#F00')
     * })
     *
     * // create fillstyle from HSV
     * const individualfill = new IndividualPointFill({
     *  color: ColorHSV(0, 1, 0.49)
     * })
     * ```
     * @param   props   Optional object containing parameters for creation of fill style.
     */
    constructor(props?: Partial<VisibleFillStyleProperties>);
    /**
     * Construct a new IndividualPointFill object based on this one, but with modified fallback color.
     *
     * Example:
     * ```javascript
     * // specify new color
     * individualfill.setColor( ColorHEX('#F00') )
     *
     * // change individual color properties
     * individualfill.setColor( color => color.setA(80) )
     * ```
     * @param   value   Either a Color object or a function, which will be used to create a new Color based on current value.
     * @return          New IndividualPointFill object
     */
    setFallbackColor(value: Color | ImmutableMutator<Color>): this;
    /**
     * Get Fallback Color of IndividualPointFill.
     * @return  Color object
     */
    getFallbackColor(): Color;
    /**
     * Get automatically computed highlight style.
     * @return  Object itself, because the Color information is stored in *PointColor*
     */
    protected createDefaultHighlightStyle(): this;
}
/**
 * Interface for all properties of a PalettedFillStyle.
 */
export interface PalettedFillProperties {
    lut: LUT;
}
/**
 * Record contractor for PalettedFillStyleProperties.
 * @hidden
 */
declare const PalettedFillStyleRecord: Record.Factory<PalettedFillProperties>;
/**
 * Fillstyle class to colorize the data based on value using LUT lookup table.
 *
 * LUT class stores information about values and its associated colors,
 * which provides efficient lookup of the color based on provided value
 * as well as linear and step interpolation between colors.
 *
 * ChartXY - LineSeries and PointSeries:
 * When this fillstyle is set, the Series will colorize the data-*Point*s based on X / Y value.
 *
 * Instances of PalettedFill are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 * @noInheritDoc
 */
export declare class PalettedFill extends PalettedFillStyleRecord implements FillStyle<PalettedFillProperties> {
    /**
     * Create a new fillstyle to fill the object with Colors based on value.
     * The color for the data-point would be selected from a specified *LUT*,
     * which contains the information about gradient steps.
     *
     * Create the paletted fillstyle with specified *LUT* lookup table.
     *
     * Example:
     * ```javascript
     * // create LUT from 0..100 with gradient steps.
     * const lut = new LUT( {
     *  steps: [
     *       { value: 0, color: ColorRGBA( 0, 0, 0 ) },
     *       { value: 30, color: ColorRGBA( 255, 255, 0 ) },
     *       { value: 45, color: ColorRGBA( 255, 204, 0 ) },
     *       { value: 60, color: ColorRGBA( 255, 128, 0 ) },
     *       { value: 100, color: ColorRGBA( 255, 0, 0 ) }
     *    ],
     *  interpolate: true
     *  } )
     *
     * // create fillstyle with attached lookup table
     * const palettedfill = new PalettedFill({ lut })
     * ```
     * @param   props   Optional object containing parameters for creation of fillstyle.
     */
    constructor(props?: Partial<PalettedFillProperties>);
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
    /**
     * Get LUT lookup table.
     * @return  LUT object.
     */
    getPalette(): LUT;
}
export {};
/**
 * The font-weight property specifies the weight (or boldness) of the font.
 * The font weights available to you will depend on the font-family you are using.
 * Some fonts are only available in normal and bold.
 */
export declare type FontWeight = 'normal' | 'bold' | 'bolder' | 'lighter' | 100 | 200 | 300 | 400 | 500 | 600 | 700 | 800 | 900;
/**
 * The font-style attribute specifies whether the text is to be rendered using a normal, italic or oblique face.
 */
export declare type FontStyle = 'normal' | 'italic' | 'oblique';
/**
 * Interface with values of FontSettings.
 */
export interface FontProperties {
    /**
     * The size, or height of the font.
     */
    size: number;
    /**
     * The list of typeface names / family names.
     */
    family: string;
    /**
     * The weight style, or thickness of the font characters.
     */
    weight: FontWeight;
    /**
     * The style of the font.
     */
    style: FontStyle;
    /**
     * Small caps or not.
     */
    variant: boolean;
}
/**
 * Constructor for a Record of FontProperties.
 * @hidden
 */
declare const FontSettingsRecord: Record.Factory<FontProperties>;
/**
 * Class for specifying a font.
 *
 * Instances of FontSettings are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 *
 * When creating a new FontSettings object from scratch, parameters can be passed like follows:
 * - new FontSettings({ size: 18, style: 'italic' })
 * @noInheritDoc
 */
export declare class FontSettings extends FontSettingsRecord {
    /**
     * When creating a new FontSettings object from scratch, parameters can be passed like follows:
     * - new FontSettings({ size: 18, style: 'italic' })
     * @param   props   Optional object containing parameters for creation of FontSettings
     */
    constructor(props?: Partial<FontProperties>);
    /**
     * Create new FontSettings object with different font size.
     * @param fontSize      The size, or height of the font.
     * @returns             New FontSettings object.
     */
    setSize(size: number): this;
    /**
     * Create new FontSettings object with different font family.
     * @param fontFamily    The list of typeface names / family names.
     * @returns             New FontSettings object.
     */
    setFamily(family: string): this;
    /**
     * Create new FontSettings object with different font weight.
     * @param weight    The weight style, or thickness of the font characters.
     *                  Options: "normal" | "bold" | "bolder" | "lighter" | 100 | 200 | 300 | 400 | 500 | 600 | 700 | 800 | 900
     * @returns         New FontSettings object.
     */
    setWeight(weight: FontWeight): this;
    /**
     * Create new FontSettings object with different font style.
     * @param style The style of the font. Options: "normal" | "italic" | "oblique"
     * @returns             New FontSettings object.
     */
    setStyle(style: FontStyle): this;
    /**
     * Create new FontSettings object with different font variant.
     * The font-variant property specifies whether or not a text should be displayed in a small-caps font.
     * @param smallCaps     true selects font-variant: "small-caps", otherwise "normal".
     * @returns             New FontSettings object.
     */
    setVariant(smallCaps: boolean): this;
    /**
     * Get size of font
     * @return          The size, or height of the font.
     */
    getSize(): number;
    /**
     * Get family of font
     * @return          The list of typeface names / family names.
     */
    getFamily(): string;
    /**
     * Get weight of font
     * @return          The weight style, or thickness of the font characters.
     */
    getWeight(): FontWeight;
    /**
     * Get style of font
     * @return          The style of the font.
     */
    getStyle(): FontStyle;
    /**
     * Get variant of font
     * @return          Small caps or not
     */
    getVariant(): boolean;
}
/**
 * Default FontSettings instance.
 * New FontSettings can be created by either modifying it or by constructing a new instance with 'FontSettings'-constructor.
 *
 * Users should be instructed to use constructor, not this!
 * @hidden
 */
export declare const _fontSettings: FontSettings;
export {};
/**
 * Interface representing a Color Stop.
 * Each ColorStop has a color and an offset.
 */
export interface ColorStop extends ColorValue {
    /**
     * Offset for the color stop
     */
    offset: number;
}
/**
 * Common functions for any gradient implementation.
 */
interface Gradient {
    /**
     * Set color stops for the gradient.
     * @param stops Color Stops
     */
    setColorStops(stops: ColorStop[]): void;
    /**
     * Get current color stops from the gradient.
     */
    getColorStops(): ColorStop[];
}
/**
 * Gradient Shapes
 */
export declare enum GradientShape {
    circle = "circle",
    ellipse = "ellipse"
}
/**
 * Gradient extents
 */
export declare enum GradientExtent {
    closestSide = "closest-side",
    closestCorner = "closest-corner",
    farthestSide = "farthest-side",
    farthestCorner = "farthest-corner"
}
/**
 * Interface for all properties of a RadialGradientFillStyle.
 */
export interface RadialGradientFillStyleProperties {
    /**
     * Gradient color stops
     */
    stops: ColorStop[];
    /**
     * Gradient center position.
     *
     * A element relative coordinate. 0 to 1 coordinate space.
     * `{ x: 0, y: 0 }` is bottom left.
     * `{ x: 1, y: 1 }` is top right.
     */
    position: Point;
    /**
     * The shape for the gradient
     */
    shape: GradientShape;
    /**
     * The extent for gradient.
     *
     * Defines where the gradient takes it's size.
     */
    extent: GradientExtent;
}
/**
 * Record contractor for RadialGradientFillStyleProperties.
 * @hidden
 */
declare const RadialGradientFillStyleRecord: Record.Factory<RadialGradientFillStyleProperties>;
/**
 * Radial Gradient fill style.
 *
 * Instances of RadialGradientFill are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 */
export declare class RadialGradientFill extends RadialGradientFillStyleRecord implements Gradient, FillStyle<RadialGradientFillStyleProperties> {
    constructor(props?: Partial<RadialGradientFillStyleProperties>);
    /**
     * Set color stops for the gradient.
     * @param stops Color Stops
     */
    setColorStops(stops: ColorStop[]): this;
    /**
     * Get current color stops from the gradient.
     */
    getColorStops(): ColorStop[];
    /**
     * Set the center position of the gradient.
     * @param position Local XY coordinate in x: [0-1], y: [0-1] range
     */
    setPosition(position: Point): this;
    /**
     * Get the center position of the gradient.
     */
    getPosition(): Point;
    /**
     * Set the shape of the gradient
     * @param shape Gradient Shape
     */
    setShape(shape: GradientShape): this;
    /**
     * Get the shape of the gradient
     */
    getShape(): GradientShape;
    /**
     * Set the extent of the gradient.
     * @param extent Gradient Extent
     */
    setExtent(extent: GradientExtent): this;
    /**
     * Get the extent of the gradient
     */
    getExtent(): GradientExtent;
    /**
     * @return Newly created default highlight style of this one, with lighter fill color
     */
    protected createDefaultHighlightStyle(): this;
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Interface for all properties of a LinearGradient.
 */
export interface LinearGradientFillStyleProperties {
    /**
     * Gradient Color stops
     */
    stops: ColorStop[];
    /**
     * Gradient angle in degrees
     */
    angle: number;
}
/**
 * Record contractor for LinearGradientFillStyleProperties.
 * @hidden
 */
declare const LinearGradientFillStyleRecord: Record.Factory<LinearGradientFillStyleProperties>;
/**
 * Linear Gradient fill style.
 *
 * Instances of LinearGradientFill are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 */
export declare class LinearGradientFill extends LinearGradientFillStyleRecord implements Gradient, FillStyle<LinearGradientFillStyleProperties> {
    constructor(props?: Partial<LinearGradientFillStyleProperties>);
    /**
     * Set color stops for the gradient.
     * @param stops Color Stops
     */
    setColorStops(stops: ColorStop[]): this;
    /**
     * Get current color stops from the gradient.
     */
    getColorStops(): ColorStop[];
    /**
     * Set the angle of the gradient line in degrees or radians.
     * @param angle Angle in degrees or radians. 0 degrees/radians is up. Clockwise rotation.
     * @param isRadians Pass `true` if the angle provided is in radians.
     */
    setAngle(angle: number, isRadians?: boolean): this;
    /**
     * Get the angle of the gradient line in degrees or radians.
     * @param isRadians Pass `true` if radians is wanted.
     */
    getAngle(isRadians?: boolean): number;
    /**
     * @return Newly created default highlight style of this one, with lighter fill color
     */
    protected createDefaultHighlightStyle(): this;
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
}
export {};
/**
 * Interface for all properties of a LineStyle.
 */
export interface LineStyleProperties<FillType extends FillStyle = FillStyle> {
    /**
     * Line fill style.
     */
    fillStyle: FillType;
    /**
     * Line thickness as an integer.
     *
     * Setting a non-integer number might result in rendering errors.
     *
     * Default value: 1.
     */
    thickness: number;
    /**
     * Value to multiply the default thickness with when the Line is highlighted.
     *
     * This will only effect the highlighted line if no other style has been set for the Line's Highlighted style.
     * Values less or equal to 0 can cause unexpected behavior.
     *
     * Default value: 2
     */
    highlightThicknessMultiplier: number;
}
/**
 * Base class for styling of 2D shapes' line area
 * @hidden  Internal class
 */
export declare abstract class LineStyle {
    /**
     * Get automatically computed highlight style.
     * @return  LineStyle object
     */
    getDefaultHighlightStyle(): this;
    /**
     * @return Newly created default highlight style of this one, with lighter fill color and bigger thickness
     */
    protected abstract createDefaultHighlightStyle(): this;
}
/**
 * Singleton object which specifies that line should not be rendered.
 *
 * When *emptyLine* is used, the line that would be rendered does **NOT** trigger mouse / touch -events, and
 * its rendering process is skipped, which results in saved performance.
 */
export declare const emptyLine: LineStyle;
/**
 * Abstract class that indicates some visible line.
 * Used only for instanceOf check at Engine
 * @hidden Internal class
 */
declare abstract class VisibleLine<FillType extends FillStyle = FillStyle> extends LineStyle {
    /**
     * Construct a new Visible line object based on this one, but with modified fill style.
     *
     * Example (SolidFill):
     * ```javascript
     * // specify new fillstyle
     * solidLineStyle.setFillStyle( new SolidFill({
     *  color: ColorHex('#F00')
     * }) )
     *
     * // change fillstyle properties
     * solidLineStyle.setFillStyle(
     *  solidfill => solidfill.setA( 80 )
     * )
     * ```
     * @param   value   Either a SolidFill object or a function, which will be used to create a new VisibleFill based on current value.
     * @return          New SolidLine object
     */
    setFillStyle(value: FillType | ImmutableMutator<FillType>): this;
    /**
     * Get fill style of SolidLine.
     * @return  SolidFill object
     */
    getFillStyle(): FillType;
    /**
     * Construct a new SolidLine object based on this one, but with modified thickness.
     *
     * @param   thickness   Thickness as pixels.
     */
    setThickness(thickness: number): this;
    /**
     * Get thickness of SolidLine
     * @return  Thickness as pixels
     */
    getThickness(): number;
    /**
     * Construct a new SolidLine object based on this one, but with modified highlight thickness multiplier.
     *
     * Only works when the highlighted style has not been set separately.
     * @param   value   Amount to multiply the line thickness with when highlighted.
     */
    setHighlightThicknessMultiplier(value: number): any;
    /**
     * Get highlighted line thickness multiplier.
     * @return Line thickness multiplier.
     */
    getHighlightThicknessMultiplier(): number;
}
/**
 * Class for specifying a solid line style.
 *
 * Instances of SolidLine are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 */
export declare class SolidLine<T extends FillStyle = SolidFill | LinearGradientFill | RadialGradientFill> extends VisibleLine<T> {
    /**
     * Create a new SolidLine to fill the line object with a single solid Color.
     *
     * Example:
     * ```javascript
     * // create linestyle with Solid fillstyle and thickness
     * const solidLineStyle = new SolidLine({
     *  fillStyle: new SolidFill({ color: ColorHEX('#F00') }),
     *  thickness: 5
     * })
     * ```
     * @param   props   Optional object containing parameters for creation of SolidLine
     */
    constructor(props?: Partial<LineStyleProperties<T>>);
    /**
     * @returns the default highlight style of this lineStyle
     */
    protected createDefaultHighlightStyle(): this;
}
export {};
/**
 * Interface to specify the color and its value.
 * Each represented as a pair object {value: number, color: Color}.
 */
export interface LUTStep extends ColorValue {
    /**
     * Value associated with a color.
     */
    value: number;
}
/**
 * Interface to a single subrange between two LUT steps.
 * This internal data-structure is used to optimize lookup.
 */
interface SubRange {
    /**
     * The lowest border of the range.
     */
    min: LUTStep;
    /**
     * The highest border of the range.
     */
    max: LUTStep;
}
/**
 * Interface to define secondary miscellaneous properties of a LUT.
 */
interface ValuePaletteOptions {
    /**
     * Title of the LUT, which describes the visualization.
     *
     * Default value: Empty string.
     */
    title: string;
    /**
     * Units of the data-values in the LUT, which describes the data domain.
     *
     * Default value: Empty string.
     */
    units: string;
    /**
     * Interpolation behavior of the LUT, which describes the distribution of color for the data:
     * - True: LUT creates a ***gradient*** LUT using linear-interpolation (LERP) between colors,
     * which were defined in the collection of steps.
     * - False: LUT creates a ***uniform*** LUT using step-function for each color
     * to describe the range of values where this color is used.
     *
     * Default value: true.
     */
    interpolate: boolean;
    /**
     * Fallback color, which is used if LUT steps are defined as empty or defined incorrectly.
     *
     * Default value: Black.
     */
    color: Color;
}
/**
 * Interface to store the collection of LUTSteps.
 */
interface LUTStepsOptions {
    /**
     * The collection of LUTSteps, which specifies the colors and their corresponding values
     * to describe the location and color of a transition point in a gradient.
     * Each represented as a pair object {value: number, color: Color}.
     *
     * Default value: [].
     */
    steps: LUTStep[];
}
/**
 * Interface to define a LUT options which were recomputed after each LUT update.
 */
interface LUTStateOptions {
    /**
     * Amount of LUT steps.
     */
    length: number;
    /**
     * Minimal value of the entire LUT.
     */
    min: number;
    /**
     * Maximal value of the entire LUT.
     */
    max: number;
    /**
     * Collection of subranges.
     */
    subranges: SubRange[];
    /**
     * Validation flag which describes that the LUT is configured correctly.
     */
    isValid: boolean;
}
/**
 * Record property object.
 */
declare type LUTRecordType = LUTStepsOptions & ValuePaletteOptions & LUTStateOptions;
/**
 * Record constructor for PaletteProperties.
 * @hidden
 */
declare const LUTRecord: Record.Factory<LUTRecordType>;
/**
 * Interface defines a *LUT* lookup table configurations.
 */
export declare type LUTOptions = LUTStepsOptions & Partial<ValuePaletteOptions>;
/**
 * Lookup Table class stores information about values and its associated colors.
 * It provides efficient lookup of the color based on provided value
 * as well as linear and step interpolation between colors.
 *
 * Instances of LUT are *immutable*, meaning that its setters don't modify the object,
 * but instead return a completely new modified object.
 *
 * PieChart, DonutChart, GaugeChart:
 * When this LUT is set, the Charts will colorize the *Slices* based on Value property of the slice.
 *
 * Can be used in *PalettedFill* style to colorize the data based on value.
 * @noInheritDoc
 */
export declare class LUT extends LUTRecord {
    /**
     * Create a new color-value lookup table using *LUTOptions*.
     *
     * Example:
     * ```javascript
     * // create LUT from 0..100 with gradient steps.
     * const lut = new LUT( {
     *  steps: [
     *       { value: 0, color: ColorRGBA( 0, 0, 0 ) },
     *       { value: 30, color: ColorRGBA( 255, 255, 0 ) },
     *       { value: 45, color: ColorRGBA( 255, 204, 0 ) },
     *       { value: 60, color: ColorRGBA( 255, 128, 0 ) },
     *       { value: 100, color: ColorRGBA( 255, 0, 0 ) }
     *    ],
     *  interpolate: true
     *  } )
     * ```
     * @param options Object containing parameters for creation of the LUT.
     */
    constructor(options: LUTOptions);
    /**
     * Set new collection of LUT steps.
     * @param steps Collection of color-value pairs.
     */
    setSteps(steps: LUTStep[]): this;
    /**
     * Get collection of LUT steps.
     * @returns Collection of steps.
     */
    getSteps(): LUTStep[];
    /**
     * Set title of the LUT, which describes the data.
     * @param title Title of the LUT.
     */
    setTitle(title: string): this;
    /**
     * Get title of the LUT.
     * @returns Title of the LUT as string.
     */
    getTitle(): string;
    /**
     * Set units of the data-values in the LUT, which describes the data domain.
     * @param units Units of the LUT.
     */
    setUnits(units: string): this;
    /**
     * Get units of the LUT.
     * @returns Units of the LUT as string.
     */
    getUnits(): string;
    /**
     * Set interpolation behavior of the LUT, which describes the distribution of color for the data:
     * - True: creates a ***gradient*** LUT using linear-interpolation (LERP) between colors,
     * which were defined in the collection of steps.
     * - False: creates a ***uniform*** LUT using step-function for each color
     * to describe the range of values where this color is used.
     * @param interpolate Interpolation behavior: True - gradient, False - uniform.
     */
    setInterpolation(interpolate: boolean): this;
    /**
     * Get interpolation behavior of the LUT.
     * @returns Intepolation behaviour state. True - gradient, False - uniform.
     */
    getInterpolation(): boolean;
    /**
     * Set fallback color.
     * The following color would be used as a backup.
     * Meaning, the LUT might be configured incorrectly or the data is incorrect.
     * @param color Color object.
     */
    setFallbackColor(color: Color): this;
    /**
     * Get fallback color of value the LUT.
     * @returns Color object.
     */
    getFallbackColor(): Color;
    /**
     * Get the color associated with the given value.
     *
     * Example:
     * ```javascript
     * const color = lut.getColors( 5 )
     * ```
     * @param values Single value.
     * @returns Associated color if the LUT is valid, otherwise fallback color.
     */
    getColors(values: number): Color;
    /**
     * Get the colors associated with the given collection of values.
     *
     * Example:
     * ```javascript
     * const colors = lut.getColors( [ 5, 10, 15 ] )
     * ```
     * @param values 1D collection of value.
     * @returns Collection of associated colors if the LUT is valid, otherwise fallback colors.
     */
    getColors(values: number[]): Color[];
    /**
     * Get the colors associated with the given collection Matrix2D of values.
     *
     * Example:
     * ```javascript
     * const colors = lut.getColors(
     *  [
     *    [ 3, 7, 9 ],
     *    [ 5, 10, 15 ]
     *  ]
     * )
     * ```
     * @param values 2D collection of values.
     * @returns Collection of associated colors if the LUT is valid, otherwise fallback colors.
     */
    getColors(values: number[][]): Color[][];
}
export {};
/**
 * Interface for all properties of a TriangulatedPoints3D.
 */
export interface TriangulatedPoints3DProperties {
    /**
     * Internally managed shape of points.
     *
     * Temporarily removed from public API because of related rendering issues.
     * @hidden
     */
    shape: 'cube' | 'sphere';
    /**
     * Size of the rendered points as *normalized World Units* (roughly equal to pixels).
     */
    size: number;
    /**
     * *FillStyle* for rendering the points.
     *
     * Currently only **SolidFill** is supported.
     */
    fillStyle: SolidFill;
}
/**
 * A style class used to specify style of 3D points rendering as triangulated shapes.
 *
 * Supports specifying shape as a **cube** or a **sphere**.
 */
export declare class TriangulatedPoints3D implements HighlightableType {
    /**
     * When creating a new TriangulatedPoints3D object, any amount of its default parameters can be *overriden*, by supplying the
     * values to its constructor:
     * ```javascript
     *  new PointStyle3D.Triangulated({
     *      size: 10,
     *      fillStyle: new SolidFill({ color: ColorHex('#FFF') }),
     *  })
     * ```
     * @param   props   Optional object containing any amount of parameters of TriangulatedPoints3D
     */
    constructor(props?: Partial<TriangulatedPoints3DProperties>);
    /**
     * Construct a new TriangulatedPoints3D object based on this one, but with different size.
     *
     * @param   size    Size of the rendered points as *normalized World Units* (roughly equal to pixels).
     * @return          New TriangulatedPoints3D object
     */
    setSize(size: number): this;
    /**
     * Get size of points rendered with this style object.
     * @return          Size of the rendered points as *normalized World Units* (roughly equal to pixels).
     */
    getSize(): number;
    /**
     * Construct a new TriangulatedPoints3D object based on this one, but with modified fill style.
     *
     * Example usage:
     *
     * | Desired result         | Argument                                      |
     * | :--------------------- | :-------------------------------------------- |
     * | Specified SolidFill    | new SolidFill({ color: ColorHex('#F00') })    |
     * | Changed transparency   | (solidFill) => solidFill.setA(80)             |
     *
     * @param   value   Either a SolidFill object or a function, which will be used to create a new SolidFill based on current value.
     * @return          New TriangulatedPoints3D object
     */
    setFillStyle(value: SolidFill | ImmutableMutator<SolidFill>): this;
    /**
     * Get fill style of TriangulatedPoints3D.
     * @return  SolidFill object
     */
    getFillStyle(): SolidFill;
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Interface for all properties of a PixelatedPoints3DProperties.
 */
export interface PixelatedPoints3DProperties {
    /**
     * Size of the rendered points in **pixels**.
     *
     * Some devices / browser configurations always render with 1 pixel, regardless of this setting.
     */
    size: number;
    /**
     * *FillStyle* for rendering the points.
     *
     * Currently only **SolidFill** is supported.
     */
    fillStyle: SolidFill;
}
/**
 * A style class used to specify style of 3D points rendering as pixelated squares.
 *
 * This rendering style is optimal for rendering large numbers of points that do not require great individual detail.
 */
export declare class PixelatedPoints3D implements HighlightableType {
    /**
     * When creating a new PixelatedPoints3D object, any amount of its default parameters can be *overriden*, by supplying the
     * values to its constructor:
     * ```javascript
     *  new PointStyle3D.Pixelated({
     *      size: 4,
     *      fillStyle: new SolidFill({ color: ColorHex('#FFF') }),
     *  })
     * ```
     * @param   props   Optional object containing any amount of parameters of PixelatedPoints3D
     */
    constructor(props?: Partial<PixelatedPoints3DProperties>);
    /**
     * Construct a new PixelatedPoints3D object based on this one, but with different size.
     *
     * @param   size    Size of the rendered points in **pixels**.
     * @return          New PixelatedPoints3D object
     */
    setSize(size: number): this;
    /**
     * Get size of points rendered with this style object.
     * @return          Size of the rendered points in **pixels**.
     */
    getSize(): number;
    /**
     * Construct a new PixelatedPoints3D object based on this one, but with modified fill style.
     *
     * Example usage:
     *
     * | Desired result         | Argument                                      |
     * | :--------------------- | :-------------------------------------------- |
     * | Specified SolidFill    | new SolidFill({ color: ColorHex('#F00') })    |
     * | Changed transparency   | (solidFill) => solidFill.setA(80)             |
     *
     * @param   value   Either a SolidFill object or a function, which will be used to create a new SolidFill based on current value.
     * @return          New PixelatedPoints3D object
     */
    setFillStyle(value: SolidFill | ImmutableMutator<SolidFill>): this;
    /**
     * Get fill style of PixelatedPoints3D.
     * @return  SolidFill object
     */
    getFillStyle(): SolidFill;
    /**
     * Get automatically computed highlight style.
     * @return  FillStyle object
     */
    getDefaultHighlightStyle(): this;
}
/**
 * Collection of constructors for specifying style of 3D points rendering.
 *
 * Used with:
 * - **PointSeries3D**
 * - **PointCloudSeries3D**
 */
export declare const PointStyle3D: {
    /**
     * A style class used to specify style of 3D points rendering as triangulated Cubes.
     */
    Triangulated: typeof TriangulatedPoints3D;
    /**
     * A style class used to specify style of 3D points rendering as pixelated squares.
     *
     * This rendering style is optimal for rendering large numbers of points that do not require great individual detail.
     */
    Pixelated: typeof PixelatedPoints3D;
};
export declare class GlLineCollection extends LineCollection<GlEngine> {
    /**
     * @param engine  Rendering engine
     * @param scale   Scale of the Shape's space
     * @param remove  Injected method to remove the shape from layer.
     * @param restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: GlEngine, scale: Vec2<Scale>, remove: RemoveHandler<GlLineCollection>, restore: RestoreHandler<GlLineCollection>);
}
/**
 * WebGL implementation of class for an immutable set of points
 * Internal class
 */
export declare class GlPointSetInstanced extends PointSet<GlEngine> {
    /**
     * @param engine  Rendering engine
     * @param scale   Scale of the Shape's space
     * @param remove  Injected method to remove the shape from layer.
     * @param restore Injected method to restore the removed shape to layer.
     */
    constructor(engine: GlEngine, scale: Vec2<Scale>, remove: RemoveHandler<GlPointSetInstanced>, restore: RestoreHandler<GlPointSetInstanced>);
}
/**
 * Generic Font, specifies settings of a text object
 * @param font          Web font in final a string format.
 * @param settings      Object with font settings [family, size, weight, style].
 */
export interface Font {
    readonly font: string;
    readonly height: number;
}
/**
 * Factory for Font Interface.
 * @param position          Position in 2D space
 * @param value             Generic value
 */
export declare const Font: (font: string, height: number) => {
    font: string;
    height: number;
};
/**
 * A factory for creating caching web-fonts settings for a further Text rendering.
 * @param   settings    FontSettings
 */
export declare const Fonts: (settings: FontSettings) => Font;
/**
 * The CanvasRenderingContext2D.textBaseline property of the Canvas 2D API specifies the current text baseline being used when drawing text.
 */
export declare type TextBase = 'top' | 'hanging' | 'middle' | 'alphabetic' | 'ideographic' | 'bottom';
/**
 * The CanvasRenderingContext2D.textAlign property of the Canvas 2D API specifies the current text alignment being used when drawing text.
 * Beware that the alignment is based on the x value of the fillText() method.
 */
export declare type TextAlign = 'left' | 'right' | 'center' | 'start' | 'end';
/**
 * @hidden Internal class
 */
export declare class TextTexture {
    private readonly _context2D;
    /**
     * The HTML5 canvas is for visual debugging only.
     */
    canvas: HTMLCanvasElement;
    /**
     * The 2D rendering context of the canvas.
     */
    context: CanvasRenderingContext2D;
    /**
     * Creates or uses a given CanvasRenderingContext for capturing the textures with a drawn text.
     * @param fontFamily    Font object with all the information about font.
     * @param _context2D     Canvas for texture generation. Set you own canvas if it is needed.
     */
    constructor(_context2D?: CanvasRenderingContext2D | null);
    /**
     * Draw a given text to texture with a given settings.
     * @param text          Specify a text to be rendered on a texture.
     * @param font          Specify a Web font for the text.
     * @param pixelRatio    Specify a pixel ratio to scale the texture with. Allows support for high DPI rendering.
     * @param margins       Specify the area between the main content and the edges.
     * @returns             ImageData object - [Array of pixels, width, height]
     */
    textureFromString(text: string, fontInfo: Font, pixelRatio: number, margins?: Margin): ImageData;
}
/**
 * A factory for creating and capturing textures with a Text for further rendering.
 * @param context2D         Canvas rendering context for Text Texture capturing.
 */
export declare const TextFactory: (context2D?: CanvasRenderingContext2D | null) => (text: string, font: Font, pixelRatio: number, margins?: Margin) => ImageData;
/**
 * A method for accurate measurement and caching of the specified text with a given font settings.
 * @param text              A string to be measured.
 * @param fontSettings      Font settings to be applied for the given text.
 */
export declare const MeasureText: (text: string, fontSettings: FontSettings) => Point;
/**
 * @hidden
 */
export declare type reduceCallback<S, V, T, U> = (result: S, val: V, key: T, collection: U) => S;
/**
 * @hidden
 */
export declare type orderedReduceCallback<S, V, T, U> = (result: S, left: V | undefined, cur: V, right: V | undefined, key: T, collection: U) => S;
/**
 * @hidden
 */
export declare class Node<T> {
    value: T;
    left: Node<T> | null;
    right: Node<T> | null;
    length: number;
    constructor(value?: T);
}
/**
 * @hidden
 */
export declare class Item<K, T> {
    key: K;
    value: T;
    constructor(key: K, value: T);
    equals(that: Item<K, T>): boolean;
    compare(that: Item<K, T>): number;
}
export declare class SortedMap<K, T> {
    contentEquals: (a: K | T, b: K | T) => boolean;
    contentCompare: (a: K | T, b: K | T) => number;
    store: SortedSet<Item<K, T>>;
    length: number;
    constructor(items?: Item<K, T> | Item<K, T>[], equals?: (a: K, b: K) => boolean, compare?: (a: K, b: K) => number);
}
/**
 * @hidden
 */
export declare class Item<K, T> {
    key: K;
    value: T;
    constructor(key: K, value: T);
    equals(that: Item<K, T>): boolean;
    compare(that: Item<K, T>): number;
}
export declare class SortedMultiMap<K, T> {
    contentEquals: (a: K | T, b: K | T) => boolean;
    contentCompare: (a: K | T, b: K | T) => number;
    store: SortedSet<Item<K, T[]>>;
    length: number;
    constructor(equals?: (a: K, b: K) => boolean, compare?: (a: K, b: K) => number);
}
/**
 * @hidden
 */
export declare class SortedSet<T> {
    root: Node<T> | null;
    length: number;
    contentCompare: (a: T, b: T) => number;
    contentEquals: (a: T, b: T) => boolean;
    constructor(values?: T | T[], equals?: (a: T, b: T) => boolean, compare?: (a: T, b: T) => number);
}
/**
 * @hidden
 * Default comparison generic<T> function. Compare 2 variables and returns
 * -1 (a < b) | 0 (a === b) | 1 ( a > b).
 * @param a
 * @param b
 * @returns {number}
 */
export declare function defaultCompareFunction<T>(a: T, b: T): number;
/**
 * @hidden
 * Default equation generic<T> function. Checks equality of 2 variables.
 * @param a
 * @param b
 * @returns {boolean}
 */
export declare function defaultEqualsFunction<T>(a: T, b: T): boolean;
/**
 * @hidden
 * Empty operation function.
 */
export declare function noop<T>(node?: T): undefined;
/**
 * @hidden
 */
export declare class _PresetCurve {
    curve: any;
    g: any;
    n: any;
    constructor(options: any);
}
declare const curves: {
    [key: string]: any;
};
export { curves };
export {};
/**
 * Interface for configuration object used in the indices generator.
 * @hidden
 */
export interface IndicesGeneratorOptions {
    /**
     * Position in the index buffer to write indices values.
     */
    position: number;
    /**
     * Target pre-allocated index buffer to store the generated indices into.
     */
    buffer: number[];
    /**
     * Prepare next indices for next call.
     */
    next?: boolean;
}
/**
 * A generic container for storing the information about indices used during triangulation.
 * Contains mutable public property numeric members for indices [1st - 6th] enough for triangulation.
 * Contains also methods to init proper numbers and increment them by +1 / +2.
 * @property first  Index for first vertex.
 * @property second Index for second vertex.
 * @property third  Index for third vertex.
 * @property fourth Index for fourth vertex.
 * @property fifth  Index for fifth vertex.
 * @property sixth  Index for sixth vertex.
 * @function initFromValue Initializes indices in correct order starting from a given value.
 * @function addOne Increments indices by +1.
 * @function addTwo Increments indices by +2.
 * @hidden
 */
interface Indices {
    /**
     * Index for first vertex.
     */
    first: number;
    /**
     * Index for second vertex.
     */
    second: number;
    /**
     * Index for third vertex.
     */
    third: number;
    /**
     * Index for fourth vertex.
     */
    fourth: number;
    /**
     * Index for fifth vertex.
     */
    fifth: number;
    /**
     * Index for sixth vertex.
     */
    sixth: number;
}
/**
 * Indices generator container for storing the information about indices used during triangulation.
 * This class contains the implementation of Indices interface.
 * @hidden
 */
export declare class IndicesGenerator implements Indices {
    first: number;
    second: number;
    third: number;
    fourth: number;
    fifth: number;
    sixth: number;
}
export {};
/**
 * Object type for intensity tiles.
 * @hidden
 */
export declare type Tiles = Array<Array<GridRangeOptions>>;
/**
 * Object with information about chopped intensity into Tiles.
 * @hidden
 */
export interface IntensityTiles {
    tiles: Tiles;
    tilesCount: Point;
}
export interface PreRenderingTile {
    range: GridRangeOptions;
    vbo: Point[];
    ibo: Uint16Array;
    boundary: Interval<Point>;
    intensities?: Float32Array;
    colors?: Float32Array;
}
export interface RenderingTile {
    /**
     * Vertices buffer.
     */
    vbo?: WebGLBuffer;
    /**
     * Indices buffer.
     */
    ibo?: WebGLBuffer;
    /**
     * Intensity buffer of floats.
     */
    intensities?: WebGLBuffer;
    /**
     * Color buffer of floats.
     */
    colors?: WebGLBuffer;
    /**
     * Vertices buffer length for indexed based rendering
     */
    length?: number;
}
export {};
export {};
export {};
/**
 * Base class for Mouse-interactable ui-objects.
 * @hidden Internal class
 */
export declare abstract class UIObject implements Interactable {
    /**
     * Subscribe to Mouse Enter event
     * @param   listener    Function that will be called when mouse enters the bounds of UiObject.
     * @param   obj         Always object itself.
     * @param   event       MouseEvent that triggered the listener.
     * @return              Token-object that is a reference ID to the listener created.
     */
    onMouseEnter(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Leave event
     * @param   listener    Function that will be called when mouse leaves the bounds of UiObject.
     * @param   obj         Always object itself.
     * @param   event       MouseEvent that triggered the listener.
     * @return              Token-object that is a reference ID to the listener created.
     */
    onMouseLeave(listener: AbruptMouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Click event
     * @param   listener    Function that will be called when mouse clicks the bounds of UiObject.
     * @param   obj         Always object itself.
     * @param   event       MouseEvent that triggered the listener.
     * @return              Token-object that is a reference ID to the listener created.
     */
    onMouseClick(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Double Click event
     */
    onMouseDoubleClick(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Down event
     */
    onMouseDown(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Up event
     */
    onMouseUp(listener: MouseEventHandler<this>): Token;
    /**
    * Subscribe to Mouse Move event
    * @param   listener    Event handler function
    * @returns             Token of subscription
    */
    onMouseMove(listener: MouseEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag Start event
     */
    onMouseDragStart(listener: MouseDragStartEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag event
     */
    onMouseDrag(listener: MouseDragEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Drag Stop event
     */
    onMouseDragStop(listener: MouseDragStopEventHandler<this>): Token;
    /**
     * Subscribe to Mouse Wheel event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onMouseWheel(listener: MouseWheelEventHandler<this>): Token;
    /**
     * Subscribe to Touch Start event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchStart(listener: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch Move event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchMove(listener: TouchEventHandler<this>): Token;
    /**
     * Subscribe to Touch End event
     * @param   listener    Event handler function
     * @returns             Token of subscription
     */
    onTouchEnd(listener: TouchEventHandler<this>): Token;
    /**
     * Remove event listener from Mouse Enter Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseEnter(token: Token): boolean;
    /**
     * Remove event listener from Mouse Leave Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseLeave(token: Token): boolean;
    /**
     * Remove event listener from Mouse Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseClick(token: Token): boolean;
    /**
     * Remove event listener from Mouse Double Click Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDoubleClick(token: Token): boolean;
    /**
     * Remove event listener from Mouse Down Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDown(token: Token): boolean;
    /**
     * Remove event listener from Mouse Up Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseUp(token: Token): boolean;
    /**
     * Remove event listener from Mouse Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseMove(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag Start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStart(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDrag(token: Token): boolean;
    /**
     * Remove event listener from Mouse Drag Stop Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseDragStop(token: Token): boolean;
    /**
     * Remove event listener from Mouse Wheel Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offMouseWheel(token: Token): boolean;
    /**
     * Remove event listener from Touch Start Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchStart(token: Token): boolean;
    /**
     * Remove event listener from Touch Move Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchMove(token: Token): boolean;
    /**
     * Remove event listener from Touch End Event
     * @param   token   Token of event listener which has to be removed
     * @return          True if the listener is successfully removed and false if it is not found
     */
    offTouchEnd(token: Token): boolean;
    /**
     * Set mouse interactions enabled.
     * Implementations should update the mouse-interactions of any Shapes they may contain here.
     * @param   state
     */
    abstract setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    abstract getMouseInteractions(): boolean;
    /**
     * Get boolean flag for whether object is currently under mouse or not
     * @return  Boolean for is object under mouse currently
     */
    getIsUnderMouse(): boolean;
}
/**
 * Public interface for a primitive UiElement that is not responsible for its own positioning.
 * This is the base-type when user is dealing with dynamically created ui-parts, for example when adding parts to layouts.
 * @hidden
 */
export interface UIPart extends Interactable, Marginable, Disposable {
    /**
     * Set mouse style when hovering over UI object.
     * @param   mouseStyle  Interface for defining how mouse should look when hovering over UI object
     * @return              Object itself
     */
    setMouseStyle(mouseStyle: UIMouseStyle): this;
    /**
     * Get mouse style.
     * @return              Interface for defining how mouse should look when hovering over UI object
     */
    getMouseStyle(): UIMouseStyle;
}
/**
 * Interface for a stand-alone *UIElement*.
 *
 * Adds ability for:
 * - Setting position
 * - Specifying draggability
 */
export interface UIElement extends UIObject, UIPart, Draggable, Plotable, Disposable {
    /**
     * Sets the position of this UiElement relative to its origin
     * @param position              Position
     */
    setPosition(position: Point): this;
    /**
     * Returns the position of this UiElement at given location relative to elements size.
     * @param relativePosition      Relative position vector (-1 to 1 which specifies position of origin, 0 is center of the object)
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the asked position. Defaults to Margin.
     * @return                      Object itself for fluent itself
     */
    getPosition(relativePosition?: Point, spaceOfInterest?: UISpace): Point;
    /**
     * Sets the position origin of this UiElement.
     * @param   origin  Relative position vector (-1 to 1, where 0 is center of the object).
     *                  UIOrigins, enum-like object can be used for easy selection of common values
     */
    setOrigin(origin: Point): this;
    /**
     * Returns the position origin of this UiElement.
     * @return  Relative position vector (-1 to 1, where 0 is center of the object).
     */
    getOrigin(): Point;
    /**
     * Returns the size of the UiElements in pixels including any Margins or Paddings
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the position. Defaults to Margin,
     *                              which includes everything. Should only ever be necessary for sub-classes
     * @return                      Object size in pixels
     */
    getSize(spaceOfInterest?: UISpace): Point;
}
/**
 * Type of constructor of UI elements.
 * @hidden
 */
export declare type UIElementConstructor<T extends UIPart> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>) => T & InternalUIElement;
/**
 * Base class for UI elements.
 * @hidden Internal class
 */
export declare abstract class InternalUIElement extends UIObject implements UIElement, Disposable {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    private readonly _remove;
    private readonly _restore;
    readonly theme: Theme;
    protected position: Point;
    protected origin: Point;
    protected size: Point;
    /**
     * @param _layer    Layer of drawing engine. Should be kept protected at all times
     * @param scale     Drawing scale of UiElement
     * @param _remove   Injected remove method from parent.
     * @param _restore  Injected restore method from parent.
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Returns the size of the UiElements in pixels including any Margins or Paddings
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the position. Defaults to Margin,
     *                              which includes everything. Should only ever be necessary for sub-classes
     * @return                      Object size in pixels
     */
    getSize(spaceOfInterest?: UISpace): Point;
    /**
     * Member function that updates the size of the UI elements contents.
     * UiElements should apply this inside 'update'
     * @param   sizeInPixels    Size of element in pixels
     */
    protected setContentSize(sizeInPixels: Point): void;
    /**
     * Utility method for getting the pixel-size of the UiElements scale.
     * NOTE: This will return the ABSOLUTE pixel size, meaning that the individual values are always positive, even with inverted axes.
     */
    getPixelSize: () => Point;
    /**
     * Returns the size of this UiElement on its rendering scale
     * Use to set the size of engine shapes
     */
    protected getSizeOnScale: (size?: Point) => Point;
    /**
     * Set margin around object in pixels.
     * @param   margin      Number with pixel margins for all sides or datastructure with individual pixel margins
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself
     */
    setMargin(margin: Partial<MMargin> | number): this;
    /**
     * Get margin around object in pixels.
     * @return  Margin datastructure
     */
    getMargin(): Margin;
    /**
     * Dispose object, ceasing its operation while keeping the object intact until call of 'restore'.
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Restore object if it was previously disposed.
     * @returns Object itself itself for fluent interface
     */
    restore(): this;
    /**
     * Return the current state of Disposable object.
     * @return True if object is disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Sets the position of this UiElement relative to its origin.
     *
     * NOTE: UIElements scale can't be changed apart from when it is created.
     * @param position  Location on the UIElements scale, where its origin should be positioned
     * @return          Object itself
     */
    setPosition(position: Point): this;
    /**
     * Returns the position of this UiElement at given location relative to elements size.
     * @param relativePosition      Relative position vector (-1 to 1 which specifies position of origin, 0 is center of the object)
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the asked position. Defaults to Margin,
     *                              which includes everything. Should only ever be necessary for other UiElements
     * @return                      Object itself for fluent itself
     */
    getPosition(relativePosition?: Point, spaceOfInterest?: UISpace): Point;
    /**
     * Sets the position origin of this UiElement. Affects how the "position" of UIElement is interpreted.
     *
     * See [[UIOrigins]] for a collection of common arguments in an easy-to-read format.
     * @param   Vec2 with each plane in range [-1, 1], where 0 is middle
     * @return  Object itself
     */
    setOrigin(origin: Point): this;
    /**
     * Get the position origin of this UiElement. Affects how the "position" of UIElement is interpreted.
     *
     * @return  Vec2 with each plane in range [-1, 1], where 0 is middle
     */
    getOrigin(): Point;
    /**
     * Set dragging mode of object. Defines how the object can be dragged by mouse.
     *
     * See [[UIDraggingModes]]collection for options.
     * @param       draggingMode    DraggingMode or undefined to disable dragging
     * @returns                     Object itself
     */
    setDraggingMode(draggingMode?: UIDraggingModes): this;
    /**
     * Get dragging mode of object.
     * Defines how the object can be dragged by mouse.
     * @returns                     Object itself
     */
    getDraggingMode(): UIDraggingModes;
    /**
     * Set mouse style when hovering over UI object.
     * @param   mouseStyle  Interface for defining how mouse should look when hovering over UI object
     * @return              Object itself
     */
    setMouseStyle(mouseStyle: UIMouseStyle): this;
    /**
     * Get mouse style.
     * @return              Interface for defining how mouse should look when hovering over UI object
     */
    getMouseStyle(): UIMouseStyle;
}
/**
 * Public interface for a UiElement that has background, but is not responsible for its own positioning.
 * @hidden
 */
export interface UIPartWithBackground<BackgroundType extends UIBackground> extends UIPart, StylableBackground<BackgroundType> {
}
/**
 * Public interface for a UiElement with background.
 * @hidden Internal class
 */
export declare abstract class UIElementWithBackground<BackgroundType extends UIBackground = UIBackground> extends InternalUIElement implements UIPartWithBackground<UIBackground> {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    private _BackgroundClass;
    /**
     * Background object.
     * Can't be changed at runtime
     */
    protected readonly backgroundElement: InternalBackground & BackgroundType;
    /**
     * @param   _layer               Rendering layer
     * @param   scale               Rendering scale
     * @param   _BackgroundClass          Constructor for Background of UiElementLine
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _BackgroundClass: BackgroundConstructor<InternalBackground & BackgroundType>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Method for mutating Background of object.
     *
     * Type of Background is generic, see [[UIBackground]] for minimum interface.
     * @param   mutator Mutator function for Background
     * @return          Object itself for fluent interface
     */
    setBackground(mutator: Mutator<BackgroundType>): this;
    /**
     * Get Background of object.
     *
     * Type of Background is generic, see [[UIBackground]] for minimum interface.
     * @returns     Background object
     */
    getBackground(): BackgroundType;
    /**
     * Dispose object, ceasing its operation while keeping the object intact until call of 'restore'.
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Restore object if it was previously disposed.
     * @returns Object itself itself for fluent interface
     */
    restore(): this;
    /**
     * @return True if all sub-elements are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Set padding around object in pixels.
     * Padding is empty space between the UiElements content and Background
     * @param   padding     Number with pixel margins for all sides or datastructure with individual pixel paddings
     *                      for each side. Any side can be omitted, only passed values will be overridden.
     * @return              Object itself
     */
    setPadding(padding: Partial<Margin> | number): this;
    /**
     * Get padding around object in pixels.
     * Padding is empty space between the UiElements content and Background
     * @return  Margin datastructure
     */
    getPadding(): Margin;
    /**
     * Returns the size of the UiElements in pixels including any Margins or Paddings
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the position. Defaults to Margin,
     *                              which includes everything. Should only ever be necessary for sub-classes
     * @return                      Object size in pixels
     */
    getSize(spaceOfInterest?: UISpace): Point;
    /**
     * Returns the position of this UiElement at given location relative to elements size.
     * @param relativePosition      Relative position vector (-1 to 1 which specifies position of origin, 0 is center of the object)
     * @param spaceOfInterest       Parameter to disregard parts of object when calculating the asked position.
     * @return                      Object itself for fluent itself
     */
    getPosition(relativePosition?: Point, spaceOfInterest?: UISpace): Point;
    /**
     * Set mouse interactions enabled or disabled
     * @para state Specifies state of mouse interactions
     * @return     Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * @return True for highlighted state of object and false for basic
     */
    getHighlighted(): boolean;
    /**
     * Set highlighted state of the Object.
     * Implementations should also remember to highlight themselves here.
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * Type definition for a dynamic mouse style setting.
 * This allows for mouse styles that depend on situation.
 * @param   uiElement   UIElement to apply
 * @return              Mouse style as string or undefined
 */
export declare type DynamicUIMouseStyle<T extends UIElement> = (uiElement: T) => string | undefined;
/**
 * Type definition for a mouse style setting. This tells how mouse should look when hovering over an UIElement.
 *
 * For a collection of mouse styles, see [[MouseStyles]].
 */
export declare type UIMouseStyle = string | DynamicUIMouseStyle<UIElement>;
/**
 * File contains interfaces for Backgrounds
 */
/**
 * Public interface of Background.
 * Type of UiElement that can be used as a Background of another element.
 */
export interface UIBackground {
    /**
     * Set FillStyle of Background.
     * @param value Fill style object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return      Current Background FillStyle
     */
    getFillStyle(): FillStyle;
    /**
     * Set stroke style of Background.
     * @param value LineStyle object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * @return      Current Background LineStyle
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set highlighted FillStyle of Background
     * @param highlightStyle    FillStyle for highlighted object or mutator to modify existing one or undefined for auto assignment
     * @returns                 Object itself for fluent interface
     */
    setFillStyleHighlight(setter: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return      Highlighted FillStyle of Background or undefined for auto assignment
     */
    getFillStyleHighlight(): FillStyle | undefined;
}
/**
 * Internal interface of Background.
 * Type of UiElement that can be used as a Background of another element.
 * The main requirement for a background is to be fitted to a rectangle of any size.
 * @hidden
 */
export interface InternalBackground extends UIElement, UIBackground, Highlightable {
}
/**
 * Type of Background constructor
 * @param   layer   Rendering layer
 * @param   scale   Rendering scale
 * @hidden
 */
export declare type BackgroundConstructor<T extends UIBackground = UIBackground> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme) => T;
/**
 * Background that can be pointed at a direction (left,right,up or down)
 */
export interface PointableBackground extends Pointable, UIBackground {
}
/**
 * Type of Pointable Background constructor
 * @param   layer   Rendering layer
 * @param   scale   Rendering scale
 * @hidden
 */
export declare type PointableBackgroundConstructor<T extends InternalBackground & PointableBackground = (InternalBackground & PointableBackground)> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme) => T;
/**
 * Type of function for styling a generic UIElement.
 */
export declare type UIElementStyler<T = UIElement> = (object: T, theme: Theme) => unknown;
/**
 * Interface for abstract UiElement builder
 */
export interface UIElementBuilder<UIElementType extends UIPart = UIPart> {
    /**
     * Make new Builder with an additional styler.
     * @param   styler  UiElementStyler for specific type
     * @returns         New Builder
     */
    addStyler(styler: UIElementStyler<UIElementType>): this;
}
/**
 * File contains enums and layout-classes for positioning uiElements relatively.
 * Also their builders.
 */
/**
 * Base class for positioning of UiElements in a line
 * @hidden Internal class
 */
export declare abstract class UIElementLine<BackgroundType extends UIBackground = UIBackground> extends UIElementWithBackground<BackgroundType> {
    /**
     * Returns list of UiElements inside Line
     */
    getMembers(): Array<UIPart>;
    /**
     * Get amount of members in group.
     * @return  Number
     */
    getMemberCount(): number;
    /**
     * Set minimum size Layout should occupy (in direction of layout).
     * If set, Layout will distribute any extra space to UiLayoutGaps among its members.
     * @param   minSize     Min size Layout should occupy (in direction of layout) or undefined to disable feature
     * @return              Object itself
     */
    setMinimumSize(minSize: pixel | undefined): this;
    /**
     * Get minimum size Layout should occupy (in direction of layout).
     * If set, Layout will distribute any extra space to UiLayoutGaps among its members.
     * @return              Min size Layout should occupy (in direction of layout) or undefined to disable feature
     */
    getMinimumSize(): pixel | undefined;
    /**
     * Add any UiElement using a builder
     * @param   builder Builder for any UiElement
     * @param   index   Index position or < 0 to push
     * @returns         Created UiElement
     */
    addElement<UiElementType extends UIPart>(builder: UIElementBuilder<UiElementType>, index?: number): UiElementType;
    /**
     * Add gap to line.
     * Gap can have fixed size and it also has custom logic which makes it occupy any extra space
     * caused by setting the minimum size for Line.
     * @param   fixedSize   Optional fixed size to set gap
     * @param   index       Index position or < 0 to push
     * @return              Object itself
     */
    abstract addGap(fixedSize?: pixel, index?: number): UILayoutGap;
    /**
     * Disposes objects inside the element.
     * UiElement will still be usable, but will not update itself nor render.
     * Disposed elements can be restored using 'restore()'
     * Implementations should use setEnabled on any other elements/Shapes they contain!
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Restore whatever resources this object has from rendering engine.
     * Implementations should use setEnabled on any other elements/Shapes they contain!
     * @returns Object itself itself for fluent interface
     */
    restore(): this;
    /**
     * @return True if all sub-elements have been disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Set mouse interactions enabled.
     * This will set the states of all members inside the Layout, overriding any previous settings.
     * @param state     Mouse interactions enabled
     */
    setMouseInteractions(state: boolean): this;
    /**
     * Get mouse interactions enabled.
     * @return  True if any member of Layout has mouse interactions enabled.
     */
    getMouseInteractions(): boolean;
    /**
     * Set highlighted state of the Lines Background and all of its members
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * UI Layout for positioning UIElements in a row.
 */
export declare class UIElementRow<BackgroundClass extends UIBackground = UIBackground> extends UIElementLine<BackgroundClass> {
    /**
     * Add gap to Row.
     * Gap can have fixed width and it also has custom logic which makes it occupy any extra space
     * caused by setting the minimum size for Line.
     * @param   fixedSize   Optional fixed size to set gap
     * @return              Object itself
     */
    addGap(fixedSize?: pixel, index?: number): UILayoutGap;
}
/**
 * UI Layout for positioning UIElements in a column.
 */
export declare class UIElementColumn<BackgroundClass extends UIBackground = UIBackground> extends UIElementLine<BackgroundClass> {
    /**
     * Add gap to Column.
     * Gap can have fixed height and it also has custom logic which makes it occupy any extra space
     * caused by setting the minimum size for Line.
     * @param   fixedSize   Optional fixed size to set gap
     * @return              Gap object
     */
    addGap(fixedSize?: pixel, index?: number): UILayoutGap;
}
/**
 * UiElement class that marks a 'gap' in line-layouts.
 * Positioning logic will make it so these gaps occupy all extra space.
 */
export declare class UILayoutGap extends EmptyUIElement {
    /**
     * Set size of gap.
     * @param   size    Size of gap as Vec2 of pixels
     * @return          Object itself
     */
    setSize(size: Point): this;
}
/**
 * Class which represents a grid of abstract UiElements.
 * Grid is formed from vertical lines, 'columns', that can have individual member anchoring.
 * @hidden  Internal class. HIDDEN FOR NOW, AS THE IMPLEMENTATION IS NOT TESTED OR USED (on public side)
 */
export declare class UIColumnGrid<BackgroundClass extends UIBackground = UIBackground> extends UIElementRow<BackgroundClass> {
    /**
     * Add new column to grid
     */
    addColumn(): UIElementColumn;
    /**
     * Get column at specified index
     * @param   index   Index to look for
     * @param   ensure? If true, grid adds the column and any missing ones if it doesn't exist
     * @return          UiElementColumn at given index
     */
    getColumn(index: number, ensure?: boolean): UIElementColumn;
}
/**
 * Class which represents a grid of abstract UiElements.
 * Grid is formed from horizontal lines, 'rows', that can have individual member anchoring.
 * @hidden  Internal class. HIDDEN FOR NOW, AS THE IMPLEMENTATION IS NOT TESTED OR USED (on public side)
 */
export declare class UIRowGrid<BackgroundClass extends UIBackground = UIBackground> extends UIElementColumn<BackgroundClass> {
    /**
     * Add new row to grid
     */
    addRow(): UIElementRow;
    /**
     * Get row at specified index
     * @param   index   Index to look for
     * @param   ensure? If true, grid adds the row and any missing ones if it doesn't exist
     * @return          UiElementRow at given index
     */
    getRow(index: number, ensure?: boolean): UIElementRow;
}
/**
 * Interface for builder of UiColumn layout
 */
export interface UIColumnBuilder<BackgroundType extends UIBackground = UIBackground> extends UIElementBuilder<UIElementColumn<BackgroundType>> {
    /**
     * Make new ColumnBuilder with different background
     */
    setBackground<NewBackgroundType extends BackgroundType>(newBackground: BackgroundConstructor<NewBackgroundType>): UIColumnBuilder<NewBackgroundType>;
}
/**
 * Interface for builder of UiRow layout
 */
export interface UIRowBuilder<BackgroundType extends UIBackground = UIBackground> extends UIElementBuilder<UIElementRow<BackgroundType>> {
    /**
     * Make new RowBuilder with different background
     */
    setBackground<NewBackgroundType extends BackgroundType>(newBackground: BackgroundConstructor<NewBackgroundType>): UIRowBuilder<NewBackgroundType>;
}
/**
 * File contains builders and interfaces for end-user backgrounds.
 */
/**
 * Collection of available [[UIBackgrounds]] Can be used to customize the *background* of an *UIElement*.
 *
 * *Background* must be specified when the *UIElement* is created by method of its *builder*.
 *
 * Example usage:
 *```javascript
 * // Create TextBox with specified Background
 * Chart.addUIElement(UIElementBuilders.TextBox.setBackground(UIBackgrounds.Circle))
 * ```
 */
export declare const UIBackgrounds: {
    /**
     * No background.
     */
    None: typeof UIEmptyBackground;
    /**
     * Rectangular background.
     */
    Rectangle: typeof UIRectangle;
    /**
     * Circular background.
     */
    Circle: typeof UICircle;
    /**
     * 45 degree rotated rectangle background.
     */
    Diamond: typeof UIDiamond;
    /**
     * Arrow-like background.
     *
     * The *Pointers* direction can be modified by, for example:
     *
     * *UIElement*.setBackground((pointer) => pointer.setDirection(**UIDirections.Up**))
     *
     * This will throw an *error* if used on an *UIElement* with any other *Background*!
     */
    Pointer: typeof UIPointer;
};
/**
 * File contains builders and interfaces for end-user button pictures.
 */
/**
 * Collection of available *UIButtonPicture*s. Can be used to customize the shape of buttons and checkboxes of *UIElements*.
 *
 * *ButtonPicture* must be specified when the *UIElement* is created by method of its *builder*.
 *
 * Example usage:
 *```javascript
 * // Create ButtonBox with specified ButtonPicture
 * Chart.addUIElement(UIElementBuilders.ButtonBox.setPictureOff(UIButtonPictures.Circle))
 * // Create LegendBox with specified ButtonPicture
 * Chart.addUIElement(UIElementBuilders.HorizontalLegendBox.setEntry(
 * UIElementBuilders.TextBox.setPictureOff(UIButtonPictures.Circle)))
 * ```
 */
export declare const UIButtonPictures: {
    /**
     * Rectangular picture.
     */
    Rectangle: typeof UIRectangle;
    /**
     * Circular picture.
     */
    Circle: typeof UICircle;
    /**
     * 45 degree rotated rectangle picture.
     */
    Diamond: typeof UIDiamond;
};
/**
 * File contains user reference for cursor and marker builders.
 */
/**
 * Collection of *StaticCursorBuilders*.
 *
 * *StaticCursorBuilder*s are used to modify structure of *Markers*, by passing one when the *Marker* is created.
 *
 * Each item is associated with a specific *Chart*-type, that it can only be used with.
 */
export declare const MarkerBuilders: {
    /**
     * *StaticCursorBuilder* for creation of *MarkerXY*.
     *
     * Used to modify structure of *MarkerXY* when it is created. There are two versions of *MarkerXY*:
     * - [[ChartMarkerXY]] created with [[ChartXY.addChartMarkerXY]]
     * - [[SeriesMarkerXY]] created with *SeriesXY*.*addMarker*
     */
    XY: StaticCursorXYBuilder<PointMarker, UIBackground, PointableBackground, PointableBackground>;
};
/**
 * Collection of *AutoCursorBuilders*.
 *
 * *AutoCursorBuilder*s are used to modify structure of *AutoCursor*s of *Chart*s, by passing one when the *Chart* is created.
 *
 * Each item is associated with a specific *Chart*-type, that it can only be used with.
 */
export declare const AutoCursorBuilders: {
    /**
     * *AutoCursorBuilder* for [[ChartXY]].
     *
     * Used to modify structure of *AutoCursor*, by passing one when creating a [[ChartXY]].
     */
    XY: AutoCursorXYBuilder<PointMarker, UIBackground, PointableBackground, PointableBackground>;
    /**
     * *AutoCursorBuilder* for [[SpiderChart]].
     *
     * Used to modify structure of *AutoCursor*, by passing one when creating a [[SpiderChart]].
     */
    Spider: AutoCursor2DBuilder<PointMarker, UIBackground>;
};
/**
 * File contains builders and interfaces for end-user uiElements.
 */
/**
 * Collection of available *UIElement* *builders*. To build *UIElements* you must pass one of these to method: **addUIElement()**.
 * This method can be accessed through *Charts*, [[Dashboard]], Etc.
 *
 * Example usage:
 *```javascript
 * // Create a TextBox on a ChartXY
 * ChartXY.addUIElement(UIElementBuilders.TextBox)
 * // Create a CheckBox on a Dashboard
 * Dashboard.addUIElement(UIElementBuilders.CheckBox)
 * ```
 */
export declare const UIElementBuilders: {
    /**
     * *UIElement* that displays text over a *Background*.
     *
     * By default, *Background* is empty. To show it you must specify it using method of the *builder*, **setBackground**
     *
     * Example usage:
     *```javascript
     * // Create a TextBox
     * Chart.addUIElement(UIElementBuilders.TextBox)
     * // Create a TextBox with specified Background
     * Chart.addUIElement(UIElementBuilders.TextBox.setBackground(UIBackgrounds.Circle))
     * ```
     */
    TextBox: UITextBoxBuilder<UIBackground>;
    /**
     * *UIElement* that displays a toggleable checkbox and text over a *Background*.
     *
     * By default, *Background* is empty. To show it you must specify it using method of the *builder*, **setBackground**
     *
     * Example usage:
     *```javascript
     * // Create a CheckBox
     * Chart.addUIElement(UIElementBuilders.CheckBox)
     * // Create a CheckBox with specified Background
     * Chart.addUIElement(UIElementBuilders.CheckBox.setBackground(UIBackgrounds.Circle))
     * // Create a CheckBox with specified ButtonPicture
     * Chart.addUIElement(UIElementBuilders.CheckBox.setPictureOff(UIButtonPictures.Diamond))
     * ```
     */
    CheckBox: UICheckBoxBuilder<UIBackground, UIButtonPicture, UIButtonPicture>;
    /**
     * *UIElement* that displays a button and text over a *Background*.
     *
     * By default, *Background* is empty. To show it you must specify it using method of the *builder*, **setBackground**
     *
     * Example usage:
        *```javascript
     * // Create a ButtonBox
     * Chart.addUIElement(UIElementBuilders.ButtonBox)
     * // Create a ButtonBox with specified Background
     * Chart.addUIElement(UIElementBuilders.ButtonBox.setBackground(UIBackgrounds.Circle))
     * // Create a ButtonBox with specified ButtonPicture
     * Chart.addUIElement(UIElementBuilders.ButtonBox.setPictureOff(UIButtonPictures.Diamond))
     * ```
     */
    ButtonBox: UICheckBoxBuilder<UIBackground, UIButtonPicture, UIButtonPicture>;
    /**
     * *UIElement* that displays text over a [[PointableBackground]]
     *
     * Direction can be changed with [[PointableTextBox.setDirection]]
     *
     * Example usage:
     *```javascript
     * // Create a PointableTextBox
     * Chart.addUIElement(UIElementBuilders.PointableTextBox)
     * // There is currently only one implementation of PointableBackground
     * ```
     */
    PointableTextBox: UIPointableTextBoxBuilder<PointableBackground>;
};
/**
 * Collection of available *LegendBox* *builders*. To build *LegendBox*es you must pass one of these to method: **addLegendBox()**.
 * This method can be accessed through *Charts*, *Dashboard*, Etc.
 *
 * Example usage:
 *```javascript
 * // Create a HorizontalLegendBox on a ChartXY
 * ChartXY.addLegendBox(LegendBoxBuilders.TextBox)
 * // Create a HorizontalLegendBox on a Dashboard
 * Dashboard.addLegendBox(LegendBoxBuilders.CheckBox)
 * ```
 */
export declare const LegendBoxBuilders: {
    /**
     * Horizontal implementation of *LegendBox*.
     *
     * Lays out each unique *group* after one another **horizontally**. Items inside each *group* are layed out vertically.
     *
     * Example usage:
     *```javascript
     * // Create a Horizontal LegendBox
     * Chart.addUIElement(UIElementBuilders.HorizontalLegendBox)
     * ```
     */
    HorizontalLegendBox: UILegendBoxBuilder<InternalBackground, UITextBox<UIBackground>, LegendBoxEntry>;
    /**
     * Vertical implementation of *LegendBox*.
     *
     * Lays out each unique *group* after one another **vertically**. Items inside each *group* are layed out horizontally.
     *
     * Example usage:
     *```javascript
     * // Create a Vertical LegendBox
     * Chart.addUIElement(UIElementBuilders.VerticalLegendBox)
     * ```
     */
    VerticalLegendBox: UILegendBoxBuilder<InternalBackground, UITextBox<UIBackground>, LegendBoxEntry>;
};
/**
 * File contains builders and interfaces for end-user layouts.
 */
/**
 * Collection of *UIElementBuilder*s for *Layout*s. These allow positioning multiple *UIElements* relative to each other.
 */
export declare const UILayoutBuilders: {
    /**
     * *UIElement* for column layout, added *UIElements* will be layed out after one another **vertically**. Has a *Background*.
     *
     * By default, *Background* is hidden (style = [[emptyFill]]). To show it you must give it a style with: **UIColumn.setFillStyle**
     *
     * Example usage:
     *```javascript
     * // Create a Column
     * Chart.addUIElement(UILayouts.Column)
     * // Create a Column with specified Background
     * Chart.addUIElement(UILayouts.Column.setBackground(UIBackgrounds.Circle))
     * ```
     */
    Column: UIColumnBuilder<UIBackground>;
    /**
     * *UIElement* for row layout, added *UIElements* will be layed out after one another **horizontally**. Has a *Background*.
     *
     * By default, *Background* is hidden (style = [[emptyFill]]). To show it you must give it a style with: **UIRow.setFillStyle**
     *
     * Example usage:
     *```javascript
     * // Create a Row
     * Chart.addUIElement(UILayouts.Row)
     * // Create a Row with specified Background
     * Chart.addUIElement(*UILayouts.Row.setBackground(UIBackgrounds.Circle))
     * ```
     */
    Row: UIRowBuilder<UIBackground>;
};
/**
 * File contains builders and interfaces for end-user cursor pointMarkers.
 */
/**
 * Collection of available *PointMarker* implementations.
 *
 * *PointMarker*s are interactable *UIElement*s that belong to *AutoCursor*s and *Marker*s, indicating their location.
 *
 * *PointMarker* can be specified when creating an *AutoCursor* or *Marker*, by method of their *builder*.
 *
 * Example usage:
 *```javascript
 * // Create SeriesMarkerXY with specified PointMarker
 * SeriesXY.addMarker(MarkerBuilders.XY.setPointMarker(PointMarkers.UICircle))
 * // Specify PointMarker of AutoCursor
 * LightningChart.ChartXY({ autoCursorBuilder: AutoCursorBuilders.XY.setPointMarker(PointMarkers.UIDiamond) })
 * ```
 */
export declare const PointMarkers: {
    /**
     * No pointMarker.
     */
    None: typeof EmptyPointMarker;
    /**
     * Rectangular pointMarker.
     */
    UIRectangle: typeof UIRectangle;
    /**
     * Circular pointMarker.
     */
    UICircle: typeof UICircle;
    /**
     * 45 degree rotated rectangle pointMarker.
     */
    UIDiamond: typeof UIDiamond;
};
/**
 * Type definition for a generic type that is reliant on date-offset.
 */
declare type NeedsDateOffset<T> = (dateOffset: number) => T;
/**
 * Interface for an internal data structure representing a displayable Date Time Unit.
 * @hidden
 */
export declare type DateTimeUnit = {
    /**
     * Identifier of date time unit.
     */
    readonly label: 'MilliSecond' | 'Second' | 'Minute' | 'Hour' | 'Day' | 'Week' | 'Month' | 'Year' | 'Decade' | 'Century' | 'Millennium';
    /**
     * Size of unit as milliseconds.
     *
     * For irregular DateTimeUnits this should be the minimal interval (eq. Month: 28 days).
     */
    readonly unit: number;
} & ({
    readonly irregular: false;
    /**
     *
     */
    readonly greatTicks: undefined | {
        /**
         * Function that is used to synchronize tick positioning when it is the greatest time unit present.
         * @param   ref     Reference date time.
         */
        readonly getReferenceKeyValue: NeedsDateOffset<(ref: number) => number>;
    };
    /**
     *
     */
    readonly majorTicks: {
        /**
         * Fitting function for **minor** ticks of this time unit.
         *
         * Defines logic of fitting minor ticks when all don't fit.
         */
        readonly fitFunction: KeyValuesFittingFunction | undefined;
    };
    /**
     * Minor ticks configuration for this time unit.
     *
     * If undefined, minor ticks will not be displayed.
     */
    readonly minorTicks: undefined | ({
        /**
         * Fitting function for **minor** ticks of this time unit.
         *
         * Defines logic of fitting minor ticks when all don't fit.
         */
        readonly fitFunction: KeyValuesFittingFunction | undefined;
        /**
         * Amount of **regular** minor ticks + 1.
         *
         * Eq. amount = 4 for second minor ticks results in:
         * 0:15, 0:30, 0:45
         */
        readonly amount: number;
    });
} | {
    readonly irregular: true;
    /**
     * Logic that finds previous key value from a reference key value for an irregular time unit.
     */
    readonly getPrevKeyValue: NeedsDateOffset<(ref: number) => number>;
    /**
     * Logic that finds next key value from a reference key value (including that ref value) for an irregular time unit.
     */
    readonly getNextKeyValueIncludingRef: NeedsDateOffset<(ref: number) => number>;
    /**
     * Logic that finds next key value from a reference key value for an irregular time unit.
     */
    readonly getNextKeyValue: NeedsDateOffset<(ref: number) => number>;
    /**
     *
     */
    readonly greatTicks: undefined | true;
    /**
     *
     */
    readonly majorTicks: {
        /**
         * Fitting function for **minor** ticks of this time unit.
         *
         * Defines logic of fitting minor ticks when all don't fit.
         */
        readonly fitFunction: KeyValuesFittingFunction | undefined;
    };
    /**
     * Minor ticks configuration for this time unit.
     *
     * If undefined, minor ticks will not be displayed.
     */
    readonly minorTicks: undefined | ({
        /**
         * Fitting function for **minor** ticks of this time unit.
         *
         * Defines logic of fitting minor ticks when all don't fit.
         */
        readonly fitFunction: KeyValuesFittingFunction | undefined;
    });
});
/**
 * List of date-time units in increasing order.
 * @hidden
 */
export declare const DateTimeUnits: DateTimeUnit[];
/**
 * Type union of supported methods of defining a formatting behavior for *DateTime TickStrategy*.
 *
 * **1. Intl.DateTimeFormatOptions:**
 *
 *  Use JavaScript API for formatting logic by supplying a *Intl.DateTimeFormatOptions* object. Example usage:
 *
 * ```javascript
 *  // 'January 2015'
 *  { year: 'numeric', month: 'long' }
 * ```
 *
 * For complete documentation of valid keys and values, refer to
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/DateTimeFormat
 *
 * **2. Custom formatting function:**
 *
 * Specify custom formatting logic by supplying a *function* that returns a *string*. Example usage:
 *
 * ```javascript
 *  ( value, range ) => {
 *      // 'value' = number position of tick along the *Axis*.
 *      // 'range' = *FormattingRange* object that can be used to find the total range of the *Axis*, if needed.
 *
 *      // Return *string*.
 *      return "any string"
 *  }
 *
 *  ( value ) => {
 *      // JS *Date* API can be used to interpret numeric *Axis* positions as *UTC Date/Time*, exposing a multitude of handy methods.
 *      const date = new Date( value )
 *      return date.toLocaleTimeString()
 *  }
 * ```
 *
 * JS *Date* documentation: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date
 */
export declare type DateTimeFormatter = Intl.DateTimeFormatOptions | FormattingFunction;
/**
 * Modifiable properties of a DateTime *TickStrategy*.
 *
 * Hidden because DateTimeTickStrategy intentionally has no constructor.
 * @hidden
 */
export interface DateTimeTickStrategyProperties {
    /**
     * Style of Great ticks.
     *
     * To disable great ticks, set to **emptyTick**.
     *
     * **NOTE: Label alignment is overridden, and has no effect on this property.**
     */
    readonly greatTickStyle: TickStyle;
    /**
     * Style of Major ticks.
     *
     * Major ticks can't be disabled (via emptyTicks), because TickLevel style doesn't support emptyTicks,
     * and Major tick level must exist for Minor tick positioning.
     */
    readonly majorTickStyle: VisibleTicks;
    /**
     * Style of Minor ticks.
     *
     * To disable minor ticks, set to **emptyTick**.
     */
    readonly minorTickStyle: TickStyle;
    /**
     * Valid javascript Date locale string, that specifies a geographical, political or cultural region.
     *
     * *undefined* passes the decision making to the browser.
     *
     * For example values, refer to https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/DateTimeFormat
     */
    readonly locale: string | undefined;
    /**
     * Optional "origin date" value.
     *
     * By default data-points are interpreted as *UTC dates* (milliseconds since January 1st 1970 GMT+0).
     * If a **dateOrigin** is defined, data-points will instead be interpreted as milliseconds since **dateOrigin**.
     */
    readonly dateOrigin: Date | undefined;
    /**
     * Formatter options for **major** ticks that are placed on relevant **century** intervals.
     */
    readonly formatOptionsMajorCentury: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **decade** intervals.
     */
    readonly formatOptionsMinorDecade: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **decade** intervals.
     */
    readonly formatOptionsMajorDecade: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **year** intervals.
     */
    readonly formatOptionsMinorYear: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **year** intervals.
     */
    readonly formatOptionsMajorYear: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **month** intervals.
     */
    readonly formatOptionsMinorMonth: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **year** intervals.
     */
    readonly formatOptionsGreatYear: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **month** intervals.
     */
    readonly formatOptionsMajorMonth: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **week** intervals.
     */
    readonly formatOptionsMinorWeek: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **month** intervals.
     */
    readonly formatOptionsGreatMonth: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **week** intervals.
     */
    readonly formatOptionsMajorWeek: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **day** intervals.
     */
    readonly formatOptionsMinorDay: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **week** intervals.
     */
    readonly formatOptionsGreatWeek: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **day** intervals.
     */
    readonly formatOptionsMajorDay: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **hour** intervals.
     */
    readonly formatOptionsMinorHour: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **day** intervals.
     */
    readonly formatOptionsGreatDay: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **hour** intervals.
     */
    readonly formatOptionsMajorHour: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **minute** intervals.
     */
    readonly formatOptionsMinorMinute: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **hour** intervals.
     */
    readonly formatOptionsGreatHour: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **minute** intervals.
     */
    readonly formatOptionsMajorMinute: DateTimeFormatter;
    /**
     * Formatter options for **minor** ticks that are placed on relevant **second** intervals.
     */
    readonly formatOptionsMinorSecond: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **minute** intervals.
     */
    readonly formatOptionsGreatMinute: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **second** intervals.
     */
    readonly formatOptionsMajorSecond: DateTimeFormatter;
    /**
     * Formatter options for **great** ticks that are placed on relevant **second** intervals.
     */
    readonly formatOptionsGreatSecond: DateTimeFormatter;
    /**
     * Formatter options for **major** ticks that are placed on relevant **millisecond** intervals.
     */
    readonly formatOptionsMajorMilliSecond: DateTimeFormatter;
}
/**
 * Default implementation of a *DateTime* *Axis* *TickStrategy*.
 *
 * Formats values as *Date*s according to JavaScript API:
 * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Date
 *
 * Places ticks at relevant Date/Time intervals.
 *
 * Customized *DateTime TickStrategies* can be created with setters of *DateTimeTickStrategy*, such as
 * setMajorTickStyle, setMinorTickStyle, setFormattingMonth, etc.
 */
export declare class DateTimeTickStrategy implements MutableAxisTickStrategy {
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified great tick style.
     *
     * *Great ticks* display the largest Date/Time information for the active time range.
     * There is always exactly one *great tick* in view.
     *
     * Example usage:
     *
     * **Disable great ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setGreatTickStyle( emptyTick )
     *  )
     * ```
     *
     * **Set font of great ticks**:
     * ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setGreatTickStyle(( tickStyle: VisibleTicks ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *TickStyle* object or a function, which creates a new one based on the existing style.
     * @return                      New *DateTimeTickStrategy* object.
     */
    setGreatTickStyle(value: TickStyle | ImmutableMutator<TickStyle>): this;
    /**
     * Get great tick style of this *DateTimeTickStrategy* object.
     *
     * *Great ticks* display the largest Date/Time information for the active time range.
     * There is always exactly one *great tick* in view.
     * @return                      Great tick style.
     */
    getGreatTickStyle(): TickStyle;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified major tick style.
     *
     * *Major ticks* display the next smaller Date/Time information after *Great ticks*.
     * Often times, they represent the most 
     *
     * Example usage:
     *
     * **Set font of major ticks**:
     * ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setMajorTickStyle(( tickStyle ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *VisibleTicks* object or a function, which creates a new one based on the existing style.
     * @return                      New *DateTimeTickStrategy* object.
     */
    setMajorTickStyle(value: VisibleTicks | ImmutableMutator<VisibleTicks>): this;
    /**
     * Get major tick style of this *DateTimeTickStrategy* object.
     *
     * *Major ticks* display the next smaller Date/Time information after *Great ticks*.
     * Often times, they represent the most 
     * @return                      Major tick style.
     */
    getMajorTickStyle(): TickStyle;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified minor tick style.
     *
     * *Minor ticks* display the next smaller Date/Time information after *Major ticks*.
     *
     * Example usage:
     *
     * **Disable minor ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setMinorTickStyle( emptyTick )
     *  )
     * ```
     *
     * **Set font of minor ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setMinorTickStyle(( tickStyle ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *TickStyle* object or a function, which creates a new one based on the existing style.
     *                              Passing a function only works if the existing style is **not** *emptyTick*.
     * @return                      New *DateTimeTickStrategy* object.
     */
    setMinorTickStyle(value: TickStyle | ImmutableMutator<VisibleTicks>): this;
    /**
     * Get minor tick style of this *DateTimeTickStrategy* object.
     *
     * *Minor ticks* display the next smaller Date/Time information after *Major ticks*.
     * @return                      Minor tick style.
     */
    getMinorTickStyle(): TickStyle;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified locale.
     *
     * The *locale* specifies a geographical, political or cultural region, affecting all formatting of *Tick labels*.
     *
     * All valid values can be found from https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/DateTimeFormat
     *
     * Example usage:
     *
     * **Use locale of browser**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setLocale( undefined )
     *  )
     * ```
     *
     * **Use specific locale**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setLocale('en-US')
     *  )
     *  ```
     * @param   locale              Valid JavaScript Date locale string, that specifies a geographical, political or cultural region.
     *                              All valid values can be found from
     *                              https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/DateTimeFormat
     * @return                      New *DateTimeTickStrategy* object.
     */
    setLocale(locale: string | undefined): this;
    /**
    * Get locale of this *DateTimeTickStrategy* object.
    *
    * The *locale* specifies a geographical, political or cultural region, affecting all formatting of *Tick labels*.
    * @return                      JavaScript Date locale string, that specifies a geographical, political or cultural region.
    */
    getLocale(): string | undefined;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified dateOrigin.
     *
     * By default data-points are interpreted as *UTC dates* (milliseconds since January 1st 1970 GMT+0).
     * If a **dateOrigin** is defined, data-points will instead be interpreted as milliseconds since **dateOrigin**.
     *
     * Specifying a *dateOrigin* can be necessary in applications where there is a long range of date-time data,
     * and high resolution zooming is desired.
     *
     * Example usage:
     *
     * **Application with one day of high-density data starting in year 2020**:
     *  ```javascript
     *  // Without specifying a dateOrigin, zooming will be limited to minutes with this range.
     *  // Milliseconds resolution can be reached by setting the dateOrigin to a Date
     *  // that is closer to the actual data (instead of the default 1.1.1970).
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setDateOrigin( new Date( 2020, 0, 1 ) )
     *  )
     * ```
     *
     * Check our DateTime Axis Interactive Example for a more thorough example on DateTime TickStrategy usage:
     * https://www.arction.com/lightningchart-js-interactive-examples/examples/lcjs-example-0020-dateTimeAxis.html
     *
     * @param   dateOrigin          A *JavaScript Date* object or *undefined*.
     * @return                      New *DateTimeTickStrategy* object.
     */
    setDateOrigin(dateOrigin: Date | undefined): this;
    /**
     * Get the *dateOrigin* of this *DateTimeTickStrategy* object.
     *
     * By default data-points are interpreted as *UTC dates* (milliseconds since January 1st 1970 GMT+0).
     * If a **dateOrigin** is defined, data-points will instead be interpreted as milliseconds since **dateOrigin**.
     * @return                      A *JavaScript Date* object or *undefined*.
     */
    getDateOrigin(): Date | undefined;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Major: Decades**
     * - **Minor: Years**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingDecade(
     *              { year: 'numeric' },
     *              { year: 'numeric' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     *
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingDecade(majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Major: Years**
     * - **Minor: Months**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingYear(
     *              { year: 'numeric' },
     *              { month: 'short' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingYear(majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Years**
     * - **Major: Months**
     * - **Minor: Weeks**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingMonth(
     *              { year: 'numeric' },
     *              { month: 'long' },
     *              { day: '2-digit' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingMonth(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Months**
     * - **Major: Weeks**
     * - **Minor: Days**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingWeek(
     *              { year: 'numeric', month: 'long' },
     *              { day: '2-digit' },
     *              { day: '2-digit' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingWeek(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Weeks**
     * - **Major: Days**
     * - **Minor: Hours**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingDay(
     *              { year: 'numeric', month: 'long' },
     *              { day: '2-digit' },
     *              { hour: '2-digit', minute: '2-digit' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingDay(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Days**
     * - **Major: Hours**
     * - **Minor: Minutes**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
        *          .setFormattingHour(
        *              { year: 'numeric', month: 'long', day: '2-digit' },
        *              { hour: '2-digit', minute: '2-digit' },
        *              { hour: '2-digit', minute: '2-digit' }
        *          )
        *  )
        *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingHour(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Hours**
     * - **Major: Minutes**
     * - **Minor: Seconds**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingMinute(
     *              { year: 'numeric', month: 'long', day: '2-digit' },
     *              { hour: '2-digit', minute: '2-digit' },
     *              { hour: '2-digit', minute: '2-digit', second: '2-digit' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @param   minorTickFormattingOptions  Formatting options for *minor ticks*.
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingMinute(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter, minorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Minutes**
     * - **Major: Seconds**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingSecond(
     *              { year: 'numeric', month: 'long', day: '2-digit', hour: '2-digit', minute: '2-digit' },
     *              { hour: '2-digit', minute: '2-digit', second: '2-digit' }
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingSecond(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter): this;
    /**
     * Construct a new *DateTimeTickStrategy* object based on this one, but with modified formatting options
     * for DateTime ranges where ticks are positioned as follows:
     *
     * - **Great: Seconds**
     * - **Major: Every tenth MilliSecond**
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setFormattingMilliSecond(
     *              { year: 'numeric', month: 'long', day: '2-digit', hour: '2-digit', minute: '2-digit', second: '2-digit' },
     *              ( value ) => new Date( value ).getUTCMilliseconds()
     *          )
     *  )
     *  ```
     *
     * The used formatting options are dynamically chosen depending on the range of *Axis*, so depending
     * on the application this formatting customization method might not have a visible effect.
     *
     * For more detailed example usage, refer to [[DateTimeFormatter]].
     * @param   greatTickFormattingOptions  Formatting options for *great ticks*.
     * @param   majorTickFormattingOptions  Formatting options for *major ticks*
     * @return                              New *DateTimeTickStrategy* object.
     */
    setFormattingMilliSecond(greatTickFormattingOptions: DateTimeFormatter, majorTickFormattingOptions: DateTimeFormatter): this;
}
export {};
/**
 * Modifiable properties of a Numeric *TickStrategy*.
 *
 * Hidden because NumericTickStrategy intentionally has no constructor.
 * @hidden
 */
export interface NumericTickStrategyProperties {
    /**
     * Style of Extreme ticks (start & end of Axis).
     *
     * To disable extreme ticks, set to **emptyTick**.
     */
    readonly extremeTickStyle: TickStyle;
    /**
     * Style of Major ticks.
     *
     * Major ticks can't be disabled (via emptyTicks), because TickLevel style doesn't support emptyTicks,
     * and Major tick level must exist for minor tick positioning.
     */
    readonly majorTickStyle: VisibleTicks;
    /**
     * Style of Minor ticks.
     *
     * To disable minor ticks, set to **emptyTick**.
     */
    readonly minorTickStyle: TickStyle;
    /**
     * Formatting function used for ticks.
     *
     * Use FormattingFunctions to select available ones.
     */
    formattingFunction: FormattingFunction;
}
/**
 * Default implementation of a *Numeric* *Axis* *TickStrategy*.
 */
export declare class NumericTickStrategy implements MutableAxisTickStrategy {
    /**
     * Construct a new *NumericTickStrategy* object based on this one, but with modified extreme tick style.
     *
     * Example usage:
     *
     * **Disable extreme ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setExtremeTickStyle( emptyTick )
     *  )
     * ```
     *
     * **Set font of extreme ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setExtremeTickStyle(( tickStyle: VisibleTicks ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *TickStyle* object or a function, which creates a new one based on the existing style.
     *                              Passing a function only works if the existing style is **not** *emptyTick*.
     * @return                      New *NumericTickStrategy* object.
     */
    setExtremeTickStyle(value: TickStyle | ImmutableMutator<VisibleTicks>): this;
    /**
     * Get extreme tick style of this *NumericTickStrategy* object.
     * @return                      Extreme tick style.
     */
    getExtremeTickStyle(): TickStyle;
    /**
     * Construct a new *NumericTickStrategy* object based on this one, but with modified major tick style.
     *
     * Example usage:
     *
     * **Set font of major ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setMajorTickStyle(( tickStyle ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *VisibleTicks* object or a function, which creates a new one based on the existing style.
     * @return                      New *NumericTickStrategy* object.
     */
    setMajorTickStyle(value: VisibleTicks | ImmutableMutator<VisibleTicks>): this;
    /**
     * Get major tick style of this *NumericTickStrategy* object.
     * @return                      Major tick style.
     */
    getMajorTickStyle(): VisibleTicks;
    /**
     * Construct a new *NumericTickStrategy* object based on this one, but with modified minor tick style.
     *
     * Example usage:
     *
     * **Disable minor ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setMinorTickStyle( emptyTick )
     *  )
     * ```
     *
     * **Set font of minor ticks**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setMinorTickStyle(( tickStyle: VisibleTicks ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     * @param   value               Either a *TickStyle* object or a function, which creates a new one based on the existing style.
     *                              Passing a function only works if the existing style is **not** *emptyTick*.
     * @return                      New *NumericTickStrategy* object.
     */
    setMinorTickStyle(value: TickStyle | ImmutableMutator<TickStyle>): this;
    /**
     * Get minor tick style of this *NumericTickStrategy* object.
     * @return                      Minor tick style.
     */
    getMinorTickStyle(): TickStyle;
    /**
     * Get formatting function of this *NumericTickStrategy* object.
     * @return          Formatting Function.
     */
    getFormattingFunction(): FormattingFunction;
    /**
     * Set formatting function of this *NumericTickStrategy object.
     * @param formattingFunction    Formatting function to use with this *NumericTickStrategy* object.
     * @return                      New *NumericTickStrategy* object.
     */
    setFormattingFunction(formattingFunction: FormattingFunction): this;
}
/**
 * Type map of valid parameter combinations for Axis.setTickStrategy().
 * @hidden
 */
export declare type TickStrategyParameters = {
    type: 'Empty';
} | {
    type: 'Numeric';
    styler: ImmutableMutator<NumericTickStrategy>;
} | {
    type: 'DateTime';
    styler: ImmutableMutator<DateTimeTickStrategy>;
};
/**
 * @hidden
 */
export declare type TickStrategyType = TickStrategyParameters['type'];
/**
 * @hidden
 */
export declare type TickStrategyStyler<A, T> = A extends {
    type: T;
    styler: any;
} ? A['styler'] : never;
/**
 * Collection of available *AxisTickStrategies*.
 *
 * *AxisTickStrategies* modify logic of drawing *Axis Ticks* and formatting to better suit different user applications.
 * For example, a *DateTime Axis* is created by selecting *AxisTickStrategies.DateTime*.
 */
export declare const AxisTickStrategies: {
    /**
     * Disables all automatic creation of Axis ticks.
     *
     * *CustomTicks* can still be created manually.
     *
     * Example usage:
     *
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.Empty )
     *  ```
     */
    Empty: "Empty";
    /**
     * Default Axis *TickStrategy*. Creates ticks at relevant intervals of powers of 10 and its fractions.
     *
     * Has optional "extreme ticks", which always display the start and end values of the *Axis*.
     *
     * Has separate styles for each tick level: *major*, *minor* and *extreme*.
     *
     * Example usage:
     *
     * **Default style**:
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.Numeric )
     *  ```
     *
     * **Customized style**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.Numeric,
     *      ( tickStrategy: NumericTickStrategy ) => tickStrategy
     *          .setMinorTickStyle(( tickStyle ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     */
    Numeric: "Numeric";
    /**
     * *DateTime* Axis *TickStrategy*. Creates ticks at relevant Dates and Times.
     *
     * Has separate styles for each tick level: *great*, *major* and *minor*. Each tick level is placed along
     * a different DateTime unit (eq. second, day, month, year), which is dynamically selected from the active *Axis* range.
     *
     * Example usage:
     *
     * **Default style**:
     *  ```javascript
     *  Axis.setTickStrategy( AxisTickStrategies.DateTime )
     *  ```
     *
     * **Customized style**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setMinorTickStyle(( tickStyle ) => tickStyle
     *              .setLabelFont(( font ) => font
     *                  .setWeight( 'bold' )
     *              )
     *          )
     *  )
     *  ```
     *
     * **Formatting based on a specific locale**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          .setLocale( 'fi )
     *  )
     *  ```
     *
     * **Specifying an offset between Axis-values and Dates**:
     *  ```javascript
     *  Axis.setTickStrategy(
     *      AxisTickStrategies.DateTime,
     *      ( tickStrategy: DateTimeTickStrategy ) => tickStrategy
     *          // This will format a data-point with value 0 as current Date and Time.
     *          .setDateOrigin( new Date( ) )
     *  )
     *  ```
     */
    DateTime: "DateTime";
};
/**
 * Interface for *AxisTickStrategy*.
 *
 * Defines the positioning and formatting logic of *Axis* ticks.
 *
 * TODO: This is intended to be published to users, but not quite yet.
 * @hidden
 */
export interface AxisTickStrategy {
}
/**
 * @hidden
 */
export declare type IndependentTickLevels = IndependentAxisTickLevel[];
/**
 * @hidden
 */
export declare type LayeredTickLevels = (PhysicalLayeredAxisTickLevel | DirectiveLayeredAxisTickLevel)[];
/**
 * Shared interface all *TickLevels*.
 * @hidden
 */
interface AxisTickLevel {
}
/**
 * Shared interface for *TickLevels* that can be styled.
 * @hidden
 */
interface StylableAxisTickLevel {
}
/**
 * Type of *AxisTickLevel* that is not related to any other *AxisTickLevel*.
 *
 * It's ticks can't be obstructed, and are always visible. They also do not collide with other ticks.
 * @hidden
 */
export interface IndependentAxisTickLevel extends AxisTickLevel, StylableAxisTickLevel {
}
/**
 * Type of *AxisTickLevel* that works inside a layered hierarchy of multiple *LayeredAxisTickLevels*.
 *
 * Each consequent *LayeredAxisTickLevel* is positioned using the key values of the upper *LayeredAxisTickLevel*.
 * @hidden
 */
export interface LayeredAxisTickLevel extends AxisTickLevel {
}
/**
 * Type of *LayeredAxisTickLevel* that has physical ticks.
 *
 * Can be configured with *automatic fitting* functionalities.
 * @hidden
 */
export interface PhysicalLayeredAxisTickLevel extends LayeredAxisTickLevel, StylableAxisTickLevel {
}
/**
 * Type of *LayeredAxisTickLevel* that doesn't have any physical ticks.
 *
 * This is only used for positioning ticks in *PhysicalLayeredAxisTickLevels* below itself.
 * @hidden
 */
export interface DirectiveLayeredAxisTickLevel extends LayeredAxisTickLevel {
}
/**
 * Function that finds tick positions.
 * @param   axisMin     Min coordinate of whole Axis.
 * @param   axisMax     Max coordinate of whole Axis.
 * @param   axisStart   Start coordinate of whole Axis (either min or max, depending if Axis is inverted or not).
 * @param   axisEnd     End coordinate of whole Axis (either min or max, depending if Axis is inverted or not).
 * @return              List of axis key values.
 *                      Ticks will be positioned on these positions.
 * @hidden
 */
export declare type IndependentKeyValuesGenerator = (axisMin: number, axisMax: number, axisStart: number, axisEnd: number) => number[];
/**
 * Function that finds tick positions for an interval of layered ticks.
 * @param   min         Min location for tick creation.
 * @param   max         Max location for tick creation.
 * @param   axisMin     Min coordinate of whole Axis.
 * @param   axisMax     Max coordinate of whole Axis.
 * @return              List of axis key values.
 *                      Ticks will be positioned on these positions (minus ticks that are removed because of collisions).
 * @hidden
 */
export declare type LayeredKeyValuesGenerator = (min: number, max: number, axisMin: number, axisMax: number) => number[];
/**
 * Type of AxisTick fitting function.
 *
 * @param   nonFittingKeyValues Key values (from _getKeyValues) that resulted in collisions.
 * @param   attempt             The amount of attempts that fitting has been attempted, starting with 0.
 * @param   min                 Min location for tick creation.
 * @param   max                 Max location for tick creation.
 * @param   axisMin             Min coordinate of whole Axis.
 * @param   axisMax             Max coordinate of whole Axis.
 * @return                      New key values that will be attempted again and checked for collisions.
 *                              If these also don't fit, _fitKeyValues will be called again.
 *                              Returning *undefined* will stop the process, resulting in no displayed ticks.
 * @hidden
 */
export declare type KeyValuesFittingFunction = (nonFittingKeyValues: number[], attempt: number, min: number, max: number, axisMin: number, axisMax: number) => number[] | undefined;
/**
 * Singleton object which indicates that Axis ticks shouldn't be created.
 *
 * The type information is not necessary for users, so it is hidden. Users refer to it with string constants ('Empty').
 * @hidden
 */
export declare const EmptyAxisTickStrategy: AxisTickStrategy;
/**
 * Internal interface for default implementations of Axis TickStrategies.
 *
 * Default implementations are immutable settings objects that users can modify with convenient setters.
 * This interface defines a method that is internally used to convert the settings object into an actual TickStrategy.
 * @hidden
 */
export interface MutableAxisTickStrategy {
}
export {};
/**
 * File contains the logic for an abstract Funnel Chart.
 * The rendering logic of a "Funnel" is abstract and defined in a sub-class of this.
 */
/**
 * Type of a FunnelChart constructor.
 * @hidden
 */
export declare type FunnelChartConstructor<T extends FunnelChart> = new (layerSupplier: LayerSupplier, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: AbstractEventInterface, panelMargin?: number) => T;
/**
 * Abstract base class for *Funnel Charts*.
 * Visualizes proportions and percentages between categories, by dividing a funnel into proportional segments.
 *
 * Set data using *FunnelChart*.**addSlice( name: string, value: number )**
 *
 * There are multiple implementations of *FunnelChart*, each with their own visual design and *API* for customizing it.
 * List of selectable options can be found in: [[FunnelChartTypes]]
 */
export declare abstract class FunnelChart extends Chart implements SlicedCharts<FunnelSlice> {
    /**
     * This method is used for the adding slices in the funnel chart.
     * @param title Funnel slice title
     * @param value  funnel slice value
     */
    addSlice(title: string, value: number): FunnelSlice;
    /**
     * This method is used for the adding multiple slices in the funnel chart.
     * @param slices Array of slices
     */
    addSlices(slices: {
        name: string;
        value: number;
    }[]): Array<FunnelSlice>;
    /**
     * Get all Slices of Funnel Chart.
     * NOTE: Manual modifications to returned Array can have unforeseen side-effects.
     * Removing or adding Slices is intended to be done using other APIs (FunnelChart.addSlice, Slice.dispose, ...)
     * @return  Array of Slices
     */
    getSlices(): FunnelSlice[];
    /**
     * Set Funnel Head Width
     * @param  headWidth   Funnel Head Width range from 0 to 100
     * @return             Funnel Chart itself
     */
    setHeadWidth(headWidth: number): this;
    /**
     * Get Funnel Head Width
     * @return  number (0 - 100)
     */
    getHeadWidth(): number;
    /**
     * Set Funnel Neck Width
     * @param neckWidth Funnel Neck Width range from 0 to 100
     * @return          Funnel Chart itself
     */
    setNeckWidth(neckWidth: number): this;
    /**
     * Get Funnel Neck Width
     * @return  number (0 - 100)
     */
    getNeckWidth(): number;
    /**
     * Set gap between Slice / start of label connector, and end of label connector / Label.
     * @param   sliceGap   Gap as pixels. Clamped between [0, 20] !
     * @return             Funnel Chart itself
     */
    setSliceGap(sliceGap: pixel): this;
    /**
     * Set FunnelSliceMode. Can be used to select between different drawing approaches for Slices.
     *
     * See [[FunnelSliceModes]] for a collection of options.
     * @param   sliceMode   FunnelSliceMode
     * @return              Funnel Chart itself
     */
    setSliceMode(sliceMode: FunnelSliceModes): this;
    /**
     * Get FunnelSliceMode. Can be used to select between different drawing approaches for Slices.
     *
     * See [[FunnelSliceModes]] for a collection of options.
     * @return  FunnelSliceMode
     */
    getFunnelSliceMode(): FunnelSliceModes;
    /**
     * Attach lookup table (LUT) to fill the slices with Colors based on value.
     *
     * The color for the slice would be selected from a specified *LUT*, which contains the information about gradient steps.
     * After setting LUT to undefined all the slices stay colorized, but no further lookup.
     *
     * LUT class stores information about values and its associated colors,
     * * which provides efficient lookup of the color based on provided value
     * * as well as linear and step interpolation between colors.
     *
     * ``` javascript
     * const funnel = lightningChart()
     *  .Funnel( { type: FunnelChartTypes.LabelsOnSides } )
     *  .setLUT( new LUT (steps: [
     *          { value: 10, color: ColorRGBA( 0, 0, 0 ) },
     *          { value: 20, color: ColorRGBA( 30, 255, 0 ) },
     *          { value: 30, color: ColorRGBA( 60, 204, 0 ) },
     *          { value: 40, color: ColorRGBA( 90, 128, 0 ) },
     *          { value: 50, color: ColorRGBA( 255, 0, 0 ) } ) ],
     *      interpolate: true } )
     * ```
     *
     * @param lut   Lookup table
     * @returns     Pie itself for fluent interface
     */
    setLUT(value: LUT): this;
    /**
     * Set style of Funnel Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Funnel will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Funnel Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @param   sliceFillStylePalette   Palette for FillStyle objects
     * @return                          Funnel Chart itself
     */
    setSliceFillStyle(sliceFillStylePalette: Palette<FillStyle>): this;
    /**
     * Get style of Funnel Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Funnel will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Funnel Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @return  Palette<FillStyle>
     */
    getSliceFillStyle(): Palette<FillStyle>;
    /**
     * Set style of Funnel Slices Stroke.
     * @param   value   LineStyle object or function which creates a new style based on previous
     * @return          Funnel Chart itself
     */
    setSliceStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Funnel Slices Stroke.
     * @return  LineStyle object
     */
    getSliceStrokeStyle(): LineStyle;
    /**
     * Set sorter of Funnels' Slices as a comparator-function.
     *
     * For some commonly needed default implementations, can refer to SliceSorters-collection.
     * @param   sliceSorter SliceSorter - function which sorts Slices of Funnel with JavaScript API: Array.sort.
     * @return              Funnel Chart itself
     */
    setSliceSorter(sliceSorter: SliceSorter<FunnelSlice>): this;
    /**
     * Get sorter of Funnels' Slices as a comparator-function.
     * @return  SliceSorter - function which sorts Slices of Funnel with JavaScript API: Array.sort.
     */
    getSliceSorter(): SliceSorter<FunnelSlice>;
    /**
     * Set fill style of Funnel Slices Labels.
     * @param   value   FillStyle object or function which creates a new style based on previous
     * @return          Funnel Chart itself
     */
    setLabelFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Funnel Slice Labels.
     * @return  FillStyle object
     */
    getLabelFillStyle(): FillStyle;
    /**
     * Set font of Slice Labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Funnel Chart itself
     */
    setLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Slice Labels.
     * @return  FontSettings
     */
    getLabelFont(): FontSettings;
    /**
     * Set formatter of Slice Labels.
     *
     * See [[SliceLabelFormatters]] for a collection of default options.
     * @param   labelFormatter  SliceLabelFormatter - function which generates text of Labels per Slice.
     * @return                  Funnel Chart itself
     */
    setLabelFormatter(labelFormatter: SliceLabelFormatter<FunnelSlice>): this;
    /**
     * Get formatter of Slice Labels.
     * @return  SliceLabelFormatter - function which generates text of Labels per Slice.
     */
    getLabelFormatter(): SliceLabelFormatter<FunnelSlice>;
    /**
     * Sets if animations are enabled or not.
     * @param   animationsEnabled   Boolean state for animations enabled
     * @return                      Funnel Chart itself
     */
    setAnimationsEnabled(animationsEnabled: boolean): this;
    /**
     * Gets if animations are enabled or not.
     * @return  Boolean state for animations enabled
     */
    getAnimationsEnabled(): boolean;
    /**
     * Disable all animations for the chart.
     *
     * All animations have to be re-enabled individually if you wish to re-enable animations.
     * @return  Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Set if slices should be highlighted on mouse hover / touch. Applies to all Slices.
     * @param state True if Slices should be highlighted on hover, false if not. This applies to all existing Slices and new Slices added.
     */
    setSliceHighlightOnHover(state: boolean): this;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...Funnel()
     * let slice = chart.addSlice({name: 'name', value: 50})
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * slice = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Enum for selecting different drawing approaches for [[FunnelChart]].
 *
 * Use with [[FunnelChart.setSliceMode]]
 */
export declare enum FunnelSliceModes {
    /**
     * Slices **height** represents its relative value inside the Funnel Chart.
     */
    VariableHeight = 0,
    /**
     * Slices **width** represents its relative value inside the Funnel Chart.
     */
    VariableWidth = 1
}
/**
 * File contains different implementations of Funnel Charts, each with their own rendering logic.
 */
/**
 * [[FunnelChart]] implementation that draws Slice Labels on its left and right sides.
 * Slices and Labels are connected by 'label connector lines'.
 */
export declare class FunnelChartWithLabelsOnSides extends FunnelChart {
    /**
     * Set style of Label connector lines.
     * @param   labelConnectorStyle LineStyle object
     * @return                      Funnel Chart itself
     */
    setLabelConnectorStyle(labelConnectorStyle: LineStyle): this;
    /**
     * Get style of Label connector lines.
     * @return  LineStyle object
     */
    getLabelConnectorStyle(): LineStyle;
    /**
     * Set gap between Slice / start of label connector, and end of label connector / Label.
     * @param   labelConnectorGap   Gap as pixels
     * @return                      Funnel Chart itself
     */
    setLabelConnectorGap(labelConnectorGap: pixel): this;
    /**
     * Get gap between Slice / start of label connector, and end of label connector / Label.
     * @return  Gap as pixels
     */
    getLabelConnectorGap(): number;
    /**
     * Set the side where label should display
     * @param   labelSide   Left /Right
     * @return              Funnel Chart itself
     */
    setLabelSide(labelSide: FunnelLabelSide): this;
    /**
     * Get the side where label shown
     * @return The label side
     */
    getLabelSide(): FunnelLabelSide;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Point minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
}
/**
 * [[FunnelChart]] implementation that draws Slice Labels inside the Slices.
 * Works well when Label texts are short and there are not a lot of Slices, as the actual Funnel has more space.
 */
export declare class FunnelChartWithLabelsInsideSlices extends FunnelChart {
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return      Point
     */
    getMinimumSize(): Point | undefined;
}
/**
 * Interface that can be used to define [[FunnelChart]] configurations that can't be changed after creation.
 *
 * Example usage:
 *```javascript
 * // Funnel Chart with default type
 * undefined
 * // Funnel Chart with specified type
 * { type: FunnelChartTypes.LabelsOnSides }
 * ```
 */
export interface FunnelChartOptions<FunnelChartType extends FunnelChartTypes> extends CommonChartOptions {
    /**
     * Interface for specifying desired "type" of Funnel Chart.
     * This can be used to select different rendering approaches, mainly reflecting how Slice Labels are positioned.
     *
     * Options are located in [[FunnelChartTypes]]-collection. If undefined, will default to [[FunnelChartWithLabelsOnSides]].
     */
    type?: FunnelChartType;
}
/**
 * Available Funnel Chart types
 * @hidden
 */
export declare type FunnelChartTypes = typeof FunnelChartTypes[keyof typeof FunnelChartTypes];
/**
 * Collection of [[FunnelChart]] implementations. Each option can have their own visual design, and *API* for customization of it.
 *
 * This must be specified when the *FunnelChart* is created (or default one will be used).
 *
 * Example usage:
 *```javascript
 * // Create a FunnelChart with default type
 * LightningChart.Funnel()
 * // Create a FunnelChart with specified type
 * LightningChart.Funnel({ type: FunnelChartTypes.LabelsInsideSlices })
 * ```
 */
export declare const FunnelChartTypes: {
    /**
     * Funnel Chart type, where Slice Labels are positioned on the either left or right sides of Chart.
     * The side can be set using setLabelSide
     * Labels are connected to their Slices with lines, which can be styled using unique API for this Funnel Chart type.
     */
    LabelsOnSides: typeof FunnelChartWithLabelsOnSides;
    /**
     * Funnel Chart type, where Slice Labels inside the Slices.
     */
    LabelsInsideSlices: typeof FunnelChartWithLabelsInsideSlices;
};
/**
 * Options for selecting side of labels in a [[FunnelChartWithLabelsOnSides]].
 *
 * Use with [[FunnelChartWithLabelsOnSides.setLabelSide]]
 */
export declare enum FunnelLabelSide {
    /**
     * Label Side  - Right
     */
    Right = 0,
    /**
     * Label Side  - Left
     */
    Left = 1
}
/**
 * Possible Shape types for parts of a Slice.
 */
declare type FunnelSliceVisual = Polygon | Text;
/**
 * Class that represents a single Slice of a Funnel Chart.
 * It is given to users when a Slice is added.
 */
export declare abstract class FunnelSlice extends Slice<FunnelSliceVisual> {
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    abstract setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    abstract getValue(): number;
}
/**
 * Internal class that hides some internal interfaces of a Slice that are only needed for interactions with the owning Funnel Chart.
 * @hidden
 */
export declare class InternalFunnelSlice extends FunnelSlice {
    protected _chart: FunnelChart;
    readonly scale: Vec2<Scale>;
    protected _removeFromChart: RemoveHandler<ChartComponent>;
    protected _restoreFromChart: RestoreHandler<ChartComponent>;
    /**
     * Index of Slice inside its owning Chart.
     * It tells how many Slices were created before this one.
     * It is not updated for disposed Slices, and so cannot be used for counting the amount of existing Slices.
     */
    readonly index: number;
    /**
     * @param   index               Index of Slice
     * @param    polygonLayer       Rendering layer for Polygon
     * @param    labelLayer         Rendering layer for Label
     * @param    _chart             Owning chart
     * @param    scale              Rendering scale
     * @param   _removeFromChart    Remove handler for Slice
     * @param    _restoreFromChart  Restore handler for Slice
     * @hidden
     */
    constructor(index: number, polygonLayer: LayerXY, labelLayer: LayerXY, _chart: FunnelChart, scale: Vec2<Scale>, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>);
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    getValue(): number;
    /**
     * Tell the owning chart to remove this component.
     * @return  Slice itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Slice itself.
     */
    restore(): this;
    /**
     * Method that owning Funnel Chart uses to assign style of a Slice it owns.
     * @param   polygonFillStyle    FillStyle for Polygon
     * @param   polygonStrokeStyle  LineStyle for Polygon
     * @param   labelFillStyle  FillStyle for Label
     * @param   labelFont       FontSettings for Label
     */
    setStyle(polygonFillStyle: FillStyle, polygonStrokeStyle: LineStyle, labelFillStyle: FillStyle, labelFont: FontSettings): void;
    /**
     * Get animated value of Slice.
     * When value of Slice is changed, the animated value will not update immediately, but after an animation.
     * (if animations are not disabled).
     * @return  Animated value
     */
    getAnimatedValue(): number;
    /**
     * Attach series to an annotation.
     * @param entry Object which has to be attached
     * @return      Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Enable or disable forced highlighting of series
     * @param highLight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * Method styles an attached entry according to Slice itself.
     */
    protected styleAttachedEntry(entry: LegendBoxEntry): void;
}
export {};
/**
 * Interval object defines the minimum and maximum slice interval.
 */
export interface SliceInterval {
    min: number;
    max: number;
}
/**
 * Abstract base class for *Gauge Charts*.
 * Gauge charts indicate where your data point(s) falls over a particular range.
 * This chart type is often used in executive dashboard reports to show key business indicators.
 *
 * There are multiple implementations of *GaugeChart*, each with their own visual design and *API* for customizing it.
 * List of selectable options can be found in: [[GaugeChartTypes]]
 */
export declare abstract class GaugeChart<PublicSlice extends GaugeSlice = GaugeSlice, InternalSlice extends GaugeSlice = any> extends Chart {
    /**
     * @param   layerSupplier           LayerSupplier. Must NOT be cached, because it contains reference to actual Engine instance.
     * @param   logoFactory             Logo factory.
     * @param   removeChart             Injectable Panel/Chart remove method.
     * @param   ScaleX                  Injectable Scale constructor
     * @param   ScaleY                  Injectable Scale constructor
     * @param   resizeEventInterface    Injectable event interface for resizing Panel (used for dashboard)
     * @param   theme                   Theme used to style elements in the Chart.
     * @param   _disableAnimations      Disable animations by default
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, theme?: Theme, _disableAnimations?: boolean);
    /**
     * Sets if animations are enabled or not.
     * @param   animationsEnabled   Boolean state for animations enabled
     * @returns                     Gauge itself for fluent interface.
     */
    setAnimationsEnabled(animationsEnabled: boolean): this;
    /**
     * Gets if animations are enabled or not.
     * @return  Boolean state for animations enabled
     */
    getAnimationsEnabled(): boolean;
    /**
     * Disable all animations for the chart.
     *
     * All animations have to be re-enabled individually if you wish to re-enable animations.
     * @return  Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...Gauge()
     * let slice = chart.getDefaultSlice()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * slice = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Type of a GaugeChart constructor.
 * @hidden
 */
export declare type GaugeChartConstructor<T extends GaugeChart> = new (layerSupplier: LayerSupplier, logoFactory?: LogoFactory, removeChart?: (chart: Panel) => void, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: AbstractEventInterface, theme?: Theme, _disableAnimations?: boolean) => T;
/**
 * Interface that can be used to define [[GaugeChart]] configurations that can't be changed after creation.
 *
 * Example usage:
 * ```javascript
 * // Gauge Chart with default type
 * undefined
 * // Gauge Chart with specified type
 * { type: GaugeChartTypes.Solid }
 * ```
 */
export interface GaugeChartOptions<GaugeChartType extends GaugeChartTypes> extends CommonChartOptions {
    /**
     * Interface for specifying desired "type" of Gauge Chart.
     * This can be used to select different gauge types.
     *
     * Options are located in [[GaugeChartTypes]] collection. If undefined, will default to Solid.
     */
    type?: GaugeChartType;
}
/**
 * Available Gauge Chart types.
 */
export declare type GaugeChartTypes = typeof GaugeChartTypes[keyof typeof GaugeChartTypes];
/**
 * Collection of [[GaugeChart]] implementations. Each option can have their own visual design, and *API* for customization of it.
 *
 * This must be specified when the [[GaugeChart]] is created (or default one will be used).
 *
 * Example usage:
 *```javascript
 * // Create a GaugeChart with specified type
 * LightningChart.Gauge({ type: GaugeChartTypes.Solid })
 * ```
 */
export declare const GaugeChartTypes: {
    /**
     * Solid Gauge Chart type, which contains a single slice represents a value within the interval.
     */
    Solid: typeof SolidGauge;
};
/**
 * Value change event listener.
 * @param slice     Slice
 * @param previous  Previous slice value
 * @param next      Next slice value
 */
export declare type ValueChangeEventListener<S extends GaugeSlice> = (slice: S, previous: number, next: number) => void;
/**
 * Interval change event listener.
 * @param slice     Slice
 * @param previous  Previous slice interval
 * @param next      Next slice interval
 */
export declare type IntervalChangeEventListener<S extends GaugeSlice> = (slice: S, previous: SliceInterval, next: SliceInterval) => void;
/**
 * Abstract class of Gauge slice.
 * The slice can be represented as a single or multiples shapes.
 */
export declare abstract class GaugeSlice<GaugeSliceVisual extends ChartVisual = ChartVisual> extends Slice<GaugeSliceVisual> {
    /**
     * Set scale interval.
     * @param  start                Start scale value
     * @param  end                  End scale value
     * @returns Slice for fluent interface
     */
    abstract setInterval(start: number, end: number): this;
    /**
     * Set font of interval labels.
     *
     * Example usage:
     *```javascript
     * // Specified FontSettings
     * GaugeSlice.setIntervalLabelsFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Set to bold
     * GaugeSlice.setIntervalLabelsFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     *
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Chart itself
     */
    abstract setIntervalLabelsFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of gauge interval labels.
     * @returns         FontSettings object for gauge interval labels.
     */
    abstract getIntervalLabelsFont(): FontSettings;
    /**
     * Set interval labels visibility enabled or disabled.
     * @param state True - labels are enabled, otherwise - disabled.
     * @returns     Slice itself for fluent interface.
     */
    abstract setIntervalLabelsVisible(state: boolean): this;
    /**
     * Get interval labels visibility state.
     * @returns True - labels are enabled, otherwise - disabled.
     */
    abstract getIntervalLabelsVisible(): boolean;
    /**
     * Remove subscription from value change event
     * @param token Event listener
     * @returns True if the listener is successfully removed and false if it is not found
     */
    offValueChange(token: Token): boolean;
    /**
     * Remove subscription from interval change event
     * @param token Event listener
     * @returns True if the listener is successfully removed and false if it is not found
     */
    offIntervalChange(token: Token): boolean;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Enable or disable forced highlighting of series
     * @param highLight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * Method styles an attached entry according to Slice itself.
     */
    protected styleAttachedEntry(entry: LegendBoxEntry): void;
}
/**
 * File contains the logic for an abstract Pie Chart.
 * The rendering logic of a "Pie" is abstract and defined in a sub-class of this.
 */
/**
 * Type of a PieChart constructor.
 * @hidden
 */
export declare type PieChartConstructor<T extends PieChart> = new (layerSupplier: LayerSupplier, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: AbstractEventInterface, panelMargin?: number) => T;
/**
 * Abstract base class for *Pie Charts*.
 * Visualizes proportions and percentages between categories, by dividing a circle into proportional segments.
 *
 * Set data using *PieChart*.**addSlice( name: string, value: number )**
 *
 * There are multiple implementations of *PieChart*, each with their own visual design and *API* for customizing it.
 * List of selectable options can be found in: [[PieChartTypes]]
 */
export declare abstract class PieChart extends Chart implements SlicedCharts<PieSlice> {
    /**
     * Add new Slice to the Pie Chart.
     * The Slice will be automatically assigned an unique style (using SliceFillStylePalette),
     * that will not be affected by sorting of Slices.
     *
     * Currently there is no way to override the individual style of a Slice - style modifications must be done using the API of Pie Chart.
     *
     * @param   name    Initial name for Slice as string.
     * @param   value   Initial value for Slice as number.
     * @return          New Slice object.
     */
    addSlice(name: string, value: number): PieSlice;
    /**
     * This method is used for the adding multiple slices in the funnel chart.
     * @param multiSlice Array of slices
     */
    addSlices(multiSlice: {
        name: string;
        value: number;
    }[]): Array<PieSlice>;
    /**
     * Get all Slices of Pie Chart.
     * NOTE: Manual modifications to returned Array can have unforeseen side-effects.
     * Removing or adding Slices is intended to be done using other APIs (PieChart.addSlice, Slice.dispose, ...)
     * @return  Array of Slices
     */
    getSlices(): PieSlice[];
    /**
     * Set if it is allowed for multiple Slices to be 'exploded' at the same time or not.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     *
     * Does not affect state of already exploded Slices!
     * @param   multipleSliceExplosionAllowed   Is behavior allowed as boolean flag
     * @return                                  Pie Chart itself
     */
    setMultipleSliceExplosion(multipleSliceExplosionAllowed: boolean): this;
    /**
     * Get a boolean flag which implies whether it is allowed for multiple Slices to be 'exploded' at the same time or not.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     * @return  Is behavior allowed as boolean flag
     */
    getMultipleSliceExplosion(): boolean;
    /**
     * Set inner radius of Pie Chart.
     * This method can be used to style the Pie Chart as a "Donut Chart", with the center being hollow.
     * @param   innerRadius     Inner radius as a percentage of outer radius [0, 100]
     * @return                  Pie Chart itself
     */
    setInnerRadius(innerRadius: number): this;
    /**
     * Get inner radius of Pie Chart..
     * This property can be used to style the Pie Chart as a "Donut Chart", with the center being hollow.
     * @return  Inner radius as a percentage of outer radius [0, 100]
     */
    getInnerRadius(): number;
    /**
     * Set offset of exploded Slices in pixels.
     * @param   sliceExplosionOffset    Offset of exploded Slices in pixels
     * @return                          Pie Chart itself
     */
    setSliceExplosionOffset(sliceExplosionOffset: pixel): this;
    /**
     * Get offset of exploded Slices in pixels.
     * @return  Offset of exploded Slices in pixels
     */
    getSliceExplosionOffset(): pixel;
    /**
     * Attach lookup table (LUT) to fill the slices with Colors based on value.
     *
     * The color for the slice would be selected from a specified *LUT*, which contains the information about gradient steps.
     * After setting LUT to undefined all the slices stay colorized, but no further lookup.
     *
     * LUT class stores information about values and its associated colors,
     * * which provides efficient lookup of the color based on provided value
     * * as well as linear and step interpolation between colors.
     *
     * ``` javascript
     * const pie = lightningChart()
     *  .Pie( { type: PieChartTypes.LabelsOnSides } )
     *  .setLUT( new LUT (steps: [
     *          { value: 10, color: ColorRGBA( 0, 0, 0 ) },
     *          { value: 20, color: ColorRGBA( 30, 255, 0 ) },
     *          { value: 30, color: ColorRGBA( 60, 204, 0 ) },
     *          { value: 40, color: ColorRGBA( 90, 128, 0 ) },
     *          { value: 50, color: ColorRGBA( 255, 0, 0 ) } ) ],
     *      interpolate: true } )
     * ```
     *
     * @param lut   Lookup table
     * @returns     Pie itself for fluent interface
     */
    setLUT(lut?: LUT): this;
    /**
     * Set style of Pie Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Pie will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Pie Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @param   sliceFillStylePalette   Palette for FillStyle objects
     * @return                          Pie Chart itself
     */
    setSliceFillStyle(sliceFillStylePalette: Palette<FillStyle>): this;
    /**
     * Get style of Pie Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Pie will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Pie Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @return  Palette<FillStyle>
     */
    getSliceFillStyle(): Palette<FillStyle>;
    /**
     * Set stroke style of Pie Slices border.
     * @param   value   LineStyle object or function which creates a new style based on previous
     * @return          Pie Chart itself
     */
    setSliceStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Pie Slices border.
     * @return  LineStyle object
     */
    getSliceStrokeStyle(): LineStyle;
    /**
     * Set sorter of Pies' Slices as a comparator-function.
     *
     * For some commonly needed default implementations, can refer to PieSliceSorters-collection.
     * @param   sliceSorter PieSliceSorter - function which sorts Slices of Pie with JavaScript API: Array.sort.
     * @return              Pie Chart itself
     */
    setSliceSorter(sliceSorter: SliceSorter<PieSlice>): this;
    /**
     * Get sorter of Pies' Slices as a comparator-function.
     * @return  PieSliceSorter - function which sorts Slices of Pie with JavaScript API: Array.sort.
     */
    getSliceSorter(): SliceSorter<PieSlice>;
    /**
     * Set fill style of Pie Slices Labels.
     * @param   value   FillStyle object or function which creates a new style based on previous
     * @return          Pie Chart itself
     */
    setLabelFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Pie Slice Labels.
     * @return  FillStyle object
     */
    getLabelFillStyle(): FillStyle;
    /**
     * Set font of Slice Labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Pie Chart itself
     */
    setLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Slice Labels.
     * @return  FontSettings
     */
    getLabelFont(): FontSettings;
    /**
     * Set formatter of Slice Labels.
     *
     * See [[SliceLabelFormatters]] for a collection of default options.
     * @param   labelFormatter  SliceLabelFormatter - function which generates text of Labels per Slice.
     * @return                  Pie Chart itself
     */
    setLabelFormatter(labelFormatter: SliceLabelFormatter<PieSlice>): this;
    /**
     * Get formatter of Slice Labels.
     * @return  SliceLabelFormatter - function which generates text of Labels per Slice.
     */
    getLabelFormatter(): SliceLabelFormatter<PieSlice>;
    /**
     * Sets if animations are enabled or not.
     * @param   animationsEnabled   Boolean state for animations enabled
     * @return                      Pie Chart itself
     */
    setAnimationsEnabled(animationsEnabled: boolean): this;
    /**
     * Gets if animations are enabled or not.
     * @return  Boolean state for animations enabled
     */
    getAnimationsEnabled(): boolean;
    /**
     * Disable all animations for the chart.
     *
     * All animations have to be re-enabled individually if you wish to re-enable animations.
     * @return  Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Set if slices should be highlighted on mouse hover / touch. Applies to all Slices.
     * @param state True if Slices should be highlighted on hover, false if not. This applies to all existing Slices and new Slices added.
     */
    setSliceHighlightOnHover(state: boolean): this;
}
/**
 * File contains different implementations of Pie Charts, each with their own rendering logic.
 */
/**
 * [[PieChart]] implementation that draws Slice Labels on its left and right sides.
 * Slices and Labels are connected by 'label connector lines'.
 */
export declare class PieChartWithLabelsOnSides extends PieChart {
    /**
     * Set style of Label connector lines.
     * @param   labelConnectorStyle LineStyle object
     * @return                      Pie Chart itself
     */
    setLabelConnectorStyle(labelConnectorStyle: LineStyle): this;
    /**
     * Get style of Label connector lines.
     * @return  LineStyle object
     */
    getLabelConnectorStyle(): LineStyle;
    /**
     * Set length of label connector line for an exploded Slice. For non-exploded Slices, the length will be the sum of
     * this and explosion offset.
     * @param   labelConnectorLength    Length as pixels
     * @return                          Pie Chart itself
     */
    setLabelConnectorLength(labelConnectorLength: pixel): this;
    /**
     * Get length of label connector line for an exploded Slice. For non-exploded Slices, the length will be the sum of
     * this and explosion offset.
     * @return  Length as pixels
     */
    getLabelConnectorLength(): number;
    /**
     * Set gap between Slice / start of label connector, and end of label connector / Label.
     * @param   labelConnectorGap   Gap as pixels
     * @return                      Pie Chart itself
     */
    setLabelConnectorGap(labelConnectorGap: pixel): this;
    /**
     * Get gap between Slice / start of label connector, and end of label connector / Label.
     * @return  Gap as pixels
     */
    getLabelConnectorGap(): number;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
}
/**
 * [[PieChart]] implementation that draws Slice Labels inside the Slices.
 * Works well when Label texts are short and there are not a lot of Slices, as the actual Pie has more space.
 * Public class
 */
export declare class PieChartWithLabelsInsideSlices extends PieChart {
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Vec2 minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
    /**
     * Set position of Labels.
     * @param   labelPositionInsideSlice    Position of labels inside their respective Slices as a number between [0, 1]
     * @return                              Pie Chart itself
     */
    setLabelPosition(labelPositionInsideSlice: number): this;
    /**
     * Get position of Labels.
     * @return  Position of labels inside their respective Slices as a number between [0, 1]
     */
    getLabelPosition(): number;
}
/**
 * Interface that can be used to define [[PieChart]] configurations that can't be changed after creation.
 *
 * Example usage:
 *```javascript
 * // Pie Chart with default type
 * undefined
 * // Pie Chart with specified type
 * { type: PieChartTypes.PieChartWithLabelsOnSides }
 * ```
 */
export interface PieChartOptions<PieChartType extends PieChartTypes> extends CommonChartOptions {
    /**
     * Interface for specifying desired "type" of Pie Chart.
     * This can be used to select different rendering approaches, mainly reflecting how Slice Labels are positioned.
     *
     * Options are located in [[PieChartTypes]] collection. If undefined, will default to PieChartWithLabelsOnSides.
     */
    type?: PieChartType;
}
/**
 * Available Pie Chart types
 * @hidden
 */
export declare type PieChartTypes = typeof PieChartTypes[keyof typeof PieChartTypes];
/**
 * Collection of [[PieChart]] implementations. Each option can have their own visual design, and *API* for customization of it.
 *
 * This must be specified when the [[PieChart]] is created (or default one will be used).
 *
 * Example usage:
 *```javascript
 * // Create a PieChart with specified type
 * LightningChart.Pie({ type: PieChartTypes.LabelsInsideSlices })
 * ```
 */
export declare const PieChartTypes: {
    /**
     * Pie Chart type, where Slice Labels are positioned on the left and right sides of Chart.
     * Labels are connected to their Slices with lines, which can be styled using unique API for this Pie Chart type.
     */
    LabelsOnSides: typeof PieChartWithLabelsOnSides;
    /**
     * Pie Chart type, where Slice Labels inside the Slices.
     * Works well when Label texts are short and there are not a lot of Slices, as the actual Pie has more space.
     */
    LabelsInsideSlices: typeof PieChartWithLabelsInsideSlices;
};
/**
 * Possible Shape types for parts of a Slice.
 */
declare type PieSliceVisual = Arc | Text;
/**
 * Abstract class represents a Pie & Donut specific slice API.
 */
export declare abstract class PieSlice extends Slice<PieSliceVisual> {
    /**
     * Set is Slice exploded.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     * @param   exploded    State of explosion as boolean
     * @return              Slice itself
     */
    abstract setExploded(exploded: boolean): this;
    /**
     * Get is Slice exploded.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     * @return  State of explosion as boolean
     */
    abstract getExploded(): boolean;
}
/**
 * Internal class that hides some internal interfaces of a Slice that are only needed for interactions with the owning Pie Chart.
 * @hidden Internal class
 */
export declare class InternalPieSlice extends PieSlice {
    protected _chart: PieChart;
    readonly scale: Vec2<Scale>;
    protected _removeFromChart: RemoveHandler<ChartComponent>;
    protected _restoreFromChart: RestoreHandler<ChartComponent>;
    /**
     * Index of Slice inside its owning Chart.
     * It tells how many Slices were created before this one.
     * It is not updated for disposed Slices, and so cannot be used for counting the amount of existing Slices.
     */
    readonly index: number;
    /**
     * @param   index               Index of Slice
     * @param    arcLayer           Rendering layer for Arc
     * @param    labelLayer         Rendering layer for Label
     * @param    _chart             Owning chart
     * @param    scale              Rendering scale
     * @param   _removeFromChart    Remove handler for Slice
     * @param    _restoreFromChart  Restore handler for Slice
     * @hidden
    */
    constructor(index: number, arcLayer: LayerXY, labelLayer: LayerXY, _chart: PieChart, scale: Vec2<Scale>, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>);
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    getValue(): number;
    /**
     * Set is Slice exploded.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     * @param   exploded    State of explosion as boolean
     * @return              Slice itself
     * @sideEffect          If set to true and Pie Chart multiple slice explosion is disabled,
     *                      this will unexplode any previously exploded Slices
     */
    setExploded(exploded: boolean): this;
    /**
     * Get is Slice exploded.
     * When a Slice is exploded, it is drawn differently from non-exploded state
     * - usually slightly "pushed away" from the center of Pie Chart.
     * @return  State of explosion as boolean
     */
    getExploded(): boolean;
    /**
     * Tell the owning chart to remove this component.
     * @return  Slice itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Slice itself.
     */
    restore(): this;
    /**
     * Method that owning Pie Chart uses to assign style of a Slice it owns.
     * @param   arcFillStyle    FillStyle for Arc
     * @param   arcStrokeStyle  LineStyle for Arc
     * @param   labelFillStyle  FillStyle for Label
     * @param   labelFont       FontSettings for Label
     */
    setStyle(arcFillStyle: FillStyle, arcStrokeStyle: LineStyle, labelFillStyle: FillStyle, labelFont: FontSettings): void;
    /**
     * Get animated value of Slice.
     * When value of Slice is changed, the animated value will not update immediately, but after an animation.
     * (if animations are not disabled).
     * @return  Animated value
     */
    getAnimatedValue(): number;
    /**
     * Get animated explosion state of Slice.
     * When state of Slice explosion is changed, this animated explosion value will move between 0 and 1 respectively,
     * but with an animation.
     * (if animations are not disabled).
     * @return  Animated value [0, 1]
     */
    getAnimatedExplosion(): number;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Enable or disable forced highlighting of series
     * @param highLight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * Method styles an attached entry according to Slice itself.
     */
    protected styleAttachedEntry(entry: LegendBoxEntry): void;
}
export {};
/**
 * File contains the logic for an abstract Pyramid Chart.
 * The rendering logic of a "Pyramid" is abstract and defined in a sub-class of this.
 */
/**
 * Type of a PyramidChart constructor.
 * @hidden
 */
export declare type PyramidChartConstructor<T extends PyramidChart> = new (layerSupplier: LayerSupplier, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: AbstractEventInterface, panelMargin?: number) => T;
/**
 * Abstract base class for *Pyramid Charts*.
 * Visualizes proportions and percentages between categories, by dividing a pyramid into proportional segments.
 *
 * Set data using *PyramidChart*.**addSlice( name: string, value: number )**
 *
 * There are multiple implementations of *PyramidChart*, each with their own visual design and *API* for customizing it.
 * List of selectable options can be found in: [[PyramidChartTypes]]
 */
export declare abstract class PyramidChart extends Chart implements SlicedCharts<PyramidSlice> {
    /**
     * This method is used for the adding slices in the pyramid chart.
     * @param title Pyramid slice title
     * @param value  pyramid slice value
     */
    addSlice(title: string, value: number): PyramidSlice;
    /**
     * This method is used for the adding multiple slices in the pyramid chart.
     * @param slices Array of slices
     */
    addSlices(slices: {
        name: string;
        value: number;
    }[]): Array<PyramidSlice>;
    /**
     * Get all Slices of Pyramid Chart.
     * NOTE: Manual modifications to returned Array can have unforeseen side-effects.
     * Removing or adding Slices is intended to be done using other APIs (PyramidChart.addSlice, Slice.dispose, ...)
     * @return  Array of Slices
     */
    getSlices(): PyramidSlice[];
    /**
     * Set Pyramid Neck Width
     * @param neckWidth Pyramid Neck Width range from 0 to 100
     * @return          Pyramid Chart itself
     */
    setNeckWidth(neckWidth: number): this;
    /**
     * Get Pyramid Neck Width
     * @return  number (0 - 100)
     */
    getNeckWidth(): number;
    /**
     * Set gap between Slice / start of label connector, and end of label connector / Label.
     * @param   sliceGap   Gap as pixels. Clamped between [0, 20] !
     * @return             Pyramid Chart itself
     */
    setSliceGap(sliceGap: pixel): this;
    /**
     * Set PyramidSliceMode. Can be used to select between different drawing approaches for Slices.
     *
     * See [[PyramidSliceModes]] for a collection of options.
     * @param   sliceMode   PyramidSliceMode
     * @return              Pyramid Chart itself
     */
    setSliceMode(sliceMode: PyramidSliceModes): this;
    /**
     * Get PyramidSliceMode. Can be used to select between different drawing approaches for Slices.
     *
     * See [[PyramidSliceModes]] for a collection of options.
     * @return  PyramidSliceMode
     */
    getPyramidSliceMode(): PyramidSliceModes;
    /**
     * Attach lookup table (LUT) to fill the slices with Colors based on value.
     *
     * The color for the slice would be selected from a specified *LUT*, which contains the information about gradient steps.
     * After setting LUT to undefined all the slices stay colorized, but no further lookup.
     *
     * LUT class stores information about values and its associated colors,
     * * which provides efficient lookup of the color based on provided value
     * * as well as linear and step interpolation between colors.
     *
     * ``` javascript
     * const pyramid = lightningChart()
     *  .Pyramid( { type: PyramidChartTypes.LabelsOnSides } )
     *  .setLUT( new LUT (steps: [
     *          { value: 10, color: ColorRGBA( 0, 0, 0 ) },
     *          { value: 20, color: ColorRGBA( 30, 255, 0 ) },
     *          { value: 30, color: ColorRGBA( 60, 204, 0 ) },
     *          { value: 40, color: ColorRGBA( 90, 128, 0 ) },
     *          { value: 50, color: ColorRGBA( 255, 0, 0 ) } ) ],
     *      interpolate: true } )
     * ```
     * @param value     Lookup table
     * @returns         Pyramid itself for fluent interface
     */
    setLUT(value: LUT): this;
    /**
     * Set style of Pyramid Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Pyramid will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Pyramid Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @param   sliceFillStylePalette   Palette for FillStyle objects
     * @return                          Pyramid Chart itself
     */
    setSliceFillStyle(sliceFillStylePalette: Palette<FillStyle>): this;
    /**
     * Get style of Pyramid Slices fill.
     * This style is managed as a continuous Palette of FillStyle objects. Each Slice of Pyramid will be assigned an incremental index,
     * which will be used to pick its fill style from this Palette.
     *
     * So, for example... We have a Pyramid Chart with 5 Slices, and we give it a Palette with only 3 possible values
     * (0 = red, 1 = green, 2 = blue). The resulting Slice fill styles will be: red, green, blue, red, green.
     * Note that this means, that the supplied Palette will have to work in a continuous manner!
     *
     * @return  Palette<FillStyle>
     */
    getSliceFillStyle(): Palette<FillStyle>;
    /**
     * Set style of Pyramid Slices Stroke.
     * @param   value   LineStyle object or function which creates a new style based on previous
     * @return          Pyramid Chart itself
     */
    setSliceStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of Pyramid Slices Stroke.
     * @return  LineStyle object
     */
    getSliceStrokeStyle(): LineStyle;
    /**
     * Set sorter of Pyramids' Slices as a comparator-function.
     *
     * For some commonly needed default implementations, can refer to SliceSorters-collection.
     * @param   sliceSorter SliceSorter - function which sorts Slices of Pyramid with JavaScript API: Array.sort.
     * @return              Pyramid Chart itself
     */
    setSliceSorter(sliceSorter: SliceSorter<PyramidSlice>): this;
    /**
     * Get sorter of Pyramids' Slices as a comparator-function.
     * @return  SliceSorter - function which sorts Slices of Pyramid with JavaScript API: Array.sort.
     */
    getSliceSorter(): SliceSorter<PyramidSlice>;
    /**
     * Set fill style of Pyramid Slices Labels.
     * @param   value   FillStyle object or function which creates a new style based on previous
     * @return          Pyramid Chart itself
     */
    setLabelFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Pyramid Slice Labels.
     * @return  FillStyle object
     */
    getLabelFillStyle(): FillStyle;
    /**
     * Set font of Slice Labels.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Pyramid Chart itself
     */
    setLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Slice Labels.
     * @return  FontSettings
     */
    getLabelFont(): FontSettings;
    /**
     * Set formatter of Slice Labels.
     *
     * See [[SliceLabelFormatters]] for a collection of default options.
     * @param   labelFormatter  SliceLabelFormatter - function which generates text of Labels per Slice.
     * @return                  Pyramid Chart itself
     */
    setLabelFormatter(labelFormatter: SliceLabelFormatter<PyramidSlice>): this;
    /**
     * Get formatter of Slice Labels.
     * @return  SliceLabelFormatter - function which generates text of Labels per Slice.
     */
    getLabelFormatter(): SliceLabelFormatter<PyramidSlice>;
    /**
     * Sets if animations are enabled or not.
     * @param   animationsEnabled   Boolean state for animations enabled
     * @return                      Pyramid Chart itself
     */
    setAnimationsEnabled(animationsEnabled: boolean): this;
    /**
     * Gets if animations are enabled or not.
     * @return  Boolean state for animations enabled
     */
    getAnimationsEnabled(): boolean;
    /**
     * Disable all animations for the chart.
     *
     * All animations have to be re-enabled individually if you wish to re-enable animations.
     * @return  Chart itself for fluent interface.
     */
    disableAnimations(): this;
    /**
     * Set if slices should be highlighted on mouse hover / touch. Applies to all Slices.
     * @param state True if Slices should be highlighted on hover, false if not. This applies to all existing Slices and new Slices added.
     */
    setSliceHighlightOnHover(state: boolean): this;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...Pyramid()
     * let slice = chart.addSlice({name: 'name', value: 50})
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * slice = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Enum for selecting different drawing approaches for [[PyramidChart]].
 *
 * Use with [[PyramidChart.setSliceMode]]
 */
export declare enum PyramidSliceModes {
    /**
     * Slices **height** represents its relative value inside the Pyramid Chart.
     */
    VariableHeight = 0,
    /**
     * Slices **width** represents its relative value inside the Pyramid Chart.
     */
    VariableWidth = 1
}
/**
 * File contains different implementations of Pyramid Charts, each with their own rendering logic.
 */
/**
 * [[PyramidChart]] implementation that draws Slice Labels on its left and right sides.
 * Slices and Labels are connected by 'label connector lines'.
 */
export declare class PyramidChartWithLabelsOnSides extends PyramidChart {
    /**
     * Set style of Label connector lines.
     * @param   labelConnectorStyle LineStyle object
     * @return                      Pyramid Chart itself
     */
    setLabelConnectorStyle(labelConnectorStyle: LineStyle): this;
    /**
     * Get style of Label connector lines.
     * @return  LineStyle object
     */
    getLabelConnectorStyle(): LineStyle;
    /**
     * Set gap between Slice / start of label connector, and end of label connector / Label.
     * @param   labelConnectorGap   Gap as pixels
     * @return                      Pyramid Chart itself
     */
    setLabelConnectorGap(labelConnectorGap: pixel): this;
    /**
     * Get gap between Slice / start of label connector, and end of label connector / Label.
     * @return  Gap as pixels
     */
    getLabelConnectorGap(): number;
    /**
     * Set the side where label should display
     * @param   labelSide   Left / Right
     * @return              Pyramid Chart itself
     */
    setLabelSide(labelSide: PyramidLabelSide): this;
    /**
     * Get the side where label shown
     * @return The label side
     */
    getLabelSide(): PyramidLabelSide;
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return  Point minimum size or undefined if unimplemented
     */
    getMinimumSize(): Point | undefined;
}
/**
 * [[PyramidChart]] implementation that draws Slice Labels inside the Slices.
 * Works well when Label texts are short and there are not a lot of Slices, as the actual Pyramid has more space.
 */
export declare class PyramidChartWithLabelsInsideSlices extends PyramidChart {
    /**
     * Get minimum size of Panel.
     * Depending on the type of class this value might be automatically computed to fit different elements.
     * @return      Point
     */
    getMinimumSize(): Point | undefined;
}
/**
 * Interface that can be used to define [[PyramidChart]] configurations that can't be changed after creation.
 *
 * Example usage:
 *```javascript
 * // Pyramid Chart with default type
 * undefined
 * // Pyramid Chart with specified type
 * { type: PyramidChartTypes.LabelsOnSides }
 * ```
 */
export interface PyramidChartOptions<PyramidChartType extends PyramidChartTypes> extends CommonChartOptions {
    /**
     * Interface for specifying desired "type" of Pyramid Chart.
     * This can be used to select different rendering approaches, mainly reflecting how Slice Labels are positioned.
     *
     * Options are located in [[PyramidChartTypes]] collection. If undefined, will default to [[PyramidChartWithLabelsOnSides]].
     */
    type?: PyramidChartType;
}
/**
 * Available Pyramid Chart types
 * @hidden
 */
export declare type PyramidChartTypes = typeof PyramidChartTypes[keyof typeof PyramidChartTypes];
/**
 * Collection of [[PyramidChart]] implementations. Each option can have their own visual type, and *API* for customization of it.
 *
 * This must be specified when the [[PyramidChart]] is created (or default one will be used).
 *
 * Example usage:
 *```javascript
 * // Create a PyramidChart with default type
 * LightningChart.Pyramid()
 * // Create a PyramidChart with specified type
 * LightningChart.Pyramid({ type: PyramidChartTypes.LabelsInsideSlices })
 * ```
 */
export declare const PyramidChartTypes: {
    /**
     * Pyramid Chart type, where Slice Labels are positioned on the either left or right sides of Chart.
     * The side can be set using setLabelSide
     * Labels are connected to their Slices with lines, which can be styled using unique API for this Pyramid Chart type.
     */
    LabelsOnSides: typeof PyramidChartWithLabelsOnSides;
    /**
     * Pyramid Chart type, where Slice Labels inside the Slices.
     */
    LabelsInsideSlices: typeof PyramidChartWithLabelsInsideSlices;
};
/**
 * Options for selecting side of labels in a [[PyramidChartWithLabelsOnSides]].
 *
 * Use with [[PyramidChartWithLabelsOnSides.setLabelSide]]
 */
export declare enum PyramidLabelSide {
    /**
     * Label Side  - Right
     */
    Right = 0,
    /**
     * Label Side  - Left
     */
    Left = 1
}
/**
 * Possible Shape types for parts of a Slice.
 */
declare type PyramidSliceVisual = Polygon | Text;
/**
 * Class that represents a single Slice of a Pyramid Chart.
 * It is given to users when a Slice is added.
 */
export declare abstract class PyramidSlice extends Slice<PyramidSliceVisual> {
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    abstract setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    abstract getValue(): number;
}
/**
 * Internal class that hides some internal interfaces of a Slice that are only needed for interactions with the owning Pyramid Chart.
 * @hidden
 */
export declare class InternalPyramidSlice extends PyramidSlice {
    protected _chart: PyramidChart;
    readonly scale: Vec2<Scale>;
    protected _removeFromChart: RemoveHandler<ChartComponent>;
    protected _restoreFromChart: RestoreHandler<ChartComponent>;
    /**
     * Index of Slice inside its owning Chart.
     * It tells how many Slices were created before this one.
     * It is not updated for disposed Slices, and so cannot be used for counting the amount of existing Slices.
     */
    readonly index: number;
    /**
     * @param   index               Index of Slice
     * @param    polygonLayer       Rendering layer for Polygon
     * @param    labelLayer         Rendering layer for Label
     * @param    _chart             Owning chart
     * @param    scale              Rendering scale
     * @param   _removeFromChart    Remove handler for Slice
     * @param    _restoreFromChart  Restore handler for Slice
     * @hidden
     */
    constructor(index: number, polygonLayer: LayerXY, labelLayer: LayerXY, _chart: PyramidChart, scale: Vec2<Scale>, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>);
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    getValue(): number;
    /**
     * Tell the owning chart to remove this component.
     * @return  Slice itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Slice itself.
     */
    restore(): this;
    /**
     * Method that owning Pyramid Chart uses to assign style of a Slice it owns.
     * @param   polygonFillStyle    FillStyle for Polygon
     * @param   polygonStrokeStyle  LineStyle for Polygon
     * @param   labelFillStyle  FillStyle for Label
     * @param   labelFont       FontSettings for Label
     */
    setStyle(polygonFillStyle: FillStyle, polygonStrokeStyle: LineStyle, labelFillStyle: FillStyle, labelFont: FontSettings): void;
    /**
     * Get animated value of Slice.
     * When value of Slice is changed, the animated value will not update immediately, but after an animation.
     * (if animations are not disabled).
     * @return  Animated value
     */
    getAnimatedValue(): number;
    /**
     * Attach series to an annotation.
     * @param entry Object which has to be attached
     * @return      Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Enable or disable forced highlighting of series
     * @param highLight True for enabled and false for disabled
     * @returns         Series itself for fluent interface
     */
    setHighlighted(highLight: boolean): this;
    /**
     * Method styles an attached entry according to Slice itself.
     */
    protected styleAttachedEntry(entry: LegendBoxEntry): void;
}
export {};
/**
 * *Axis* is a child component of *ChartXY*. It defines a numeric range on a single plane (*X* or *Y*),
 * that will be used to scale attached *Series* to the *ChartXY*s viewport.
 *
 * A *ChartXY* can have any number of *Axes*. They can be positioned on all four sides of the *ChartXY*:
 * - left       (default Y)
 * - bottom     (default X)
 * - right
 * - top
 *
 * *Axes* have automatic scrolling logic to fit attached *Series*.
 * This can be modified with [[Axis.setScrollStrategy]]
 *
 * *Axes* are associated with a title, which can be enabled with [[Axis.setTitle]]
 */
export declare class Axis extends GenericAxis<Scale, ChartXY, SeriesXY, DimensionalAxisStrategy, Tick, TickPlottingVariables> implements Validatable, Disposable {
    protected readonly _gridlineLayer: LayerXY;
    protected readonly _minorGridLineLayer: LayerXY;
    protected readonly _majorGridLineLayer: LayerXY;
    protected readonly _fg: LayerXY;
    protected readonly _ui: LayerXY;
    protected readonly _layerHighlightersBelow: LayerXY;
    protected readonly _layerHighlightersAbove: LayerXY;
    readonly heightScale: Scale;
    readonly chart: ChartXY;
    protected readonly _uiPosition: number;
    protected _removeAxis: (axis: Axis) => void;
    protected _restoreAxis: (axis: Axis) => void;
    /**
     * Describe height direction of axis, affects label position, tick line and grid line directions.
     */
    readonly directionFactor: 1 | -1;
    /**
     * Pair of scales, which describes space of axis sub-elements
     */
    readonly plottingScale: any;
    /**
     * @param _gridlineLayer            Rendering Layer for other Grid lines.
     * @param _minorGridLineLayer       Rendering Layer for Minor Grid Lines and ticks.
     * @param _majorGridLineLayer       Rendering Layer for Major Grid Lines and ticks.
     * @param _fg                       Rendering Layer for Axis, Ticks and Title.
     * @param _ui                       Rendering Layer for user interaction Shapes.
     * @param _layerHighlightersBelow   Rendering layer for Highlighters with "below" setting.
     * @param _layerHighlightersAbove   Rendering layer for Highlighters with "above" setting.
     * @param scale                     Scale of the Axis value
     * @param heightScale               Height Scale or the Axis
     * @param _axisStrategy             Axis strategy, defines X or Y positing
     * @param chart                     Chart that owns the Axis.
     * @param _uiPosition               UI position in percents. 0 means bottom/right, 100 means top/left,
     *                                  anything in between places the axis in the custom position along the chart's space
     * @param _removeAxis               Injected remove method from owner.
     * @param _restoreAxis              Injected restore method from owner.
     * @param setSeriesAttachHandler    Function that axis calls to inject series attach handler to its owning chart.
     * @param _theme                    Theme from owning chart, used to apply styling to Axis.
     *                                  Cached for sub components of Axis (custom tick, highlighters, etc.)
     * @param   _disableAnimations      Disable animations by default
     * @hidden
     */
    constructor(_gridlineLayer: LayerXY, _minorGridLineLayer: LayerXY, _majorGridLineLayer: LayerXY, _fg: LayerXY, _ui: LayerXY, _layerHighlightersBelow: LayerXY, _layerHighlightersAbove: LayerXY, scale: Scale, heightScale: Scale, _axisStrategy: DimensionalAxisStrategy, chart: ChartXY, _uiPosition: number, _removeAxis: (axis: Axis) => void, _restoreAxis: (axis: Axis) => void, setSeriesAttachHandler: (axis: Axis, handler: AxisAttachHandler) => void, _theme: Theme, _animationsDefaultDisable: boolean);
    /**
     * Add a highlighter Band to the Axis.
     * A Band can be used to highlight an interval on the Axis.
     *
     * @param   onTop   Is Band rendered above Series, or below. Default to above.
     * @return          Band object.
     */
    addBand(onTop?: boolean): Band;
    /**
     * Add a highlighter ConstantLine to the Axis.
     * A ConstantLine can be used to highlight a specific value on the Axis.
     *
     * @param   onTop   Is ConstantLine rendered above Series, or below. Default to above.
     * @return          ConstantLine object.
     */
    addConstantLine(onTop?: boolean): ConstantLine;
    /**
     * Get all Highlighters of Axis.
     * @return  array of highlighters
     */
    getHighlighters(): Highlighter[];
    /**
     * Set enabled flags for all mouse-interactions on axis directly.
     * Does not affect chart mouse-interactions.
     * @param   enabled     Boolean: are mouse-interactions enabled
     * @return              Axis itself for fluent interface
     */
    setMouseInteractions(enabled: boolean): this;
    /**
     * Get height of axis in pixels
     * @return      Number
     */
    getHeight(): number;
    /**
     * Add custom tick.
     *
     * Example usage:
     *```javascript
     * // Custom tick with default background
     * Axis.addCustomTick(undefined)
     * // Custom tick with no background
     * Axis.addCustomTick(addStyler((textBox) => textBox.setBackground((bg) => bg.setFillStyle(emptyFill))))
     * ```
     * @param markerBuilder     Builder for marker of custom tick.
     *                          Currently only option is a version of *UIElementBuilders.PointableTextBox*
     * @returns                 CustomTick created object
     */
    addCustomTick<TickMarkerBackgroundType extends PointableBackground>(markerBuilder?: UIPointableTextBoxBuilder<TickMarkerBackgroundType>): CustomTick<TickMarkerBackgroundType>;
    /**
     * Get position of axis on its chart as a %
     */
    getUiPosition(): number;
    /**
     * @returns Axis stroke as a LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Specifies axis stroke
     * @param  value        Axis stroke style
     * @returns             Axis itself for fluent interface
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of axis overlay (shown only when interacting with mouse / touch).
     * @return  FillStyle object
     */
    getOverlayStyle(): FillStyle;
    /**
     * Set style of axis overlay (shown only when interacting with mouse / touch).
     * @param   style   FillStyle object or mutator to modify existing one
     */
    setOverlayStyle(style: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set is mouse-interaction enabled:
     * Zooming by dragging on axis. (LMB)
     * @param   enabled     Boolean flag
     */
    setAxisInteractionZoomByDragging(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming by dragging on axis. (LMB)
     * @return  Boolean flag
     */
    getAxisInteractionZoomByDragging(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Panning by dragging on axis. (RMB)
     * @param   enabled     Boolean flag
     */
    setAxisInteractionPanByDragging(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Panning by dragging on axis. (RMB)
     * @return  Boolean flag
     */
    getAxisInteractionPanByDragging(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Zooming by mouse-wheeling on axis.
     * @param   enabled     Boolean flag
     */
    setAxisInteractionZoomByWheeling(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming by mouse-wheeling on axis.
     * @return  Boolean flag
     */
    getAxisInteractionZoomByWheeling(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Release axis by double-clicking on axis.
     * @param   enabled     Boolean flag
     */
    setAxisInteractionReleaseByDoubleClicking(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Release axis by double-clicking on axis.
     * @return  Boolean flag
     */
    getAxisInteractionReleaseByDoubleClicking(): boolean;
    /**
     * Set mouse style when hovering over axis area.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setAxisMouseHoverStyle(mouseStyle?: string): this;
    /**
     * Get mouse style when hovering over axis area.
     * @return  Mouse-style preset name
     */
    getAxisMouseHoverStyle(): string;
    /**
     * Set mouse style when panning axis.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setAxisMousePanStyle(mouseStyle?: string): this;
    /**
     * Get mouse style when panning axis.
     * @return  Mouse-style preset name
     */
    getAxisMousePanStyle(): string;
    /**
     * Set mouse style when zooming axis.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setAxisMouseZoomStyle(mouseStyle?: string): this;
    /**
     * Get mouse style when zooming axis.
     * @return  Mouse-style preset name
     */
    getAxisMouseZoomStyle(): string;
    /**
     * @returns Padding after Axis title
     */
    getTitleMargin(): number;
    /**
     * Specifies padding after Axis title.
     * This is only accounted when title is visible.
     * @param  margin   Gap between the title and the next axis in pixels. Can also affect chart margins
     * @returns         Axis itself for fluent interface
     */
    setTitleMargin(margin: pixel): this;
    /**
     * @returns Axis nib stroke length in pixels
     */
    getNibLength(): number;
    /**
     * Specifies Axis nib stroke length in pixels
     * @param  length  Axis nib stroke length in pixels
     * @returns        Axis itself for fluent interface
     */
    setNibLength(length: pixel): this;
    /**
     * @returns nib stroke fillstyle as a Fillstyle object
     */
    getNibStyle(): LineStyle;
    /**
     * Specifies Axis nibs StrokeStyle
     * @param   style       LineStyle object or mutator to modify existing one
     * @returns             Axis itself for fluent interface
     */
    setNibStyle(style: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of nib overlay (shown only when interacting with mouse / touch).
     * @return  FillStyle object
     */
    getNibOverlayStyle(): FillStyle;
    /**
     * Set style of nib overlay (shown only when interacting with mouse / touch).
     * @param   style   FillStyle object or mutator to modify existing one
     */
    setNibOverlayStyle(style: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set ideal size of nib mouse-picking area in pixels.
     * @param   size   Size in pixels
     * @returns Object itself
     */
    setNibMousePickingAreaSize(size: pixel): this;
    /**
     * Get size of nib mouse-picking area in pixels.
     * @returns Size in pixels
     */
    getNibMousePickingAreaSize(): number;
    /**
     * Set is mouse-interaction enabled:
     * Scaling by dragging on nib.
     * @param   enabled     Boolean flag
     */
    setNibInteractionScaleByDragging(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Scaling by dragging on nib.
     * @return  Boolean flag
     */
    getNibInteractionScaleByDragging(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Scaling by mouse-wheeling on nib.
     * @param   enabled     Boolean flag
     */
    setNibInteractionScaleByWheeling(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Scaling by mouse-wheeling on nib.
     * @return  Boolean flag
     */
    getNibInteractionScaleByWheeling(): boolean;
    /**
     * Set mouse style when hovering over nib area.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setNibMouseHoverStyle(mouseStyle?: string): this;
    /**
     * Get mouse style when hovering over nib area.
     * @return  Mouse-style preset name
     */
    getNibMouseHoverStyle(): string;
    /**
     * Set mouse style when scaling nib.
     * @param   mouseStyle  Mouse-style preset name (see [[MouseStyles]])
     * @return              Object itself
     */
    setNibMouseScaleStyle(mouseStyle?: string): this;
    /**
     * Get mouse style when hovering over nib area.
     * @return  Mouse-style preset name
     */
    getNibMouseScaleStyle(): string;
    /**
     * Set all states of chart mouse interactions on axis at once.
     * @param   enabled Boolean flag
     */
    setChartInteractions(enabled: boolean): this;
    /**
     * Set is mouse-interaction enabled:
     * Panning by dragging on chart.
     * @param   enabled     Boolean flag
     */
    setChartInteractionPanByDrag(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Panning by dragging on chart.
     * @return  Boolean flag
     */
    getChartInteractionPanByDrag(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Zooming by mouse-wheeling on chart.
     * @param   enabled     Boolean flag
     */
    setChartInteractionZoomByWheel(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming by mouse-wheeling on chart.
     * @return  Boolean flag
     */
    getChartInteractionZoomByWheel(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Zooming by capturing rectangle on chart.
     * @param   enabled     Boolean flag
     */
    setChartInteractionZoomByDrag(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Zooming by capturing rectangle on chart.
     * @return  Boolean flag
     */
    getChartInteractionZoomByDrag(): boolean;
    /**
     * Set is mouse-interaction enabled:
     * Fitting by capturing rectangle on chart.
     * @param   enabled     Boolean flag
     */
    setChartInteractionFitByDrag(enabled: boolean): this;
    /**
     * Get is mouse-interaction enabled:
     * Fitting by capturing rectangle on chart.
     * @return  Boolean flag
     */
    getChartInteractionFitByDrag(): boolean;
    /**
     * Dispose all Axis sub-elements and remove this Axis from collection it's in.
     * @returns this for fluent interface
     */
    dispose(): this;
    /**
     * @return True if all Axis sub-elements are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Restore all Axis sub-elements and restore this Axis to the collection it was in.
     * @returns this for fluent interface
     * TODO: Needs to properly restore the nibs - or recreate them. Current dispose would force us to use the latter method.
     * Needs to put the axis back to a proper position.
     */
    restore(): this;
}
/**
 * Implementation specific values necessary for tick plotting.
 */
interface TickPlottingVariables extends AbstractTickPlottingVariables {
    /**
     *
     */
    startPosition: number;
    /**
     *
     */
    gridStrokeLen: number;
    /**
     * Height level of Grid Stroke Start
     */
    gridStrokeStart: pixel;
    /**
     * Height level of Tick Stroke Start
     */
    tickStart: number;
}
/**
 * Implementation of 2D Axis Tick.
 */
export declare class Tick extends AbstractAxisTick {
    protected readonly _gridlineLayer: LayerXY;
    protected readonly _gridlineScale: Vec2<Scale>;
    /**
     * @param   tickLevel       AxisTickLevel tick belongs to.
     * @param   value           Position of Tick on Axis.
     * @param   _removeFromAxis Remove handler for Tick.
     * @param   _restoreToAxis  Restore handler for Tick.
     * @param   _labelLayer     Layer for rendering Tick Label.
     * @param   _labelScale     Scale for rendering Tick label.
     * @param   _gridlineLayer  Layer for rendering Gridline shape.
     * @param   _gridlineScale  Scale for rendering Gridline shape.
     * @param   label           Optionally injectable Tick Label shape.
     *                          Injection can be useful to reuse Tick shapes for performance.
     */
    constructor(tickLevel: AxisTickLevel, value: number, _removeFromAxis: RemoveHandler<AbstractAxisTick>, _restoreToAxis: RestoreHandler<AbstractAxisTick>, _labelLayer: LayerXY, _labelScale: Vec2<Scale>, _gridlineLayer: LayerXY, _gridlineScale: Vec2<Scale>, label?: Text);
}
export {};
/**
 * Interface for a strategy which defines Axis dimension
 */
interface AxisStrategy extends AbstractAxisStrategy<SeriesXY> {
    /**
     * Mouse style when dragging over axis
     */
    readonly defaultDragMouseStyle: string;
    /**
     * Correct CustomTickStrategy which match dimension of the Axis
     */
    readonly customTickStrategy: CustomTickStrategy & MultidimensionalStrategy;
    /**
     * Used internally for rendering the axis title text at a specified angle
     * @param   direction Axis direction factor
     * @returns           Configured title text rotation in degrees
     */
    readonly getTitleTextRotation: (direction: 1 | -1) => number;
}
/**
 * Union of Dimensional and Axis Strategies
 * @hidden
 */
export declare type DimensionalAxisStrategy = MultidimensionalStrategy & AxisStrategy;
export {};
/**
 * Public interface for TickMarkers of CustomTicks.
 */
export declare type TickMarker<BackgroundType extends PointableBackground = PointableBackground> = StylableText & StylableBackground<BackgroundType> & Pointable;
/**
 * Internal interface for TickMarkers of CustomTicks.
 * Basically restricts mouse-interaction methods. ( if required, these should be implemented by the class that owns the TickMarker )
 * @hidden
 */
export declare type InternalTickmarker<BackgroundType extends PointableBackground = PointableBackground> = PointableTextBox<BackgroundType>;
/**
 * Interface for function which specifies CustomTick text.
 */
export declare type CustomTickTextFormatter<TickMarkerBackgroundType extends PointableBackground = PointableBackground> = (value: number, customTick: CustomTick<TickMarkerBackgroundType>) => string;
/**
 * Custom tick.
 *
 * Is designed to be used strictly by Axis objects.
 */
export declare abstract class CustomTick<TickMarkerBackgroundType extends PointableBackground = PointableBackground> extends UIObject {
    protected readonly _bg: LayerXY;
    protected readonly _ui: LayerXY;
    readonly scale: Vec2<Scale>;
    protected readonly _strategy: DimensionalCustomTickStrategy;
    protected _direction: UIDirections;
    private _markerBuilder;
    protected readonly _remove: RemoveHandler<CustomTick>;
    protected readonly _restore: RestoreHandler<CustomTick>;
    /**
     * Axis that CustomTick belongs to.
     */
    readonly axis: Axis;
    /**
     * Scale of owning axis.
     */
    readonly mainScale: Scale;
    /**
     * @param axis              Axis that CustomTick belongs to
     * @param _strategy         CustomTick strategy, defines X or Y positing
     * @param _direction        Direction of the tick pointer as enum value
     * @param _markerBuilder    Custom builder for marker of custom tick
     * @hidden
     */
    constructor(axis: Axis, _bg: LayerXY, _ui: LayerXY, scale: Vec2<Scale>, _strategy: DimensionalCustomTickStrategy, _direction: UIDirections, _markerBuilder: UIPointableTextBoxBuilder<TickMarkerBackgroundType>, _remove: RemoveHandler<CustomTick>, _restore: RestoreHandler<CustomTick>, _theme: Theme);
    /**
     * Restore all sub-elements of custom tick
     * @return This for fluent interface
     */
    restore(): this;
    /**
     * Disposes all custom tick sub-elements
     * @returns This for fluid interface
     */
    dispose(): this;
    /**
     * @return True if all customTick child elements are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Check that customTick fit the main scale
     * @returns         Boolean with the result
     */
    isInScale(): boolean;
    /**
     * Sets the position of this custom tick on its Axis
     * @param value Value in the units of main scale
     * @returns     This for fluid interface
     * @sideEffect  Overrides text of CustomTicks Marker with formated value.
     */
    setValue(value: number): this;
    /**
     * Value of CustomTick
     */
    getValue(): number;
    /**
     * Set text of CustomTicks' Marker with a formatting function.
     *
     * Example usage:
     *```javascript
     * // Marker shows formatted position of CustomTick on its Axis
     * CustomTick.setTextFormatter((position, customTick) => customTick.axis.formatValue(position))
     * // Marker shows 'Hello world'
     * CustomTick.setTextFormatter((position, customTick) => 'Hello world')
     * ```
     * @param   textFormatter   A function of type: *CustomTickTextFormatter*, that defines text of CustomTicks' Marker.
     * @return                  Object itself
     */
    setTextFormatter(textFormatter: CustomTickTextFormatter): this;
    /**
     * Remove Marker from rendering collection, so it can be safely trashed by GC
     * @returns Object itself for fluent interface
     */
    disposeMarker(): this;
    /**
     * Place Marker back to rendering collection, so it became visible again
     * @returns Object itself for fluent interface
     */
    restoreMarker(): this;
    /**
     * @returns True if visible and False for invisible
     */
    isDisposedMarker(): boolean;
    /**
     * Set length of grid stroke in percents
     * @param length     Grid line length as a % of viewport size
     * @returns          This for fluent interface
     */
    setGridStrokeLength(length: number): this;
    /**
     * @returns Grid stroke length as a % of the viewport size
     */
    getGridStrokeLength(): number;
    /**
     * @param value Grid stroke style
     * @returns This for fluent interface
     */
    setGridStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * @returns Grid stroke style as a LineStyle object
     */
    getGridStrokeStyle(): LineStyle;
    /**
     * Set padding on sides of label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    setSidePaddings(padding: pixel): this;
    /**
     * @returns Size of padding at sides of label
     */
    getSidePaddings(): number;
    /**
     * Mutator function for the TickMarker
     * @param   mutator     TickMarker mutator function
     * @returns             Object itself for fluent interface
     */
    setMarker(mutator: Mutator<TickMarker<TickMarkerBackgroundType>>): this;
    /**
     * Get marker of tick.
     * @returns PointableTextBox object
     */
    getMarker(): TickMarker<TickMarkerBackgroundType>;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return      Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
}
/**
 * Custom tick marker extended by some internal APIs
 * @hidden Internal class
 */
export declare class InternalCustomTick<TickMarkerBackgroundType extends PointableBackground = PointableBackground> extends CustomTick<TickMarkerBackgroundType> {
    protected readonly _bg: LayerXY;
    protected readonly _ui: LayerXY;
    readonly scale: Vec2<Scale>;
    protected readonly _add: RemoveHandler<InternalCustomTick>;
    protected readonly _remove: RestoreHandler<InternalCustomTick>;
    readonly _theme: Theme;
    /**
     * @param axis              Axis that CustomTick belongs to
     * @param scale             X and Y Axis used for drawing of the attached axis
     * @param mainScale         Scale of the custom tick`s value
     * @param direction         Direction of the tick pointer as enum value
     * @param markerBuilder     Custom builder for marker of custom tick
     * @hidden
     */
    constructor(axis: Axis, _bg: LayerXY, _ui: LayerXY, scale: Vec2<Scale>, strategy: DimensionalCustomTickStrategy, direction: UIDirections, _add: RemoveHandler<InternalCustomTick>, _remove: RestoreHandler<InternalCustomTick>, _theme: Theme, markerBuilder?: UIPointableTextBoxBuilder<TickMarkerBackgroundType>);
    /**
     * @return True if all customTick child elements are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
    * Disposes all custom tick sub-elements
    * @returns This for fluid interface
    */
    dispose(): this;
    /**
     * Set distance between tick and label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    setTopPadding(padding: pixel): this;
    /**
     * Set padding after label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    setPaddingBottom(padding: pixel): this;
    /**
     * Update sub-elements of custom tick
     * @returns Object itself for fluent interface
     */
    update(): this;
    /**
     * Similarly to Axis.plot(), plots all the relevant shapes of this customTick
     * and shoves them into the passed engine.
     * @param  axisScale     Scale object of the axis this customTick is contained in.
     * @param  startHeight   Start height in pixels of the axis this customTick is contained in
     * @param  axisThickness Thickness in pixels of the axis this customTick is contained in
     * @param  margins       Vec2 of owning axis' margins in percents (0 to 1)
     */
    plot(gridStrokeStart: number, gridStrokeLen: number, gridStrokeOffset: number, tickStart: number): this;
    /**
     * @param  length   Length of the customTick line in pixels
     * @returns         This for fluent interface
     */
    setTickLength(length: pixel): this;
    /**
     * @param shouldAxisAllocateSpace   Should axis allocate space for a custom tick
     * @returns                         This for fluent interface
     */
    setShouldAxisAllocateSpace(shouldAxisAllocateSpace: boolean): this;
    /**
     * @returns Length of this CustomTick line in pixels
     */
    getTickLength(): number;
    /**
     * @returns Height of tick marker
     */
    getTickSize(): number;
    /**
     * @returns Flag of should axis allocate space for a custom tick
     */
    getShouldAxisAllocateSpace(): boolean;
}
/**
 * Interface for a strategy which defines CustomTick dimension
 * @hidden
 */
export interface CustomTickStrategy {
    /**
     * Set distance between tick and label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    readonly setTopPadding: (marker: TickMarker, direction: UIDirections, padding: number) => void;
    /**
     * Set padding after label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    readonly setPaddingBottom: (marker: TickMarker, direction: UIDirections, padding: number) => void;
    /**
     * Set padding on sides of label
     * @param padding Distance in pixels
     * @returns       Object itself for fluent interface
     */
    readonly setSidePaddings: (marker: TickMarker, padding: number) => void;
    /**
     * @returns Size of padding at sides of label
     */
    readonly getSidePaddings: (marker: TickMarker) => number;
}
/**
 * Union of Dimensional and CustomTick Strategies
 * @hidden
 */
export declare type DimensionalCustomTickStrategy = CustomTickStrategy & MultidimensionalStrategy;
/**
 * Interface for a strategy which defines dimension
 */
export interface MultidimensionalStrategy {
    /**
     * @param size Two dimensional value width of which has to be extracted
     * @returns    Width of Vec2
     */
    readonly getWidth: <T>(sizes: Vec2<T>) => T;
    /**
     * @param size Two dimensional value height of which has to be extracted
     * @returns    Height of Vec2
     */
    readonly getHeight: <T>(size: Vec2<T>) => T;
    /**
     * Combine argument with the tick value to create relevant Vec2
     * @param   height Value on height Scale units
     * @return         Vec2 which represents relevant for custom tick position
     */
    readonly toVec2: <T>(value: T, height: T) => Vec2<T>;
    /**
     * Combine argument with the tick value to create relevant Point
     * @param   height Value on height Scale units
     * @return         Point
     */
    readonly toPoint: (value: number, height: number) => Point;
}
/**
 * MultidimensionalStrategy for X Dimension
 */
export declare const xDimensionStrategy: MultidimensionalStrategy;
/**
 * MultidimensionalStrategy for X Dimension
 */
export declare const yDimensionStrategy: MultidimensionalStrategy;
/**
 * EllipseSeries, implementation of FigureSeries that simply plots individual ellipses (using Arcs).
 */
/**
 * Data type that defines a ellipse shape
 */
export interface EllipseDimensions {
    /**
     * X coordinate of ellipses center.
     */
    readonly x: number;
    /**
     * Y coordinate of ellipses center.
     */
    readonly y: number;
    /**
     * X radius of ellipse.
     */
    readonly radiusX: number;
    /**
     * Y radius of ellipse
     */
    readonly radiusY: number;
}
/**
 * Class for series visual that is an Ellipse.
 */
export declare class EllipseFigure extends CustomizableFigure {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected readonly _figureBoundsChanged: () => void;
    protected dimensions: EllipseDimensions;
    /**
     * @param   _layer                  Rendering layer
     * @param   scale                   Rendering scale
     * @param   _remove                 Callback that is called when Figure.dispose() is called.
     * @param   _restore                Callback that is called when Figure.restore() is called.
     * @param   _figureBoundsChanged    Callback that is called when Figure boundaries are changed
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<Figure>, _restore: RestoreHandler<Figure>, _figureBoundsChanged: () => void, _theme: Theme);
    /**
     * Get boundaries that contain figure.
     * @return  Interval<Point>
     */
    getBoundaries(): Interval<Point>;
    /**
     * Set new dimensions for figure.
     * @param   dimensions  Dimensions
     * @return              Object itself
     * @sideEffect          Owning series will be informed of change in size, possible initiating scrolling.
     */
    setDimensions(dimensions: EllipseDimensions): this;
    /**
     * Get current dimensions of figure.
     * @return  Dimensions
     */
    getDimensions(): EllipseDimensions;
    /**
     * Set fill style of Ellipse.
     * @param   fillStyle   FillStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Ellipse.
     * @return              FillStyle object
     */
    getFillStyle(): FillStyle;
    /**
     * Set fill style of Ellipse when highlighted.
     * @param   fillStyle   FillStyle object or mutator to modify existing one or undefined for auto assignment
     * @return              Object itself
     */
    setFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get fill style of Ellipse when highlighted.
     * @return              FillStyle object or undefined for auto assignment
     */
    getFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set stroke style of Ellipse.
     * @param   value   LineStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Ellipse.
     * @return              LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Ellipse when highlighted.
     * @param   value   LineStyle object or mutator to modify existing one or undefined for auto assignment
     * @return              Object itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of Ellipse when highlighted.
     * @return              LineStyle object or undefined for auto assignment
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * Return some dominant fill style of the figure
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
}
/**
 * Implementation of EllipseSeries
 */
export declare class EllipseSeries extends SimpleFigureSeries<EllipseFigure, FigureSeriesFormatter<EllipseFigure, EllipseSeries>, EllipseDimensions> {
    /**
     * Add new figure to the series.
     * @param   dimensions  Dimensions that figure must represent
     * @return  Created figure
     */
    add(dimensions: EllipseDimensions): EllipseFigure;
}
/**
 * Abstract figure class for series visuals that are formed of multiple primitive shapes.
 * @hidden Internal class
 */
export declare abstract class Figure extends UIObject implements Disposable, Highlightable {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    private readonly _removeFigure;
    private readonly _restoreFigure;
    /**
     * Figure implementations should add primitive shapes in their constructors using
     * this.addShape( layer.addX( ... ) ) for proper functionality!
     *
     * @param   _layer   Rendering layer. Used to create primitive shapes
     * @param   scale   Rendering scale
     * @param   _removeFigure  Callback that is called when Figure.dispose() is called
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _removeFigure: RemoveHandler<Figure>, _restoreFigure: RestoreHandler<Figure>, _theme: Theme);
    /**
     * Return some dominant fill style of the figure
     * @returns     FillStyle object
     */
    abstract getDominantStyle(): FillStyle;
    /**
     * Dispose shapes from rendering layer
     */
    dispose(): this;
    /**
     * @return True if all shapes are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Restore shapes to the rendering layer.
     */
    restore(): this;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * @return True for highlighted state of object and false for basic
     */
    getHighlighted: () => boolean;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return     Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
}
/**
 * Implementation of SeriesXY that uses abstract 'Figures' to display segments
 *
 */
/**
 * Type for styler function for Figure
 * @param   figure  Figure
 */
export declare type FigureStyler<T extends Figure> = (figure: T) => void;
/**
 * Type of FigureConstructor
 * Basically any kind of constructor for 'PlottableFigure' object
 * @hidden
 */
export declare type FigureConstructor<T extends Figure> = new (...args: any[]) => T;
/**
 * Abstract base class for series based on figures.
 * @hidden Internal class
 */
export declare abstract class FigureSeries<FigureType extends Figure, CursorPointInterface extends CursorPoint<SeriesXY>> extends SeriesXY<FigureType, CursorPointInterface> {
    /**
     * Clear all data from the series
     * @returns         Series itself for fluent interface
     */
    clear(): this;
}
/**
 * Extension of Figure to allow changing of individual figure boundaries from user triggered customizations.
 * @hidden Internal class
 */
export declare abstract class CustomizableFigure extends Figure {
    /**
     * Get boundaries that contain figure.
     * @return  Interval<Point>
     */
    abstract getBoundaries(): Interval<Point>;
}
/**
 * Base class for simple figure series that are designed for low amounts of figures.
 * Adds unified API for adding segments and always returns created figures, which allows users
 * to apply individual style upon each figure. Also gives user direct access to any created figures for full customizability.
 * @hidden Internal class
 */
export declare abstract class SimpleFigureSeries<FigureType extends CustomizableFigure, FormatterType extends FigureSeriesFormatter<FigureType, any>, InputType> extends FigureSeries<FigureType, SimpleFigureSeriesCursorPoint<FigureType>> {
    /**
     * Add new figure to the series.
     * @param   dimensions  Dimensions that figure must represent
     * @return              Created figure
     */
    abstract add(dimensions: InputType): FigureType;
    /**
     * Set style for all figures of series.
     * NOTE: Because the function is applied for each figure added, it is not advised to create any objects inside the function.
     * Instead they should be previously cached and later referred to.
     *
     * Example usage:
     *```javascript
     * // Explicit style
     * // The type of 'figure' is equal to type parameter: FigureType
     * SimpleFigureSeries.setDefaultStyle((figure) => ...)
     * ```
     * @param   styler  Styler function that is applied to all existing and newly added segments
     * @return          Object itself
     */
    setDefaultStyle(styler: FigureStyler<FigureType>): this;
    /**
     * Set highlight mode of series.
     * Defines how mouse affects highlighting of figures.
     * @param   highlightMode   HighlightMode
     * @return                  Object itself
     */
    setHighlightMode(highlightMode: HighlightModes): this;
    /**
     * Get highlight mode of series.
     * Defines how mouse affects highlighting of figures.
     * @return                  HighlightMode
     */
    getHighlightMode(): HighlightModes;
    /**
     * Method for customizing contents of ResultTables when pointing at this Series.
     * @param   formatter   Function which builds ResultTable content.
     *                      See definition of [[FigureSeriesFormatter]] for supplied formatting information.
     * @return              Object itself
     */
    setResultTableFormatter(formatter: FormatterType): this;
    /**
     * Get ResultTable Formatter.
     * @return  Function which builds ResultTable content for the Series.
     */
    getResultTableFormatter(): FormatterType;
    /**
     * Solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point): undefined | SimpleFigureSeriesCursorPoint<FigureType>;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: FigureType): undefined | SimpleFigureSeriesCursorPoint<FigureType>;
    /**
     * Clear all data from the series
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * @return Max X value of the series
     */
    getXMax(): number;
    /**
     * @return Min X value of the series
     */
    getXMin(): number;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
}
/**
 * Interface for CursorPoints that point to a Figure of SimpleFigureSeries.
 * Used to pack information about pointed segment to users.
 */
export interface SimpleFigureSeriesCursorPoint<FigureType extends Figure> extends CursorPoint<SimpleFigureSeries<any, any, any>> {
    /**
     * Pointed figure.
     */
    figure: FigureType;
}
/**
 * Interface for a function which builds ResultTable content when pointing at a FigureSeries.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable.
 *                                  Use addRow() method for adding content.
 * @param   series                  Series
 * @param   segment                 Figure that is pointed at. This type is abstract and depends on the type of Series in question.
 *                                  For example, if you are using a BoxSeries this 'figure' will be of type: "BoxFigure".
 * @return                          TableContentBuilder that was supplied
 */
export declare type FigureSeriesFormatter<FigureType extends CustomizableFigure, P extends SimpleFigureSeries<FigureType, any, any>> = <T extends TableContentBuilder>(tableContentBuilder: T, series: P, figure: FigureType) => T;
/**
 * RectSeries, implementation of FigureSeries that simply plots individual 'Rect' shapes
 */
/**
 * Interface for defining dimensions of a Rectangle with position and size.
 */
export interface RectanglePositionAndSize {
    /**
     * X coordinate of rectangles bottom-left corner.
     */
    readonly x: number;
    /**
     * Y coordinate of rectangles bottom-left corner.
     */
    readonly y: number;
    /**
     * Width of rectangle
     */
    readonly width: number;
    /**
     * Height of rectangle
     */
    readonly height: number;
}
/**
 * Interface for defining dimensions of a Rectangle with two locations.
 */
export interface RectangleTwoPoints {
    /**
     * X coordinate of rectangles bottom-left corner.
     */
    readonly x1: number;
    /**
     * Y coordinate of rectangles bottom-left corner.
     */
    readonly y1: number;
    /**
     * X coordinate of rectangles top-right corner.
     */
    readonly x2: number;
    /**
     * Y coordinate of rectangles top-right corner.
     */
    readonly y2: number;
}
/**
 * Class for series visual that is a Rectangle.
 */
export declare class RectangleFigure extends CustomizableFigure {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected readonly _figureBoundsChanged: () => void;
    /**
     * @param   _layer                  Rendering layer
     * @param   scale                   Rendering scale
     * @param   _remove                 Callback that is called when Figure.dispose() is called
     * @param   _restore                Callback that is called when Figure.restore() is called
     * @param   _figureBoundsChanged    Callback that is called when Figure boundaries are changed
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<Figure>, _restore: RestoreHandler<Figure>, _figureBoundsChanged: () => void, _theme: Theme);
    /**
     * Get boundaries that contain figure.
     * @return  Interval<Point>
     */
    getBoundaries(): Interval<Point>;
    /**
     * Set new dimensions for figure.
     * @param   dimensions  Dimensions as either of supported Rectangle interfaces
     * @return              Object itself
     * @sideEffect          Owning series will be informed of change in size, possible initiating scrolling.
     */
    setDimensions(dimensions: RectanglePositionAndSize | RectangleTwoPoints): this;
    /**
     * Get current dimensions of figure as interface 'RectanglePositionAndSize'.
     * @return  RectanglePositionAndSize
     */
    getDimensionsPositionAndSize(): RectanglePositionAndSize;
    /**
     * Get current dimensions of figure as interface 'RectangleTwoPoints'.
     * @return  RectangleTwoPoints
     */
    getDimensionsTwoPoints(): RectangleTwoPoints;
    /**
     * Set fill style of Rectangle.
     * @param   fillStyle   FillStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Rectangle.
     * @return              FillStyle object
     */
    getFillStyle(): FillStyle;
    /**
     * Set fill style of Rectangle when highlighted.
     * @param   fillStyle   FillStyle object or mutator to modify existing one or undefined for auto assignment
     * @return              Object itself
     */
    setFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get fill style of Rectangle when highlighted.
     * @return              FillStyle object or undefined for auto assignment
     */
    getFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set stroke style of Rectangle.
     * @param   value       LineStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Rectangle.
     * @return              LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Rectangle when highlighted.
     * @param   value   LineStyle object or mutator to modify existing one or undefined for auto assignment
     * @return              Object itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of Rectangle when highlighted.
     * @return              LineStyle object or undefined for auto assignment
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * Return some dominant fill style of the figure
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
}
/**
 * Series for that lets user draw Rectangles with independent figures.
 */
export declare class RectangleSeries extends SimpleFigureSeries<RectangleFigure, FigureSeriesFormatter<RectangleFigure, RectangleSeries>, RectanglePositionAndSize | RectangleTwoPoints> {
    /**
     * Add new figure to the series.
     * @param   dimensions  Dimensions that figure must represent
     * @return              Created figure
     */
    add(dimensions: RectanglePositionAndSize | RectangleTwoPoints): RectangleFigure;
}
/**
 * LineSeries, abstract implementation of FigureSeries that simply plots individual 'Line' shapes
 */
/**
 * Data structure that defines dimensions of a line-segment
 */
export interface SegmentDimensions {
    /**
     * X value of start location
     */
    startX: number;
    /**
     * Y value of start location
     */
    startY: number;
    /**
     * X value of end location
     */
    endX: number;
    /**
     * Y value of end location
     */
    endY: number;
}
/**
 * Class for series visual that is a Segment.
 */
export declare class SegmentFigure extends CustomizableFigure {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    protected readonly _figureBoundsChanged: () => void;
    /**
     * Dimensions of figure.
     */
    protected dimensions: SegmentDimensions;
    /**
     * @param   _layer                  Rendering layer
     * @param   scale                   Rendering scale
     * @param   _remove                 Callback that is called when Figure.dispose() is called
     * @param   _restore                Callback that is called when Figure.restore() is called
     * @param   _figureBoundsChanged    Callback that is called when Figure boundaries are changed
     * @param   _theme                  Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<Figure>, _restore: RestoreHandler<Figure>, _figureBoundsChanged: () => void, _theme: Theme);
    /**
     * Get boundaries that contain figure.
     * @return  Interval<Point>
     */
    getBoundaries(): Interval<Point>;
    /**
     * Set new dimensions for figure.
     * @param   dimensions  Dimensions
     * @return              Object itself
     * @sideEffect          Owning series will be informed of change in size, possible initiating scrolling.
     */
    setDimensions(dimensions: SegmentDimensions): this;
    /**
     * Get current dimensions of figure.
     * @return  Dimensions
     */
    getDimensions(): SegmentDimensions;
    /**
     * Set stroke style of Segment.
     * @param   value       FillStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Segment.
     * @return              FillStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Segment when highlighted.
     * @param   value   FillStyle object or mutator to modify existing one or undefined for auto assignment
     * @return              Object itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of Segment when highlighted.
     * @return              FillStyle object or undefined for auto assignment
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * Return some dominant fill style of the figure
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
}
/**
 * Series for that lets user draw Segments with independent figures.
 */
export declare class SegmentSeries extends SimpleFigureSeries<SegmentFigure, FigureSeriesFormatter<SegmentFigure, SegmentSeries>, SegmentDimensions> {
    /**
     * Add new figure to the series.
     * @param   dimensions  Dimensions that figure must represent
     * @return              Created figure
     */
    add(dimensions: SegmentDimensions): SegmentFigure;
}
/**
 * IntensityGridSeries for visualization of magnitude in two dimensions.
 *
 * IntensityGridSeries are created with [[ChartXY.addHeatmapSeries]] with IntensitySeriesType of [[IntensitySeriesTypes.Grid]]
 */
export declare class IntensityGridSeries extends IntensitySeries {
    /**
     *  The name of a series
     */
    protected _name: string;
}
/**
 * IntensityMeshSeries for visualization of magnitude in two dimensions.
 *
 * Mesh allows to edit the geometry of the displayed intensity series.
 *
 * IntensityMeshSeries are created with [[ChartXY.addHeatmapSeries]] with IntensitySeriesType of [[IntensitySeriesTypes.Mesh]]
 */
export declare class IntensityMeshSeries extends IntensitySeries {
    /**
     *  The name of a series
     */
    protected _name: string;
    /**
     * Treat the data of the matrix as any of the *Point*-based type of points.
     * *Point*-based data is represented in format { x: number, y: number } to modify the geometry only.
     *
     * Invalidates only the **geometry** coordinates without update the intensity or color data,
     * providing significantly faster rendering of dynamically changed geometry.
     *
     * @param vertices Matrix of new vertices.
     * The resolution of the IntensityMesh should be valid.
     * @param range    Optional configuration object to specify the range of the grid to be invalidated.
     * @returns   Series itself for fluent interface.
     */
    invalidateGeometryOnly(vertices: Matrix<Point>, range?: GridRangeOptions): this;
    /**
     * Treat the data of the matrix as any of the *Point*-based type of points.
     * *Point*-based data is represented in format { x: number, y: number } to modify the geometry only.
     *
     * Invalidates only the **geometry** coordinates without update the intensity or color data,
     * providing significantly faster rendering of dynamically changed geometry.
     *
     * @param callback Callback function to map through the input to modify the matrix geometry.
     * The resolution of the IntensityMesh should be valid.
     * @param range    Optional configuration object to specify the range of the grid to be invalidated.
     * @returns   Series itself for fluent interface.
     */
    invalidateGeometryOnly(vertices: UpdateGeometryCallback, range?: GridRangeOptions): this;
}
/**
 * The abstract class implements the common logic for Intensity Series.
 * The series of this type does not have any data-cleaning.
 * The series contains the following elements:
 * - Intensity shape with stylable and switchable fill styles for intensity points.
 * - Contour lines to highlight the intensity areas (or zones).
 * - Contour labels attached to contours to show the intensity values in the areas (or zones).
 * @hidden
 */
export declare abstract class IntensitySeries extends SeriesXY<Intensity> {
    /**
     * @param layer                 Rendering layer for the entire series.
     * @param _chart                Cartesian chart surface.
     * @param _removeFromChart      Injected method to remove the created series from Chart that owns it.
     * @param axisX                 X-axis to which the series has to be attached.
     * @param axisY                 Y-axis to which the series has to be attached.
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param options               Major mandatory properties of Intensity.
     * @param _dataPattern          Data-Pattern for enabling case-specific optimizations
     * @hidden
     */
    constructor(_chart: ChartXY, _removeFromChart: RemoveHandler<IntensitySeries>, _restoreFromChart: RestoreHandler<IntensitySeries>, layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, options: IntensityOptions, _theme: Theme);
    /**
     * Reset the existing intensity shape and apply new settings.
     * The following method removes all the existing data.
     * The shape would be reset to the default state:
     * - Old Geometry transformations do not valid. The Intensity is a uniform grid.
     * - Old IntensityValues and/or ColorValues do not valid and exist anymore.
     * @param options   Major mandotary properties of Intensity.
     * @returns   Series itself for fluent interface.
     */
    reset(options: IntensityOptions): this;
    /**
     * Set fill style of Intensity Heatmap Series.
     * * SolidFill: apply single solid color.
     * * IndividualPointFill: apply individual color per data-point.
     * * PalettedFill: apply palette using *LUT* lookup table of colors.
     * * emptyFill: no color, empty rendering.
     * @param   fillstyle  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns            Series itself for fluent interface.
     */
    setFillStyle(fillstyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Append new rows of data to the end of the Intensity.
     * Update color data of the rows.
     * Example:
     * ```ts
     * // scroll two rows and update colors
     * heatmap.addRow(2, 'color', [
     *  [ColorHEX( '0xFF0000' ), ColorHEX( '0x00FF00' )],
     *  [ColorHEX( '0xFF00FF' ), ColorHEX( '0x00FF00' )]
     * ])
     * ```
     */
    addRow(rows: number, type: 'color', colors: Matrix<Color>): this;
    /**
     * Append new rows of data to the end of the Intensity.
     * Update intensity data of new rows.
     * Example:
     * ```ts
     * // scroll two rows and update values
     * heatmap.addColumn(2, 'value', [
     *  [10, 20],
     *  [50, 68]
     * ])
     * ```
     */
    addRow(rows: number, type: 'value', values: Matrix<number>): this;
    /**
     * Append new columns of data to the end of the Intensity.
     * Update color data of new columns.
     * Example:
     * ```ts
     * // scroll two columns and update colors
     * heatmap.addColumn(2, 'color', [
     *  [ColorHEX( '0xFF0000' ), ColorHEX( '0x00FF00' )],
     *  [ColorHEX( '0xFF00FF' ), ColorHEX( '0x00FF00' )]
     * ])
     * ```
     */
    addColumn(columns: number, type: 'color', colors: Matrix<Color>): this;
    /**
     * Append new columns of data to the end of the Intensity.
     * Update intensity data of new columns.
     * Example:
     * ```ts
     * // scroll two columns and update values
     * heatmap.addColumn(2, 'value', [
     *  [10, 20],
     *  [50, 68]
     * ])
     * ```
     */
    addColumn(columns: number, type: 'value', values: Matrix<number>): this;
    /**
     * Treat the data of the matrix as *ColorValue*-based type of points.
     * *ColorValue*-based data is represented in format { ...color: Color } for *IndividualPointFill* style.
     *
     * Invalidates only the **color** without update the geometry data,
     * providing significantly faster rendering of dynamically changed colors.
     *
     * @param colors Matrix of new colors.
     * The resolution of the IntensityShape should be valid.
     * @param range  Optional configuration object to specify the range of the grid to be invalidated.
     * @returns      Series itself for fluent interface.
     */
    invalidateColorsOnly(colors: Matrix<Color>, range?: GridRangeOptions): this;
    /**
     * Treat the data of the matrix as *ColorValue*-based type of points.
     * *ColorValue*-based date is represented in format { ...color: Color } for *IndividualPointFill* style.
     *
     * Invalidates only the **color** without update the geometry data,
     * providing significantly faster rendering of dynamically changed colors.
     *
     * @param callback Callback function to map through the input to modify the matrix colors.
     * The resolution of the IntensityShape should be valid.
     * @param range    Optional configuration object to specify the range of the grid to be invalidated.
     * @returns        Series itself for fluent interface.
     */
    invalidateColorsOnly(callback: UpdateColorCallback, range?: GridRangeOptions): this;
    /**
     * Treat the data of the matrix as *IntensityValue*-based type of points.
     * *IntensityValue*-based data is represented in format { ...intensity: number } for *PalettedFill* style.
     *
     * Invalidates only the **intensity** values without update the geometry data,
     * providing significantly faster rendering of dynamically changed intensity.
     *
     * @param values Matrix of new intensity values.
     * @param range  Optional configuration object to specify the range of the grid to be invalidated.
     * @returns      Series itself for fluent interface.
     */
    invalidateValuesOnly(values: Matrix<number>, range?: GridRangeOptions): this;
    /**
    * Treat the data of the matrix as *IntensityValue*-based type of points.
    * *IntensityValue*-based data is represented in format { ...intensity: number } for *PalettedFill* style.
    *
    * Invalidates only the **intensity** values without update the geometry data,
    * providing significantly faster rendering of dynamically changed intensity.
    *
    * @param callback Callback function to map through the input to modify the matrix of intensity values.
    * The resolution of the IntensityShape should be valid.
    * @param range  Optional configuration object to specify the range of the grid to be invalidated.
    * @returns      Series itself for fluent interface.
    */
    invalidateValuesOnly(callback: UpdateValueCallback, range?: GridRangeOptions): this;
    solveNearestFromScreen(location: Point): undefined | CursorPoint;
    solveNearestFromSegment(location: Point, segment: Intensity): undefined | CursorPoint;
    /**
     * @return Max X value of the series
     */
    getXMax(): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin(): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number | undefined;
}
export declare type IntensitySeriesTypes = typeof IntensitySeriesTypes[keyof typeof IntensitySeriesTypes];
export declare const IntensitySeriesTypes: {
    /**
     * IntensityGridSeries for visualization of magnitude in two dimensions.
     */
    Grid: typeof IntensityGridSeries;
    /**
     * IntensityMeshSeries for visualization of magnitude in two dimensions.
     *
     * Mesh allows to edit the geometry of the displayed intensity series.
     */
    Mesh: typeof IntensityMeshSeries;
};
/**
 * Implementation of *SeriesXY* for visualizing a collection of progressive *AreaPoints*
 * (which consist of one *X*-value, and two *Y*-values) by filling the area between the points two *Y*-values.
 *
 * Composed of the areas *fill* and *border*, both of which have two possible styles:
 * - **High**
 * - **Low**. This is used for *AreaPoints* whose *high*-value is **lower** than the *low*-value.
 *
 * *AreaRangeSeries* are created with [[ChartXY.addAreaRangeSeries]].
 */
export declare class AreaRangeSeries extends RangeSeries implements ObservableXYData<AreaPoint>, DataInputHighLow {
    /**
     * Add point or array of points to the dataset.
     * @param   points   Single new point or an array of new points.
     * @returns          Series itself for fluent interface.
     */
    add(data: AreaPoint | AreaPoint[]): this;
    /**
    * Add two individual Arrays, one for high values, and another for low values.
    * @param   arrayHigh  Array of High values.
    * @param   arrayLow   Array of Low values. Length should be equal to length of *array1*.
    * @return             Object itself for fluent interface.
    */
    addArraysHighLow(arrayHigh: number[], arrayLow: number[], step?: number, start?: number): this;
    /**
     * Set fill style of high area of the Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaRangeSeries.setHighFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaRangeSeries.setHighFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaRangeSeries.setHighFillStyle(transparentFill)
     * ```
     * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns      Series itself for fluent interface.
     */
    setHighFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set fill style of low area of the Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaRangeSeries.setLowFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaRangeSeries.setLowFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaRangeSeries.setLowFillStyle(transparentFill)
     * ```
     * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns      Series itself for fluent interface.
     */
    setLowFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set fill style of high area of the Series when it is highlighted.
     *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * AreaRangeSeries.setHighFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaRangeSeries.setHighFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaRangeSeries.setHighFillStyleHighlight(transparentFill)
     * // Automatic
     * AreaRangeSeries.setHighFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setHighFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
    * Set fill style of low are of the Series when it is highlighted.
    *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * AreaRangeSeries.setLowFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaRangeSeries.setLowFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaRangeSeries.setLowFillStyleHighlight(transparentFill)
     * // Automatic
     * AreaRangeSeries.setLowFillStyleHighlight(undefined)
     * ```
    * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
    * @returns      Series itself for fluent interface.
    */
    setLowFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Set style of the Series high stroke.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaRangeSeries.setHighStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaRangeSeries.setHighStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaRangeSeries.setHighStrokeStyle(transparentLine)
     * ```
     * @param value  Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns      Series itself for fluent interface.
     */
    setHighStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
    * Set style of the Series low stroke.
    *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaRangeSeries.setLowStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaRangeSeries.setLowStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaRangeSeries.setLowStrokeStyle(transparentLine)
     * ```
    * @param value  Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
    * @returns      Series itself for fluent interface.
    */
    setLowStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Set style of the Series high stroke when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaRangeSeries.setHighStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaRangeSeries.setHighStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaRangeSeries.setHighStrokeStyleHighlight(transparentLine)
     * // Automatic
     * AreaRangeSeries.setHighStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setHighStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Set style of the Series low stroke when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaRangeSeries.setLowStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaRangeSeries.setLowStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaRangeSeries.setLowStrokeStyleHighlight(transparentLine)
     * // Automatic
     * AreaRangeSeries.setLowStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setLowStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get a current fill style used for the coloring of the high area in the series.
     * @returns      Current fill style used for the coloring of the high area in the series.
     */
    getHighFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of the high area by series.
     * @returns     Current highlight fill style used for the coloring of the high area by series.
     */
    getHighFillStyleHighlight(): FillStyle;
    /**
     * Get a current fill style used for the coloring of the low area in the series.
     * @returns      Current fill style used for the coloring of the low area in the series.
     */
    getLowFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of the low area by series.
     * @returns     Current highlight fill style used for the coloring of the low area by series.
     */
    getLowFillStyleHighlight(): FillStyle;
    /**
     * Get a current line style of a stroke used for the coloring of the high border in the series.
     * @returns     Current line style of a stroke used for the coloring of the high border.
     */
    getHighStrokeStyle(): LineStyle;
    /**
     * Get a current line style of a border used for the coloring of the high border by series.
     * @returns     Current line style of a border used for the coloring of the high border by series.
     */
    getHighStrokeStyleHighlight(): LineStyle;
    /**
     * Get a current line style of a border used for the coloring of the low border in the series.
     * @returns     Current line style of a border used for the coloring of the low border.
     */
    getLowStrokeStyle(): LineStyle;
    /**
     * Get a current line style of a border used for the coloring of of the low border by series.
     * @returns     Current line style of a border used for the coloring of the low border by series.
     */
    getLowStrokeStyleHighlight(): LineStyle;
}
/**
 * The abstact class implements the most part of general logic for mountains.
 * The series contains the following elements:
 * - Junction area with stylable and switchable fill styles for High and Low values.
 * - Line with points for High values border.
 * - Line with points for Low values border.
 * @hidden Internal class
 */
export declare abstract class RangeSeries extends SeriesXY<Junction> {
    /**
     * Clear all points and segments from the dataset.
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * Get amount of points that series currently has.
     * @return  Number of points
     */
    getPointAmount(): number;
    /**
     * Set if cursor interpolates solved data-points along series by default.
     * @param   state   Boolean flag
     * @returns         Object itself for fluent interface
     */
    setCursorInterpolationEnabled(state: boolean): this;
    /**
     * Get if cursor interpolates solved data-points along series by default.
     * @returns         Boolean flag
     */
    getCursorInterpolationEnabled(): boolean;
    /**
     * Set amount of points that should be kept around at all times (data-cleaning won't touch them).
     * NOTE: The actual data starts if there is at least 1 full segment (>8000 points normally).
     * @param   maxPointCount  Guaranteed amount of visible points. If undefined or 0 is passed, data-cleaning will be disabled.
     * @returns                Object itself
     */
    setMaxPointCount(maxPointCount?: number): this;
    /**
     * Get amount of points that series should keep around at all times (data-cleaning won't touch them).
     * @return  Number of points, or undefined if data-cleaning is disabled
     */
    getMaxPointCount(): number | undefined;
    /**
     * Method for customizing contents of ResultTables when pointing at this Series.
     * @param   formatter   Function which builds ResultTable content.
     *                      See definition of [[RangeSeriesFormatter]] for supplied formatting information.
     * @return              Object itself
     */
    setResultTableFormatter(formatter: RangeSeriesFormatter): this;
    /**
     * Get ResultTable Formatter.
     * @return  Function which builds ResultTable content for RangeSeries.
     */
    getResultTableFormatter(): RangeSeriesFormatter;
    /**
     * @return Max X value of the series
     */
    getXMax(): number | undefined;
    /**
     * @return Min X value of the series
     */
    getXMin(): number | undefined;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number | undefined;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number | undefined;
    /**
     * Tell the owning chart to remove this series.
     * @return  Object itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @return  Object itself.
     */
    restore(): this;
    /**
     * Method that solves the nearest datapoint on mountain to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point, interpolate?: boolean): undefined | CursorPoint;
    /**
     * Method that solves the nearest datapoint on mountain to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: Junction, interpolate?: boolean): undefined | CursorPoint;
}
/**
 * Interface for a function which builds ResultTable content when pointing at a RangeSeries.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable.
 *                                  Use addRow() method for adding content.
 * @param series                    RangeSeries.
 * @param position                  Position on the axis.
 * @param high                      High value on the axis.
 * @param low                       Low value on the axis.
 * @return                          TableContentBuilder that was supplied
 */
export declare type RangeSeriesFormatter = <T extends TableContentBuilder>(tableContentBuilder: T, series: RangeSeries, position: number, high: number, low: number) => T;
/**
 * Enum for selecting step behavior for [[StepSeries]].
 *
 * This must be specified when the [[StepSeries]] is created, and can't be changed afterwards.
 */
export declare enum StepOptions {
    /**
     * The y-value changes before the x-value.
     */
    before = 0,
    /**
     * The y-value changes at the midpoint of each pair of adjacent x-values.
     */
    middle = 0.5,
    /**
     * The y-value changes after the x-value.
     */
    after = 1
}
/**
 * Class for visualization of polynom function.
 */
export declare class SplineSeries extends PointLineSeries {
    /**
     * Solves the nearest datapoint of a given coordinate on screen
     * @param   location    Location on screen
     * @param   interpolate Should interpolate? If omitted, defaults to setting of series
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point, interpolate?: boolean): undefined | CursorPoint;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve data-point from
     * @param   interpolate Should interpolate? If omitted, defaults to setting of series
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: LineSet | PointSet, interpolate?: boolean): undefined | CursorPoint;
    /**
     * Set amount of points that should be kept around at all times (data-cleaning won't touch them).
     * NOTE: The actual data cleaning can only be started if there is at least 1 full segment (about 8000 points).
     * @param   maxPointCount  Guaranteed amount of visible points. If undefined or 0 is passed, data-cleaning will be disabled.
     * @returns                 Object itself
     */
    setMaxPointCount(maxPointCount: number | undefined): this;
}
/**
 * Step Series that plots incoming data-points using Step preprocessing function.
 */
export declare class StepSeries extends PointLineSeries {
    private _step;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _dataPattern          Data-Pattern for enabling case-specific optimizations
     * @param _pointShape           Shape for points of PointSeries
     * @param _step                 Step function, which defines how series will be visualized.
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _pointShape: PointShape, _step: StepOptions, _theme: Theme);
}
export {};
export {};
export {};
export {};
/**
 * @hidden
 */
export declare const _precomputed: {
    doubles: {
        step: number;
        points: string[][];
    };
    naf: {
        wnd: number;
        points: string[][];
    };
};
/**
 * Information about Vertex/Index buffers for rendering cube sets.
 */
export declare const CUBE_BUFFERS: {
    /**
     * Vertex amount per each Cube.
     */
    VERTICES: number;
    /**
     * Attribute amount per each Vertex.
     */
    ATTRIBUTES: number;
    /**
     * Index amount per each Cube.
     */
    INDICES: any;
    /**
     * Max object amount that can be rendered with a single Float32 Index Buffer.
     */
    MAX_OBJECT_COUNT: number;
    /**
     * Max size of Vertex buffer.
     */
    MAX_VERTEX_BUFFER_SIZE: number;
};
/**
 * Method computes Vertex and Index Buffers for a set of 3D Lines.
 * @param   points          Input points.
 * @param   thickness       Line thickness.
 * @param   scale           Rendering scale.
 * @param   isFatVertices   Should vertices be computed as "fat" or not. "Fat" = including thickness.
 *                          The amount of attributes per vertex will depend on this flag.
 * @param   prevIndices     Optional index buffer of points to be appended before the 'points'
 * @param   prevPoint       Optional previous point coordinates. Lines will be connected to this
 * @return                  [ Vertices, Indices ]
 *                          Vertices only includes new Points, while Indices contain possible 'prevIndices', too.
 *
 *                          Vertex attributes in format: [
 *                              X, Y, Z,
 *                              Normals X, Y, Z,
 *                              Thickness Direction X, Y, Z
 *                          ]
 */
export declare const _calculate3DLineSets: (points: Point3D[], thickness: number, scale: Vec3<UnitScale>, isFatVertices: boolean, prevIndices?: Uint16Array | undefined, prevPoint?: Point3D | undefined) => [number[], Uint16Array];
/**
 * Information about Vertex/Index buffers for rendering 3D line sets.
 */
export declare const LINE_BUFFERS_3D: {
    /**
     * Vertex amount for Line set with n points.
     */
    VERTICES: (n: number) => number;
    /**
     * Attribute amount for each Line vertex.
     */
    ATTRIBUTES: number;
    /**
     * Index amount for Line set with n points.
     */
    INDICES: (n: number) => number;
    /**
     * Max object amount that can be rendered with a single Float32 Index Buffer.
     */
    MAX_OBJECT_COUNT: number;
    /**
     * Max size of Vertex buffer.
     */
    MAX_VERTEX_BUFFER_SIZE: number;
};
/**
 * Method computes Vertex and Index Buffers for a set of Spheres.
 * @param   points          Input points.
 * @param   pointSize       Size of points in world units.
 * @param   scale           Rendering scale.
 * @param   isFatVertices   Should vertices be computed as "fat" or not. "Fat" = including thickness.
 *                          The amount of attributes per vertex will depend on this flag.
 * @param   prevIndices     Optional index buffer of points to be appended before the 'points'
 * @return                  [ Vertices, Indices ]
 *                          Vertices only includes new Points, while Indices contain possible 'prevIndices', too.
 *
 *                          Vertex attributes in format: [
 *                              X, Y, Z,
 *                              Normals X, Y, Z,
 *                              Thickness Direction X, Y, Z
 *                          ]
 */
export declare const _calculateSphereSet: (points: Point3D[], pointSize: number, scale: Vec3<UnitScale>, isFatVertices: boolean, prevIndices?: Uint16Array | undefined) => [number[], Uint16Array];
/**
 * Information about Vertex/Index buffers for rendering sphere sets.
 */
export declare const SPHERE_BUFFERS: {
    /**
     * Vertex amount per each Sphere.
     */
    VERTICES: number;
    /**
     * Attribute amount per each Vertex.
     */
    ATTRIBUTES: number;
    /**
     * Index amount per each Sphere.
     */
    INDICES: number;
    /**
     * Max object amount that can be rendered with a single Float32 Index Buffer.
     */
    MAX_OBJECT_COUNT: number;
    /**
     * Max size of Vertex buffer.
     */
    MAX_VERTEX_BUFFER_SIZE: number;
};
export {};
/**
 * The types of events of simple polygon vertices for polygon partitioning.
 */
export declare type VertexType = 'START' | 'END' | 'REGULAR' | 'SPLIT' | 'MERGE';
/**
 * A generic container for storing the information about diagonal, which joins two simple polygon vertices.
 * The diagonal cuts off y-monotone polygon ear from a simple polygon.
 * @property    begin: The beginning of a diagonal represented by a doubly-connected node, or simple polygon vertex.
 * @property    end  : The end of a diagonal represented by a doubly-connected node, or simple polygon vertex.
 */
export interface Diag {
}
/**
 * A generic container for storing references to the specific polygon vertices in the original list of points and assign tag to the line.
 * @property    begin: Reference index to vertex index in the original list of points, which is the beginning of polygon edge.
 * @property    end  : Reference index to vertex index in the original list of points which is the end of polygon edge.
 * @property    tag  : Reference index or the order in the list of polygon edges.
 */
export interface Edge {
}
/**
 * A generic container for storing helper references to the specific polygon edge and doubly-connected node (Simple Polygon vertex).
 * @property    segment: Directly on a left polygon edge, to which the Simple Polygon vertex belongs to.
 * @property    vertex : Reference index to Simple Polygon vertex in a Priority Queue.
 */
export interface EventEdge {
}
/**
 * Generic container for storing information about Simple Polygon vertex as doubly-connected node.
 * @property    index:   Reference to the current vertex index in the original list of points.
 * @property    prev :   Reference to the previous vertex index in the original list of points (previous point in a polyline).
 * @property    next :   Reference to the next vertex index in the original list of points (next point in a polyline).
 * @property    type :   Type of a turn vertex, which is used as an event to process the polygon partitioning into y-monotones.
 */
export interface SimpleVertex {
}
/**
 * A generic container for storing a helper edges for a specific doubly-connected node (Simple Polygon vertex).
 * @property    edge :  Reference to the directly on a left line segment in the list of polygon edges.
 */
export interface Helper extends EventEdge {
}
/**
 * A generic container for storing the information about Monotone Polygon vertex.
 * @property    vertex: Vector in cartesian coordinates space.
 * @property    index : Reference index to current vertex in the original list of points.
 * @property    chain : Reference to which chain the vertex belongs to. [-1: Lower chain, 0: Begin or End of chains, 1: Upper chain]
 */
export interface MonotoneVertex {
}
export {};
/**
 * File contains interfaces and builder for CheckBox
 */
/**
 * Interface for 'CheckBox'.
 */
export interface UICheckBox<BackgroundType extends UIBackground = UIBackground, PictureOffType extends UIButtonPicture = UIButtonPicture, PictureOnType extends UIButtonPicture = UIButtonPicture> extends UIPartWithBackground<BackgroundType>, CustomizableText, StylableButton, Switchable {
}
/**
 * Interface for 'CheckBox'-builder.
 */
export interface UICheckBoxBuilder<BackgroundType extends UIBackground = UIBackground, PictureOffType extends UIButtonPicture = UIButtonPicture, PictureOnType extends UIButtonPicture = UIButtonPicture> extends UIElementBuilder<UICheckBox<BackgroundType, PictureOffType, PictureOnType>> {
    /**
     * Make new CheckBoxBuilder with different background.
     * @param   newBackground   Constructor for desired Background. See [[UIBackgrounds]] for a collection of options.
     */
    setBackground<NewBackgroundType extends BackgroundType & InternalBackground>(newBackground: BackgroundConstructor<NewBackgroundType>): UICheckBoxBuilder<NewBackgroundType, PictureOffType, PictureOnType>;
    /**
     * Make new CheckBoxBuilder with different Picture OFF.
     * @param   newPictureOff   Constructor for desired Picture OFF. See [[UIButtonPictures]] for a collection of options.
     * @return                  New CheckBoxBuilder with different Picture OFF.
     */
    setPictureOff<NewPictureOffType extends PictureOffType>(newPictureOff: PrimitiveUiConstructor<NewPictureOffType>): UICheckBoxBuilder<BackgroundType, NewPictureOffType, PictureOnType>;
    /**
     * Make new CheckBoxBuilder with different Picture ON.
     * @param   newPictureOff   Constructor for desired Picture ON. See [[UIButtonPictures]] for a collection of options.
     * @return                  New CheckBoxBuilder with different Picture ON.
     */
    setPictureOn<NewPictureOnType extends PictureOnType>(newPictureOn: PrimitiveUiConstructor<NewPictureOnType>): UICheckBoxBuilder<BackgroundType, PictureOffType, NewPictureOnType>;
}
/**
 * Builder for 'CheckBox'.
 * @hidden
 */
export declare const _checkBoxBuilder: UICheckBoxBuilder<UIBackground, UIButtonPicture, UIButtonPicture>;
/**
 * File contains interfaces and builder for TextBox
 */
/**
 * Interface for 'TextBox'.
 */
export interface UITextBox<BackgroundType extends UIBackground = UIBackground> extends UIPartWithBackground<BackgroundType>, CustomizableText {
}
/**
 * Interface for 'TextBox'-builder.
 */
export interface UITextBoxBuilder<BackgroundType extends UIBackground = UIBackground> extends UIElementBuilder<UITextBox<BackgroundType>> {
    /**
     * Make new TextBoxBuilder with different background
     * @param   newBackground   Constructor for desired Background. See [[UIBackgrounds]] for a collection of options.
     */
    setBackground<NewBackgroundType extends BackgroundType & InternalBackground>(newBackground: BackgroundConstructor<NewBackgroundType>): UITextBoxBuilder<NewBackgroundType>;
}
/**
 * Interface for 'PointableTextBox'.
 */
export interface PointableTextBox<BackgroundType extends UIBackground = UIBackground> extends UITextBox<BackgroundType>, Pointable {
}
/**
 * Interface for 'PointableTextBox'-builder.
 */
export interface UIPointableTextBoxBuilder<BackgroundType extends PointableBackground = PointableBackground> extends UIElementBuilder<PointableTextBox<BackgroundType>> {
    /**
     * Make new PointableTextBoxBuilder with different background.
     * @param   newBackground   Constructor for desired PointableBackground. Currently only UIBackgrounds.Arrow is available.
     */
    setBackground<NewBackgroundType extends BackgroundType & InternalBackground>(newBackground: PointableBackgroundConstructor<NewBackgroundType>): UIPointableTextBoxBuilder<NewBackgroundType>;
}
/**
 * File contains interfaces and classes for primitive UI buttons
 */
/**
 * Indicates object whose size can be fitted into an arbitrary Vec2
 * @hidden
 */
export interface Fittable {
    /**
     * Fit object to bounding box.
     * @param   bounds  Bounds in pixels
     * @return          Object itself
     */
    fitTo(bounds: Point): this;
}
/**
 * Type requirement for Pictures of Buttons.
 */
export interface UIButtonPicture extends BorderedPicture, Fittable {
}
/**
 * Switchable UI element with separate visuals for (ON/OFF) states.
 * @hidden Internal class
 */
export declare class Button<PictureOff extends UIButtonPicture = UIButtonPicture, PictureOn extends UIButtonPicture = UIButtonPicture> extends InternalUIElement implements Highlightable {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    /**
     * @param _layer                 Layer of drawing engine
     * @param scale                 Drawing scale of UiElement
     * @param _picOffConstructor     Constructor for OFF picture
     * @param _picOnConstructor      Constructor for ON picture
     * @param remove                Injected remove method from parent.
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _picOffConstructor: PrimitiveUiConstructor<PictureOff>, _picOnConstructor: PrimitiveUiConstructor<PictureOn>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Set state of switchable object
     * @param isOn  State as boolean flag
     * @returns     Object itself for fluent interface
     */
    setOn(isOn: boolean): this;
    /**
     * @return State as boolean flag
     */
    getOn: () => boolean;
    /**
     * Set fill style of checkbox when state is OFF
     * @param   value   FillStyle object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setOffFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of checkbox when state is OFF
     * @return          FillStyle object
     */
    getOffFillStyle(): FillStyle;
    /**
     * Set highlighted fill style of checkbox when state is OFF
     * @param   value   FillStyle object or mutator to modify existing one or undefined for auto assignment
     * @return          Object itself for fluent interface
     */
    setOffFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get highlighted fill style of checkbox when state is OFF
     * @return          FillStyle object or undefined for auto assignment
     */
    getOffFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set style of checkbox when state is OFF
     * @param   value   LineStyle object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setOffStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of checkbox when state is OFF
     * @return           LineStyle object
     */
    getOffStrokeStyle(): LineStyle;
    /**
     * Set size of checkbox when state is OFF.
     * @param   size    Size to fit picture as Point or pixel for squared size
     */
    setOffSize(size: Point | pixel): this;
    /**
     * Get size of checkbox in pixels when state is OFF
     */
    getOffSize(): Point;
    /**
     * Set fill style of checkbox when state is ON
     * @param   value   FillStyle object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setOnFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of checkbox when state is ON
     * @return          FillStyle object
     */
    getOnFillStyle(): FillStyle;
    /**
     * Set highlighted fill style of checkbox when state is ON
     * @param   value   FillStyle object or mutator to modify existing one or undefined for auto assignment
     * @return          Object itself for fluent interface
     */
    setOnFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get highlighted fill style of checkbox when state is ON
     * @return          FillStyle object or undefined for auto assignment
     */
    getOnFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set style of checkbox when state is ON
     * @param   value   LineStyle object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setOnStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of checkbox when state is ON
     * @return           LineStyle object
     */
    getOnStrokeStyle(): LineStyle;
    /**
     * Set size of checkbox when state is ON.
     * @param   size    Size to fit picture to as Point or pixel for squared size
     */
    setOnSize(size: Point | pixel): this;
    /**
     * Get size of checkbox in pixels when state is ON
     */
    getOnSize(): Point;
    /**
     * Restore object if it was previously disposed.
     * @returns Object itself itself for fluent interface
     */
    restore(): this;
    /**
     * Dispose object, ceasing its operation while keeping the object intact until call of 'restore'.
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * @return True if all sub elements are disposed, false if not.
     */
    isDisposed(): boolean;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return     Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
    * @return Flag is highlighted
    */
    getHighlighted(): boolean;
    /**
    * Set highlighted state
    * @param isHighlighted Highlight state of the object
    * @returns             Object itself for fluent interface
    */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * Interface for Button-builder.
 * @hidden
 */
export interface ButtonBuilder<PictureOffType extends UIButtonPicture = UIButtonPicture, PictureOnType extends UIButtonPicture = UIButtonPicture> extends UIElementBuilder<Button<PictureOffType, PictureOnType>> {
    /**
     * Make new ButtonBuilder with different Picture OFF
     */
    setPictureOff<NewPictureOffType extends PictureOffType>(newPictureOff: PrimitiveUiConstructor<NewPictureOffType>): ButtonBuilder<NewPictureOffType, PictureOnType>;
    /**
     * Make new ButtonBuilder with different Picture ON
     */
    setPictureOn<NewPictureOnType extends PictureOnType>(newPictureOn: PrimitiveUiConstructor<NewPictureOnType>): ButtonBuilder<PictureOffType, NewPictureOnType>;
}
/**
 * File contains class and builder for LegendBox and relative interfaces.
 */
/**
 * Interface for LegendBoxEntry.
 *
 * Implementations of LegendBoxEntry include:
 * - [[UICheckBox]]
 */
export interface LegendBoxEntry extends UIPart, CustomizableText, StylableBackground, StylableButton, Switchable {
}
/**
 * Object which can be attached to a LegendBox
 * @hidden
 */
export interface Attachable {
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick: boolean): this;
}
/**
 * Common interface for LegendBoxPanel and UILegendBox.
 * @hidden
 */
export interface LegendBox<TitleType extends UITextBox, DefaultEntryType extends LegendBoxEntry> {
    /**
     * Add a dynamic value to LegendBox, creating a group and entries for it depending on type of value.
     * Supports series, charts and dashboards.
     * @param value             Series, Chart or Dashboard
     * @param disposeOnClick    Optional flag that determines whether clicking the LegendBoxEntry will dispose the Attached objects
     * @param tag               Optional group name
     * @param builder           Optional builder for custom entry
     * @return                  Entry attached to a Series or Collection of Entries in case of Chart or Dashboard
     */
    add: <EntryType extends LegendBoxEntry = DefaultEntryType>(value: Attachable | Chart | Dashboard, disposeOnClick?: boolean, tag?: string, builder?: UIElementBuilder<EntryType>) => EntryType | EntryType[] | EntryType[][];
}
/**
 * LegendBox that is a standalone UIElement.
 */
export declare type UILegendBox<BackgroundType extends InternalBackground = any, TitleType extends UITextBox = UITextBox, DefaultEntryType extends LegendBoxEntry = LegendBoxEntry> = UIPartWithBackground<BackgroundType> & LegendBox<TitleType, DefaultEntryType>;
/**
 * Public interface for builder of LegendBox.
 */
export interface UILegendBoxBuilder<BackgroundType extends InternalBackground = InternalBackground, TitleType extends UITextBox = UITextBox, EntryType extends LegendBoxEntry = LegendBoxEntry> extends UIElementBuilder<UILegendBox<BackgroundType>> {
    /**
     * Make new LegendBoxBuilder with different background
     * @param   newBackground   Constructor for Background
     * @return                  New LegendBoxBuilder
     */
    setBackground<NewBackgroundType extends BackgroundType>(newBackground: BackgroundConstructor<NewBackgroundType>): UILegendBoxBuilder<NewBackgroundType, TitleType>;
    /**
     * Make new LegendBoxBuilder with different alignment of entries.
     *
     * Eq. "Horizontal" meaning that the LegendBox progresses in the X-direction,
     * and aligns its groups downwards.
     * @param   alignment       Alignment for LegendBox
     * @return                  New LegendBoxBuilder
     */
    setAlignment(alignment: 'horizontal' | 'vertical'): UILegendBoxBuilder<BackgroundType, TitleType>;
    /**
     * Make new LegendBoxBuilder with different titles
     * @param   value   Either builder for new title (extends TextBox) or styler for current title type
     * @return          New LegendBoxBuilder
     */
    setTitle<NewTitleType extends TitleType>(value: UIElementBuilder<NewTitleType> | Mutator<TitleType>): UILegendBoxBuilder<BackgroundType, NewTitleType>;
    /**
     * Make new LegendBoxBuilder with different entries
     * @param   value   Either builder for new entry (extends LegendBoxEntry) or styler for current entry type
     * @return          New LegendBoxBuilder
     */
    setEntry<NewEntryType extends EntryType>(entryBuilder: UIElementBuilder<NewEntryType> | Mutator<EntryType>): UILegendBoxBuilder<BackgroundType, TitleType, NewEntryType>;
}
/**
 * File contains abstract base-classes for implementation of primitive UI elements
 */
/**
 * Type of constructor for primitive uiElement
 * @param layer Layer of drawing engine
 * @param scale Drawing scale of UiElement
 * @hidden
 */
export declare type PrimitiveUiConstructor<UiElementType extends UIElement = UIElement> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>) => UiElementType;
/**
 * Class represents any kind of picture, it might be raster image rendered as texture,
 * just colored rectangle or polygon of another shape,
 * several different geometry shapes and so on.
 * @hidden Internal class
 */
export declare abstract class Picture extends InternalUIElement implements Highlightable {
    /**
     * Set fill style of Picture
     * @param value Fill style object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Picture
     */
    getFillStyle(): FillStyle;
    /**
     * Set highlight fill style of object filling
     * @param highlightStyle FillStyle for highlighted object or mutator to modify existing one or undefined for auto assignment
     * @returns         Object itself for fluent interface
     */
    setFillStyleHighlight(highlightStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return Highlight FillStyle of the object or undefined for auto assignment
     */
    getFillStyleHighlight(): FillStyle | undefined;
    /**
     * @return True for highlighted state of object and false for basic
     */
    getHighlighted(): boolean;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return     Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
    /**
     * Dispose object, ceasing its operation while keeping the object intact until call of 'restore'.
     * @return Object itself for fluent interface
     */
    dispose(): this;
    /**
     * Restore object if it was previously disposed.
     * @returns Object itself itself for fluent interface
     */
    restore(): this;
    /**
     * @return True if all sub elements are disposed, false if not.
     */
    isDisposed(): boolean;
}
/**
 * Abstract Picture with stylable border.
 * @hidden
 */
export declare abstract class BorderedPicture extends Picture {
    /**
     * Set stoke style of Picture
     * @param value LineStyle object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Picture
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of object when it is highlighted
     * @param value     LineStyle for highlighted object or mutator to modify existing one or undefined for auto assignment
     * @returns         Object itself for fluent interface
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * @return Highlight LineStyle of the object or undefined for auto assignment
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * Abstract background formed with a polygon shape
 * @hidden
 */
export declare abstract class UIPolygon extends BorderedPicture implements Validatable {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    /**
     * Implementations should initialize all of their
     * Shapes and UiElements in the constructor.
     * Sub-classes must call 'updatePolygon' initially !
     * @param _layer         Layer of drawing engine
     * @param scale         Drawing scale of UiElement
     * @param polygonType   Type of polygon used for rendering shape
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, polygonType: PolygonType, remove: RemoveHandler<UIElement>, restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Sets the position of this UiElement relative to its origin.
     *
     * NOTE: UIElements scale can't be changed apart from when it is created.
     * @param position  Point on the UIElements scale, where its origin should be positioned
     * @return          Object itself
     */
    setPosition(position: Point): this;
    /**
     * Sets the position origin of this UiElement. Affects how the "position" of UIElement is interpreted.
     *
     * See [[UIOrigins]] for a collection of common arguments in an easy-to-read format.
     * @param   origin  Point with each plane in range [-1, 1], where 0 is middle
     * @return          Object itself
     */
    setOrigin(origin: Point): this;
}
/**
 * File contains librarys most basic primitive UI elements
 * together in one file because very similar class implementations
 */
/**
 * Class which represents a single line of text
 * @hidden Internal class
 */
export declare class UILabel extends Picture {
    /**
     * Implementations should initialize all of their
     * Shapes and UiElements in the constructor.
     * @param layer Layer of drawing engine
     * @param scale Drawing scale of UiElement
     * @hidden
     */
    constructor(layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Specify a text string.
     * @param text          The string to be rendered.
     * @returns             Object itself for fluent interface.
     */
    setText(text: string): this;
    /**
     * Get the text of the entire shape.
     * @returns             The entire text string.
     */
    getText(): string;
    /**
     * Set font of Label.
     * @param   value   FontSettings or mutator function for existing settings
     * @return          Object itself
     */
    setFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Label.
     * @return          FontSettings
     */
    getFont(): FontSettings;
}
/**
 * Rectangular UI shape that can be used as Background, Button picture or cursor PointMarker.
 */
export declare class UIRectangle extends BorderedPicture implements PointMarker, InternalBackground, UIButtonPicture {
    /**
     * Implementations should initialize all of their
     * Shapes and UiElements in the constructor.
     * @param layer Layer of drawing engine
     * @param scale Drawing scale of UiElement
     * @hidden
     */
    constructor(layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Fit object to bounding box.
     * @param   bounds  Bounds in pixels
     * @return          Object itself
     */
    fitTo: (size: Point) => this;
    /**
     * Set size of PointMarker
     * @param   size        Size of PointMarker in pixels
     * @returns             Object itself
     */
    setSize: (size: Point) => this;
}
/**
 * Circular UI shape that can be used as Background and as Button picture.
 */
export declare class UICircle extends BorderedPicture implements PointMarker, InternalBackground, UIButtonPicture {
    /**
     * @param layer Layer of drawing engine
     * @param scale Drawing scale of UiElement
     * @hidden
     */
    constructor(layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Fit object to bounding box.
     * @param   bounds  Bounds in pixels
     * @return          Object itself
     */
    fitTo(bounds: Point): this;
    /**
     * Set size of PointMarker
     * @param   size        Size of PointMarker in pixels
     * @returns             Object itself
     */
    setSize: (bounds: Point) => this;
}
/**
 * 45 degrees rotated Rectangle background.
 */
export declare class UIDiamond extends UIPolygon implements PointMarker, InternalBackground, UIButtonPicture {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    /**
     * @param _layer Layer of drawing engine
     * @param scale Drawing scale of UiElement
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Fit object to bounding box.
     * @param   bounds  Bounds in pixels
     * @return          Object itself
     */
    fitTo(bounds: Point): this;
    /**
     * Set size of PointMarker
     * @param   size        Size of PointMarker in pixels
     * @returns             Object itself
     */
    setSize: (bounds: Point) => this;
}
/**
 * Background that has a pointable 'arrow'
 */
export declare class UIPointer extends UIPolygon implements InternalBackground {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    /**
     * @param   _layer   Rendering layer
     * @param   scale   Rendering scale
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, _remove: RemoveHandler<UIElement>, _restore: RestoreHandler<UIElement>, theme: Theme);
    /**
     * Set direction.
     * @param   direction   Enum Direction
     * @returns             Object itself for fluent interface
     */
    setDirection(direction: UIDirections): this;
    /**
     * Get direction.
     * @returns             Enum Direction
     */
    getDirection(): UIDirections;
    /**
     * Set length of Pointable head in pixels.
     * @param   length  Head length in pixels
     * @returns         Object itself for fluent interface
     */
    setPointerLength(length: pixel): this;
    /**
     * Get length of Pointable head in pixels.
     * @returns             Pixel length
     */
    getPointerLength(): pixel;
    /**
     * Set angle of Pointable in degrees.
     * @param   angle   Angle of pointer or undefined to match head & body size
     * @returns         Object itself for fluent interface
     */
    setPointerAngle(angle?: number): this;
    /**
     * Get angle of Pointable in degrees.
     * @returns         Angle in degrees
     */
    getPointerAngle(): pixel;
}
/**
 * Empty UiElement
 * @hidden Internal class
 */
export declare class EmptyUIElement extends InternalUIElement {
    /**
     * Set mouse interactions enabled or disabled
     * @param state Specifies state of mouse interactions
     * @return     Object itself for fluent interface
     */
    setMouseInteractions(state: boolean): this;
    /**
     * @return Mouse interactions state
     */
    getMouseInteractions(): boolean;
}
/**
 * Empty background.
 *
 * Indicates that the *Background* can't and shouldn't be styled as it won't be rendered.
 */
export declare class UIEmptyBackground extends EmptyUIElement implements InternalBackground {
    /**
     * @return True for highlighted state of object and false for basic
     */
    getHighlighted(): boolean;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
    /**
     * Set highlight fill style of object filling
     * @param highlightStyle    FillStyle for highlighted object or mutator to modify existing one or undefined for default highlighting style
     * @returns                 Object itself for fluent interface
     */
    setFillStyleHighlight(setter: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * @return Highlight FillStyle of the object
     */
    getFillStyleHighlight(): FillStyle;
    /**
     * Set fill style object
     * @param value Fill style object or function which modifies it
     * @return      Object itself for fluent interface
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * @return Current fill style object
     */
    getFillStyle(): FillStyle;
    /**
     * Set stroke style object
     * @param value     LineStyle object or function which modifies it
     * @return          Object itself for fluent interface
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * @return          Current stroke style object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke thickness in pixels
     * @param thickness Stroke thickness in pixels
     * @returns         Icon itself for fluent interface
     */
    setStrokeThickness(thickness: number): this;
    /**
     * @return Object stroke thickness
     */
    getStrokeThickness(): number;
}
/**
 * Empty PointMarker
 * @hidden Internal class
 */
export declare class EmptyPointMarker extends UIEmptyBackground implements PointMarker {
    setSize: (size: Point) => this;
}
/**
 * Angular interval object defines the minimum and maximum interval in degrees.
 */
export declare type AngleInterval = SliceInterval;
/**
 * Event handler for gauge angle interval changed
 * @param   obj             Object
 * @param   previous        Previous angle interval of the Gauge
 * @param   current         Current angle interval of the Gauge
 */
export declare type GaugeAngleIntervalEventHandler<T> = (obj: T, previous: AngleInterval, current: AngleInterval) => void;
/**
 * Class of Radial Gauge represents the type of the gauge of a circular shape.
 */
export declare abstract class RadialGauge<P extends GaugeSlice, I extends P> extends GaugeChart<P, I> {
    protected removeChart: (chart: Panel) => void;
    /**
     * Inherited constructor from Gauge Chart
     * @param   layerSupplier       LayerSupplier. Must NOT be cached, because it contains reference to actual Engine instance.
     * @param   removeChart         Injectable Panel/Chart remove method.
     * @param   logoFactory         Logo factory.
     * @param   ScaleX              Injectable Scale constructor
     * @param   ScaleY              Injectable Scale constructor
     * @param   onScaleChange       Injectable subscribe method for when chart should _update its positioning logic (used for dashboard)
     * @param   theme               Theme used to style elements in the Chart.
     * @param   _disableAnimations      Disable animations by default
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, theme?: Theme, _disableAnimations?: boolean);
    /**
     * Set angular interval of the gauge in degrees.
     * @param start Start angle of the gauge in degrees.
     * @param end   End angle of the gauge in degrees.
     * @returns Gauge itself for fluent interface.
     */
    setAngleInterval(start: number, end: number): this;
    /**
     * Get the angular interval of the gauge.
     * @returns Angle interval object {min, max} in degrees.
     */
    getAngleInterval(): AngleInterval;
    /**
     * Apply new fill style to slice arc.
     * @param value FillStyle or mutator to modify the existing one.
     * @returns     Gauge itself for fluent interface.
     */
    setGaugeFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set stroke of gauge background
     * @param value LineStyle or mutator to modify the existing one.
     * @returns     Gauge itself for fluent interface.
     */
    setGaugeStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Subscribe to Gauge Angle Change event.
     * @returns Token of the listener.
     */
    onAngleIntervalChange(clbk: GaugeAngleIntervalEventHandler<this>): Token;
    /**
     * Remove listener with provided token.
     * @param token  Token of the listener.
     * @returns True if the listener is successfully removed and false if it is not found.
     */
    offAngleIntervalChange(token: Token): boolean;
}
/**
 * The Gauge Chart with a single solid colored slice.
 *
 * Solid Gauge extends Radial Gauge.
 * Use [[GaugeChart]].setAngleInterval(start: number, end: number)** to set angular appearance of the Chart.
 *
 * Before setting the data, request the slice using *GaugeChart*.**getDefaultSlice()**
 * Set data range using *GaugeChart*.**setInterval(start: number, end: number)**
 * Set data using *GaugeChart*.**setValue(value: number)**
 */
export declare class SolidGauge extends RadialGauge<SolidGaugeSlice, InternalSolidGaugeSlice> {
    /**
     * Inherited constructor from Gauge Chart
     * @param   layerSupplier       LayerSupplier. Must NOT be cached, because it contains reference to actual Engine instance.
     * @param   removeChart         Injectable Panel/Chart remove method.
     * @param   logoFactory         Logo factory.
     * @param   ScaleX              Injectable Scale constructor
     * @param   ScaleY              Injectable Scale constructor
     * @param   onScaleChange       Injectable subscribe method for when chart should _update its positioning logic (used for dashboard)
     * @param   panelMargin         Margin that panel should not touch around it. Used for dashboard splitters and borders.
     * @param   theme               Theme used to style elements in the Chart.
     * @param   _disableAnimations      Disable animations by default
     * @hidden
     */
    constructor(layerSupplier: LayerSupplier, removeChart: (chart: Panel) => void, logoFactory?: LogoFactory, ScaleX?: ScaleFactory, ScaleY?: ScaleFactory, resizeEventInterface?: DashboardResizeEventInterface, theme?: Theme, _disableAnimations?: boolean);
    /**
     * Get the slice of the gauge.
     * @returns Solid Gauge Slice object for further modification.
     */
    getDefaultSlice(): SolidGaugeSlice;
    /**
     * Set the Auto Scaling mode enabled or disabled.
     * @param state True - autofit is enabled, otherwise - False.
     * @returns Gauge itself for fluent interface.
     */
    setAutoScaling(state: boolean): this;
    /**
     * Get the current state of the Auto Scaling mode.
     * @returns True - autofit is enabled, otherwise - False.
     */
    getAutoScaling(): boolean;
    /**
     * Set a new number formatter for the Data label.
     * @param formatter Number formatter
     * @returns Gauge itself for fluent interface.
     */
    setDataLabelFormatter(formatter: Intl.NumberFormat): this;
    /**
     * Get the formatter for the Data label.
     * @returns Number formatter object.
     */
    getDataLabelFormatter(): Intl.NumberFormat;
    /**
     * Set a new number formatter for the scale labels.
     * @param formatter Number formatter
     * @returns Gauge itself for fluent interface.
     */
    setIntervalLabelFormatter(formatter: Intl.NumberFormat): this;
    /**
     * Get the formatter for the scale labels.
     * @returns Number formatter object.
     */
    getIntervalLabelFormatter(): Intl.NumberFormat;
    /**
     * Set padding between Gauge and interval labels in pixels.
     * @param   padding     Number with pixel margin
     * @returns Gauge itself for fluent interface.
     */
    setIntervalLabelPadding(padding: number): this;
    /**
     * Get padding around Chart in pixels.
     * @return  Padding datastructure
     */
    getIntervalLabelPadding(): number;
    /**
     * Set thickness of the gauge.
     * @param thickness
     * @returns Gauge itself for fluent interface.
     */
    setThickness(thickness: number): this;
    /**
     * Set lookup table.
     *
     * Example usage:
     *```javascript
     * // Gauge slice color depending on value
     * SolidGauge.setLUT(new LUT ( { steps: [ { value: 0, color: ColorRGBA( 0, 0, 0 ) },
     *  { value: 500, color: ColorRGBA( 12, 213, 87 ) } ],
     *  interpolate: true })
     * ```
     * @param lut   Lookup table |
     * @returns     Gauge itself for fluent interface
     */
    setLUT(lut?: LUT): this;
    /**
     * Set font of Gauge Data Label.
     *
     * Example usage:
     *```javascript
     * // Specified FontSettings
     * SolidGauge.setDataLabelFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Set to bold
     * SolidGauge.setDataLabelFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     *
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Gauge itself for fluent interface.
     */
    setDataLabelFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of Gauge Data Label.
     * @returns         FontSettings object for gauge data label.
     */
    getDataLabelFont(): FontSettings;
    /**
     * Get the minimum size of the chart.
     * @returns Size {x, y} or undefined
     */
    getMinimumSize(): Point | undefined;
    /**
     * Apply new fill style to Gauge Data label.
     * @param value FillStyle or mutator to modify the existing one.
     * @returns     Gauge itself for a fluent interface.
     */
    setDataLabelFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
    * Get Fill Style of Gauge Data Label.
    * @return FillStyle object
    */
    getDataLabelFillStyle(): FillStyle;
    /**
     * **Permanently** dispose the component.
     *
     * To fully allow Garbage-Collection to free the resources used by the component, make sure to remove **any references**
     * **to the component and its children** in application code.
     * ```javascript
     * let chart = ...Gauge()
     * let slice = chart.getDefaultSlice()
     * // Dispose Chart, and remove all references so that they can be garbage-collected.
     * chart.dispose()
     * chart = undefined
     * slice = undefined
     * ```
     * @return  Object itself for fluent interface
     */
    dispose(): this;
}
/**
 * Class of Solid colored slice Gauge slice.
 * The slice is represented as a single radial Arc shape.
 */
export declare abstract class SolidGaugeSlice extends GaugeSlice {
    /**
     * Apply new fill style to a slice.
     * @param value FillStyle for normal state.
     * @returns     Slice itself for a fluent interface.
     */
    abstract setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Apply new highlight fill style to a slice.
     * @param  value    FillStyle for highlighted state, if omitted then a highlight color is automatically generated.
     * @returns         Slice itself for a fluent interface.
     */
    abstract setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Subscribe to value change event.
     * @param listener  Event listener.
     * @returns Token that is used to unsubscribe from the event
     * @hidden
     */
    onValueChange(listener: ValueChangeEventListener<SolidGaugeSlice>): Token;
    /**
     * Subscribe to interval change event.
     * @param listener  Event listener.
     * @returns Token that is used to unsubscribe from the event
     */
    onIntervalChange(listener: IntervalChangeEventListener<SolidGaugeSlice>): Token;
}
/**
 * Class contains internal implementation of the Solid Gauge Slice.
 * @hidden
 */
export declare class InternalSolidGaugeSlice extends SolidGaugeSlice {
    protected readonly _arcLayer: LayerXY;
    protected readonly _labelLayer: LayerXY;
    protected _chart: SolidGauge;
    readonly scale: Vec2<Scale>;
    readonly _theme: Theme;
    /**
     * Shape of the solid angular slice.
     */
    readonly arc: Arc;
    /**
     * Text shape to show the slice value.
     */
    readonly label: Text;
    /**
     * Text shape to show the minimum interval value.
     */
    readonly minLabel: Text;
    /**
     * Text shape to show the maximum interval value.
     */
    readonly maxLabel: Text;
    constructor(_arcLayer: LayerXY, _labelLayer: LayerXY, _chart: SolidGauge, scale: Vec2<Scale>, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _theme: Theme);
    /**
     * Set name for the Slice as string.
     * @param name Slice name as string.
     * @returns Slice itself for fluent interface.
     */
    setName(name: string): this;
    /**
     * Set value of Slice.
     * @param   value   Numeric value
     * @return          Slice itself
     */
    setValue(value: number): this;
    /**
     * Get value of Slice.
     * @return          Numeric value
     */
    getValue(): number;
    /**
     * Tell the owning chart to remove this component.
     * @return  Slice itself.
     */
    dispose(): this;
    /**
     * Tell the owning chart to restore this series.
     * @returns     Slice itself for fluent interface.
     */
    restore(): this;
    /**
     * Set scale interval.
     * @param  start                Start scale value
     * @param  end                  End scale value
     * @returns this for fluent interface
     */
    setInterval(start: number, end: number): this;
    /**
     * Set font of interval labels.
     *
     * Example usage:
     *```javascript
     * // Specified FontSettings
     * InternalSolidGaugeSlice.setIntervalLabelsFont(new FontSettings({ size: 24, style: 'italic' }))
     * // Set to bold
     * InternalSolidGaugeSlice.setIntervalLabelsFont((fontSettings) => fontSettings.setWeight('bold'))
     * ```
     * @param   value   Either a FontSettings object or a function, which will be used to create a new FontSettings based on current value.
     * @returns         Chart itself
     */
    setIntervalLabelsFont(value: FontSettings | ImmutableMutator<FontSettings>): this;
    /**
     * Get font of gauge interval labels.
     * @returns         FontSettings object for gauge interval labels.
     */
    getIntervalLabelsFont(): FontSettings;
    /**
     * Set interval labels visibility enabled or disabled.
     * @param state True - labels are enabled, otherwise - disabled.
     * @returns     Slice itself for fluent interface.
     */
    setIntervalLabelsVisible(state: boolean): this;
    /**
     * Get interval labels visibility state.
     * @returns True - labels are enabled, otherwise - disabled.
     */
    getIntervalLabelsVisible(): boolean;
    /**
     * Set the angle interval of a slice.
     * @param start Start angle in degrees.
     * @param end   End angle in degrees.
     * @returns     Slice itself for fluent interface.
     */
    setAngleInterval(start: number, end: number): this;
    /**
     * Set start angle of the slice.
     * @param angle Min angle in degrees.
     * @returns     Slice itself for fluent interface.
     */
    setMinAngle(angle: number): this;
    /**
     * Set max angle of the slice.
     * @param angle
     * @returns     Slice itself for fluent interface.
     */
    setMaxAngle(angle: number): this;
    /**
     * Set offset margins for the slice in degrees.
     * @param left  Left margin in degrees.
     * @param right Right margin in degrees.
     */
    setMarginInDegrees(left?: number, right?: number): this;
    /**
     * Apply new fill style to slice.
     * @param value FillStyle for normal state.
     * @returns     Slice itself for a fluent interface.
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Apply new highlight fill style to slice.
     * @param  value    FillStyle for highlighted state.
     * if omitted then a highlight color is automatically generated.
     * @returns         Slice itself for a fluent interface.
     */
    setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get animated value of Slice.
     * When value of Slice is changed, the animated value will not update immediately, but after an animation.
     * (if animations are not disabled).
     * @return  Animated value
     */
    getAnimatedValue(): number;
}
/**
 * Axis Highlighter that highlights an interval on the Axis.
 */
export declare class Band extends Highlighter<Rect> {
    /**
     * Set start value of Band. This is in values of its owning Axis.
     * @param   valueStart  Value on Axis.
     * @return              Object itself for fluent interface.
     */
    setValueStart(valueStart: number): this;
    /**
     * Get start value of Band. This is in values of its owning Axis.
     * @return              Value on Axis.
     */
    getValueStart(): number;
    /**
     * Set end value of Band. This is in values of its owning Axis.
     * @param   valueEnd    Value on Axis.
     * @return              Object itself for fluent interface.
     */
    setValueEnd(valueEnd: number): this;
    /**
     * Get end value of Band. This is in values of its owning Axis.
     * @return              Value on Axis.
     */
    getValueEnd(): number;
    /**
     * Set fill style of Band.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * Band.setFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * Band.setFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * Band.setFillStyle(transparentFill)
     * ```
     * @param fillStyle     Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns             Object itself for fluent interface.
     */
    setFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of Band.
     * @return  Normal FillStyle
     */
    getFillStyle(): FillStyle;
    /**
     * Set fill style of Band when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Band (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     *```javascript
     * // Specified FillStyle
     * Band.setFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * Band.setFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * Band.setFillStyleHighlight(transparentFill)
     * // Automatic
     * Band.setFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Object itself for fluent interface.
     */
    setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get highlight fill style of Band.
     * @return  FillStyle.
     */
    getFillStyleHighlight(): FillStyle;
    /**
     * Set stroke style of Band.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * Band.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * Band.setStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * Band.setStrokeStyle(transparentLine)
     * ```
     * @param   value   Either a LineStyle object or a function, which will be used to create a new SolidLine based on current value.
     * @returns         Chart itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of Band.
     * @return  Normal StrokeStyle
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Band when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Band (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * Band.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * Band.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * Band.setStrokeStyleHighlight(transparentLine)
     * // Automatic
     * Band.setStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get highlight stroke style of Band.
     * @return  StrokeStyle.
     */
    getStrokeStyleHighlight(): LineStyle;
    /**
     * Subscribe to value change event.
     *
     * This event is called whenever the position of the *Band* is changed via either **Band.setValueStart/End** or user interactions.
     * @param   handler     Function that is called when event is triggered.
     * @param   band        Band itself.
     * @param   start       New 'start' position of Band.
     * @param   end         New 'end' position of Band.
     * @return              Token that can be used to unsubscribe from the event.
     */
    onValueChange(handler: (band: this, start: number, end: number) => void): Token;
    /**
     * Unsubscribe from value change event.
     *
     * This event is called whenever the position of the *Band* is changed via either **Band.setValueStart/End** or user interactions.
     * @param   token       Token that was received when the subscription was created.
     * @return              True if unsubscription was successful.
     */
    offValueChange(token: Token): boolean;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Object itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
}
/**
 * Axis Highlighter that highlights a single position on the Axis.
 */
export declare class ConstantLine extends Highlighter<Rect> {
    /**
     * Set value of ConstantLine. This is in values of its owning Axis.
     * @param   value       Value on Axis.
     * @return              Object itself for fluent interface.
     */
    setValue(value: number): this;
    /**
     * Get value of ConstantLine. This is in values of its owning Axis.
     * @return              Value on Axis.
     */
    getValue(): number;
    /**
     * Set stroke style of ConstantLine.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * ConstantLine.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * ConstantLine.setStrokeStyle((solidLine) => solidLine.setThickness(5))
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns         Chart itself
     */
    setStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Get stroke style of ConstantLine.
     * @return  Normal StrokeStyle
     */
    getStrokeStyle(): SolidLine;
    /**
     * Set stroke style of ConstantLine when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching ConstantLine (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * ConstantLine.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * ConstantLine.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * ConstantLine.setStrokeStyleHighlight(transparentLine)
     * // Automatic
     * ConstantLine.setStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get highlight stroke style of ConstantLine.
     * @return  StrokeStyle.
     */
    getStrokeStyleHighlight(): LineStyle;
    /**
     * Subscribe to value change event.
     *
     * This event is called whenever the position of the *ConstantLine* is changed via either
     * **ConstantLine.setValueStart/End** or user interactions.
     * @param   handler         Function that is called when event is triggered.
     * @param   constantLine    ConstantLine itself.
     * @param   value           New 'value' position of ConstantLine.
     * @return                  Token that can be used to unsubscribe from the event.
     */
    onValueChange(handler: (constantLine: this, value: number) => void): Token;
    /**
     * Unsubscribe from value change event.
     *
     * This event is called whenever the position of the *ConstantLine* is changed via either
     * **ConstantLine.setValueStart/End** or user interactions.
     * @param   token       Token that was received when the subscription was created.
     * @return              True if unsubscription was successful.
     */
    offValueChange(token: Token): boolean;
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Object itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
}
/**
 * Abstract base class for Axis Highlighters.
 *
 * These components are placed along a single Axis to highlight some area of data.
 */
export declare abstract class Highlighter<VisualType extends ChartVisual = ChartVisual> extends ChartComponent<ChartVisual> {
}
/**
 * Datastructure that defines the dimensions of a Box Figure.
 * Used to feed segment data to Box Series.
 */
export interface BoxFigureDimensions {
    readonly start: number;
    readonly end: number;
    readonly lowerExtreme: number;
    readonly lowerQuartile: number;
    readonly median: number;
    readonly upperQuartile: number;
    readonly upperExtreme: number;
}
/**
 * Type of constructor for BoxFigures.
 * This is the type that is used to set type of Figure in BoxSeries.
 * @param layer             Rendering layer
 * @param scale             Rendering scale
 * @param remove            Callback function when figure.dispose() is called
 * @param dimensionStrategy Strategy that is used to flip Figure depending alignment of its series
 * @param start             The start of X segment
 * @param end               The end of X segment
 * @param lowerExtreme      Smallest value excluding outliers
 * @param lowerQuartile     Twenty-five percent of the data points fall below the lower quartile
 * @param median            Marks the mid-point of data. half of the segments values are greater or equal to this value.
 * @param upperQuartile     Seventy-five percent of the data points fall below the upper quartile
 * @param upperExtreme      Highest value excluding outliers
 * @hidden
 */
export declare type BoxFigureConstructor<Type extends BoxFigure> = new (layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<Figure>, restore: RestoreHandler<Figure>, dimensionStrategy: MultidimensionalStrategy, start: number, end: number, lowerExtreme: number, lowerQuartile: number, median: number, upperQuartile: number, upperExtreme: number, theme: Theme) => Type;
/**
 * Abstract base class for figures of BoxSeries
 * @hidden Internal class
 */
export declare abstract class BoxFigure extends CustomizableFigure implements BoxFigureDimensions {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    readonly dimensionStrategy: MultidimensionalStrategy;
    readonly start: number;
    readonly end: number;
    readonly lowerExtreme: number;
    readonly lowerQuartile: number;
    readonly median: number;
    readonly upperQuartile: number;
    readonly upperExtreme: number;
    readonly _theme: Theme;
    /**
     * Boundaries of BoxFigure.
     * Constant and computed in constructor.
     */
    readonly boundaries: Interval<Point>;
    /**
     * @param _layer            Rendering layer
     * @param scale             Rendering scale
     * @param remove            Callback function when figure.dispose() is called
     * @param dimensionStrategy Strategy that is used to flip Figure depending alignment of its series
     * @param start             The start of X segment
     * @param end               The end of X segment
     * @param lowerExtreme      Smallest value excluding outliers
     * @param lowerQuartile     Twenty-five percent of the data points fall below the lower quartile
     * @param median            Marks the mid-point of data. half of the segments values are greater or equal to this value.
     * @param upperQuartile     Seventy-five percent of the data points fall below the upper quartile
     * @param upperExtreme      Highest value excluding outliers
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, remove: RemoveHandler<Figure>, restore: RestoreHandler<Figure>, dimensionStrategy: MultidimensionalStrategy, start: number, end: number, lowerExtreme: number, lowerQuartile: number, median: number, upperQuartile: number, upperExtreme: number, _theme: Theme);
    /**
     * Return some dominant fill style of the segment
     * @returns     FillStyle object
     */
    abstract getDominantStyle(): FillStyle;
    /**
     * Get boundaries that contain figure.
     * @return  Interval<Point>
     */
    getBoundaries(): Interval<Point>;
}
/**
 * Box and whiskers StatisticFigure implementation.
 */
export declare class BoxAndWhiskers extends BoxFigure {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    readonly dimensionStrategy: MultidimensionalStrategy;
    readonly start: number;
    readonly end: number;
    readonly lowerExtreme: number;
    readonly lowerQuartile: number;
    readonly median: number;
    readonly upperQuartile: number;
    readonly upperExtreme: number;
    /**
     * @hidden
    */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, remove: (figure: Figure) => void, restore: (figure: Figure) => void, dimensionStrategy: MultidimensionalStrategy, start: number, end: number, lowerExtreme: number, lowerQuartile: number, median: number, upperQuartile: number, upperExtreme: number, _theme: Theme);
    /**
     * Set width of box body as a % of the width of its interval width.
     * @param   width   Ratio between box body width and the segments interval
     * @return          Object itself
     */
    setBodyWidth(width: number): this;
    /**
     * Get width of box body as a % of the width of its interval width.
     * @return          Ratio between box body width and the segments interval
     */
    getBodyWidth(): number;
    /**
     * Set fill style of Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * BoxAndWhiskers.setBodyFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * BoxAndWhiskers.setBodyFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * BoxAndWhiskers.setBodyFillStyle(transparentFill)
     * ```
     * @param value  FillStyle which has to be used for recoloring or mutator to modify existing one.
     * @returns      Series itself for fluent interface.
     */
    setBodyFillStyle(fillStyle: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of box body when not highlighted.
     * @return              FillStyle object
     */
    getBodyFillStyle(): FillStyle;
    /**
     * Set fill style of Series when it is highlighted.
     *
     *```javascript
     * // Specified FillStyle
     * BoxAndWhiskers.setBodyFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * BoxAndWhiskers.setBodyFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * BoxAndWhiskers.setBodyFillStyleHighlight(transparentFill)
     * // Automatic
     * BoxAndWhiskers.setBodyFillStyleHighlight(undefined)
     * ```
     * @param value FillStyle which has to be used during highlighting or mutator to modify existing one or undefined for auto.
     * @returns     Series itself for fluent interface.
     */
    setBodyFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get fill style of box body when highlighted.
     * @return              FillStyle object or undefined if not assigned
     */
    getBodyFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set border style of Series.
     *
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setBodyStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setBodyStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setBodyStrokeStyle(transparentLine)
     * ```
     * @param value  LineStyle which has to be used for recoloring or mutator to modify existing one.
     * @returns      Series itself for fluent interface.
     */
    setBodyStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get style of box body when not highlighted.
     * @return                  LineStyle object
     */
    getBodyStrokeStyle(): LineStyle;
    /**
     * Set line style of Series border when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setBodyStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setBodyStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setBodyStrokeStyleHighlight(transparentLine)
     * // Automatic
     * BoxAndWhiskers.setBodyStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value.
     * @returns         Chart itself
     */
    setBodyStrokeStyleHighlight(lineStyle: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get style of box body when highlighted.
     * @return                  LineStyle object or undefined if not assigned
     */
    getBodyStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set width of box tails as a % of the width of its interval width.
     * @param   width   Ratio between box tail width and the segments interval
     * @return          Object itself
     */
    setTailWidth(width: number): this;
    /**
     * Get width of box tails as a % of the width of its interval width.
     * @return          Ratio between box tail width and the segments interval
     */
    getTailWidth(): number;
    /**
     * Set stroke style of Series whiskers and tails.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setStrokeStyle(transparentLine)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns         Chart itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of box whiskers and tails when not highlighted.
     * @return              LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Series whiskers and tails when they are highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setStrokeStyleHighlight(transparentLine)
     * // Automatic
     * BoxAndWhiskers.setStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value.
     * @returns         Chart itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of box whiskers and tails when highlighted.
     * @return              LineStyle object or undefined if not assigned
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set stroke style of Series median line.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setMedianStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setMedianStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setMedianStrokeStyle(transparentLine)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns         Chart itself
     */
    setMedianStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of box median line when not highlighted.
     * @return              LineStyle object
     */
    getMedianStrokeStyle(): LineStyle;
    /**
     * Set stroke style of Series median line when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * BoxAndWhiskers.setMedianStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * BoxAndWhiskers.setMedianStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * BoxAndWhiskers.setMedianStrokeStyleHighlight(transparentLine)
     * // Automatic
     * BoxAndWhiskers.setMedianStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to modify current value.
     * @returns         Chart itself
     */
    setMedianStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of box median line when highlighted.
     * @return              LineStyle object or undefined if not assigned
     */
    getMedianStrokeStrokeHighlight(): LineStyle | undefined;
    /**
     * Return some dominant fill style of the segment
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * BoxSeries class.
 * Takes in types of 'BoxFigureDimensions' and plots it using 'StatisticFigure'
 *
 * Currently always on X
 */
export declare class BoxSeries<FigureType extends BoxFigure = BoxFigure> extends SimpleFigureSeries<FigureType, BoxSeriesFormatter, BoxFigureDimensions> {
    protected readonly _figureType: BoxFigureConstructor<FigureType>;
    protected readonly _dimensionStrategy: MultidimensionalStrategy;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _figureType           Figure type
     * @param _dimensionStrategy    Dimension strategy for positioning BoxFigures (horizontal/vertical)
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _figureType: BoxFigureConstructor<FigureType>, _dimensionStrategy: MultidimensionalStrategy, _theme: Theme);
    /**
     * Add new figure to the series.
     * @param   dimensions  Dimensions that figure must represent
     * @return              Created figure
     */
    add(dimensions: BoxFigureDimensions): FigureType;
}
/**
 * Type of a BoxSeriesFormatter function.
 * Defines what Cursor ResultTables show.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable
 * @param   series                  BoxSeries
 * @param   segment                 StatisticData that is to be displayed with ResultTable
 * @return                          TableContentBuilder that was supplied
 */
export declare type BoxSeriesFormatter = <T extends TableContentBuilder>(tableContentBuilder: T, series: BoxSeries, segment: BoxFigureDimensions) => T;
/**
 * Type of constructor for OHLCFigures.
 * @param layer     Rendering layer
 * @param scale     Rendering scale
 * @param positive  Does figure represent positive or negative segments
 * @param _theme    Theme of owning Chart, used for styling
 * @hidden
 */
export declare type OHLCFigureConstructor<Type extends OHLCFigure> = new (layer: LayerXY, scale: Vec2<Scale>, remove: (figure: Figure) => void, restore: (figure: Figure) => void, positive: boolean, _theme: Theme) => Type;
/**
 * Interface for data values of an OHLC segment.
 */
export interface OHLCSegment {
    /**
     * Get Position of OHLC segment.
     * @return  Position
     */
    getPosition(): number;
    /**
     * Get Open value of OHLC segment.
     * @return  Open value
     */
    getOpen(): number;
    /**
     * Get High value of OHLC segment.
     * @return  High value
     */
    getHigh(): number;
    /**
     * Get Low value of OHLC segment.
     * @return  Low value
     */
    getLow(): number;
    /**
     * Get Close value of OHLC segment.
     * @return  Close value
     */
    getClose(): number;
}
/**
 * Abstract base class for OHLCFigures.
 * OHLCFigures are designed to be recycleable, which means they
 * must be able to be resized at any moment. Because OHLC series can have different classes for
 * positive/negative figures, this state is not changeable! So any figure that was created as 'positive',
 * can not be recycled to be 'negative'!
 */
export declare abstract class OHLCFigure extends Figure implements OHLCSegment {
    protected readonly _layer: LayerXY;
    readonly scale: Vec2<Scale>;
    readonly positive: boolean;
    /**
     * @param _layer            Rendering layer
     * @param scale             Rendering scale
     * @param remove            Remove handler
     * @param restore           Restore handler
     * @param positive          Does figure represent positive or negative segments
     * @param _theme            Theme from owning chart, used for styling.
     * @hidden
     */
    constructor(_layer: LayerXY, scale: Vec2<Scale>, remove: (figure: Figure) => void, restore: (figure: Figure) => void, positive: boolean, _theme: Theme);
    /**
     * Get Middle X position
     * @return  Middle X position
     */
    getPosition(): number;
    /**
     * Get Open value
     * @return  Open value
     */
    getOpen(): number;
    /**
     * Get High value
     * @return  High value
     */
    getHigh(): number;
    /**
     * Get Low value
     * @return  Low value
     */
    getLow(): number;
    /**
     * Get Close value
     * @return  Close value
     */
    getClose(): number;
    /**
     * Get indices of data that figure represents.
     * @return  Either index array for multiple samples or single index
     */
    getDataIndices(): number | number[];
}
/**
 * Candlestick [[OHLCFigure]].
 */
export declare class OHLCCandleStick extends OHLCFigure {
    /**
     * Set stroke style of candles lines.
     * @param   value      LineStyle object or mutator to modify existing one
     * @return             Object itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stoke style of candles.
     * @return              LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of candles when highlighted.
     * @param   value       FillStyle object or mutator to modify existing one or undefined for automatic computation
     * @return              Object itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke style of candles when highlighted.
     * @return              FillStyle object or undefined if unassigned
     */
    getStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Set fill style of candles body.
     * @param   value       FillStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setBodyFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Get fill style of candles body.
     * @return              FillStyle object
     */
    getBodyFillStyle(): FillStyle;
    /**
     * Set fill style of candles body when highlighted.
     * @param   fillStyle   FillStyle object or mutator to modify existing one or undefined for automatic assignment
     * @return              Object itself
     */
    setBodyFillStyleHighlight(fillStyle: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get fill style of candles body when highlighted.
     * @return              FillStyle object if unassigned
     */
    getBodyFillStyleHighlight(): FillStyle | undefined;
    /**
     * Set stroke style of candles body.
     * @param   value       LineStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setBodyStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of candles body.
     * @return              LineStyle object
     */
    getBodyStrokeStyle(): LineStyle;
    /**
     * Set style of candles body when highlighted.
     * @param   value       LineStyle object or mutator to modify existing one or undefined for automatic assignment
     * @return              Object itself
     */
    setBodyStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get style of candles body when highlighted.
     * @return              LineStyle object or undefined if unassigned
     */
    getBodyStrokeStyleHighlight(): LineStyle | undefined;
    /**
     * Return some dominant fill style of the segment
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * Bar [[OHLCFigure]].
 */
export declare class OHLCBar extends OHLCFigure {
    /**
     * Set stroke style of bar lines.
     * @param   value       LineStyle object or mutator to modify existing one
     * @return              Object itself
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Get stroke style of bar lines.
     * @return              LineStyle object
     */
    getStrokeStyle(): LineStyle;
    /**
     * Set stroke style of bar lines when highlighted.
     * @param   value       LineStyle object or mutator to modify existing one or undefined for default
     * @return              Object itself
     */
    setStrokeStyleHighlight(value: LineStyle | ImmutableMutator<LineStyle> | undefined): this;
    /**
     * Get stroke fill style of bar lines when highlighted.
     * @return              LineStyle object or undefined if unassigned
     */
    getStrokeHighlight(): LineStyle | undefined;
    /**
     * Return some dominant fill style of the segment
     * @returns     FillStyle object
     */
    getDominantStyle(): FillStyle;
    /**
     * Set highlighted state of the Object
     * @param isHighlighted Highlight state of the object
     * @returns             Object itself for fluent interface
     */
    setHighlighted(isHighlighted: boolean): this;
}
/**
 * Collection of [[OHLCFigure]] options.
 *
 * Used for selecting different figure designs for *OHLCSeries*. eq.
 * - Candlestick Chart can be created using [[OHLCFigures.Candlestick]]
 * - OHLC Chart can be created using [[OHLCFigures.Bar]]
 *
 * Example usage:
 *```javascript
 * // Specify OHLCFigure of OHLCSeries
 * ChartXY.addOHLCSeries(undefined, undefined, OHLCFigures.Candlestick)
 * ```
 */
export declare const OHLCFigures: {
    /**
     * Candlestick *OHLCFigure*.
     */
    Candlestick: typeof OHLCCandleStick;
    /**
     * Bar *OHLCFigure*.
     */
    Bar: typeof OHLCBar;
};
/**
 * StockSeries implementation using FigureSeries.
 * Actual types used are in file 'stockInterfaces.ts'
 */
/**
 * Ordered tuple that contains values for:
 * - X
 * - Open
 * - High
 * - Low
 * - Close
 */
export declare type XOHLC = [number, number, number, number, number];
/**
 * Type of styler function for OHLC figures
 */
export declare type OHLCFigureStyler<T extends OHLCFigure> = (figure: T) => void;
/**
 * Type definition for OHLC-series constructor.
 * @param chart                 Owning Chart
 * @param _removeFromChart      Handler for removing reference to series from owning chart
 * @param _restoreFromChart     Handler for restoring reference to series from owning chart
 * @param _layer                Rendering layer
 * @param axisX                 Axis X
 * @param axisY                 Axis Y
 * @param axisXAttachHandler    Attach handler for Axis X
 * @param axisYAttachHandler    Attach handler for Axis Y
 * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
 * @param _positiveFigure   OHLCFigure constructor for positive figure
 * @param _negativeFigure   OHLCFigure constructor for negative figure
 * @hidden
 */
export declare type OHLCSeriesConstructor<PositiveFigure extends OHLCFigure, NegativeFigure extends OHLCFigure, OHLCSeriesType extends OHLCSeriesTypes<PositiveFigure, NegativeFigure>> = new (chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _positiveFigure: OHLCFigureConstructor<PositiveFigure>, _negativeFigure: OHLCFigureConstructor<NegativeFigure>, _theme: Theme) => OHLCSeriesType;
/**
 * Abstract base class for series that display OHLC-segments using OHLCFigures.
 * Currently only supports progressive X timeline!
 * @hidden Internal class
 */
export declare abstract class OHLCSeries<PositiveFigure extends OHLCFigure = OHLCFigure, NegativeFigure extends OHLCFigure = PositiveFigure> extends FigureSeries<PositiveFigure | NegativeFigure, OHLCCursorPoint> implements ObservableXYData<XOHLC> {
    protected _positiveFigure: OHLCFigureConstructor<PositiveFigure>;
    protected _negativeFigure: OHLCFigureConstructor<NegativeFigure>;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _positiveFigure       OHLCFigure constructor for positive figure
     * @param _negativeFigure       OHLCFigure constructor for negative figure
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _positiveFigure: OHLCFigureConstructor<PositiveFigure>, _negativeFigure: OHLCFigureConstructor<NegativeFigure>, _theme: Theme);
    /**
     * Set common style for both positive and negative figures.
     * NOTE: Because the function is applied for each figure added, it is not advised to create any objects inside the function.
     * Instead they should be previously cached and later referred to.
     *
     * Example usage:
     *```javascript
     * // Explicit style
     * // The type of figure can be equal to type parameter PositiveFigure or NegativeFigure
     * OHLCSeries.setStyle((figure) => ... )
     * ```
     * @param   styler  Styler function that is applied to all existing and newly added segments
     * @return          Object itself
     */
    setStyle(style: OHLCFigureStyler<PositiveFigure | NegativeFigure>): this;
    /**
     * Set style of positive figures.
     * Positive style is applied after common style.
     * NOTE: Because the function is applied for each figure added, it is not advised to create any objects inside the function.
     * Instead they should be previously cached and later referred to.
     *
     * Example usage:
     *```javascript
     * // Explicit style
     * // The type of figure can be equal to type parameter PositiveFigure
     * OHLCSeries.setPositiveStyle((figure) => ... )
     * ```     * @param   styler  Styler function that is applied to all existing and newly added segments
     * @return          Object itself
     */
    setPositiveStyle(style: OHLCFigureStyler<PositiveFigure>): this;
    /**
     * Set style of negative figures.
     * Negative style is applied after common style.
     * NOTE: Because the function is applied for each figure added, it is not advised to create any objects inside the function.
     *
     * Example usage:
     *```javascript
     * // Explicit style
     * // The type of figure can be equal to type parameter NegativeFigure
     * OHLCSeries.setNegativeStyle((figure) => ... )
     * ```
     * @param   styler  Styler function that is applied to all existing and newly added segments
     * @return          Object itself
     */
    setNegativeStyle(style: OHLCFigureStyler<NegativeFigure>): this;
    /**
     * Set width of figures in pixels.
     * @param   width   Width in pixels
     * @return          Object itself
     */
    setFigureWidth(width: pixel): this;
    /**
     * Get width of figures in pixels.
     */
    getFigureWidth(): pixel;
    /**
     * Set whether auto-fitting of Figures is enabled. When enabled, figures are automatically split / fused based on distance
     * from each other.
     * @param   enabled Is auto-fitting enabled.
     * @return          Object itself for fluent interface
     */
    setFigureAutoFitting(enabled: boolean): this;
    /**
     * Get whether auto-fitting of Figures is enabled. When enabled, figures are automatically split / fused based on distance
     * from each other.
     * @return          Is auto-fitting enabled.
     */
    getFigureAutoFitting(): boolean;
    /**
     * Set maximum amount of OHLC data-points
     * @param maxPointCount     Maximum amount of OHLC data-points that should be kept around.
     *                          If undefined or 0 is passed data-cleaning will be disabled.
     * @returns                 Object itself
     */
    setMaxPointCount(maxPointCount: number | undefined): this;
    /**
     * Solves the nearest datapoint to a given coordinate on screen.
     * @param   location    Location on screen
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromScreen(location: Point): undefined | OHLCCursorPoint;
    /**
     * Solves the nearest datapoint to a given coordinate on a screen from a specific segment.
     * @param   location    Location on screen
     * @param   segment     Segment to solve from
     * @return              Undefined or data-structure for positioning of cursors
     */
    solveNearestFromSegment(location: Point, segment: OHLCFigure): undefined | OHLCCursorPoint;
    /**
     * Method for customizing contents of ResultTables when pointing at this Series.
     * @param   formatter   Function which builds ResultTable content.
     *                      See definition of [[OHLCSeriesFormatter]] for supplied formatting information.
     * @return              Object itself
     */
    setResultTableFormatter(formatter: OHLCSeriesFormatter): this;
    /**
     * Get ResultTable Formatter.
     * @return  Function which builds ResultTable content for OHLCSeries.
     */
    getResultTableFormatter(): OHLCSeriesFormatter;
    /**
     * Clear all data from the series
     * @returns         Series itself for fluent interface
     */
    clear(): this;
    /**
     * @return Max X value of the series
     */
    getXMax(): number;
    /**
     * @return Min X value of the series
     */
    getXMin(): number;
    /**
     * @return Max Y value of the series
     */
    getYMax(): number;
    /**
     * @return Min Y value of the series
     */
    getYMin(): number;
}
/**
 * OHLCSeries class.
 * Takes data in format of OHLC segment interface and renders it using generic StockFigures.
 * Currently only supports progressive X timeline!
 */
export declare class OHLCSeriesTraditional<PositiveFigure extends OHLCFigure = OHLCFigure, NegativeFigure extends OHLCFigure = PositiveFigure> extends OHLCSeries<PositiveFigure, NegativeFigure> {
    /**
     * Add OHLC segments to series.
     * NOTE: Added segments must always have progressive X values!
     * @param   data    Tuple of X+OHLC values or array of such tuples
     * @return          Object itself
     */
    add(data: XOHLC | XOHLC[]): this;
}
/**
 * Type of OHLCSeries that automatically packages progressive (X) Vec2 data.
 */
export declare class OHLCSeriesWithAutomaticPacking<PositiveFigure extends OHLCFigure = OHLCFigure, NegativeFigure extends OHLCFigure = PositiveFigure> extends OHLCSeries<PositiveFigure, NegativeFigure> implements DataInput, DataInputY {
    /**
     * Add point or array of points
     * @param    data    Point or array of points
     * @returns          Series itself for fluent interface
     */
    add(data: Point | Point[]): this;
    /**
     * Add point to the Series.
     * @param   p       New point
     * @returns         Series itself for fluent interface
     */
    addPoint(p: Point): this;
    /**
     * Add points to the Stock series.
     * @param   points   Array of new points
     * @returns          Series itself for fluent interface
     */
    addPoints(points: Point[]): this;
    /**
     * Each Y-value will be paired with an automatically generated X-value, based on *step*-argument.
     * @param   arrayY  Array of Y-values.
     * @param   step    Optional step between each X coordinate. Defaults to 1.
     * @param   start   Optional value for first generated X-value. If undefined, will continue after last point's X value in series,
     *                  or 0 if there are no points in series.
     * @return          Object itself for fluent interface.
     */
    addArrayY(arrayY: number[], step?: number, start?: number): this;
    /**
     * Set resolution of Stock segment packing.
     * Smaller resolution will let user zoom to greater detail.
     * If no resolution has been defined, series will use pixel width of figures as packing resolution.
     * @param   resolution  Axis value interval for resolution of a single Stock segment
     *                      or undefined to be automatically calculated based on pixelSize.
     * @return              Object itself
     * @sideEffect          Series will consume more memory if resolution value is lowered.
     */
    setPackingResolution(resolution?: number): this;
    /**
     * @return Copy of last point added to the Series or undefined if it doesn't exist.
     */
    getLastPoint(): any;
}
/**
 * Available OHLC Series types
 */
export declare type OHLCSeriesTypes<PositiveFigure extends OHLCFigure, NegativeFigure extends OHLCFigure> = OHLCSeriesTraditional<PositiveFigure, NegativeFigure> | OHLCSeriesWithAutomaticPacking<PositiveFigure, NegativeFigure>;
/**
 * Collection of *OHLCSeries* types.
 *
 * By default, *OHLCSeries* will be [[OHLCSeriesTraditional]], but different types can be created with these options.
 * Note, that based on the selection the *Series* can have different *API*!
 *
 * Example usage:
 *```javascript
 * // Create OHLCSeries with automatic packing
 * ChartXY.addOHLCSeries(undefined, undefined, undefined, undefined, OHLCSeriesTypes.AutomaticPacking)
 * ```
 */
export declare const OHLCSeriesTypes: {
    /**
     * *OHLCSeries* type that takes data traditionally in XOHLC-tuples.
     */
    Normal: typeof OHLCSeriesTraditional;
    /**
     * *OHLCSeries* type that takes data as X-progressive Points.
     * The *Series* automatically packs these into OHLC-segments.
     *
     * **If this option is selected, the "add()"-method of the created *Series* will only accept *Points*, rather than *XOHLC*-values**.
     */
    AutomaticPacking: typeof OHLCSeriesWithAutomaticPacking;
};
/**
 * Interface for CursorPoints that point to an OHLCSegment.
 * Used to pack information about pointed segment to users.
 */
export interface OHLCCursorPoint extends CursorPoint<OHLCSeries<OHLCFigure, OHLCFigure>> {
    /**
     * Interface that contains information about the pointed OHLCSegment.
     */
    ohlcSegment: OHLCSegment;
}
/**
 * Interface for a function which builds ResultTable content when pointing at an OHLCSeries.
 * @param   tableContentBuilder     Builder that is used to build contents of ResultTable.
 *                                  Use addRow() method for adding content.
 * @param   series                  OHLCSeries
 * @param   ohlcSegment             OHLCSegment that is pointed. Has methods for reading its Open, High, Low, Close and Position values.
 * @return                          TableContentBuilder that was supplied
 */
export declare type OHLCSeriesFormatter = <T extends TableContentBuilder>(tableContentBuilder: T, series: OHLCSeries<OHLCFigure, OHLCFigure>, ohlcSegment: OHLCSegment) => T;
/**
 * The abstract class implements the most part of general logic for area series.
 * All the derivative series implements their own logic for processing incoming data.
 * @hidden Internal class
 */
export declare abstract class AreaSeries extends RangeSeries implements ObservableXYData<Point>, DataInputY {
    protected readonly _baseline: number;
    /**
     * @param chart                 Owning Chart
     * @param _removeFromChart      Handler for removing reference to series from owning chart
     * @param _restoreFromChart     Handler for restoring reference to series from owning chart
     * @param _layer                Rendering layer
     * @param axisX                 Axis X
     * @param axisY                 Axis Y
     * @param axisXAttachHandler    Attach handler for Axis X
     * @param axisYAttachHandler    Attach handler for Axis Y
     * @param _newUILayer           Factory for creating new UI layers for drawing SeriesMarkers
     * @param _baseline             The limit at which series starts.
     * @param _theme                Theme from owning Chart, used for styling
     * @hidden
     */
    constructor(chart: ChartXY, _removeFromChart: RemoveHandler<ChartComponent>, _restoreFromChart: RestoreHandler<ChartComponent>, _layer: LayerXY, axisX: Axis, axisY: Axis, axisXAttachHandler: AxisAttachHandler, axisYAttachHandler: AxisAttachHandler, _newUILayer: () => LayerXY, _baseline: number, _theme: Theme);
    /**
     * Add point or array of points to the dataset.
     * @param points   Single new point or an array of new points.
     * @returns        Series itself for fluent interface.
     */
    add(data: Point | Point[]): this;
    addArrayY(arrayY: number[], step?: number, start?: number): this;
}
/**
 * Implementation of *SeriesXY* for visualizing a collection of progressive *Points* by
 * filling the area between the points *Y*-values and a static *baseline* value.
 *
 * This type of *AreaSeries* shows data on both sides of the *baseline*, and it has individual styles for each side:
 * *positive* and *negative*. Each side is also composed of the areas *fill* and *border*.
 *
 * *AreaSeriesBipolar* are created with [[ChartXY.addAreaSeries]] and selecting *AreaSeriesTypes.Bipolar*.
 */
export declare class AreaSeriesBipolar extends AreaSeries {
    /**
     * Set positive area style of Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesBipolar.setPositiveFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesBipolar.setPositiveFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesBipolar.setPositiveFillStyle(transparentFill)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns     Series itself for fluent interface.
     */
    setPositiveFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set positive area style of Series when it is highlighted.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesBipolar.setPositiveFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesBipolar.setPositiveFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesBipolar.setPositiveFillStyleHighlight(transparentFill)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setPositiveFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Set negative area style of Series.
     *
       *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesBipolar.setNegativeFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesBipolar.setNegativeFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesBipolar.setNegativeFillStyle(transparentFill)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns     Series itself for fluent interface.
     */
    setNegativeFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set negative area style of Series when it is highlighted.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesBipolar.setNegativeFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesBipolar.setNegativeFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesBipolar.setNegativeFillStyleHighlight(transparentFill)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setNegativeFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Set positive stroke style of Series.
     *
     * Example usage:
     *```javascript
     * // Specified SolidLine
     * AreaSeriesBipolar.setPositiveStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesBipolar.setPositiveStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesBipolar.setPositiveStrokeStyle(transparentLine)
     * ```
     * @param value  Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns      Series itself for fluent interface.
     */
    setPositiveStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Set positive stroke style of Series when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaSeriesBipolar.setPositiveStrokeStyleHighlight(new SolidLine(
     * { thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesBipolar.setPositiveStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesBipolar.setPositiveStrokeStyleHighlight(transparentLine)
     * // Automatic
     * AreaSeriesBipolar.setPositiveStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setPositiveStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Set negative stroke style of Series.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaSeriesBipolar.setNegativeStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesBipolar.setNegativeStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesBipolar.setNegativeStrokeStyle(transparentLine)
     * ```
     * @param value  Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns      Series itself for fluent interface.
     */
    setNegativeStrokeStyle(value: SolidLine | ImmutableMutator<SolidLine>): this;
    /**
     * Set negative stroke style of Series when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaSeriesBipolar.setNegativeStrokeStyleHighlight(new SolidLine(
     * { thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesBipolar.setNegativeStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesBipolar.setNegativeStrokeStyleHighlight(transparentLine)
     * // Automatic
     * AreaSeriesBipolar.setNegativeStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setNegativeStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get a current fill style used for the coloring of the positive area in the series.
     * @returns      Current fill style used for the coloring of the positive area in the series.
     */
    getPositiveFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of the positive area during series highlighting.
     * @returns     Current highlight fill style used for the coloring of the positive area during series highlighting.
     */
    getPositiveFillStyleHighlight(): FillStyle;
    /**
     * Get a current fill style used for the coloring of the negative area in the series.
     * @returns      Current fill style used for the coloring of the negative area in the series.
     */
    getNegativeFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of the negative area during series highlighting.
     * @returns     Current highlight fill style used for the coloring of the negative area during series highlighting.
     */
    getNegativeFillStyleHighlight(): FillStyle;
    /**
     * Get a current line style of a stroke used for the coloring of the positive stroke in the series.
     * @returns     Current line style of a stroke used for the coloring of the positive stroke.
     */
    getPositiveStrokeStyle(): LineStyle;
    /**
     * Get a current line style of a stroke used for the coloring of the positive border during highlighting.
     * @returns     Current line style of a border used for the coloring of the positive border during highlighting.
     */
    getPositiveStrokeStyleHighlight(): LineStyle;
    /**
     * Get a current line style of a border used for the coloring of the negative border in the series.
     * @returns     Current line style of a border used for the coloring of the negative border.
     */
    getNegativeStrokeStyle(): LineStyle;
    /**
     * Get a current line style of a border used for the coloring of of the negative border during highlighting.
     * @returns     Current line style of a border used for the coloring of the negative border during highlighting.
     */
    getNegativeStrokeStyleHighlight(): LineStyle;
}
/**
 * The abstract class implements the most part of general logic for specific area series types.
 * These series use only one fill style and only one border.
 * All the derivative series implements their own logic for processing incoming data.
 * @hidden Internal class
 */
export declare abstract class AreaSeriesMonopolar extends AreaSeries {
    /**
     * Attach object to an legendBox entry
     * @param entry             Object which has to be attached
     * @param disposeOnClick    Flag that indicates whether the Attachable should be disposed/restored,
     *                          when its respective Entry is clicked.
     * @return                  Series itself for fluent interface
     */
    attach(entry: LegendBoxEntry, disposeOnClick?: boolean): this;
    /**
     * Set fill style of Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesMonopolar.setFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesMonopolar.setFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesMonopolar.setFillStyle(transparentFill)
     * ```
     * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns      Series itself for fluent interface.
     */
    abstract setFillStyle(fill: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set fill style of Series when it is highlighted.
     *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesMonopolar.setFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesMonopolar.setFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesMonopolar.setFillStyleHighlight(transparentFill)
     * // Automatic
     * AreaSeriesMonopolar.setFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    abstract setFillStyleHighlight(fill: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Set stroke style of Series.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaSeriesMonopolar.setStrokeStyle(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesMonopolar.setStrokeStyle((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesMonopolar.setStrokeStyle(transparentLine)
     * ```
     * @param value  Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value.
     * @returns      Series itself for fluent interface.
     */
    setStrokeStyle(value: LineStyle | ImmutableMutator<LineStyle>): this;
    /**
     * Set stroke style of Series border when it is highlighted.
     * Highlighting is activated by placing mouse on top / touching Series (if mouse-interactions are not disabled),
     * or by using setHighlighted() method.
     *
     * Example usage:
      *```javascript
     * // Specified SolidLine
     * AreaSeriesMonopolar.setStrokeStyleHighlight(new SolidLine({ thickness: 2, fillStyle: new SolidFill({ color: ColorHEX('#F00') }) }))
     * // Changed thickness
     * AreaSeriesMonopolar.setStrokeStyleHighlight((solidLine) => solidLine.setThickness(5))
     * // Hidden (emptyLine is not supported)
     * AreaSeriesMonopolar.setStrokeStyleHighlight(transparentLine)
     * // Automatic
     * AreaSeriesMonopolar.setStrokeStyleHighlight(undefined)
     * ```
     * @param   value   Either a SolidLine object or a function, which will be used to create a new SolidLine based on current value or
     *                  undefined for automatic value based on normal style.
     * @returns         Chart itself
     */
    setStrokeStyleHighlight(value: SolidLine | ImmutableMutator<SolidLine> | undefined): this;
    /**
     * Get a current fill style used for the coloring of an area in the series.
     * @returns      Current fill style used for the coloring of an area in the series.
     */
    abstract getFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of an area during series highlighting.
     * @returns     Current highlight fill style used for the coloring of an area during series highlighting.
     */
    abstract getFillStyleHighlight(): FillStyle;
    /**
     * Get a current style of a stroke used for the coloring of a series border.
     * @returns     Current style of a stroke used for the coloring of a border.
     */
    getStrokeStyle(): LineStyle;
    /**
     * Get a current style of a stroke used for the coloring of a series border by series.
     * @returns     Current style of a stroke used for the coloring of a series border by series.
     */
    getStrokeStyleHighlight(): LineStyle;
}
/**
 * Implementation of *SeriesXY* for visualizing a collection of progressive *Points* by
 * filling the area between the points *Y*-values and a static *baseline* value.
 * This type of *AreaSeries* only shows data that is **below the baseline**.
 *
 * Composed of the areas *fill* and *border*.
 *
 * *AreaSeriesNegative* are created with [[ChartXY.addAreaSeries]] and selecting *AreaSeriesTypes.Negative*.
 */
export declare class AreaSeriesNegative extends AreaSeriesMonopolar {
    /**
     * Set fill style of Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesNegative.setFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesNegative.setFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesNegative.setFillStyle(transparentFill)
     * ```
     * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns      Series itself for fluent interface.
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set fill style of Series when it is highlighted.
     *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesNegative.setFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesNegative.setFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesNegative.setFillStyleHighlight(transparentFill)
     * // Automatic
     * AreaSeriesNegative.setFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get a current fill style used for the coloring of an area in the series.
     * @returns      Current fill style used for the coloring of an area in the series.
     */
    getFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of an area during series highlighting.
     * @returns     Current highlight fill style used for the coloring of an area during series highlighting.
     */
    getFillStyleHighlight(): FillStyle;
}
/**
 * Implementation of *SeriesXY* for visualizing a collection of progressive *Points* by
 * filling the area between the points *Y*-values and a static *baseline* value.
 * This type of *AreaSeries* only shows data that is **above the baseline**.
 *
 * Composed of the areas *fill* and *border*.
 *
 * *AreaSeriesPositive* are created with [[ChartXY.addAreaSeries]] and selecting *AreaSeriesTypes.Positive*.
 */
export declare class AreaSeriesPositive extends AreaSeriesMonopolar {
    /**
     * Set fill style of Series.
     *
     *Example Usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesPositive.setFillStyle(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesPositive.setFillStyle((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesPositive.setFillStyle(transparentFill)
     * ```
     * @param value  Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value.
     * @returns      Series itself for fluent interface.
     */
    setFillStyle(value: FillStyle | ImmutableMutator<FillStyle>): this;
    /**
     * Set fill style of Series when it is highlighted.
     *
     * Example usage:
     *```javascript
     * // Specified FillStyle
     * AreaSeriesPositive.setFillStyleHighlight(new SolidFill({ color: ColorHEX('#F00') }))
     * // Changed transparency
     * AreaSeriesPositive.setFillStyleHighlight((solidFill) => solidFill.setA(80))
     * // Hidden (emptyFill is not supported)
     * AreaSeriesPositive.setFillStyleHighlight(transparentFill)
     * // Automatic
     * AreaSeriesPositive.setFillStyleHighlight(undefined)
     * ```
     * @param value Either a FillStyle object or a function, which will be used to create a new FillStyle based on current value or
     *              undefined for automatic value based on normal style.
     * @returns     Series itself for fluent interface.
     */
    setFillStyleHighlight(value: FillStyle | ImmutableMutator<FillStyle> | undefined): this;
    /**
     * Get a current fill style used for the coloring of an area in the series.
     * @returns      Current fill style used for the coloring of an area in the series.
     */
    getFillStyle(): FillStyle;
    /**
     * Get a current highlight fill style used for the coloring of an area during series highlighting.
     * @returns     Current highlight fill style used for the coloring of an area during series highlighting.
     */
    getFillStyleHighlight(): FillStyle;
}
/**
 * Available Area Series types
 */
export declare type AreaSeriesTypes = typeof AreaSeriesTypes[keyof typeof AreaSeriesTypes];
/**
 * Collection of *AreaSeries* implementations.
 *
 * Used when creating an *AreaSeries* with [[ChartXY.addAreaSeries]].
 * Selected option tells what the returned *Series* type will be - different *Series* types can have different *API*s !
 *
 * - Select AreaSeriesTypes.Positive to show only area above the baseline.
 * - Select AreaSeriesTypes.Negative to show only area below the baseline.
 * - Select AreaSeriesTypes.Both to show both areas from both sides of the baseline.
 */
export declare const AreaSeriesTypes: {
    /**
     * Type of *AreaSeries* that only shows data that is **above the baseline**.
     */
    Positive: typeof AreaSeriesPositive;
    /**
     * Type of *AreaSeries* that only shows data that is **below the baseline**.
     */
    Negative: typeof AreaSeriesNegative;
    /**
     * Type of *AreaSeries* that shows data on both sides of baseline.
     *
     * Has individual styles for positive/negative areas.
     */
    Bipolar: typeof AreaSeriesBipolar;
};
